USE [UBL2.1]
GO

/*
===============================================================================
Aggregate Business Information Entities
===============================================================================
*/

/****** Object:  Table [dbo].[ApplicationResponse] Script Date: 2013-10-13 00:21z
A document to indicate the application's response to a transaction. This may be a business response initiated by a user or a technical response sent automatically by an application.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ApplicationResponse](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [ResponseDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which the information in the response was created. */
  [ResponseTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which the information in the response was created. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the current version of this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this document. */
  [DocumentResponse] [numeric](18,0) NULL, /* 0..n ASBIE Document Response ** A response to a document. */
 CONSTRAINT [PK_ApplicationResponse] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_UBLVersionID] ON [dbo].[ApplicationResponse] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_CustomizationID] ON [dbo].[ApplicationResponse] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_ProfileID] ON [dbo].[ApplicationResponse] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_ProfileExecutionID] ON [dbo].[ApplicationResponse] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_ID] ON [dbo].[ApplicationResponse] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_UUID] ON [dbo].[ApplicationResponse] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_IssueDate] ON [dbo].[ApplicationResponse] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_IssueTime] ON [dbo].[ApplicationResponse] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_ResponseDate] ON [dbo].[ApplicationResponse] 
(
	[ResponseDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_ResponseTime] ON [dbo].[ApplicationResponse] 
(
	[ResponseTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_Note] ON [dbo].[ApplicationResponse] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_VersionID] ON [dbo].[ApplicationResponse] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_Signature] ON [dbo].[ApplicationResponse] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_SenderParty] ON [dbo].[ApplicationResponse] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_ReceiverParty] ON [dbo].[ApplicationResponse] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ApplicationResponse_DocumentResponse] ON [dbo].[ApplicationResponse] 
(
	[DocumentResponse] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[AttachedDocument] Script Date: 2013-10-13 00:21z
A wrapper that allows a document of any kind to be packaged with the UBL document that references it.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[AttachedDocument](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of document. */
  [DocumentType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Text specifying the type of document. */
  [ParentDocumentID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** The Identifier of the parent document. */
  [ParentDocumentTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of parent document. */
  [ParentDocumentVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Indicates the current version of the referred document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this document. */
  [Attachment] [numeric](18,0) NOT NULL, /* 1 ASBIE Attachment ** An attachment containing the document content. */
  [ParentDocumentLineReference] [numeric](18,0) NULL, /* 0..n ASBIE Line Reference ** A reference to a line in the attached document. */
 CONSTRAINT [PK_AttachedDocument] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_UBLVersionID] ON [dbo].[AttachedDocument] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_CustomizationID] ON [dbo].[AttachedDocument] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_ProfileID] ON [dbo].[AttachedDocument] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_ProfileExecutionID] ON [dbo].[AttachedDocument] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_ID] ON [dbo].[AttachedDocument] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_UUID] ON [dbo].[AttachedDocument] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_IssueDate] ON [dbo].[AttachedDocument] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_IssueTime] ON [dbo].[AttachedDocument] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_Note] ON [dbo].[AttachedDocument] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_DocumentTypeCode] ON [dbo].[AttachedDocument] 
(
	[DocumentTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_DocumentType] ON [dbo].[AttachedDocument] 
(
	[DocumentType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_ParentDocumentID] ON [dbo].[AttachedDocument] 
(
	[ParentDocumentID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_ParentDocumentTypeCode] ON [dbo].[AttachedDocument] 
(
	[ParentDocumentTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_ParentDocumentVersionID] ON [dbo].[AttachedDocument] 
(
	[ParentDocumentVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_Signature] ON [dbo].[AttachedDocument] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_SenderParty] ON [dbo].[AttachedDocument] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_ReceiverParty] ON [dbo].[AttachedDocument] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_Attachment] ON [dbo].[AttachedDocument] 
(
	[Attachment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AttachedDocument_ParentDocumentLineReference] ON [dbo].[AttachedDocument] 
(
	[ParentDocumentLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[AwardedNotification] Script Date: 2013-10-13 00:21z
The document used to communicate a contract award to the winner.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[AwardedNotification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [ContractFolderID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier, assigned by the sender, for the process file (i.e., record) to which this document belongs. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [ContractName] [numeric](18,0) NULL, /* 0..n BBIE Text ** The name, expressed as text, of this procurement project. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this document. */
  [MinutesDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a set of minutes associated with this award. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [TenderResult] [numeric](18,0) NOT NULL, /* 1..n ASBIE Tender Result ** The result of the tendering process reported in this notification. */
  [FinalFinancialGuarantee] [numeric](18,0) NULL, /* 0..n ASBIE Financial Guarantee ** A bond guarantee by the submitter of a tender or bid, required of the tender winner. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
 CONSTRAINT [PK_AwardedNotification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_UBLVersionID] ON [dbo].[AwardedNotification] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_CustomizationID] ON [dbo].[AwardedNotification] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_ProfileID] ON [dbo].[AwardedNotification] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_ProfileExecutionID] ON [dbo].[AwardedNotification] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_ID] ON [dbo].[AwardedNotification] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_CopyIndicator] ON [dbo].[AwardedNotification] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_UUID] ON [dbo].[AwardedNotification] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_ContractFolderID] ON [dbo].[AwardedNotification] 
(
	[ContractFolderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_IssueDate] ON [dbo].[AwardedNotification] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_IssueTime] ON [dbo].[AwardedNotification] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_ContractName] ON [dbo].[AwardedNotification] 
(
	[ContractName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_Note] ON [dbo].[AwardedNotification] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_SenderParty] ON [dbo].[AwardedNotification] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_ReceiverParty] ON [dbo].[AwardedNotification] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_MinutesDocumentReference] ON [dbo].[AwardedNotification] 
(
	[MinutesDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_AdditionalDocumentReference] ON [dbo].[AwardedNotification] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_TenderResult] ON [dbo].[AwardedNotification] 
(
	[TenderResult] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_FinalFinancialGuarantee] ON [dbo].[AwardedNotification] 
(
	[FinalFinancialGuarantee] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardedNotification_Signature] ON [dbo].[AwardedNotification] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[BillOfLading] Script Date: 2013-10-13 00:21z
A document issued by the party who acts as an agent for a transportation carrier or other agents to the party who gives instructions for the transportation services (shipper, consignor, etc.) stating the details of the transportation, charges, and terms and conditions under which the transportation service is provided. The party issuing this document does not necessarily provide the physical transportation service. The information in the Bill of Lading corresponds to the information on the Forwarding Instructions. It is used for any mode of transport. A Bill of Lading can serve as a contractual document between the parties for the transportation service. The document evidences a contract of carriage by sea and the acceptance of responsibility for the goods by the carrier, by which the carrier undertakes to deliver the goods against surrender of the document. A provision in the document that the goods are to be delivered to the order of a named person, or to order, or to bearer, constitutes such an undertaking.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[BillOfLading](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CarrierAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Reference number (such as a booking reference number) assigned by a carrier or its agent to identify a specific shipment when cargo space is reserved prior to loading. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Text, assigned by the sender, that identifies this document to business users. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Textual description of the document instance. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of the Bill Of Lading (revision, replacement, etc.). */
  [ShippingOrderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Reference number to identify a Shipping Order or Forwarding Instruction. */
  [ToOrderIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether the transport document is consigned to order. */
  [AdValoremIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** A term used in commerce in reference to certain duties, called ad valorem duties, which are levied on commodities at certain rates per centum on their value. */
  [DeclaredCarriageValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** Value declared by the shipper or his agent solely for the purpose of varying the carrier's level of liability from that provided in the contract of carriage in case of loss or damage to goods or delayed delivery. */
  [OtherInstruction] [numeric](18,0) NULL, /* 0..n BBIE Text ** Other free-text instructions to the forwarders or carriers related to the shipment. This element should only be used where such information cannot be represented in other structured information entities within the document. */
  [ConsignorParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party consigning goods as stipulated in the transport contract by the party ordering transport. */
  [CarrierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party providing the transport of goods between named points. */
  [FreightForwarderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A party combining individual smaller consignments into a single larger shipment (a so-called consolidated consignment or shipment) that is sent to a counterpart who mirrors the consolidator's activity by dividing the consolidated consignment into its original components. */
  [Shipment] [numeric](18,0) NULL, /* 0..1 ASBIE Shipment ** An identifiable collection of one or more goods items to be transported between the seller party and the buyer party. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [ExchangeRate] [numeric](18,0) NULL, /* 0..n ASBIE Exchange Rate ** Information that directly relates to the rate of exchange (conversion) between two currencies. */
  [DocumentDistribution] [numeric](18,0) NULL, /* 0..n ASBIE Document Distribution ** A list of interested parties to whom this document is distributed. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
 CONSTRAINT [PK_BillOfLading] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_UBLVersionID] ON [dbo].[BillOfLading] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_CustomizationID] ON [dbo].[BillOfLading] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_ProfileID] ON [dbo].[BillOfLading] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_ProfileExecutionID] ON [dbo].[BillOfLading] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_ID] ON [dbo].[BillOfLading] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_CarrierAssignedID] ON [dbo].[BillOfLading] 
(
	[CarrierAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_UUID] ON [dbo].[BillOfLading] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_IssueDate] ON [dbo].[BillOfLading] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_IssueTime] ON [dbo].[BillOfLading] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_Name] ON [dbo].[BillOfLading] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_Description] ON [dbo].[BillOfLading] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_Note] ON [dbo].[BillOfLading] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_DocumentStatusCode] ON [dbo].[BillOfLading] 
(
	[DocumentStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_ShippingOrderID] ON [dbo].[BillOfLading] 
(
	[ShippingOrderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_ToOrderIndicator] ON [dbo].[BillOfLading] 
(
	[ToOrderIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_AdValoremIndicator] ON [dbo].[BillOfLading] 
(
	[AdValoremIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_DeclaredCarriageValueAmount] ON [dbo].[BillOfLading] 
(
	[DeclaredCarriageValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_OtherInstruction] ON [dbo].[BillOfLading] 
(
	[OtherInstruction] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_ConsignorParty] ON [dbo].[BillOfLading] 
(
	[ConsignorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_CarrierParty] ON [dbo].[BillOfLading] 
(
	[CarrierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_FreightForwarderParty] ON [dbo].[BillOfLading] 
(
	[FreightForwarderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_Shipment] ON [dbo].[BillOfLading] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_DocumentReference] ON [dbo].[BillOfLading] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_ExchangeRate] ON [dbo].[BillOfLading] 
(
	[ExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_DocumentDistribution] ON [dbo].[BillOfLading] 
(
	[DocumentDistribution] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillOfLading_Signature] ON [dbo].[BillOfLading] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CallForTenders] Script Date: 2013-10-13 00:21z
A document used by a Contracting Party to define a procurement project to buy goods, services, or works during a specified period.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CallForTenders](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [ContractFolderID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier, assigned by the sender, for the process file (i.e., record) to which this document belongs. */
  [ApprovalDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the contracting party, on which the Call For Tenders was approved. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Indicates the current version of the Call for Tenders. */
  [PreviousVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the previous version of the Call for Tenders which is superceded by this version. */
  [LegalDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a legal document. */
  [TechnicalDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a technical document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [ContractingParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Contracting Party ** The contracting party. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..n ASBIE Customer Party ** The party who originated Order. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving this document. */
  [TenderingTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Tendering Terms ** The tendering terms associated with this tendering process. */
  [TenderingProcess] [numeric](18,0) NULL, /* 0..1 ASBIE Tendering Process ** A description of the tendering process itself. */
  [ProcurementProject] [numeric](18,0) NOT NULL, /* 1 ASBIE Procurement Project ** An overall definition of this procurement project. */
  [ProcurementProjectLot] [numeric](18,0) NULL, /* 0..n ASBIE Procurement Project Lot ** One of the procurement project lots into which this contract can be split. */
 CONSTRAINT [PK_CallForTenders] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_UBLVersionID] ON [dbo].[CallForTenders] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_CustomizationID] ON [dbo].[CallForTenders] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_ProfileID] ON [dbo].[CallForTenders] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_ProfileExecutionID] ON [dbo].[CallForTenders] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_ID] ON [dbo].[CallForTenders] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_CopyIndicator] ON [dbo].[CallForTenders] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_UUID] ON [dbo].[CallForTenders] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_ContractFolderID] ON [dbo].[CallForTenders] 
(
	[ContractFolderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_ApprovalDate] ON [dbo].[CallForTenders] 
(
	[ApprovalDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_IssueDate] ON [dbo].[CallForTenders] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_IssueTime] ON [dbo].[CallForTenders] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_Note] ON [dbo].[CallForTenders] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_VersionID] ON [dbo].[CallForTenders] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_PreviousVersionID] ON [dbo].[CallForTenders] 
(
	[PreviousVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_LegalDocumentReference] ON [dbo].[CallForTenders] 
(
	[LegalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_TechnicalDocumentReference] ON [dbo].[CallForTenders] 
(
	[TechnicalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_AdditionalDocumentReference] ON [dbo].[CallForTenders] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_Signature] ON [dbo].[CallForTenders] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_ContractingParty] ON [dbo].[CallForTenders] 
(
	[ContractingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_OriginatorCustomerParty] ON [dbo].[CallForTenders] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_ReceiverParty] ON [dbo].[CallForTenders] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_TenderingTerms] ON [dbo].[CallForTenders] 
(
	[TenderingTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_TenderingProcess] ON [dbo].[CallForTenders] 
(
	[TenderingProcess] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_ProcurementProject] ON [dbo].[CallForTenders] 
(
	[ProcurementProject] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CallForTenders_ProcurementProjectLot] ON [dbo].[CallForTenders] 
(
	[ProcurementProjectLot] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Catalogue] Script Date: 2013-10-13 00:21z
A document that describes items, prices, and price validity.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Catalogue](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [ActionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying whether the transaction is a replacement or an update. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Text, assigned by the sender, that identifies this document to business users. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [RevisionDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the seller party, on which the information in the Catalogue was last revised. */
  [RevisionTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the Seller party, at which the information in the Catalogue was last revised. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Textual description of the document instance. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the current version of the Catalogue. */
  [PreviousVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the previous version of the Catalogue that is superseded by this version. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Catalogue Lines in the document. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period, assigned by the seller, during which the information in the Catalogue is effective. This may be given as start and end dates or as a duration. */
  [ReferencedContract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** A contract or framework agreement with which this Catalogue is associated. */
  [SourceCatalogueReference] [numeric](18,0) NULL, /* 0..1 ASBIE Catalogue Reference ** A reference to the source catalogue. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [ProviderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party providing the Catalogue. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving the Catalogue. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [ContractorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The customer party responsible for the contracts with which the Catalogue is associated. */
  [TradingTerms] [numeric](18,0) NULL, /* 0..n ASBIE Trading Terms ** The trading terms associated with this Catalogue. */
  [CatalogueLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Catalogue Line ** A line in a Catalogue describing an item of sale. */
 CONSTRAINT [PK_Catalogue] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_UBLVersionID] ON [dbo].[Catalogue] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_CustomizationID] ON [dbo].[Catalogue] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_ProfileID] ON [dbo].[Catalogue] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_ProfileExecutionID] ON [dbo].[Catalogue] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_ID] ON [dbo].[Catalogue] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_UUID] ON [dbo].[Catalogue] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_ActionCode] ON [dbo].[Catalogue] 
(
	[ActionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_Name] ON [dbo].[Catalogue] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_IssueDate] ON [dbo].[Catalogue] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_IssueTime] ON [dbo].[Catalogue] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_RevisionDate] ON [dbo].[Catalogue] 
(
	[RevisionDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_RevisionTime] ON [dbo].[Catalogue] 
(
	[RevisionTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_Note] ON [dbo].[Catalogue] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_Description] ON [dbo].[Catalogue] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_VersionID] ON [dbo].[Catalogue] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_PreviousVersionID] ON [dbo].[Catalogue] 
(
	[PreviousVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_LineCountNumeric] ON [dbo].[Catalogue] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_ValidityPeriod] ON [dbo].[Catalogue] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_ReferencedContract] ON [dbo].[Catalogue] 
(
	[ReferencedContract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_SourceCatalogueReference] ON [dbo].[Catalogue] 
(
	[SourceCatalogueReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_DocumentReference] ON [dbo].[Catalogue] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_Signature] ON [dbo].[Catalogue] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_ProviderParty] ON [dbo].[Catalogue] 
(
	[ProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_ReceiverParty] ON [dbo].[Catalogue] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_SellerSupplierParty] ON [dbo].[Catalogue] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_ContractorCustomerParty] ON [dbo].[Catalogue] 
(
	[ContractorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_TradingTerms] ON [dbo].[Catalogue] 
(
	[TradingTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Catalogue_CatalogueLine] ON [dbo].[Catalogue] 
(
	[CatalogueLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CatalogueDeletion] Script Date: 2013-10-13 00:21z
A document used to cancel an entire Catalogue.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CatalogueDeletion](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Text, assigned by the sender, that identifies this document to business users. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [EffectiveDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The effective date, assigned by the seller, on which the Catalogue expires. */
  [EffectiveTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The effective time, assigned by the seller, at which the Catalogue expires. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the current version of the Catalogue. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Textual description of the document instance. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** The period during which the Deletion of the catalogue becomes effective. This may be given as start (after date) and end dates (before date). */
  [DeletedCatalogueReference] [numeric](18,0) NOT NULL, /* 1 ASBIE Catalogue Reference ** A reference to the Catalogue being deleted. */
  [ReferencedContract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** A contract or framework agreement with which the Catalogue was associated. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving the Catalogue Deletion. */
  [ProviderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending the Catalogue Deletion. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [ContractorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The customer party responsible for the contracts with which the Catalogue was associated. */
 CONSTRAINT [PK_CatalogueDeletion] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_UBLVersionID] ON [dbo].[CatalogueDeletion] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_CustomizationID] ON [dbo].[CatalogueDeletion] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_ProfileID] ON [dbo].[CatalogueDeletion] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_ProfileExecutionID] ON [dbo].[CatalogueDeletion] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_ID] ON [dbo].[CatalogueDeletion] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_UUID] ON [dbo].[CatalogueDeletion] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_Name] ON [dbo].[CatalogueDeletion] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_IssueDate] ON [dbo].[CatalogueDeletion] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_IssueTime] ON [dbo].[CatalogueDeletion] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_EffectiveDate] ON [dbo].[CatalogueDeletion] 
(
	[EffectiveDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_EffectiveTime] ON [dbo].[CatalogueDeletion] 
(
	[EffectiveTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_Note] ON [dbo].[CatalogueDeletion] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_VersionID] ON [dbo].[CatalogueDeletion] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_Description] ON [dbo].[CatalogueDeletion] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_ValidityPeriod] ON [dbo].[CatalogueDeletion] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_DeletedCatalogueReference] ON [dbo].[CatalogueDeletion] 
(
	[DeletedCatalogueReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_ReferencedContract] ON [dbo].[CatalogueDeletion] 
(
	[ReferencedContract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_Signature] ON [dbo].[CatalogueDeletion] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_ReceiverParty] ON [dbo].[CatalogueDeletion] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_ProviderParty] ON [dbo].[CatalogueDeletion] 
(
	[ProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_SellerSupplierParty] ON [dbo].[CatalogueDeletion] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueDeletion_ContractorCustomerParty] ON [dbo].[CatalogueDeletion] 
(
	[ContractorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CatalogueItemSpecificationUpdate] Script Date: 2013-10-13 00:21z
A document used to update information (e.g., technical descriptions and properties) about Items in an existing Catalogue.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CatalogueItemSpecificationUpdate](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the subset of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Text, assigned by the sender, that identifies this document to business users. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [RevisionDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the seller, on which the Catalogue was revised. */
  [RevisionTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the seller, at which the Catalogue was revised. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Textual description of the document instance. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the current version of the Catalogue. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Catalogue Item Specification Update Lines in this document. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period, assigned by the seller, during which the information in the Catalogue Revision is effective. This may be given as start and end dates or as a duration. */
  [RelatedCatalogueReference] [numeric](18,0) NOT NULL, /* 1 ASBIE Catalogue Reference ** A reference to the Catalogue being updated. */
  [ReferencedContract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** A contract or framework agreement with which the Catalogue is associated. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [ProviderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending the Catalogue Item Specification Update. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving the Catalogue Item Specification Update. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [ContractorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The customer party responsible for the contracts with which the Catalogue is associated. */
  [TradingTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Trading Terms ** The trading terms associated with the Catalogue. */
  [DefaultLanguage] [numeric](18,0) NULL, /* 0..1 ASBIE Language ** The default language for the item specifications. */
  [CatalogueItemSpecificationUpdateLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Catalogue Item Specification Update Line ** One or more lines in the Catalogue Item Specification Update, each line updating a specific catalogue item. */
 CONSTRAINT [PK_CatalogueItemSpecificationUpdate] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_UBLVersionID] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_CustomizationID] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_ProfileID] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_ProfileExecutionID] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_ID] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_UUID] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_Name] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_IssueDate] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_IssueTime] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_RevisionDate] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[RevisionDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_RevisionTime] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[RevisionTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_Note] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_Description] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_VersionID] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_LineCountNumeric] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_ValidityPeriod] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_RelatedCatalogueReference] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[RelatedCatalogueReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_ReferencedContract] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[ReferencedContract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_Signature] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_ProviderParty] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[ProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_ReceiverParty] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_SellerSupplierParty] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_ContractorCustomerParty] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[ContractorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_TradingTerms] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[TradingTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_DefaultLanguage] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[DefaultLanguage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdate_CatalogueItemSpecificationUpdateLine] ON [dbo].[CatalogueItemSpecificationUpdate] 
(
	[CatalogueItemSpecificationUpdateLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CataloguePricingUpdate] Script Date: 2013-10-13 00:21z
A document used to update information about prices in an existing Catalogue.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CataloguePricingUpdate](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the subset of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Text, assigned by the sender, that identifies this document to business users. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [RevisionDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the seller, on which the Catalogue was revised. */
  [RevisionTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the seller, at which the Catalogue was revised. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Describes the Catalogue Revision. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Indicates the current version of the catalogue. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of lines in the document. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period, assigned by the seller, during which the information in the Catalogue Revision is effective. This may be given as start and end dates or as a duration. */
  [RelatedCatalogueReference] [numeric](18,0) NOT NULL, /* 1 ASBIE Catalogue Reference ** A reference to the Catalogue being updated. */
  [ReferencedContract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** A contract or framework agreement with which the Catalogue is associated. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [ProviderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending the Catalogue Pricing Update. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving the Catalogue Pricing Update. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [ContractorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The customer party responsible for the contracts with which the Catalogue is associated. */
  [TradingTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Trading Terms ** The trading terms associated with the Catalogue. */
  [DefaultLanguage] [numeric](18,0) NULL, /* 0..1 ASBIE Language ** The default language for the catalogue pricing update. */
  [CataloguePricingUpdateLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Catalogue Pricing Update Line ** One or more lines in the Catalogue Pricing Update, each line updating a specific catalogue item. */
 CONSTRAINT [PK_CataloguePricingUpdate] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_UBLVersionID] ON [dbo].[CataloguePricingUpdate] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_CustomizationID] ON [dbo].[CataloguePricingUpdate] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_ProfileID] ON [dbo].[CataloguePricingUpdate] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_ProfileExecutionID] ON [dbo].[CataloguePricingUpdate] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_ID] ON [dbo].[CataloguePricingUpdate] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_UUID] ON [dbo].[CataloguePricingUpdate] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_Name] ON [dbo].[CataloguePricingUpdate] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_IssueDate] ON [dbo].[CataloguePricingUpdate] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_IssueTime] ON [dbo].[CataloguePricingUpdate] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_RevisionDate] ON [dbo].[CataloguePricingUpdate] 
(
	[RevisionDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_RevisionTime] ON [dbo].[CataloguePricingUpdate] 
(
	[RevisionTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_Note] ON [dbo].[CataloguePricingUpdate] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_Description] ON [dbo].[CataloguePricingUpdate] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_VersionID] ON [dbo].[CataloguePricingUpdate] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_LineCountNumeric] ON [dbo].[CataloguePricingUpdate] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_ValidityPeriod] ON [dbo].[CataloguePricingUpdate] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_RelatedCatalogueReference] ON [dbo].[CataloguePricingUpdate] 
(
	[RelatedCatalogueReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_ReferencedContract] ON [dbo].[CataloguePricingUpdate] 
(
	[ReferencedContract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_Signature] ON [dbo].[CataloguePricingUpdate] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_ProviderParty] ON [dbo].[CataloguePricingUpdate] 
(
	[ProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_ReceiverParty] ON [dbo].[CataloguePricingUpdate] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_SellerSupplierParty] ON [dbo].[CataloguePricingUpdate] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_ContractorCustomerParty] ON [dbo].[CataloguePricingUpdate] 
(
	[ContractorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_TradingTerms] ON [dbo].[CataloguePricingUpdate] 
(
	[TradingTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_DefaultLanguage] ON [dbo].[CataloguePricingUpdate] 
(
	[DefaultLanguage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdate_CataloguePricingUpdateLine] ON [dbo].[CataloguePricingUpdate] 
(
	[CataloguePricingUpdateLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CatalogueRequest] Script Date: 2013-10-13 00:21z
A document used to request a Catalogue.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CatalogueRequest](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Text, assigned by the sender, that identifies this document to business users. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Textual description of the document instance. */
  [PricingUpdateRequestIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates a request for a pricing update. */
  [ItemUpdateRequestIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates a request for an update of the item specifications. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Catalogue Lines in this document. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** The period, assigned by the Catalogue Managing party, during which the information in the Catalogue requested is to be effective. This may be given as start and end dates or a duration. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving the Catalogue Request. */
  [ProviderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending the Catalogue Request. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [ContractorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The customer party responsible for the contracts with which the Catalogue is associated. */
  [RequestedCatalogueReference] [numeric](18,0) NULL, /* 0..1 ASBIE Catalogue Reference ** A reference to a specific Catalogue; used if the Catalogue Request is for an update. */
  [ReferencedContract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** A contract or framework agreement with which the Catalogue being requested is associated. */
  [TradingTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Trading Terms ** The trading terms associated with the requested Catalogue. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [ApplicableTerritoryAddress] [numeric](18,0) NULL, /* 0..n ASBIE Address ** A reference to a territory (region, country, city, etc.) to which the requested Catalogue will apply, expressed as an Address. */
  [RequestedLanguage] [numeric](18,0) NULL, /* 0..1 ASBIE Language ** The language in which the Catalogue is requested to be provided. */
  [RequestedClassificationScheme] [numeric](18,0) NULL, /* 0..n ASBIE Classification Scheme ** A requested classification scheme for the requested Catalogue. */
  [CatalogueRequestLine] [numeric](18,0) NULL, /* 0..n ASBIE Catalogue Request Line ** An association to specific Catalogue Lines for the catalogue requested. */
 CONSTRAINT [PK_CatalogueRequest] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_UBLVersionID] ON [dbo].[CatalogueRequest] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_CustomizationID] ON [dbo].[CatalogueRequest] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_ProfileID] ON [dbo].[CatalogueRequest] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_ProfileExecutionID] ON [dbo].[CatalogueRequest] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_ID] ON [dbo].[CatalogueRequest] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_UUID] ON [dbo].[CatalogueRequest] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_Name] ON [dbo].[CatalogueRequest] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_IssueDate] ON [dbo].[CatalogueRequest] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_IssueTime] ON [dbo].[CatalogueRequest] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_Note] ON [dbo].[CatalogueRequest] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_Description] ON [dbo].[CatalogueRequest] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_PricingUpdateRequestIndicator] ON [dbo].[CatalogueRequest] 
(
	[PricingUpdateRequestIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_ItemUpdateRequestIndicator] ON [dbo].[CatalogueRequest] 
(
	[ItemUpdateRequestIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_LineCountNumeric] ON [dbo].[CatalogueRequest] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_ValidityPeriod] ON [dbo].[CatalogueRequest] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_Signature] ON [dbo].[CatalogueRequest] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_ReceiverParty] ON [dbo].[CatalogueRequest] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_ProviderParty] ON [dbo].[CatalogueRequest] 
(
	[ProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_SellerSupplierParty] ON [dbo].[CatalogueRequest] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_ContractorCustomerParty] ON [dbo].[CatalogueRequest] 
(
	[ContractorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_RequestedCatalogueReference] ON [dbo].[CatalogueRequest] 
(
	[RequestedCatalogueReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_ReferencedContract] ON [dbo].[CatalogueRequest] 
(
	[ReferencedContract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_TradingTerms] ON [dbo].[CatalogueRequest] 
(
	[TradingTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_DocumentReference] ON [dbo].[CatalogueRequest] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_ApplicableTerritoryAddress] ON [dbo].[CatalogueRequest] 
(
	[ApplicableTerritoryAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_RequestedLanguage] ON [dbo].[CatalogueRequest] 
(
	[RequestedLanguage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_RequestedClassificationScheme] ON [dbo].[CatalogueRequest] 
(
	[RequestedClassificationScheme] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequest_CatalogueRequestLine] ON [dbo].[CatalogueRequest] 
(
	[CatalogueRequestLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CertificateOfOrigin] Script Date: 2013-10-13 00:21z
A document that describes the Certificate of Origin.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CertificateOfOrigin](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Textual description of the document instance. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the version of this Certificate of Origin. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [ExporterParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The Party who makes the export declaration, or on whose behalf the export declaration is made, and who is the owner of the goods or has similar right of disposal over them at the time when the declaration is accepted. */
  [ImporterParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The Party who makes an import declaration, or on whose behalf a Customs clearing agent or other authorized person makes an import declaration. This may include a person who has possession of the goods or to whom the goods are consigned. */
  [EndorserParty] [numeric](18,0) NULL, /* 0..n ASBIE Endorser Party ** The Party providing the endorsement. */
  [CertificateOfOriginApplication] [numeric](18,0) NOT NULL, /* 1 ASBIE Certificate Of Origin Application ** Details of the application for a Certificate of Origin. */
  [IssuerEndorsement] [numeric](18,0) NOT NULL, /* 1 ASBIE Endorsement ** Issuer Endorsement details. */
  [EmbassyEndorsement] [numeric](18,0) NULL, /* 0..1 ASBIE Endorsement ** Embassy Endorsement details. */
  [InsuranceEndorsement] [numeric](18,0) NULL, /* 0..1 ASBIE Endorsement ** Insurance Endorsement details. */
 CONSTRAINT [PK_CertificateOfOrigin] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_UBLVersionID] ON [dbo].[CertificateOfOrigin] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_CustomizationID] ON [dbo].[CertificateOfOrigin] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_ProfileID] ON [dbo].[CertificateOfOrigin] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_ProfileExecutionID] ON [dbo].[CertificateOfOrigin] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_ID] ON [dbo].[CertificateOfOrigin] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_UUID] ON [dbo].[CertificateOfOrigin] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_IssueDate] ON [dbo].[CertificateOfOrigin] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_IssueTime] ON [dbo].[CertificateOfOrigin] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_Description] ON [dbo].[CertificateOfOrigin] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_Note] ON [dbo].[CertificateOfOrigin] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_VersionID] ON [dbo].[CertificateOfOrigin] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_Signature] ON [dbo].[CertificateOfOrigin] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_ExporterParty] ON [dbo].[CertificateOfOrigin] 
(
	[ExporterParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_ImporterParty] ON [dbo].[CertificateOfOrigin] 
(
	[ImporterParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_EndorserParty] ON [dbo].[CertificateOfOrigin] 
(
	[EndorserParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_CertificateOfOriginApplication] ON [dbo].[CertificateOfOrigin] 
(
	[CertificateOfOriginApplication] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_IssuerEndorsement] ON [dbo].[CertificateOfOrigin] 
(
	[IssuerEndorsement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_EmbassyEndorsement] ON [dbo].[CertificateOfOrigin] 
(
	[EmbassyEndorsement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOrigin_InsuranceEndorsement] ON [dbo].[CertificateOfOrigin] 
(
	[InsuranceEndorsement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ContractAwardNotice] Script Date: 2013-10-13 00:21z
A document published by a Contracting Party to announce the awarding of a procurement project.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ContractAwardNotice](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [ContractFolderID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier, assigned by the sender, for the process file (i.e., record) to which this document belongs. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [RegulatoryDomain] [numeric](18,0) NULL, /* 0..n BBIE Text ** Information about the law that defines the regulatory domain. */
  [PublishAwardIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator specifying if the notice is published for service contracts within certain service categories (true) or not (false). */
  [PreviousDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a previously sent document. */
  [MinutesDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a set of minutes. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [ContractingParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Contracting Party ** The contracting party. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The party who originated Order. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving this document. */
  [TenderingTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Tendering Terms ** The tendering terms associated with this tendering process. */
  [TenderingProcess] [numeric](18,0) NULL, /* 0..1 ASBIE Tendering Process ** A description of the tendering process itself. */
  [ProcurementProject] [numeric](18,0) NULL, /* 0..1 ASBIE Procurement Project ** An overall definition of this procurement project. */
  [ProcurementProjectLot] [numeric](18,0) NULL, /* 0..n ASBIE Procurement Project Lot ** One of the procurement project lots into which this contract can be split. */
  [TenderResult] [numeric](18,0) NOT NULL, /* 1..n ASBIE Tender Result ** A result of the bid opening in the tendering process. */
 CONSTRAINT [PK_ContractAwardNotice] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_UBLVersionID] ON [dbo].[ContractAwardNotice] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_CustomizationID] ON [dbo].[ContractAwardNotice] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_ProfileID] ON [dbo].[ContractAwardNotice] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_ProfileExecutionID] ON [dbo].[ContractAwardNotice] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_ID] ON [dbo].[ContractAwardNotice] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_CopyIndicator] ON [dbo].[ContractAwardNotice] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_UUID] ON [dbo].[ContractAwardNotice] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_ContractFolderID] ON [dbo].[ContractAwardNotice] 
(
	[ContractFolderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_IssueDate] ON [dbo].[ContractAwardNotice] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_IssueTime] ON [dbo].[ContractAwardNotice] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_Note] ON [dbo].[ContractAwardNotice] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_RegulatoryDomain] ON [dbo].[ContractAwardNotice] 
(
	[RegulatoryDomain] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_PublishAwardIndicator] ON [dbo].[ContractAwardNotice] 
(
	[PublishAwardIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_PreviousDocumentReference] ON [dbo].[ContractAwardNotice] 
(
	[PreviousDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_MinutesDocumentReference] ON [dbo].[ContractAwardNotice] 
(
	[MinutesDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_Signature] ON [dbo].[ContractAwardNotice] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_ContractingParty] ON [dbo].[ContractAwardNotice] 
(
	[ContractingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_OriginatorCustomerParty] ON [dbo].[ContractAwardNotice] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_ReceiverParty] ON [dbo].[ContractAwardNotice] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_TenderingTerms] ON [dbo].[ContractAwardNotice] 
(
	[TenderingTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_TenderingProcess] ON [dbo].[ContractAwardNotice] 
(
	[TenderingProcess] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_ProcurementProject] ON [dbo].[ContractAwardNotice] 
(
	[ProcurementProject] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_ProcurementProjectLot] ON [dbo].[ContractAwardNotice] 
(
	[ProcurementProjectLot] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractAwardNotice_TenderResult] ON [dbo].[ContractAwardNotice] 
(
	[TenderResult] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ContractNotice] Script Date: 2013-10-13 00:21z
A document used by a Contracting party to announce a project to buy goods, services, or works.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ContractNotice](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [ContractFolderID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier, assigned by the sender, for the process file (i.e., record) to which this document belongs. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [RequestedPublicationDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The requested publication date for this Contract Notice. */
  [RegulatoryDomain] [numeric](18,0) NULL, /* 0..n BBIE Text ** Information about the law that defines the regulatory domain. */
  [FrequencyPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The estimated frequency of future notices. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [ContractingParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Contracting Party ** The contracting party. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..n ASBIE Customer Party ** A party who originally requested the tender. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving this document. */
  [TenderingTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Tendering Terms ** The tendering terms associated with this tendering process. */
  [TenderingProcess] [numeric](18,0) NULL, /* 0..1 ASBIE Tendering Process ** A description of the tendering process itself. */
  [ProcurementProject] [numeric](18,0) NOT NULL, /* 1 ASBIE Procurement Project ** An overall definition of this procurement project. */
  [ProcurementProjectLot] [numeric](18,0) NULL, /* 0..n ASBIE Procurement Project Lot ** One of the procurement project lots into which this contract can be split. */
 CONSTRAINT [PK_ContractNotice] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_UBLVersionID] ON [dbo].[ContractNotice] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_CustomizationID] ON [dbo].[ContractNotice] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_ProfileID] ON [dbo].[ContractNotice] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_ProfileExecutionID] ON [dbo].[ContractNotice] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_ID] ON [dbo].[ContractNotice] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_CopyIndicator] ON [dbo].[ContractNotice] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_UUID] ON [dbo].[ContractNotice] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_ContractFolderID] ON [dbo].[ContractNotice] 
(
	[ContractFolderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_IssueDate] ON [dbo].[ContractNotice] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_IssueTime] ON [dbo].[ContractNotice] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_Note] ON [dbo].[ContractNotice] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_RequestedPublicationDate] ON [dbo].[ContractNotice] 
(
	[RequestedPublicationDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_RegulatoryDomain] ON [dbo].[ContractNotice] 
(
	[RegulatoryDomain] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_FrequencyPeriod] ON [dbo].[ContractNotice] 
(
	[FrequencyPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_Signature] ON [dbo].[ContractNotice] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_ContractingParty] ON [dbo].[ContractNotice] 
(
	[ContractingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_OriginatorCustomerParty] ON [dbo].[ContractNotice] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_ReceiverParty] ON [dbo].[ContractNotice] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_TenderingTerms] ON [dbo].[ContractNotice] 
(
	[TenderingTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_TenderingProcess] ON [dbo].[ContractNotice] 
(
	[TenderingProcess] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_ProcurementProject] ON [dbo].[ContractNotice] 
(
	[ProcurementProject] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractNotice_ProcurementProjectLot] ON [dbo].[ContractNotice] 
(
	[ProcurementProjectLot] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CreditNote] Script Date: 2013-10-13 00:21z
A document used to specify credits due to the Debtor from the Creditor.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CreditNote](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [TaxPointDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of the Credit Note, used to indicate the point at which tax becomes applicable. */
  [CreditNoteTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of the Credit Note. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [TaxCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for tax amounts in the Credit Note. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for prices in the Credit Note. */
  [PaymentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for payment in the Credit Note. */
  [PaymentAlternativeCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the alternative currency used for payment in the Credit Note. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting code, applied to the Credit Note as a whole. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting code, applied to the Credit Note as a whole, expressed as text. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Credit Note Lines in the document. */
  [BuyerReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A reference provided by the buyer used for internal routing of the document. */
  [InvoicePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** Associates the Credit Note with Invoicing Periods rather than with a specific Invoice. */
  [DiscrepancyResponse] [numeric](18,0) NULL, /* 0..n ASBIE Response ** A reason for the Credit Note as a whole. */
  [OrderReference] [numeric](18,0) NULL, /* 0..1 ASBIE Order Reference ** The Order associated with this Credit Note. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this document. */
  [DespatchDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Despatch Advice associated with this document. */
  [ReceiptDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Receipt Advice associated with this document. */
  [ContractDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a contract associated with this document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [StatementDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Statement associated with this document. */
  [OriginatorDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an originator document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [AccountingSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The accounting supplier party. */
  [AccountingCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The accounting customer party. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payee. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [TaxRepresentativeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The tax representative. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this document. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..n ASBIE Delivery Terms ** A set of delivery terms associated with this document. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..n ASBIE Payment Means ** Expected means of payment. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A set of payment terms associated with this document. */
  [TaxExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the tax currency. */
  [PricingExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the pricing currency. */
  [PaymentExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment currency. */
  [PaymentAlternativeExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment alternative currency. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [LegalMonetaryTotal] [numeric](18,0) NOT NULL, /* 1 ASBIE Monetary Total ** The total amount payable on the Credit Note, including allowances, charges, and taxes. */
  [CreditNoteLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Credit Note Line ** A Credit Note line. */
 CONSTRAINT [PK_CreditNote] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_UBLVersionID] ON [dbo].[CreditNote] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_CustomizationID] ON [dbo].[CreditNote] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_ProfileID] ON [dbo].[CreditNote] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_ProfileExecutionID] ON [dbo].[CreditNote] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_ID] ON [dbo].[CreditNote] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_CopyIndicator] ON [dbo].[CreditNote] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_UUID] ON [dbo].[CreditNote] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_IssueDate] ON [dbo].[CreditNote] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_IssueTime] ON [dbo].[CreditNote] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_TaxPointDate] ON [dbo].[CreditNote] 
(
	[TaxPointDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_CreditNoteTypeCode] ON [dbo].[CreditNote] 
(
	[CreditNoteTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_Note] ON [dbo].[CreditNote] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_DocumentCurrencyCode] ON [dbo].[CreditNote] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_TaxCurrencyCode] ON [dbo].[CreditNote] 
(
	[TaxCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_PricingCurrencyCode] ON [dbo].[CreditNote] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_PaymentCurrencyCode] ON [dbo].[CreditNote] 
(
	[PaymentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_PaymentAlternativeCurrencyCode] ON [dbo].[CreditNote] 
(
	[PaymentAlternativeCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_AccountingCostCode] ON [dbo].[CreditNote] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_AccountingCost] ON [dbo].[CreditNote] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_LineCountNumeric] ON [dbo].[CreditNote] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_BuyerReference] ON [dbo].[CreditNote] 
(
	[BuyerReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_InvoicePeriod] ON [dbo].[CreditNote] 
(
	[InvoicePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_DiscrepancyResponse] ON [dbo].[CreditNote] 
(
	[DiscrepancyResponse] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_OrderReference] ON [dbo].[CreditNote] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_BillingReference] ON [dbo].[CreditNote] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_DespatchDocumentReference] ON [dbo].[CreditNote] 
(
	[DespatchDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_ReceiptDocumentReference] ON [dbo].[CreditNote] 
(
	[ReceiptDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_ContractDocumentReference] ON [dbo].[CreditNote] 
(
	[ContractDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_AdditionalDocumentReference] ON [dbo].[CreditNote] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_StatementDocumentReference] ON [dbo].[CreditNote] 
(
	[StatementDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_OriginatorDocumentReference] ON [dbo].[CreditNote] 
(
	[OriginatorDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_Signature] ON [dbo].[CreditNote] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_AccountingSupplierParty] ON [dbo].[CreditNote] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_AccountingCustomerParty] ON [dbo].[CreditNote] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_PayeeParty] ON [dbo].[CreditNote] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_BuyerCustomerParty] ON [dbo].[CreditNote] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_SellerSupplierParty] ON [dbo].[CreditNote] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_TaxRepresentativeParty] ON [dbo].[CreditNote] 
(
	[TaxRepresentativeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_Delivery] ON [dbo].[CreditNote] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_DeliveryTerms] ON [dbo].[CreditNote] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_PaymentMeans] ON [dbo].[CreditNote] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_PaymentTerms] ON [dbo].[CreditNote] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_TaxExchangeRate] ON [dbo].[CreditNote] 
(
	[TaxExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_PricingExchangeRate] ON [dbo].[CreditNote] 
(
	[PricingExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_PaymentExchangeRate] ON [dbo].[CreditNote] 
(
	[PaymentExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_PaymentAlternativeExchangeRate] ON [dbo].[CreditNote] 
(
	[PaymentAlternativeExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_AllowanceCharge] ON [dbo].[CreditNote] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_TaxTotal] ON [dbo].[CreditNote] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_LegalMonetaryTotal] ON [dbo].[CreditNote] 
(
	[LegalMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNote_CreditNoteLine] ON [dbo].[CreditNote] 
(
	[CreditNoteLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DebitNote] Script Date: 2013-10-13 00:21z
A document used to specify debts incurred by the Debtor.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DebitNote](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [TaxPointDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of the Debit Note, used to indicate the point at which tax becomes applicable. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [TaxCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for tax amounts in the Debit Note. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for prices in the Debit Note. */
  [PaymentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for payment in the Debit Note. */
  [PaymentAlternativeCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the alternative currency used for payment in the Debit Note. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The Buyer's accounting code, applied to the Credit Note as a whole. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The Buyer's accounting code, applied to the Credit Note as a whole, expressed as text. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Debit Note Lines in this document. */
  [InvoicePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period (rather than a specific invoice) associated with this document. */
  [DiscrepancyResponse] [numeric](18,0) NULL, /* 0..n ASBIE Response ** A reason for the Debit Note as a whole. */
  [OrderReference] [numeric](18,0) NULL, /* 0..1 ASBIE Order Reference ** A reference to an Order with which this Debit Note is associated. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this document. */
  [DespatchDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Despatch Advice associated with this document. */
  [ReceiptDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Receipt Advice associated with this document. */
  [StatementDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Statement associated with this document. */
  [ContractDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a contract associated with this document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [AccountingSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The accounting supplier party. */
  [AccountingCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The accounting customer party. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payee. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [TaxRepresentativeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The tax representative. */
  [PrepaidPayment] [numeric](18,0) NULL, /* 0..n ASBIE Payment ** A prepaid payment. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this document. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..n ASBIE Delivery Terms ** A set of delivery terms associated with this document. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..n ASBIE Payment Means ** Expected means of payment. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A set of payment terms associated with this document. */
  [TaxExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the tax currency. */
  [PricingExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the pricing currency. */
  [PaymentExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment currency. */
  [PaymentAlternativeExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment alternative currency. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [RequestedMonetaryTotal] [numeric](18,0) NOT NULL, /* 1 ASBIE Monetary Total ** The total amount payable on the Debit Note, including allowances, charges, and taxes. */
  [DebitNoteLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Debit Note Line ** A Debit Note line. */
 CONSTRAINT [PK_DebitNote] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_UBLVersionID] ON [dbo].[DebitNote] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_CustomizationID] ON [dbo].[DebitNote] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_ProfileID] ON [dbo].[DebitNote] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_ProfileExecutionID] ON [dbo].[DebitNote] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_ID] ON [dbo].[DebitNote] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_CopyIndicator] ON [dbo].[DebitNote] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_UUID] ON [dbo].[DebitNote] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_IssueDate] ON [dbo].[DebitNote] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_IssueTime] ON [dbo].[DebitNote] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_Note] ON [dbo].[DebitNote] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_TaxPointDate] ON [dbo].[DebitNote] 
(
	[TaxPointDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_DocumentCurrencyCode] ON [dbo].[DebitNote] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_TaxCurrencyCode] ON [dbo].[DebitNote] 
(
	[TaxCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_PricingCurrencyCode] ON [dbo].[DebitNote] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_PaymentCurrencyCode] ON [dbo].[DebitNote] 
(
	[PaymentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_PaymentAlternativeCurrencyCode] ON [dbo].[DebitNote] 
(
	[PaymentAlternativeCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_AccountingCostCode] ON [dbo].[DebitNote] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_AccountingCost] ON [dbo].[DebitNote] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_LineCountNumeric] ON [dbo].[DebitNote] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_InvoicePeriod] ON [dbo].[DebitNote] 
(
	[InvoicePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_DiscrepancyResponse] ON [dbo].[DebitNote] 
(
	[DiscrepancyResponse] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_OrderReference] ON [dbo].[DebitNote] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_BillingReference] ON [dbo].[DebitNote] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_DespatchDocumentReference] ON [dbo].[DebitNote] 
(
	[DespatchDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_ReceiptDocumentReference] ON [dbo].[DebitNote] 
(
	[ReceiptDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_StatementDocumentReference] ON [dbo].[DebitNote] 
(
	[StatementDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_ContractDocumentReference] ON [dbo].[DebitNote] 
(
	[ContractDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_AdditionalDocumentReference] ON [dbo].[DebitNote] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_Signature] ON [dbo].[DebitNote] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_AccountingSupplierParty] ON [dbo].[DebitNote] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_AccountingCustomerParty] ON [dbo].[DebitNote] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_PayeeParty] ON [dbo].[DebitNote] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_BuyerCustomerParty] ON [dbo].[DebitNote] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_SellerSupplierParty] ON [dbo].[DebitNote] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_TaxRepresentativeParty] ON [dbo].[DebitNote] 
(
	[TaxRepresentativeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_PrepaidPayment] ON [dbo].[DebitNote] 
(
	[PrepaidPayment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_AllowanceCharge] ON [dbo].[DebitNote] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_Delivery] ON [dbo].[DebitNote] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_DeliveryTerms] ON [dbo].[DebitNote] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_PaymentMeans] ON [dbo].[DebitNote] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_PaymentTerms] ON [dbo].[DebitNote] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_TaxExchangeRate] ON [dbo].[DebitNote] 
(
	[TaxExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_PricingExchangeRate] ON [dbo].[DebitNote] 
(
	[PricingExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_PaymentExchangeRate] ON [dbo].[DebitNote] 
(
	[PaymentExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_PaymentAlternativeExchangeRate] ON [dbo].[DebitNote] 
(
	[PaymentAlternativeExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_TaxTotal] ON [dbo].[DebitNote] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_RequestedMonetaryTotal] ON [dbo].[DebitNote] 
(
	[RequestedMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNote_DebitNoteLine] ON [dbo].[DebitNote] 
(
	[DebitNoteLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DespatchAdvice] Script Date: 2013-10-13 00:21z
A document used to describe the despatch or delivery of goods and services.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DespatchAdvice](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [DocumentStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of the Despatch Advice with respect to its original state. This code may be used if the document precedes the event and is subsequently found to be incorrect and in need of cancellation or revision. */
  [DespatchAdviceTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of the Despatch Advice. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Despatch Lines in this document. */
  [OrderReference] [numeric](18,0) NULL, /* 0..n ASBIE Order Reference ** A reference to an Order with which this Despatch Advice is associated. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [DespatchSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The despatch party. */
  [DeliveryCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The delivery recipient. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** A customer party as originator. */
  [Shipment] [numeric](18,0) NULL, /* 0..1 ASBIE Shipment ** The shipment. */
  [DespatchLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Despatch Line ** A Despatch Line associated with a kind of item delivered. */
 CONSTRAINT [PK_DespatchAdvice] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_UBLVersionID] ON [dbo].[DespatchAdvice] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_CustomizationID] ON [dbo].[DespatchAdvice] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_ProfileID] ON [dbo].[DespatchAdvice] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_ProfileExecutionID] ON [dbo].[DespatchAdvice] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_ID] ON [dbo].[DespatchAdvice] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_CopyIndicator] ON [dbo].[DespatchAdvice] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_UUID] ON [dbo].[DespatchAdvice] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_IssueDate] ON [dbo].[DespatchAdvice] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_IssueTime] ON [dbo].[DespatchAdvice] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_DocumentStatusCode] ON [dbo].[DespatchAdvice] 
(
	[DocumentStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_DespatchAdviceTypeCode] ON [dbo].[DespatchAdvice] 
(
	[DespatchAdviceTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_Note] ON [dbo].[DespatchAdvice] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_LineCountNumeric] ON [dbo].[DespatchAdvice] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_OrderReference] ON [dbo].[DespatchAdvice] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_AdditionalDocumentReference] ON [dbo].[DespatchAdvice] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_Signature] ON [dbo].[DespatchAdvice] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_DespatchSupplierParty] ON [dbo].[DespatchAdvice] 
(
	[DespatchSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_DeliveryCustomerParty] ON [dbo].[DespatchAdvice] 
(
	[DeliveryCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_BuyerCustomerParty] ON [dbo].[DespatchAdvice] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_SellerSupplierParty] ON [dbo].[DespatchAdvice] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_OriginatorCustomerParty] ON [dbo].[DespatchAdvice] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_Shipment] ON [dbo].[DespatchAdvice] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchAdvice_DespatchLine] ON [dbo].[DespatchAdvice] 
(
	[DespatchLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DocumentStatus] Script Date: 2013-10-13 00:21z
A document used to provide information about document status.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DocumentStatus](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving this document. */
  [DocumentResponse] [numeric](18,0) NULL, /* 0..1 ASBIE Document Response ** A response to the document. */
  [AdditionalDocumentResponse] [numeric](18,0) NULL, /* 0..n ASBIE Document Response ** A document linked or related to the document for which the status was requested. */
 CONSTRAINT [PK_DocumentStatus] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_UBLVersionID] ON [dbo].[DocumentStatus] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_CustomizationID] ON [dbo].[DocumentStatus] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_ProfileID] ON [dbo].[DocumentStatus] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_ProfileExecutionID] ON [dbo].[DocumentStatus] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_ID] ON [dbo].[DocumentStatus] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_CopyIndicator] ON [dbo].[DocumentStatus] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_UUID] ON [dbo].[DocumentStatus] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_IssueDate] ON [dbo].[DocumentStatus] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_IssueTime] ON [dbo].[DocumentStatus] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_Note] ON [dbo].[DocumentStatus] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_Signature] ON [dbo].[DocumentStatus] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_SenderParty] ON [dbo].[DocumentStatus] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_ReceiverParty] ON [dbo].[DocumentStatus] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_DocumentResponse] ON [dbo].[DocumentStatus] 
(
	[DocumentResponse] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatus_AdditionalDocumentResponse] ON [dbo].[DocumentStatus] 
(
	[AdditionalDocumentResponse] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DocumentStatusRequest] Script Date: 2013-10-13 00:21z
A document used to request the status of another document.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DocumentStatusRequest](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [TrackingID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for tracking status of the business process . */
  [RequestedDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** The document about which status is requested. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving this document. */
 CONSTRAINT [PK_DocumentStatusRequest] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_UBLVersionID] ON [dbo].[DocumentStatusRequest] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_CustomizationID] ON [dbo].[DocumentStatusRequest] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_ProfileID] ON [dbo].[DocumentStatusRequest] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_ProfileExecutionID] ON [dbo].[DocumentStatusRequest] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_ID] ON [dbo].[DocumentStatusRequest] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_CopyIndicator] ON [dbo].[DocumentStatusRequest] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_UUID] ON [dbo].[DocumentStatusRequest] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_IssueDate] ON [dbo].[DocumentStatusRequest] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_IssueTime] ON [dbo].[DocumentStatusRequest] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_Note] ON [dbo].[DocumentStatusRequest] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_TrackingID] ON [dbo].[DocumentStatusRequest] 
(
	[TrackingID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_RequestedDocumentReference] ON [dbo].[DocumentStatusRequest] 
(
	[RequestedDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_Signature] ON [dbo].[DocumentStatusRequest] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_SenderParty] ON [dbo].[DocumentStatusRequest] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentStatusRequest_ReceiverParty] ON [dbo].[DocumentStatusRequest] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ExceptionCriteria] Script Date: 2013-10-13 00:21z
A document used to specify the thresholds for forecast variance, product activity, and performance history beyond which exceptions should be triggered.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ExceptionCriteria](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the current version of this document. */
  [ValidityPeriod] [numeric](18,0) NOT NULL, /* 1 ASBIE Period ** The period of time during which the Exception Criteria is valid. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this document. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [ExceptionCriteriaLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Exception Criteria Line ** A line expressing an exception criterion setting thresholds beyond which an exception should be triggered. */
 CONSTRAINT [PK_ExceptionCriteria] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_UBLVersionID] ON [dbo].[ExceptionCriteria] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_CustomizationID] ON [dbo].[ExceptionCriteria] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_ProfileID] ON [dbo].[ExceptionCriteria] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_ProfileExecutionID] ON [dbo].[ExceptionCriteria] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_ID] ON [dbo].[ExceptionCriteria] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_CopyIndicator] ON [dbo].[ExceptionCriteria] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_UUID] ON [dbo].[ExceptionCriteria] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_IssueDate] ON [dbo].[ExceptionCriteria] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_IssueTime] ON [dbo].[ExceptionCriteria] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_Note] ON [dbo].[ExceptionCriteria] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_VersionID] ON [dbo].[ExceptionCriteria] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_ValidityPeriod] ON [dbo].[ExceptionCriteria] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_DocumentReference] ON [dbo].[ExceptionCriteria] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_Signature] ON [dbo].[ExceptionCriteria] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_SenderParty] ON [dbo].[ExceptionCriteria] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_ReceiverParty] ON [dbo].[ExceptionCriteria] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_BuyerCustomerParty] ON [dbo].[ExceptionCriteria] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_SellerSupplierParty] ON [dbo].[ExceptionCriteria] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteria_ExceptionCriteriaLine] ON [dbo].[ExceptionCriteria] 
(
	[ExceptionCriteriaLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ExceptionNotification] Script Date: 2013-10-13 00:21z
A document used to notify an exception in forecast variance, product activity, or performance history.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ExceptionNotification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [ExceptionObservationPeriod] [numeric](18,0) NOT NULL, /* 1 ASBIE Period ** The period of time during which the exceptions are observed. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this document. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [ExceptionNotificationLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Exception Notification Line ** A line in the Exception Notification. */
 CONSTRAINT [PK_ExceptionNotification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_UBLVersionID] ON [dbo].[ExceptionNotification] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_CustomizationID] ON [dbo].[ExceptionNotification] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_ProfileID] ON [dbo].[ExceptionNotification] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_ProfileExecutionID] ON [dbo].[ExceptionNotification] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_ID] ON [dbo].[ExceptionNotification] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_CopyIndicator] ON [dbo].[ExceptionNotification] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_UUID] ON [dbo].[ExceptionNotification] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_IssueDate] ON [dbo].[ExceptionNotification] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_IssueTime] ON [dbo].[ExceptionNotification] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_Note] ON [dbo].[ExceptionNotification] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_ExceptionObservationPeriod] ON [dbo].[ExceptionNotification] 
(
	[ExceptionObservationPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_DocumentReference] ON [dbo].[ExceptionNotification] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_Signature] ON [dbo].[ExceptionNotification] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_SenderParty] ON [dbo].[ExceptionNotification] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_ReceiverParty] ON [dbo].[ExceptionNotification] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_BuyerCustomerParty] ON [dbo].[ExceptionNotification] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_SellerSupplierParty] ON [dbo].[ExceptionNotification] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotification_ExceptionNotificationLine] ON [dbo].[ExceptionNotification] 
(
	[ExceptionNotificationLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Forecast] Script Date: 2013-10-13 00:21z
A document used to forecast sales or orders.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Forecast](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the current version of this document. */
  [BasedOnConsensusIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether the Forecast is based on consensus (true) or not (false). */
  [ForecastPurposeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the purpose of the Forecast document. */
  [ForecastPeriod] [numeric](18,0) NOT NULL, /* 1 ASBIE Period ** The period to which the Forecast applies. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this document. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [ForecastLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Forecast Line ** A Forecast Line. */
 CONSTRAINT [PK_Forecast] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_UBLVersionID] ON [dbo].[Forecast] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_CustomizationID] ON [dbo].[Forecast] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_ProfileID] ON [dbo].[Forecast] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_ProfileExecutionID] ON [dbo].[Forecast] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_ID] ON [dbo].[Forecast] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_CopyIndicator] ON [dbo].[Forecast] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_UUID] ON [dbo].[Forecast] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_IssueDate] ON [dbo].[Forecast] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_IssueTime] ON [dbo].[Forecast] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_Note] ON [dbo].[Forecast] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_VersionID] ON [dbo].[Forecast] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_BasedOnConsensusIndicator] ON [dbo].[Forecast] 
(
	[BasedOnConsensusIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_ForecastPurposeCode] ON [dbo].[Forecast] 
(
	[ForecastPurposeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_ForecastPeriod] ON [dbo].[Forecast] 
(
	[ForecastPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_AdditionalDocumentReference] ON [dbo].[Forecast] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_Signature] ON [dbo].[Forecast] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_SenderParty] ON [dbo].[Forecast] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_ReceiverParty] ON [dbo].[Forecast] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_BuyerCustomerParty] ON [dbo].[Forecast] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_SellerSupplierParty] ON [dbo].[Forecast] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Forecast_ForecastLine] ON [dbo].[Forecast] 
(
	[ForecastLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ForecastRevision] Script Date: 2013-10-13 00:21z
A document used to revise a Forecast.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ForecastRevision](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [SequenceNumberID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** A sequence number, to ensure the proper sequencing of revisions. */
  [RevisionStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Indicates the revision status of this Forecast Revision. */
  [PurposeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Indicates the purpose of the revision. */
  [ForecastPeriod] [numeric](18,0) NOT NULL, /* 1 ASBIE Period ** The period to which the Forecast applies. */
  [OriginalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** The Forecast document being revised. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this document. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [ForecastRevisionLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Forecast Revision Line ** A line that revises a line in the Forecast. */
 CONSTRAINT [PK_ForecastRevision] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_UBLVersionID] ON [dbo].[ForecastRevision] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_CustomizationID] ON [dbo].[ForecastRevision] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_ProfileID] ON [dbo].[ForecastRevision] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_ProfileExecutionID] ON [dbo].[ForecastRevision] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_ID] ON [dbo].[ForecastRevision] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_CopyIndicator] ON [dbo].[ForecastRevision] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_UUID] ON [dbo].[ForecastRevision] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_IssueDate] ON [dbo].[ForecastRevision] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_IssueTime] ON [dbo].[ForecastRevision] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_Note] ON [dbo].[ForecastRevision] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_SequenceNumberID] ON [dbo].[ForecastRevision] 
(
	[SequenceNumberID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_RevisionStatusCode] ON [dbo].[ForecastRevision] 
(
	[RevisionStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_PurposeCode] ON [dbo].[ForecastRevision] 
(
	[PurposeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_ForecastPeriod] ON [dbo].[ForecastRevision] 
(
	[ForecastPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_OriginalDocumentReference] ON [dbo].[ForecastRevision] 
(
	[OriginalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_Signature] ON [dbo].[ForecastRevision] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_SenderParty] ON [dbo].[ForecastRevision] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_ReceiverParty] ON [dbo].[ForecastRevision] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_BuyerCustomerParty] ON [dbo].[ForecastRevision] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_SellerSupplierParty] ON [dbo].[ForecastRevision] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevision_ForecastRevisionLine] ON [dbo].[ForecastRevision] 
(
	[ForecastRevisionLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ForwardingInstructions] Script Date: 2013-10-13 00:21z
A document issued to a forwarder, giving instructions regarding the action to be taken for the forwarding of goods described therein. Forwarding Instructions is used by any party who gives instructions for the transportation services required for a consignment of goods to any party who is contracted to provide the transportation services. The parties who issue this document are commonly referred to as the shipper or consignor, while the parties who receive this document are forwarders, carriers, shipping agents, etc. This document may also be issued by a forwarder or shipping agent in its capacity as a shipper. This document can be used to arrange for the transportation (1) of different types of goods or cargoes; (2) whether containerized or non-containerized; (3) through different modes of transport including multi-modal; and (4) from any origin to any destination.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ForwardingInstructions](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CarrierAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Reference number assigned by a carrier or its agent to identify a specific shipment, such as a booking reference number when cargo space is reserved prior to loading. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Text, assigned by the sender, that identifies this document to business users. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Textual description of the document instance. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of the Forwarding Instructions with respect to its original state. This code may be used if the document precedes the event and is subsequently found to be incorrect and in need of cancellation or revision. */
  [ShippingOrderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Reference number to identify a Shipping Order. */
  [ToOrderIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether the transport document is consigned to order. */
  [AdValoremIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** A term used in commerce in reference to certain duties, called ad valorem duties, which are levied on commodities at certain rates per centum on their value. */
  [DeclaredCarriageValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** Value declared by the shipper or his agent solely for the purpose of varying the carrier's level of liability from that provided in the contract of carriage in case of loss or damage to goods or delayed delivery. */
  [OtherInstruction] [numeric](18,0) NULL, /* 0..n BBIE Text ** Contains other free-text instructions to the forwarders or carriers related to the shipment. This should only be used where such information cannot be represented in other structured information entities within the document. */
  [ConsignorParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party consigning goods, as stipulated in the transport contract by the party ordering transport. */
  [CarrierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party providing the transport of goods between named points. */
  [FreightForwarderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A party combining individual smaller consignments into a single larger shipment (a so-called consolidated consignment or shipment) that is sent to a counterpart who mirrors the consolidator's activity by dividing the consolidated consignment into its original components. */
  [Shipment] [numeric](18,0) NOT NULL, /* 1 ASBIE Shipment ** An identifiable collection of one or more goods items to be transported between the seller party and the buyer party. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [ExchangeRate] [numeric](18,0) NULL, /* 0..n ASBIE Exchange Rate ** Information about the rate of exchange (conversion) between two currencies. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
 CONSTRAINT [PK_ForwardingInstructions] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_UBLVersionID] ON [dbo].[ForwardingInstructions] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_CustomizationID] ON [dbo].[ForwardingInstructions] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_ProfileID] ON [dbo].[ForwardingInstructions] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_ProfileExecutionID] ON [dbo].[ForwardingInstructions] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_ID] ON [dbo].[ForwardingInstructions] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_CarrierAssignedID] ON [dbo].[ForwardingInstructions] 
(
	[CarrierAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_UUID] ON [dbo].[ForwardingInstructions] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_IssueDate] ON [dbo].[ForwardingInstructions] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_IssueTime] ON [dbo].[ForwardingInstructions] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_Name] ON [dbo].[ForwardingInstructions] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_Description] ON [dbo].[ForwardingInstructions] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_Note] ON [dbo].[ForwardingInstructions] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_DocumentStatusCode] ON [dbo].[ForwardingInstructions] 
(
	[DocumentStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_ShippingOrderID] ON [dbo].[ForwardingInstructions] 
(
	[ShippingOrderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_ToOrderIndicator] ON [dbo].[ForwardingInstructions] 
(
	[ToOrderIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_AdValoremIndicator] ON [dbo].[ForwardingInstructions] 
(
	[AdValoremIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_DeclaredCarriageValueAmount] ON [dbo].[ForwardingInstructions] 
(
	[DeclaredCarriageValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_OtherInstruction] ON [dbo].[ForwardingInstructions] 
(
	[OtherInstruction] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_ConsignorParty] ON [dbo].[ForwardingInstructions] 
(
	[ConsignorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_CarrierParty] ON [dbo].[ForwardingInstructions] 
(
	[CarrierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_FreightForwarderParty] ON [dbo].[ForwardingInstructions] 
(
	[FreightForwarderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_Shipment] ON [dbo].[ForwardingInstructions] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_DocumentReference] ON [dbo].[ForwardingInstructions] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_ExchangeRate] ON [dbo].[ForwardingInstructions] 
(
	[ExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForwardingInstructions_Signature] ON [dbo].[ForwardingInstructions] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[FreightInvoice] Script Date: 2013-10-13 00:21z
A document stating the charges incurred for a logistics service.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[FreightInvoice](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [InvoiceTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of the Freight Invoice. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [TaxPointDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of the Freight Invoice, used to indicate the point at which tax becomes applicable. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [TaxCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for tax amounts in the Freight Invoice. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for prices in the Freight Invoice. */
  [PaymentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for payment in the Freight Invoice. */
  [PaymentAlternativeCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the alternative currency used for payment in the Freight Invoice. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting code, applied to the Freight Invoice as a whole. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting cost centre, applied to the Freight Invoice as a whole, expressed as text. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Invoice Lines in the document. */
  [InvoicePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** The time periods to which the Freight Invoice applies. */
  [Shipment] [numeric](18,0) NOT NULL, /* 1..n ASBIE Shipment ** Details about one or more shipments covered by this Freight Invoice. */
  [OrderReference] [numeric](18,0) NULL, /* 0..1 ASBIE Order Reference ** Reference to an Order associated with this Freight Invoice. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this document. */
  [DespatchDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Despatch Advice associated with this document. */
  [ReceiptDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Receipt Advice associated with this document. */
  [OriginatorDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an originator document associated with this document. */
  [ContractDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a contract associated with this document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [AccountingSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The accounting supplier party. */
  [AccountingCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The accounting customer party. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payee. */
  [TaxRepresentativeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The tax representative. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..n ASBIE Payment Means ** Expected means of payment. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A set of payment terms associated with this document. */
  [PrepaidPayment] [numeric](18,0) NULL, /* 0..n ASBIE Payment ** A prepaid payment. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [TaxExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the tax currency. */
  [PricingExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the pricing currency. */
  [PaymentExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment currency. */
  [PaymentAlternativeExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment alternative currency. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [LegalMonetaryTotal] [numeric](18,0) NOT NULL, /* 1 ASBIE Monetary Total ** The total amount payable on the Freight Invoice, including Allowances, Charges, and Taxes. */
  [InvoiceLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Invoice Line ** An Invoice Line. */
 CONSTRAINT [PK_FreightInvoice] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_UBLVersionID] ON [dbo].[FreightInvoice] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_CustomizationID] ON [dbo].[FreightInvoice] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_ProfileID] ON [dbo].[FreightInvoice] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_ProfileExecutionID] ON [dbo].[FreightInvoice] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_ID] ON [dbo].[FreightInvoice] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_CopyIndicator] ON [dbo].[FreightInvoice] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_UUID] ON [dbo].[FreightInvoice] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_IssueDate] ON [dbo].[FreightInvoice] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_IssueTime] ON [dbo].[FreightInvoice] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_InvoiceTypeCode] ON [dbo].[FreightInvoice] 
(
	[InvoiceTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_Note] ON [dbo].[FreightInvoice] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_TaxPointDate] ON [dbo].[FreightInvoice] 
(
	[TaxPointDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_DocumentCurrencyCode] ON [dbo].[FreightInvoice] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_TaxCurrencyCode] ON [dbo].[FreightInvoice] 
(
	[TaxCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_PricingCurrencyCode] ON [dbo].[FreightInvoice] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_PaymentCurrencyCode] ON [dbo].[FreightInvoice] 
(
	[PaymentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_PaymentAlternativeCurrencyCode] ON [dbo].[FreightInvoice] 
(
	[PaymentAlternativeCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_AccountingCostCode] ON [dbo].[FreightInvoice] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_AccountingCost] ON [dbo].[FreightInvoice] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_LineCountNumeric] ON [dbo].[FreightInvoice] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_InvoicePeriod] ON [dbo].[FreightInvoice] 
(
	[InvoicePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_Shipment] ON [dbo].[FreightInvoice] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_OrderReference] ON [dbo].[FreightInvoice] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_BillingReference] ON [dbo].[FreightInvoice] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_DespatchDocumentReference] ON [dbo].[FreightInvoice] 
(
	[DespatchDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_ReceiptDocumentReference] ON [dbo].[FreightInvoice] 
(
	[ReceiptDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_OriginatorDocumentReference] ON [dbo].[FreightInvoice] 
(
	[OriginatorDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_ContractDocumentReference] ON [dbo].[FreightInvoice] 
(
	[ContractDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_AdditionalDocumentReference] ON [dbo].[FreightInvoice] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_Signature] ON [dbo].[FreightInvoice] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_AccountingSupplierParty] ON [dbo].[FreightInvoice] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_AccountingCustomerParty] ON [dbo].[FreightInvoice] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_PayeeParty] ON [dbo].[FreightInvoice] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_TaxRepresentativeParty] ON [dbo].[FreightInvoice] 
(
	[TaxRepresentativeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_PaymentMeans] ON [dbo].[FreightInvoice] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_PaymentTerms] ON [dbo].[FreightInvoice] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_PrepaidPayment] ON [dbo].[FreightInvoice] 
(
	[PrepaidPayment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_AllowanceCharge] ON [dbo].[FreightInvoice] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_TaxExchangeRate] ON [dbo].[FreightInvoice] 
(
	[TaxExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_PricingExchangeRate] ON [dbo].[FreightInvoice] 
(
	[PricingExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_PaymentExchangeRate] ON [dbo].[FreightInvoice] 
(
	[PaymentExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_PaymentAlternativeExchangeRate] ON [dbo].[FreightInvoice] 
(
	[PaymentAlternativeExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_TaxTotal] ON [dbo].[FreightInvoice] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_LegalMonetaryTotal] ON [dbo].[FreightInvoice] 
(
	[LegalMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FreightInvoice_InvoiceLine] ON [dbo].[FreightInvoice] 
(
	[InvoiceLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[FulfilmentCancellation] Script Date: 2013-10-13 00:21z
A document used to cancel an entire fulfilment document (Despatch Advice or Receipt Advice).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[FulfilmentCancellation](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [CancellationNote] [numeric](18,0) NOT NULL, /* 1..n BBIE Text ** The reason for cancellation of the referenced document. */
  [DespatchDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Despatch Advice associated with this document. */
  [ReceiptDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Receipt Advice associated with this document. */
  [OrderReference] [numeric](18,0) NULL, /* 0..n ASBIE Order Reference ** A reference to an Order document associated with the referenced Despatch or Receipt Advice(s). */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Contract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** The contracts or framework agreements with which the referenced fulfilment document is associated. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [BuyerCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The seller. */
  [DeliveryCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The delivery party. */
  [DespatchSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The despatch party. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The originator party */
 CONSTRAINT [PK_FulfilmentCancellation] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_UBLVersionID] ON [dbo].[FulfilmentCancellation] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_CustomizationID] ON [dbo].[FulfilmentCancellation] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_ProfileID] ON [dbo].[FulfilmentCancellation] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_ProfileExecutionID] ON [dbo].[FulfilmentCancellation] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_ID] ON [dbo].[FulfilmentCancellation] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_CopyIndicator] ON [dbo].[FulfilmentCancellation] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_UUID] ON [dbo].[FulfilmentCancellation] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_IssueDate] ON [dbo].[FulfilmentCancellation] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_IssueTime] ON [dbo].[FulfilmentCancellation] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_Note] ON [dbo].[FulfilmentCancellation] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_CancellationNote] ON [dbo].[FulfilmentCancellation] 
(
	[CancellationNote] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_DespatchDocumentReference] ON [dbo].[FulfilmentCancellation] 
(
	[DespatchDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_ReceiptDocumentReference] ON [dbo].[FulfilmentCancellation] 
(
	[ReceiptDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_OrderReference] ON [dbo].[FulfilmentCancellation] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_AdditionalDocumentReference] ON [dbo].[FulfilmentCancellation] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_Contract] ON [dbo].[FulfilmentCancellation] 
(
	[Contract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_Signature] ON [dbo].[FulfilmentCancellation] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_BuyerCustomerParty] ON [dbo].[FulfilmentCancellation] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_SellerSupplierParty] ON [dbo].[FulfilmentCancellation] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_DeliveryCustomerParty] ON [dbo].[FulfilmentCancellation] 
(
	[DeliveryCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_DespatchSupplierParty] ON [dbo].[FulfilmentCancellation] 
(
	[DespatchSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FulfilmentCancellation_OriginatorCustomerParty] ON [dbo].[FulfilmentCancellation] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[GoodsItemItinerary] Script Date: 2013-10-13 00:21z
A document providing details relating to a transport service, such as transport movement, identification of equipment and goods, subcontracted service providers, etc.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[GoodsItemItinerary](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NOT NULL, /* 1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [VersionID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** Identifies a version of a Goods Item Itinerary in order to distinguish updates. */
  [TransportExecutionPlanReferenceID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** The Transport Execution Plan associated with this Goods Item Itinerary. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The sender of this Goods Item Itinerary. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The receiver of this Goods Item Itinerary. */
  [ReferencedConsignment] [numeric](18,0) NULL, /* 0..n ASBIE Consignment ** A consignment being transported in the transport service associated with this Goods Item Itinerary. */
  [ReferencedTransportEquipment] [numeric](18,0) NULL, /* 0..n ASBIE Transport Equipment ** Transport equipment being transported in the transport service associated with this Goods Item Itinerary. */
  [ReferencedPackage] [numeric](18,0) NULL, /* 0..n ASBIE Package ** A package being transported in the transport service associated with this Goods Item Itinerary. */
  [ReferencedGoodsItem] [numeric](18,0) NULL, /* 0..n ASBIE Goods Item ** An item of goods being transported in the transport service associated with this Goods Item Itinerary. */
  [TransportationSegment] [numeric](18,0) NOT NULL, /* 1..n ASBIE Transportation Segment ** A part of a transport service that has its own Transport Execution Plan. A Transportation Segment may cover services other than transport, such as terminal handling, document management, customs procedures, etc. */
 CONSTRAINT [PK_GoodsItemItinerary] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_UBLVersionID] ON [dbo].[GoodsItemItinerary] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_CustomizationID] ON [dbo].[GoodsItemItinerary] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_ProfileID] ON [dbo].[GoodsItemItinerary] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_ProfileExecutionID] ON [dbo].[GoodsItemItinerary] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_ID] ON [dbo].[GoodsItemItinerary] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_CopyIndicator] ON [dbo].[GoodsItemItinerary] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_UUID] ON [dbo].[GoodsItemItinerary] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_IssueDate] ON [dbo].[GoodsItemItinerary] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_IssueTime] ON [dbo].[GoodsItemItinerary] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_Note] ON [dbo].[GoodsItemItinerary] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_VersionID] ON [dbo].[GoodsItemItinerary] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_TransportExecutionPlanReferenceID] ON [dbo].[GoodsItemItinerary] 
(
	[TransportExecutionPlanReferenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_Signature] ON [dbo].[GoodsItemItinerary] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_SenderParty] ON [dbo].[GoodsItemItinerary] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_ReceiverParty] ON [dbo].[GoodsItemItinerary] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_ReferencedConsignment] ON [dbo].[GoodsItemItinerary] 
(
	[ReferencedConsignment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_ReferencedTransportEquipment] ON [dbo].[GoodsItemItinerary] 
(
	[ReferencedTransportEquipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_ReferencedPackage] ON [dbo].[GoodsItemItinerary] 
(
	[ReferencedPackage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_ReferencedGoodsItem] ON [dbo].[GoodsItemItinerary] 
(
	[ReferencedGoodsItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemItinerary_TransportationSegment] ON [dbo].[GoodsItemItinerary] 
(
	[TransportationSegment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[GuaranteeCertificate] Script Date: 2013-10-13 00:21z
A document to notify the deposit of a bid bond guarantee.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[GuaranteeCertificate](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [ContractFolderID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier, assigned by the sender, for the process file (i.e., record) to which this document belongs. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [GuaranteeTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of the guarantee. */
  [Purpose] [numeric](18,0) NULL, /* 0..n BBIE Text ** A textual description of the purpose of the bid bond guarantee. */
  [LiabilityAmount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The liability amount (a monetary value) in the bid bond guarantee. */
  [ConstitutionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The code stating the constitution means of the guarantee. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [ApplicablePeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The specified period in the tendering process for which this bid bond guarantee is effective */
  [ApplicableRegulation] [numeric](18,0) NULL, /* 0..n ASBIE Regulation ** A reference to an applicable regulation. */
  [GuaranteeDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a legal document. */
  [ImmobilizedSecurity] [numeric](18,0) NULL, /* 0..n ASBIE Immobilized Security ** Details of an immobilized security. */
  [Signature] [numeric](18,0) NOT NULL, /* 1..n ASBIE Signature ** A signature applied to this document. */
  [GuarantorParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The guarantee creditor organization that has the authority to charge bid bond guarantee credit. */
  [InterestedParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party depositing the bid bond guarantee. */
  [BeneficiaryParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The beneficiary of the bid bond guarantee. */
 CONSTRAINT [PK_GuaranteeCertificate] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_UBLVersionID] ON [dbo].[GuaranteeCertificate] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_CustomizationID] ON [dbo].[GuaranteeCertificate] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_ProfileID] ON [dbo].[GuaranteeCertificate] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_ProfileExecutionID] ON [dbo].[GuaranteeCertificate] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_ID] ON [dbo].[GuaranteeCertificate] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_CopyIndicator] ON [dbo].[GuaranteeCertificate] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_UUID] ON [dbo].[GuaranteeCertificate] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_ContractFolderID] ON [dbo].[GuaranteeCertificate] 
(
	[ContractFolderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_IssueDate] ON [dbo].[GuaranteeCertificate] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_IssueTime] ON [dbo].[GuaranteeCertificate] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_GuaranteeTypeCode] ON [dbo].[GuaranteeCertificate] 
(
	[GuaranteeTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_Purpose] ON [dbo].[GuaranteeCertificate] 
(
	[Purpose] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_LiabilityAmount] ON [dbo].[GuaranteeCertificate] 
(
	[LiabilityAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_ConstitutionCode] ON [dbo].[GuaranteeCertificate] 
(
	[ConstitutionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_Note] ON [dbo].[GuaranteeCertificate] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_ApplicablePeriod] ON [dbo].[GuaranteeCertificate] 
(
	[ApplicablePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_ApplicableRegulation] ON [dbo].[GuaranteeCertificate] 
(
	[ApplicableRegulation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_GuaranteeDocumentReference] ON [dbo].[GuaranteeCertificate] 
(
	[GuaranteeDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_ImmobilizedSecurity] ON [dbo].[GuaranteeCertificate] 
(
	[ImmobilizedSecurity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_Signature] ON [dbo].[GuaranteeCertificate] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_GuarantorParty] ON [dbo].[GuaranteeCertificate] 
(
	[GuarantorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_InterestedParty] ON [dbo].[GuaranteeCertificate] 
(
	[InterestedParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GuaranteeCertificate_BeneficiaryParty] ON [dbo].[GuaranteeCertificate] 
(
	[BeneficiaryParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[InstructionForReturns] Script Date: 2013-10-13 00:21z
A document used to initiate a return of goods. The producer is requesting the return of products that are not selling well, either to use in other places or to free up rack or shelf space.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[InstructionForReturns](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SellerSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The seller. */
  [RetailerCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The retailer. */
  [ManufacturerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The manufacturer. */
  [Shipment] [numeric](18,0) NULL, /* 0..1 ASBIE Shipment ** The shipment. */
  [InstructionForReturnsLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Instruction For Returns Line ** A line providing details about one type of article to be returned. */
 CONSTRAINT [PK_InstructionForReturns] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_UBLVersionID] ON [dbo].[InstructionForReturns] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_CustomizationID] ON [dbo].[InstructionForReturns] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_ProfileID] ON [dbo].[InstructionForReturns] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_ProfileExecutionID] ON [dbo].[InstructionForReturns] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_ID] ON [dbo].[InstructionForReturns] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_CopyIndicator] ON [dbo].[InstructionForReturns] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_UUID] ON [dbo].[InstructionForReturns] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_IssueDate] ON [dbo].[InstructionForReturns] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_IssueTime] ON [dbo].[InstructionForReturns] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_Note] ON [dbo].[InstructionForReturns] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_DocumentReference] ON [dbo].[InstructionForReturns] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_Signature] ON [dbo].[InstructionForReturns] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_SellerSupplierParty] ON [dbo].[InstructionForReturns] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_RetailerCustomerParty] ON [dbo].[InstructionForReturns] 
(
	[RetailerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_ManufacturerParty] ON [dbo].[InstructionForReturns] 
(
	[ManufacturerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_Shipment] ON [dbo].[InstructionForReturns] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturns_InstructionForReturnsLine] ON [dbo].[InstructionForReturns] 
(
	[InstructionForReturnsLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[InventoryReport] Script Date: 2013-10-13 00:21z
A report on the quantities of each item that are, or will be, in stock. This document is sent by a Buyer (for example a retailer) to a Seller (for example a producer).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[InventoryReport](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the Inventory Report, assigned by the Issuer. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which the Inventory Report was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency in which the Document is presented. This may be the same currency as the pricing or as the tax. */
  [InventoryPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period covered by this report. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [RetailerCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The retailer, who sends this message. */
  [InventoryReportingParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** An association to the Party that will really use the Inventory report (normally the branch for which the stock is reported). */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [InventoryReportLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Inventory Report Line ** A line representing a particular item of sale and associated with a line in the Catalogue. */
 CONSTRAINT [PK_InventoryReport] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_UBLVersionID] ON [dbo].[InventoryReport] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_CustomizationID] ON [dbo].[InventoryReport] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_ProfileID] ON [dbo].[InventoryReport] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_ProfileExecutionID] ON [dbo].[InventoryReport] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_ID] ON [dbo].[InventoryReport] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_CopyIndicator] ON [dbo].[InventoryReport] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_UUID] ON [dbo].[InventoryReport] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_IssueDate] ON [dbo].[InventoryReport] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_IssueTime] ON [dbo].[InventoryReport] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_Note] ON [dbo].[InventoryReport] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_DocumentCurrencyCode] ON [dbo].[InventoryReport] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_InventoryPeriod] ON [dbo].[InventoryReport] 
(
	[InventoryPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_DocumentReference] ON [dbo].[InventoryReport] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_Signature] ON [dbo].[InventoryReport] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_RetailerCustomerParty] ON [dbo].[InventoryReport] 
(
	[RetailerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_InventoryReportingParty] ON [dbo].[InventoryReport] 
(
	[InventoryReportingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_SellerSupplierParty] ON [dbo].[InventoryReport] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReport_InventoryReportLine] ON [dbo].[InventoryReport] 
(
	[InventoryReportLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Invoice] Script Date: 2013-10-13 00:21z
A document used to request payment.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Invoice](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [DueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which Invoice is due. */
  [InvoiceTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of the Invoice. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [TaxPointDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of the Invoice, used to indicate the point at which tax becomes applicable. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [TaxCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for tax amounts in the Invoice. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for prices in the Invoice. */
  [PaymentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for payment in the Invoice. */
  [PaymentAlternativeCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the alternative currency used for payment in the Invoice. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting code, applied to the Invoice as a whole. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting code, applied to the Invoice as a whole, expressed as text. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of lines in the document. */
  [BuyerReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A reference provided by the buyer used for internal routing of the document. */
  [InvoicePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period to which the Invoice applies. */
  [OrderReference] [numeric](18,0) NULL, /* 0..1 ASBIE Order Reference ** A reference to the Order with which this Invoice is associated. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this document. */
  [DespatchDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Despatch Advice associated with this document. */
  [ReceiptDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Receipt Advice associated with this document. */
  [StatementDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Statement associated with this document. */
  [OriginatorDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an originator document associated with this document. */
  [ContractDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a contract associated with this document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [ProjectReference] [numeric](18,0) NULL, /* 0..n ASBIE Project Reference ** Information about a project. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [AccountingSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The accounting supplier party. */
  [AccountingCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The accounting customer party. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payee. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [TaxRepresentativeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The tax representative. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this document. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery Terms ** A set of delivery terms associated with this document. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..n ASBIE Payment Means ** Expected means of payment. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A set of payment terms associated with this document. */
  [PrepaidPayment] [numeric](18,0) NULL, /* 0..n ASBIE Payment ** A prepaid payment. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [TaxExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the tax currency. */
  [PricingExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the pricing currency. */
  [PaymentExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment currency. */
  [PaymentAlternativeExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment alternative currency. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [WithholdingTaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total withholding tax. */
  [LegalMonetaryTotal] [numeric](18,0) NOT NULL, /* 1 ASBIE Monetary Total ** The total amount payable on the Invoice, including Allowances, Charges, and Taxes. */
  [InvoiceLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Invoice Line ** A line describing an invoice item. */
 CONSTRAINT [PK_Invoice] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_UBLVersionID] ON [dbo].[Invoice] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_CustomizationID] ON [dbo].[Invoice] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_ProfileID] ON [dbo].[Invoice] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_ProfileExecutionID] ON [dbo].[Invoice] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_ID] ON [dbo].[Invoice] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_CopyIndicator] ON [dbo].[Invoice] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_UUID] ON [dbo].[Invoice] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_IssueDate] ON [dbo].[Invoice] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_IssueTime] ON [dbo].[Invoice] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_DueDate] ON [dbo].[Invoice] 
(
	[DueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_InvoiceTypeCode] ON [dbo].[Invoice] 
(
	[InvoiceTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_Note] ON [dbo].[Invoice] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_TaxPointDate] ON [dbo].[Invoice] 
(
	[TaxPointDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_DocumentCurrencyCode] ON [dbo].[Invoice] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_TaxCurrencyCode] ON [dbo].[Invoice] 
(
	[TaxCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_PricingCurrencyCode] ON [dbo].[Invoice] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_PaymentCurrencyCode] ON [dbo].[Invoice] 
(
	[PaymentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_PaymentAlternativeCurrencyCode] ON [dbo].[Invoice] 
(
	[PaymentAlternativeCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_AccountingCostCode] ON [dbo].[Invoice] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_AccountingCost] ON [dbo].[Invoice] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_LineCountNumeric] ON [dbo].[Invoice] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_BuyerReference] ON [dbo].[Invoice] 
(
	[BuyerReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_InvoicePeriod] ON [dbo].[Invoice] 
(
	[InvoicePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_OrderReference] ON [dbo].[Invoice] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_BillingReference] ON [dbo].[Invoice] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_DespatchDocumentReference] ON [dbo].[Invoice] 
(
	[DespatchDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_ReceiptDocumentReference] ON [dbo].[Invoice] 
(
	[ReceiptDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_StatementDocumentReference] ON [dbo].[Invoice] 
(
	[StatementDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_OriginatorDocumentReference] ON [dbo].[Invoice] 
(
	[OriginatorDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_ContractDocumentReference] ON [dbo].[Invoice] 
(
	[ContractDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_AdditionalDocumentReference] ON [dbo].[Invoice] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_ProjectReference] ON [dbo].[Invoice] 
(
	[ProjectReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_Signature] ON [dbo].[Invoice] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_AccountingSupplierParty] ON [dbo].[Invoice] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_AccountingCustomerParty] ON [dbo].[Invoice] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_PayeeParty] ON [dbo].[Invoice] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_BuyerCustomerParty] ON [dbo].[Invoice] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_SellerSupplierParty] ON [dbo].[Invoice] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_TaxRepresentativeParty] ON [dbo].[Invoice] 
(
	[TaxRepresentativeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_Delivery] ON [dbo].[Invoice] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_DeliveryTerms] ON [dbo].[Invoice] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_PaymentMeans] ON [dbo].[Invoice] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_PaymentTerms] ON [dbo].[Invoice] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_PrepaidPayment] ON [dbo].[Invoice] 
(
	[PrepaidPayment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_AllowanceCharge] ON [dbo].[Invoice] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_TaxExchangeRate] ON [dbo].[Invoice] 
(
	[TaxExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_PricingExchangeRate] ON [dbo].[Invoice] 
(
	[PricingExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_PaymentExchangeRate] ON [dbo].[Invoice] 
(
	[PaymentExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_PaymentAlternativeExchangeRate] ON [dbo].[Invoice] 
(
	[PaymentAlternativeExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_TaxTotal] ON [dbo].[Invoice] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_WithholdingTaxTotal] ON [dbo].[Invoice] 
(
	[WithholdingTaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_LegalMonetaryTotal] ON [dbo].[Invoice] 
(
	[LegalMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Invoice_InvoiceLine] ON [dbo].[Invoice] 
(
	[InvoiceLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ItemInformationRequest] Script Date: 2013-10-13 00:21z
A document used to request product activity, forecast, or performance data.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ItemInformationRequest](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [Period] [numeric](18,0) NOT NULL, /* 1 ASBIE Period ** The period of time to which the Item Information Request applies. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The buyer. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The seller. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [ItemInformationRequestLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Item Information Request Line ** A line requesting information regarding an item of sale. */
 CONSTRAINT [PK_ItemInformationRequest] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_UBLVersionID] ON [dbo].[ItemInformationRequest] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_CustomizationID] ON [dbo].[ItemInformationRequest] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_ProfileID] ON [dbo].[ItemInformationRequest] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_ProfileExecutionID] ON [dbo].[ItemInformationRequest] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_ID] ON [dbo].[ItemInformationRequest] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_CopyIndicator] ON [dbo].[ItemInformationRequest] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_UUID] ON [dbo].[ItemInformationRequest] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_IssueDate] ON [dbo].[ItemInformationRequest] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_IssueTime] ON [dbo].[ItemInformationRequest] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_Note] ON [dbo].[ItemInformationRequest] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_Period] ON [dbo].[ItemInformationRequest] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_DocumentReference] ON [dbo].[ItemInformationRequest] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_Signature] ON [dbo].[ItemInformationRequest] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_SenderParty] ON [dbo].[ItemInformationRequest] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_ReceiverParty] ON [dbo].[ItemInformationRequest] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_BuyerCustomerParty] ON [dbo].[ItemInformationRequest] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_SellerSupplierParty] ON [dbo].[ItemInformationRequest] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequest_ItemInformationRequestLine] ON [dbo].[ItemInformationRequest] 
(
	[ItemInformationRequestLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Order] Script Date: 2013-10-13 00:21z
A document used to order goods and services.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Order](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [SalesOrderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the Order, assigned by the seller. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [OrderTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of Order. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [RequestedInvoiceCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency requested for amount totals in Invoices related to this Order. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for all prices in the Order. */
  [TaxCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency requested for tax amounts in Invoices related to this Order. */
  [CustomerReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A supplementary reference for the Order. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting code, applied to the Order as a whole. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting cost centre, applied to the Order as a whole, expressed as text. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Order Lines in the document. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** The period for which the Order is valid. */
  [QuotationDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a Quotation. */
  [OrderDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another Order. */
  [OriginatorDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to an originator document associated with this document. */
  [CatalogueReference] [numeric](18,0) NULL, /* 0..1 ASBIE Catalogue Reference ** A reference to the Catalogue on which this Order is based. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Contract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** A contracts associated with this Order. */
  [ProjectReference] [numeric](18,0) NULL, /* 0..n ASBIE Project Reference ** A project with which this Order is associated. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [BuyerCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The seller. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The originator. */
  [FreightForwarderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A freight forwarder or carrier. */
  [AccountingCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The accounting customer party. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this document. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..n ASBIE Delivery Terms ** A set of delivery terms associated with this document. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..n ASBIE Payment Means ** Expected means of payment. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A set of payment terms associated with this document. */
  [TransactionConditions] [numeric](18,0) NULL, /* 0..1 ASBIE Transaction Conditions ** A specification of purchasing or sales conditions applying to the whole Order. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [TaxExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the tax currency. */
  [PricingExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the pricing currency. */
  [PaymentExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment currency. */
  [DestinationCountry] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country of destination (for customs purposes). */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [AnticipatedMonetaryTotal] [numeric](18,0) NULL, /* 0..1 ASBIE Monetary Total ** The total amount for the Order anticipated by the buyer. */
  [OrderLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Order Line ** A line associated with a line in the Catalogue and specifying a kind of item being ordered. */
 CONSTRAINT [PK_Order] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_UBLVersionID] ON [dbo].[Order] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_CustomizationID] ON [dbo].[Order] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_ProfileID] ON [dbo].[Order] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_ProfileExecutionID] ON [dbo].[Order] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_ID] ON [dbo].[Order] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_SalesOrderID] ON [dbo].[Order] 
(
	[SalesOrderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_CopyIndicator] ON [dbo].[Order] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_UUID] ON [dbo].[Order] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_IssueDate] ON [dbo].[Order] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_IssueTime] ON [dbo].[Order] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_OrderTypeCode] ON [dbo].[Order] 
(
	[OrderTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_Note] ON [dbo].[Order] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_RequestedInvoiceCurrencyCode] ON [dbo].[Order] 
(
	[RequestedInvoiceCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_DocumentCurrencyCode] ON [dbo].[Order] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_PricingCurrencyCode] ON [dbo].[Order] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_TaxCurrencyCode] ON [dbo].[Order] 
(
	[TaxCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_CustomerReference] ON [dbo].[Order] 
(
	[CustomerReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_AccountingCostCode] ON [dbo].[Order] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_AccountingCost] ON [dbo].[Order] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_LineCountNumeric] ON [dbo].[Order] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_ValidityPeriod] ON [dbo].[Order] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_QuotationDocumentReference] ON [dbo].[Order] 
(
	[QuotationDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_OrderDocumentReference] ON [dbo].[Order] 
(
	[OrderDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_OriginatorDocumentReference] ON [dbo].[Order] 
(
	[OriginatorDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_CatalogueReference] ON [dbo].[Order] 
(
	[CatalogueReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_AdditionalDocumentReference] ON [dbo].[Order] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_Contract] ON [dbo].[Order] 
(
	[Contract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_ProjectReference] ON [dbo].[Order] 
(
	[ProjectReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_Signature] ON [dbo].[Order] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_BuyerCustomerParty] ON [dbo].[Order] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_SellerSupplierParty] ON [dbo].[Order] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_OriginatorCustomerParty] ON [dbo].[Order] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_FreightForwarderParty] ON [dbo].[Order] 
(
	[FreightForwarderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_AccountingCustomerParty] ON [dbo].[Order] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_Delivery] ON [dbo].[Order] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_DeliveryTerms] ON [dbo].[Order] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_PaymentMeans] ON [dbo].[Order] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_PaymentTerms] ON [dbo].[Order] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_TransactionConditions] ON [dbo].[Order] 
(
	[TransactionConditions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_AllowanceCharge] ON [dbo].[Order] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_TaxExchangeRate] ON [dbo].[Order] 
(
	[TaxExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_PricingExchangeRate] ON [dbo].[Order] 
(
	[PricingExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_PaymentExchangeRate] ON [dbo].[Order] 
(
	[PaymentExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_DestinationCountry] ON [dbo].[Order] 
(
	[DestinationCountry] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_TaxTotal] ON [dbo].[Order] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_AnticipatedMonetaryTotal] ON [dbo].[Order] 
(
	[AnticipatedMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Order_OrderLine] ON [dbo].[Order] 
(
	[OrderLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[OrderCancellation] Script Date: 2013-10-13 00:21z
A document used to cancel an entire Order.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[OrderCancellation](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [CancellationNote] [numeric](18,0) NOT NULL, /* 1..n BBIE Text ** The general reason for cancellation of the referenced order. */
  [OrderReference] [numeric](18,0) NOT NULL, /* 1..n ASBIE Order Reference ** A reference to the Order being cancelled. While multiple references are allowed, it is considered better practice to cancel only one Order in each Order Cancellation document. */
  [OriginatorDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to an originator document associated with this document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Contract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** A contract associated with the original Order(s). */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [BuyerCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The seller. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The originator. */
 CONSTRAINT [PK_OrderCancellation] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_UBLVersionID] ON [dbo].[OrderCancellation] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_CustomizationID] ON [dbo].[OrderCancellation] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_ProfileID] ON [dbo].[OrderCancellation] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_ProfileExecutionID] ON [dbo].[OrderCancellation] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_ID] ON [dbo].[OrderCancellation] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_CopyIndicator] ON [dbo].[OrderCancellation] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_UUID] ON [dbo].[OrderCancellation] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_IssueDate] ON [dbo].[OrderCancellation] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_IssueTime] ON [dbo].[OrderCancellation] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_Note] ON [dbo].[OrderCancellation] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_CancellationNote] ON [dbo].[OrderCancellation] 
(
	[CancellationNote] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_OrderReference] ON [dbo].[OrderCancellation] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_OriginatorDocumentReference] ON [dbo].[OrderCancellation] 
(
	[OriginatorDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_AdditionalDocumentReference] ON [dbo].[OrderCancellation] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_Contract] ON [dbo].[OrderCancellation] 
(
	[Contract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_Signature] ON [dbo].[OrderCancellation] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_BuyerCustomerParty] ON [dbo].[OrderCancellation] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_SellerSupplierParty] ON [dbo].[OrderCancellation] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderCancellation_OriginatorCustomerParty] ON [dbo].[OrderCancellation] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[OrderChange] Script Date: 2013-10-13 00:21z
A document used to specify changes to an existing Order.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[OrderChange](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [SalesOrderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the Order Change, assigned by the seller. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [SequenceNumberID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** The Order Change Sequence Number assigned by the Buyer to ensure the proper sequencing of changes. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [RequestedInvoiceCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying he currency requested for amount totals in Invoices related to this Order Change. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency that is used for all prices in the Order Change. */
  [TaxCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency requested for tax amounts in Invoices related to this Order Change. */
  [CustomerReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A supplementary reference for the transaction (e.g., CRI when using purchasing card). */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting code, applied to the Order Change as a whole. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting code, applied to the Order Change as a whole, expressed as text. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Order Change lines in the document. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period during which the Order Change is valid. */
  [OrderReference] [numeric](18,0) NOT NULL, /* 1 ASBIE Order Reference ** A reference to the Order being changed. */
  [QuotationDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a Quotation. */
  [OriginatorDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to an originator document associated with this document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Contract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** A contract associated with the Order being changed. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [BuyerCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The seller. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The originator. */
  [FreightForwarderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A freight forwarder or carrier. */
  [AccountingCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The accounting customer party. */
  [AccountingSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The accounting supplier party. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this document. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery Terms ** A set of delivery terms associated with this document. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..n ASBIE Payment Means ** Expected means of payment. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A set of payment terms associated with this document. */
  [TransactionConditions] [numeric](18,0) NULL, /* 0..1 ASBIE Transaction Conditions ** Purchasing, sales, or payment conditions applying to the whole Order being changed. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [TaxExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the tax currency. */
  [PricingExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the pricing currency. */
  [PaymentExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment currency. */
  [DestinationCountry] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country of destination (for customs purposes). */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [AnticipatedMonetaryTotal] [numeric](18,0) NULL, /* 0..1 ASBIE Monetary Total ** The amount of change to the total cost of the order anticipated by the buyer. */
  [OrderLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Order Line ** An association to one or more (changed) Order Lines. */
 CONSTRAINT [PK_OrderChange] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_UBLVersionID] ON [dbo].[OrderChange] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_CustomizationID] ON [dbo].[OrderChange] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_ProfileID] ON [dbo].[OrderChange] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_ProfileExecutionID] ON [dbo].[OrderChange] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_ID] ON [dbo].[OrderChange] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_SalesOrderID] ON [dbo].[OrderChange] 
(
	[SalesOrderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_CopyIndicator] ON [dbo].[OrderChange] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_UUID] ON [dbo].[OrderChange] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_IssueDate] ON [dbo].[OrderChange] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_IssueTime] ON [dbo].[OrderChange] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_SequenceNumberID] ON [dbo].[OrderChange] 
(
	[SequenceNumberID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_Note] ON [dbo].[OrderChange] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_RequestedInvoiceCurrencyCode] ON [dbo].[OrderChange] 
(
	[RequestedInvoiceCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_DocumentCurrencyCode] ON [dbo].[OrderChange] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_PricingCurrencyCode] ON [dbo].[OrderChange] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_TaxCurrencyCode] ON [dbo].[OrderChange] 
(
	[TaxCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_CustomerReference] ON [dbo].[OrderChange] 
(
	[CustomerReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_AccountingCostCode] ON [dbo].[OrderChange] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_AccountingCost] ON [dbo].[OrderChange] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_LineCountNumeric] ON [dbo].[OrderChange] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_ValidityPeriod] ON [dbo].[OrderChange] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_OrderReference] ON [dbo].[OrderChange] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_QuotationDocumentReference] ON [dbo].[OrderChange] 
(
	[QuotationDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_OriginatorDocumentReference] ON [dbo].[OrderChange] 
(
	[OriginatorDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_AdditionalDocumentReference] ON [dbo].[OrderChange] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_Contract] ON [dbo].[OrderChange] 
(
	[Contract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_Signature] ON [dbo].[OrderChange] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_BuyerCustomerParty] ON [dbo].[OrderChange] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_SellerSupplierParty] ON [dbo].[OrderChange] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_OriginatorCustomerParty] ON [dbo].[OrderChange] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_FreightForwarderParty] ON [dbo].[OrderChange] 
(
	[FreightForwarderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_AccountingCustomerParty] ON [dbo].[OrderChange] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_AccountingSupplierParty] ON [dbo].[OrderChange] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_Delivery] ON [dbo].[OrderChange] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_DeliveryTerms] ON [dbo].[OrderChange] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_PaymentMeans] ON [dbo].[OrderChange] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_PaymentTerms] ON [dbo].[OrderChange] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_TransactionConditions] ON [dbo].[OrderChange] 
(
	[TransactionConditions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_AllowanceCharge] ON [dbo].[OrderChange] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_TaxExchangeRate] ON [dbo].[OrderChange] 
(
	[TaxExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_PricingExchangeRate] ON [dbo].[OrderChange] 
(
	[PricingExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_PaymentExchangeRate] ON [dbo].[OrderChange] 
(
	[PaymentExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_DestinationCountry] ON [dbo].[OrderChange] 
(
	[DestinationCountry] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_TaxTotal] ON [dbo].[OrderChange] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_AnticipatedMonetaryTotal] ON [dbo].[OrderChange] 
(
	[AnticipatedMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderChange_OrderLine] ON [dbo].[OrderChange] 
(
	[OrderLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[OrderResponse] Script Date: 2013-10-13 00:21z
A document used to indicate detailed acceptance or rejection of an Order or to make a counter-offer.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[OrderResponse](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [SalesOrderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the Order, issued by the Seller. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [OrderResponseCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of response for this Order. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency that is used for all prices in the Order Response. */
  [TaxCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency that is used for all tax amounts in the Order Response. */
  [TotalPackagesQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total number of packages contained in the Order Response. */
  [GrossWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total gross weight for the Order Response (goods + packaging + transport equipment). */
  [NetWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total net weight for the Order Response (goods + packaging). */
  [NetNetWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total net weight of the goods in the Order Response excluding packaging. */
  [GrossVolumeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total volume of the goods in the Order Response including packaging. */
  [NetVolumeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total volume of the goods in the Order Response excluding packaging. */
  [CustomerReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A supplementary reference assigned by the buyer, e.g., the CRI in a purchasing card transaction. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** An accounting cost code applied to the order as a whole. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An accounting cost code applied to the order as a whole, expressed as text. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Order Lines in this document. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** The period for which the Order Response is valid. */
  [OrderReference] [numeric](18,0) NOT NULL, /* 1..n ASBIE Order Reference ** A reference to the Order being responded to. */
  [OrderDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an Order other than the one being responded to. */
  [OriginatorDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to an originator document associated with this document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Contract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** A contract associated with the Order being responded to. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SellerSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The seller. */
  [BuyerCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The buyer. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The originator. */
  [FreightForwarderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A freight forwarder or carrier. */
  [AccountingSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The accounting supplier party. */
  [AccountingCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The accounting customer party. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this document. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery Terms ** A set of delivery terms associated with this document. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..n ASBIE Payment Means ** Expected means of payment. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A set of payment terms associated with this document. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [TransactionConditions] [numeric](18,0) NULL, /* 0..1 ASBIE Transaction Conditions ** A specification of purchasing or sales conditions applying to the whole Order. */
  [TaxExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the tax currency. */
  [PricingExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the pricing currency. */
  [PaymentExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment currency. */
  [DestinationCountry] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country of destination (for customs purposes). */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax, as calculated by the seller. */
  [LegalMonetaryTotal] [numeric](18,0) NULL, /* 0..1 ASBIE Monetary Total ** The total amount of the Order (or counter-offer). */
  [OrderLine] [numeric](18,0) NULL, /* 0..n ASBIE Order Line ** A line associated with a line in the Catalogue and specifying a kind of item being ordered. */
 CONSTRAINT [PK_OrderResponse] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_UBLVersionID] ON [dbo].[OrderResponse] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_CustomizationID] ON [dbo].[OrderResponse] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_ProfileID] ON [dbo].[OrderResponse] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_ProfileExecutionID] ON [dbo].[OrderResponse] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_ID] ON [dbo].[OrderResponse] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_SalesOrderID] ON [dbo].[OrderResponse] 
(
	[SalesOrderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_CopyIndicator] ON [dbo].[OrderResponse] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_UUID] ON [dbo].[OrderResponse] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_IssueDate] ON [dbo].[OrderResponse] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_IssueTime] ON [dbo].[OrderResponse] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_OrderResponseCode] ON [dbo].[OrderResponse] 
(
	[OrderResponseCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_Note] ON [dbo].[OrderResponse] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_DocumentCurrencyCode] ON [dbo].[OrderResponse] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_PricingCurrencyCode] ON [dbo].[OrderResponse] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_TaxCurrencyCode] ON [dbo].[OrderResponse] 
(
	[TaxCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_TotalPackagesQuantity] ON [dbo].[OrderResponse] 
(
	[TotalPackagesQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_GrossWeightMeasure] ON [dbo].[OrderResponse] 
(
	[GrossWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_NetWeightMeasure] ON [dbo].[OrderResponse] 
(
	[NetWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_NetNetWeightMeasure] ON [dbo].[OrderResponse] 
(
	[NetNetWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_GrossVolumeMeasure] ON [dbo].[OrderResponse] 
(
	[GrossVolumeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_NetVolumeMeasure] ON [dbo].[OrderResponse] 
(
	[NetVolumeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_CustomerReference] ON [dbo].[OrderResponse] 
(
	[CustomerReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_AccountingCostCode] ON [dbo].[OrderResponse] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_AccountingCost] ON [dbo].[OrderResponse] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_LineCountNumeric] ON [dbo].[OrderResponse] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_ValidityPeriod] ON [dbo].[OrderResponse] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_OrderReference] ON [dbo].[OrderResponse] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_OrderDocumentReference] ON [dbo].[OrderResponse] 
(
	[OrderDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_OriginatorDocumentReference] ON [dbo].[OrderResponse] 
(
	[OriginatorDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_AdditionalDocumentReference] ON [dbo].[OrderResponse] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_Contract] ON [dbo].[OrderResponse] 
(
	[Contract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_Signature] ON [dbo].[OrderResponse] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_SellerSupplierParty] ON [dbo].[OrderResponse] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_BuyerCustomerParty] ON [dbo].[OrderResponse] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_OriginatorCustomerParty] ON [dbo].[OrderResponse] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_FreightForwarderParty] ON [dbo].[OrderResponse] 
(
	[FreightForwarderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_AccountingSupplierParty] ON [dbo].[OrderResponse] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_AccountingCustomerParty] ON [dbo].[OrderResponse] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_Delivery] ON [dbo].[OrderResponse] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_DeliveryTerms] ON [dbo].[OrderResponse] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_PaymentMeans] ON [dbo].[OrderResponse] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_PaymentTerms] ON [dbo].[OrderResponse] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_AllowanceCharge] ON [dbo].[OrderResponse] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_TransactionConditions] ON [dbo].[OrderResponse] 
(
	[TransactionConditions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_TaxExchangeRate] ON [dbo].[OrderResponse] 
(
	[TaxExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_PricingExchangeRate] ON [dbo].[OrderResponse] 
(
	[PricingExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_PaymentExchangeRate] ON [dbo].[OrderResponse] 
(
	[PaymentExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_DestinationCountry] ON [dbo].[OrderResponse] 
(
	[DestinationCountry] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_TaxTotal] ON [dbo].[OrderResponse] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_LegalMonetaryTotal] ON [dbo].[OrderResponse] 
(
	[LegalMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponse_OrderLine] ON [dbo].[OrderResponse] 
(
	[OrderLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[OrderResponseSimple] Script Date: 2013-10-13 00:21z
A document used to indicate simple acceptance or rejection of an entire Order.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[OrderResponseSimple](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [AcceptedIndicator] [numeric](18,0) NOT NULL, /* 1 BBIE Indicator ** Indicates whether the Order is accepted (true) or rejected (false). */
  [RejectionNote] [numeric](18,0) NULL, /* 0..n BBIE Text ** The reason for rejection if the order was not accepted. */
  [CustomerReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A supplementary reference for the transaction (e.g., when using a purchasing card). */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** An accounting cost code applied to the order as a whole. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An accounting cost code applied to the order as a whole, expressed as text. */
  [OrderReference] [numeric](18,0) NOT NULL, /* 1 ASBIE Order Reference ** A reference to the Order being responded to. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SellerSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The seller. */
  [BuyerCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The buyer. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The originator. */
  [AccountingSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The accounting supplier party. */
  [AccountingCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The accounting customer party. */
 CONSTRAINT [PK_OrderResponseSimple] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_UBLVersionID] ON [dbo].[OrderResponseSimple] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_CustomizationID] ON [dbo].[OrderResponseSimple] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_ProfileID] ON [dbo].[OrderResponseSimple] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_ProfileExecutionID] ON [dbo].[OrderResponseSimple] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_ID] ON [dbo].[OrderResponseSimple] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_CopyIndicator] ON [dbo].[OrderResponseSimple] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_UUID] ON [dbo].[OrderResponseSimple] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_IssueDate] ON [dbo].[OrderResponseSimple] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_IssueTime] ON [dbo].[OrderResponseSimple] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_Note] ON [dbo].[OrderResponseSimple] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_AcceptedIndicator] ON [dbo].[OrderResponseSimple] 
(
	[AcceptedIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_RejectionNote] ON [dbo].[OrderResponseSimple] 
(
	[RejectionNote] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_CustomerReference] ON [dbo].[OrderResponseSimple] 
(
	[CustomerReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_AccountingCostCode] ON [dbo].[OrderResponseSimple] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_AccountingCost] ON [dbo].[OrderResponseSimple] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_OrderReference] ON [dbo].[OrderResponseSimple] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_AdditionalDocumentReference] ON [dbo].[OrderResponseSimple] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_Signature] ON [dbo].[OrderResponseSimple] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_SellerSupplierParty] ON [dbo].[OrderResponseSimple] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_BuyerCustomerParty] ON [dbo].[OrderResponseSimple] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_OriginatorCustomerParty] ON [dbo].[OrderResponseSimple] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_AccountingSupplierParty] ON [dbo].[OrderResponseSimple] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderResponseSimple_AccountingCustomerParty] ON [dbo].[OrderResponseSimple] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PackingList] Script Date: 2013-10-13 00:21z
A document describing how goods are packed.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PackingList](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the subset of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document.. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Text, assigned by the sender, that identifies this document to business users. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Textual description of the document instance. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Version identifier of a Packing List. */
  [OtherInstruction] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Contains other free-text-based instructions related to the shipment to the forwarders or carriers. This should only be used where such information cannot be represented in other structured information entities within the document. */
  [ConsignorParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party consigning goods, as stipulated in the transport contract by the party ordering transport. */
  [CarrierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party providing the transport of goods between named points. */
  [FreightForwarderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party combining individual smaller shipments into a single larger consignment (a so-called consolidated consignment) that is sent to a counterpart who mirrors the consolidator's activity by dividing the consolidated consignment into its original components. */
  [Shipment] [numeric](18,0) NOT NULL, /* 1 ASBIE Shipment ** A description of the shipment. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [DocumentDistribution] [numeric](18,0) NULL, /* 0..n ASBIE Document Distribution ** A list of interested parties to whom this document is distributed. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
 CONSTRAINT [PK_PackingList] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_UBLVersionID] ON [dbo].[PackingList] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_CustomizationID] ON [dbo].[PackingList] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_ProfileID] ON [dbo].[PackingList] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_ProfileExecutionID] ON [dbo].[PackingList] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_ID] ON [dbo].[PackingList] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_UUID] ON [dbo].[PackingList] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_IssueDate] ON [dbo].[PackingList] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_IssueTime] ON [dbo].[PackingList] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_Name] ON [dbo].[PackingList] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_Description] ON [dbo].[PackingList] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_Note] ON [dbo].[PackingList] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_VersionID] ON [dbo].[PackingList] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_OtherInstruction] ON [dbo].[PackingList] 
(
	[OtherInstruction] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_ConsignorParty] ON [dbo].[PackingList] 
(
	[ConsignorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_CarrierParty] ON [dbo].[PackingList] 
(
	[CarrierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_FreightForwarderParty] ON [dbo].[PackingList] 
(
	[FreightForwarderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_Shipment] ON [dbo].[PackingList] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_DocumentReference] ON [dbo].[PackingList] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_DocumentDistribution] ON [dbo].[PackingList] 
(
	[DocumentDistribution] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PackingList_Signature] ON [dbo].[PackingList] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PriorInformationNotice] Script Date: 2013-10-13 00:21z
A document used by a contracting party to declare the intention to buy goods, services, or works during a specified period.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PriorInformationNotice](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [ContractFolderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier, assigned by the sender, for the process file (i.e., record) to which this document belongs. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [PlannedDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date planned by the Contracting Party for publication of the contract notice. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [ContractingParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Contracting Party ** The contracting party. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..n ASBIE Customer Party ** A party who originated the tendering process. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving this document. */
  [TenderingTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Tendering Terms ** The tendering terms associated with this tendering process. */
  [TenderingProcess] [numeric](18,0) NULL, /* 0..1 ASBIE Tendering Process ** A description of the tendering process itself. */
  [ProcurementProject] [numeric](18,0) NULL, /* 0..1 ASBIE Procurement Project ** An overall definition of this procurement project. */
  [ProcurementProjectLot] [numeric](18,0) NULL, /* 0..n ASBIE Procurement Project Lot ** One of the procurement project lots into which this contract can be split. */
 CONSTRAINT [PK_PriorInformationNotice] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_UBLVersionID] ON [dbo].[PriorInformationNotice] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_CustomizationID] ON [dbo].[PriorInformationNotice] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_ProfileID] ON [dbo].[PriorInformationNotice] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_ProfileExecutionID] ON [dbo].[PriorInformationNotice] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_ID] ON [dbo].[PriorInformationNotice] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_CopyIndicator] ON [dbo].[PriorInformationNotice] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_UUID] ON [dbo].[PriorInformationNotice] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_ContractFolderID] ON [dbo].[PriorInformationNotice] 
(
	[ContractFolderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_IssueDate] ON [dbo].[PriorInformationNotice] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_IssueTime] ON [dbo].[PriorInformationNotice] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_Note] ON [dbo].[PriorInformationNotice] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_PlannedDate] ON [dbo].[PriorInformationNotice] 
(
	[PlannedDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_DocumentReference] ON [dbo].[PriorInformationNotice] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_Signature] ON [dbo].[PriorInformationNotice] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_ContractingParty] ON [dbo].[PriorInformationNotice] 
(
	[ContractingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_OriginatorCustomerParty] ON [dbo].[PriorInformationNotice] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_ReceiverParty] ON [dbo].[PriorInformationNotice] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_TenderingTerms] ON [dbo].[PriorInformationNotice] 
(
	[TenderingTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_TenderingProcess] ON [dbo].[PriorInformationNotice] 
(
	[TenderingProcess] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_ProcurementProject] ON [dbo].[PriorInformationNotice] 
(
	[ProcurementProject] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriorInformationNotice_ProcurementProjectLot] ON [dbo].[PriorInformationNotice] 
(
	[ProcurementProjectLot] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ProductActivity] Script Date: 2013-10-13 00:21z
A document reporting the movement of goods at specified retail locations for inventory tracking purposes.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ProductActivity](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [ActivityPeriod] [numeric](18,0) NOT NULL, /* 1 ASBIE Period ** The period covered by this Product Activity report. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The sender of the Product Activity. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The receiver of the Product Activity. */
  [SupplyChainActivityDataLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Activity Data Line ** A line describing the movement of goods to a specific location. */
 CONSTRAINT [PK_ProductActivity] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_UBLVersionID] ON [dbo].[ProductActivity] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_CustomizationID] ON [dbo].[ProductActivity] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_ProfileID] ON [dbo].[ProductActivity] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_ProfileExecutionID] ON [dbo].[ProductActivity] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_ID] ON [dbo].[ProductActivity] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_CopyIndicator] ON [dbo].[ProductActivity] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_UUID] ON [dbo].[ProductActivity] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_IssueDate] ON [dbo].[ProductActivity] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_IssueTime] ON [dbo].[ProductActivity] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_Note] ON [dbo].[ProductActivity] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_DocumentCurrencyCode] ON [dbo].[ProductActivity] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_ActivityPeriod] ON [dbo].[ProductActivity] 
(
	[ActivityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_DocumentReference] ON [dbo].[ProductActivity] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_Signature] ON [dbo].[ProductActivity] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_SenderParty] ON [dbo].[ProductActivity] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_ReceiverParty] ON [dbo].[ProductActivity] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProductActivity_SupplyChainActivityDataLine] ON [dbo].[ProductActivity] 
(
	[SupplyChainActivityDataLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Quotation] Script Date: 2013-10-13 00:21z
A document used to quote for the provision of goods and services.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Quotation](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the subset of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for all prices in the Quotation. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Quotation Lines in this document. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period for which the Quotation is valid. */
  [RequestForQuotationDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the Request for Quotation associated with this Quotation. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Contract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** A contract associated with this Quotation. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SellerSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The seller. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** Association to the Buyer. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The originator. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this document. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery Terms ** A set of delivery terms associated with this document. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Means ** Expected means of payment. */
  [TransactionConditions] [numeric](18,0) NULL, /* 0..1 ASBIE Transaction Conditions ** A specification of purchasing, sales, or payment conditions applying to Orders related to this Quotation. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [DestinationCountry] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country of destination of potential orders (for customs purposes). */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [QuotedMonetaryTotal] [numeric](18,0) NOT NULL, /* 1 ASBIE Monetary Total ** The total amount of the Quotation. */
  [QuotationLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Quotation Line ** A line quoting a cost for one kind of item. */
 CONSTRAINT [PK_Quotation] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_UBLVersionID] ON [dbo].[Quotation] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_CustomizationID] ON [dbo].[Quotation] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_ProfileID] ON [dbo].[Quotation] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_ProfileExecutionID] ON [dbo].[Quotation] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_ID] ON [dbo].[Quotation] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_CopyIndicator] ON [dbo].[Quotation] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_UUID] ON [dbo].[Quotation] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_IssueDate] ON [dbo].[Quotation] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_IssueTime] ON [dbo].[Quotation] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_Note] ON [dbo].[Quotation] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_PricingCurrencyCode] ON [dbo].[Quotation] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_LineCountNumeric] ON [dbo].[Quotation] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_ValidityPeriod] ON [dbo].[Quotation] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_RequestForQuotationDocumentReference] ON [dbo].[Quotation] 
(
	[RequestForQuotationDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_AdditionalDocumentReference] ON [dbo].[Quotation] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_Contract] ON [dbo].[Quotation] 
(
	[Contract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_Signature] ON [dbo].[Quotation] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_SellerSupplierParty] ON [dbo].[Quotation] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_BuyerCustomerParty] ON [dbo].[Quotation] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_OriginatorCustomerParty] ON [dbo].[Quotation] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_Delivery] ON [dbo].[Quotation] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_DeliveryTerms] ON [dbo].[Quotation] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_PaymentMeans] ON [dbo].[Quotation] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_TransactionConditions] ON [dbo].[Quotation] 
(
	[TransactionConditions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_AllowanceCharge] ON [dbo].[Quotation] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_DestinationCountry] ON [dbo].[Quotation] 
(
	[DestinationCountry] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_TaxTotal] ON [dbo].[Quotation] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_QuotedMonetaryTotal] ON [dbo].[Quotation] 
(
	[QuotedMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Quotation_QuotationLine] ON [dbo].[Quotation] 
(
	[QuotationLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ReceiptAdvice] Script Date: 2013-10-13 00:21z
A document used to describe the receipt of goods and services.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ReceiptAdvice](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the subset of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [DocumentStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of the Receipt Advice with respect to its original state. This code may be used if the document precedes the event and is subsequently found to be incorrect and in need of cancellation or revision. */
  [ReceiptAdviceTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of the Receipt Advice. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Receipt Lines in this document. */
  [OrderReference] [numeric](18,0) NULL, /* 0..n ASBIE Order Reference ** A reference to an Order associated with this Receipt Advice. */
  [DespatchDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Despatch Advice associated with this document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [DeliveryCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The customer party. */
  [DespatchSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The supplier party. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [Shipment] [numeric](18,0) NULL, /* 0..1 ASBIE Shipment ** Details about the Shipment. */
  [ReceiptLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Receipt Line ** A line detailing a kind of item received. */
 CONSTRAINT [PK_ReceiptAdvice] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_UBLVersionID] ON [dbo].[ReceiptAdvice] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_CustomizationID] ON [dbo].[ReceiptAdvice] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_ProfileID] ON [dbo].[ReceiptAdvice] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_ProfileExecutionID] ON [dbo].[ReceiptAdvice] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_ID] ON [dbo].[ReceiptAdvice] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_CopyIndicator] ON [dbo].[ReceiptAdvice] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_UUID] ON [dbo].[ReceiptAdvice] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_IssueDate] ON [dbo].[ReceiptAdvice] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_IssueTime] ON [dbo].[ReceiptAdvice] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_DocumentStatusCode] ON [dbo].[ReceiptAdvice] 
(
	[DocumentStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_ReceiptAdviceTypeCode] ON [dbo].[ReceiptAdvice] 
(
	[ReceiptAdviceTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_Note] ON [dbo].[ReceiptAdvice] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_LineCountNumeric] ON [dbo].[ReceiptAdvice] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_OrderReference] ON [dbo].[ReceiptAdvice] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_DespatchDocumentReference] ON [dbo].[ReceiptAdvice] 
(
	[DespatchDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_AdditionalDocumentReference] ON [dbo].[ReceiptAdvice] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_Signature] ON [dbo].[ReceiptAdvice] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_DeliveryCustomerParty] ON [dbo].[ReceiptAdvice] 
(
	[DeliveryCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_DespatchSupplierParty] ON [dbo].[ReceiptAdvice] 
(
	[DespatchSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_BuyerCustomerParty] ON [dbo].[ReceiptAdvice] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_SellerSupplierParty] ON [dbo].[ReceiptAdvice] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_Shipment] ON [dbo].[ReceiptAdvice] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptAdvice_ReceiptLine] ON [dbo].[ReceiptAdvice] 
(
	[ReceiptLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Reminder] Script Date: 2013-10-13 00:21z
A document used to remind a customer of payments past due.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Reminder](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [ReminderTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of the Reminder. */
  [ReminderSequenceNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of the current Reminder in the sequence of reminders relating to the specified payments; the number of reminders previously sent plus one. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [TaxPointDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of the Reminder, used to indicate the point at which tax becomes applicable. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [TaxCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for tax amounts in the Reminder. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for prices in the Reminder. */
  [PaymentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for payment in the Reminder. */
  [PaymentAlternativeCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the alternative currency used for payment in the Reminder. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting code, applied to the Reminder as a whole. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting code, applied to the Reminder as a whole, expressed as text. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Reminder Lines in this document. */
  [ReminderPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** The periods to which the Reminder applies. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [AccountingSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The accounting supplier party. */
  [AccountingCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The accounting customer party. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payee. */
  [TaxRepresentativeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The tax representative. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..n ASBIE Payment Means ** Expected means of payment. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A set of payment terms associated with this document. */
  [PrepaidPayment] [numeric](18,0) NULL, /* 0..n ASBIE Payment ** A prepaid payment. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [TaxExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the tax currency. */
  [PricingExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the pricing currency. */
  [PaymentExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment currency. */
  [PaymentAlternativeExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment alternative currency. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [LegalMonetaryTotal] [numeric](18,0) NOT NULL, /* 1 ASBIE Monetary Total ** The total amount payable on the Invoice, including Allowances, Charges, and Taxes. */
  [ReminderLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Reminder Line ** A line describing a payment past due. */
 CONSTRAINT [PK_Reminder] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_UBLVersionID] ON [dbo].[Reminder] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_CustomizationID] ON [dbo].[Reminder] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_ProfileID] ON [dbo].[Reminder] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_ProfileExecutionID] ON [dbo].[Reminder] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_ID] ON [dbo].[Reminder] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_CopyIndicator] ON [dbo].[Reminder] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_UUID] ON [dbo].[Reminder] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_IssueDate] ON [dbo].[Reminder] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_IssueTime] ON [dbo].[Reminder] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_ReminderTypeCode] ON [dbo].[Reminder] 
(
	[ReminderTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_ReminderSequenceNumeric] ON [dbo].[Reminder] 
(
	[ReminderSequenceNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_Note] ON [dbo].[Reminder] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_TaxPointDate] ON [dbo].[Reminder] 
(
	[TaxPointDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_DocumentCurrencyCode] ON [dbo].[Reminder] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_TaxCurrencyCode] ON [dbo].[Reminder] 
(
	[TaxCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_PricingCurrencyCode] ON [dbo].[Reminder] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_PaymentCurrencyCode] ON [dbo].[Reminder] 
(
	[PaymentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_PaymentAlternativeCurrencyCode] ON [dbo].[Reminder] 
(
	[PaymentAlternativeCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_AccountingCostCode] ON [dbo].[Reminder] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_AccountingCost] ON [dbo].[Reminder] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_LineCountNumeric] ON [dbo].[Reminder] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_ReminderPeriod] ON [dbo].[Reminder] 
(
	[ReminderPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_AdditionalDocumentReference] ON [dbo].[Reminder] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_Signature] ON [dbo].[Reminder] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_AccountingSupplierParty] ON [dbo].[Reminder] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_AccountingCustomerParty] ON [dbo].[Reminder] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_PayeeParty] ON [dbo].[Reminder] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_TaxRepresentativeParty] ON [dbo].[Reminder] 
(
	[TaxRepresentativeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_PaymentMeans] ON [dbo].[Reminder] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_PaymentTerms] ON [dbo].[Reminder] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_PrepaidPayment] ON [dbo].[Reminder] 
(
	[PrepaidPayment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_AllowanceCharge] ON [dbo].[Reminder] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_TaxExchangeRate] ON [dbo].[Reminder] 
(
	[TaxExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_PricingExchangeRate] ON [dbo].[Reminder] 
(
	[PricingExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_PaymentExchangeRate] ON [dbo].[Reminder] 
(
	[PaymentExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_PaymentAlternativeExchangeRate] ON [dbo].[Reminder] 
(
	[PaymentAlternativeExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_TaxTotal] ON [dbo].[Reminder] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_LegalMonetaryTotal] ON [dbo].[Reminder] 
(
	[LegalMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Reminder_ReminderLine] ON [dbo].[Reminder] 
(
	[ReminderLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[RemittanceAdvice] Script Date: 2013-10-13 00:21z
A document that specifies details of an actual payment.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RemittanceAdvice](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [TotalDebitAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The totals of all debit amounts for the Remittance Advice. */
  [TotalCreditAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The totals of all credit amounts for the Remittance Advice. */
  [TotalPaymentAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total payable amount for the Remittance Advice (must be positive). */
  [PaymentOrderReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An internal reference to the order for payment from the payer to the payer's bank. */
  [PayerReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An internal reference to the payer's order for payment. */
  [InvoicingPartyReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An internal reference to the order for payment by the invoicing party. This may have been requested of the payer by the payee to accompany the payer's remittance. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Remittance Advice Lines in the document. */
  [InvoicePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period (rather than a specific invoice) associated with this document. */
  [BillingReference] [numeric](18,0) NULL, /* 0..1 ASBIE Billing Reference ** A reference to a billing document associated with this document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [AccountingCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The accounting customer party. */
  [AccountingSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The accounting supplier party. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payee. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Means ** Expected means of payment. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [RemittanceAdviceLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Remittance Advice Line ** A line specifying a balance. */
 CONSTRAINT [PK_RemittanceAdvice] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_UBLVersionID] ON [dbo].[RemittanceAdvice] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_CustomizationID] ON [dbo].[RemittanceAdvice] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_ProfileID] ON [dbo].[RemittanceAdvice] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_ProfileExecutionID] ON [dbo].[RemittanceAdvice] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_ID] ON [dbo].[RemittanceAdvice] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_CopyIndicator] ON [dbo].[RemittanceAdvice] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_UUID] ON [dbo].[RemittanceAdvice] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_IssueDate] ON [dbo].[RemittanceAdvice] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_IssueTime] ON [dbo].[RemittanceAdvice] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_Note] ON [dbo].[RemittanceAdvice] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_DocumentCurrencyCode] ON [dbo].[RemittanceAdvice] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_TotalDebitAmount] ON [dbo].[RemittanceAdvice] 
(
	[TotalDebitAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_TotalCreditAmount] ON [dbo].[RemittanceAdvice] 
(
	[TotalCreditAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_TotalPaymentAmount] ON [dbo].[RemittanceAdvice] 
(
	[TotalPaymentAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_PaymentOrderReference] ON [dbo].[RemittanceAdvice] 
(
	[PaymentOrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_PayerReference] ON [dbo].[RemittanceAdvice] 
(
	[PayerReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_InvoicingPartyReference] ON [dbo].[RemittanceAdvice] 
(
	[InvoicingPartyReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_LineCountNumeric] ON [dbo].[RemittanceAdvice] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_InvoicePeriod] ON [dbo].[RemittanceAdvice] 
(
	[InvoicePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_BillingReference] ON [dbo].[RemittanceAdvice] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_AdditionalDocumentReference] ON [dbo].[RemittanceAdvice] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_Signature] ON [dbo].[RemittanceAdvice] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_AccountingCustomerParty] ON [dbo].[RemittanceAdvice] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_AccountingSupplierParty] ON [dbo].[RemittanceAdvice] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_PayeeParty] ON [dbo].[RemittanceAdvice] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_PaymentMeans] ON [dbo].[RemittanceAdvice] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_TaxTotal] ON [dbo].[RemittanceAdvice] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdvice_RemittanceAdviceLine] ON [dbo].[RemittanceAdvice] 
(
	[RemittanceAdviceLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[RequestForQuotation] Script Date: 2013-10-13 00:21z
A document used to request a Quotation for goods and services from a Seller.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RequestForQuotation](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NOT NULL, /* 1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [SubmissionDueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The due date for submission of the Quotation. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The currency that the Seller should use to price the Quotation. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Request For Quotation Lines in this document. */
  [RequestedValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The validity period requested for this Quotation. */
  [CatalogueDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** The Catalogue on which this Request for Quotation is based. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The originator. */
  [SellerSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The seller. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this document. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..n ASBIE Delivery Terms ** A set of delivery terms associated with this document. */
  [DestinationCountry] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country of destination of potential orders (for customs purposes). */
  [Contract] [numeric](18,0) NULL, /* 0..n ASBIE Contract ** A contract associated with this Request for Quotation.. */
  [RequestForQuotationLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Request For Quotation Line ** A line specifying a kind of item of sale. */
 CONSTRAINT [PK_RequestForQuotation] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_UBLVersionID] ON [dbo].[RequestForQuotation] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_CustomizationID] ON [dbo].[RequestForQuotation] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_ProfileID] ON [dbo].[RequestForQuotation] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_ProfileExecutionID] ON [dbo].[RequestForQuotation] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_ID] ON [dbo].[RequestForQuotation] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_CopyIndicator] ON [dbo].[RequestForQuotation] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_UUID] ON [dbo].[RequestForQuotation] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_IssueDate] ON [dbo].[RequestForQuotation] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_IssueTime] ON [dbo].[RequestForQuotation] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_SubmissionDueDate] ON [dbo].[RequestForQuotation] 
(
	[SubmissionDueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_Note] ON [dbo].[RequestForQuotation] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_PricingCurrencyCode] ON [dbo].[RequestForQuotation] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_LineCountNumeric] ON [dbo].[RequestForQuotation] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_RequestedValidityPeriod] ON [dbo].[RequestForQuotation] 
(
	[RequestedValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_CatalogueDocumentReference] ON [dbo].[RequestForQuotation] 
(
	[CatalogueDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_AdditionalDocumentReference] ON [dbo].[RequestForQuotation] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_Signature] ON [dbo].[RequestForQuotation] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_OriginatorCustomerParty] ON [dbo].[RequestForQuotation] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_SellerSupplierParty] ON [dbo].[RequestForQuotation] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_BuyerCustomerParty] ON [dbo].[RequestForQuotation] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_Delivery] ON [dbo].[RequestForQuotation] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_DeliveryTerms] ON [dbo].[RequestForQuotation] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_DestinationCountry] ON [dbo].[RequestForQuotation] 
(
	[DestinationCountry] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_Contract] ON [dbo].[RequestForQuotation] 
(
	[Contract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotation_RequestForQuotationLine] ON [dbo].[RequestForQuotation] 
(
	[RequestForQuotationLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[RetailEvent] Script Date: 2013-10-13 00:21z
A document used to specify basic information about retail events (such as promotions, product introductions, and community or environmental events) that affect supply or demand.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RetailEvent](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [RetailEventName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** A title, theme, slogan, or other identifier for the event for use by trading partners. */
  [RetailEventStatusCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** Describes the logical state of the discrete activity affecting supply or demand in the supply chain */
  [SellerEventID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An event tracking identifier assigned by the seller. */
  [BuyerEventID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An event tracking identifier assigned by the buyer. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Definition of the discrete activity affecting supply or demand in the supply chain */
  [Period] [numeric](18,0) NOT NULL, /* 1 ASBIE Period ** The period during which the event takes place. */
  [OriginalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Forecast document associated with this event. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this document. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [EventComment] [numeric](18,0) NULL, /* 0..n ASBIE Event Comment ** A comment regarding the event. */
  [PromotionalEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Promotional Event ** The description of a promotional event associated with this event. */
  [MiscellaneousEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Miscellaneous Event ** A miscellaneous event associated with this event. */
 CONSTRAINT [PK_RetailEvent] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_UBLVersionID] ON [dbo].[RetailEvent] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_CustomizationID] ON [dbo].[RetailEvent] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_ProfileID] ON [dbo].[RetailEvent] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_ProfileExecutionID] ON [dbo].[RetailEvent] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_ID] ON [dbo].[RetailEvent] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_CopyIndicator] ON [dbo].[RetailEvent] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_UUID] ON [dbo].[RetailEvent] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_IssueDate] ON [dbo].[RetailEvent] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_IssueTime] ON [dbo].[RetailEvent] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_Note] ON [dbo].[RetailEvent] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_RetailEventName] ON [dbo].[RetailEvent] 
(
	[RetailEventName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_RetailEventStatusCode] ON [dbo].[RetailEvent] 
(
	[RetailEventStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_SellerEventID] ON [dbo].[RetailEvent] 
(
	[SellerEventID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_BuyerEventID] ON [dbo].[RetailEvent] 
(
	[BuyerEventID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_Description] ON [dbo].[RetailEvent] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_Period] ON [dbo].[RetailEvent] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_OriginalDocumentReference] ON [dbo].[RetailEvent] 
(
	[OriginalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_Signature] ON [dbo].[RetailEvent] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_SenderParty] ON [dbo].[RetailEvent] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_ReceiverParty] ON [dbo].[RetailEvent] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_BuyerCustomerParty] ON [dbo].[RetailEvent] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_SellerSupplierParty] ON [dbo].[RetailEvent] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_EventComment] ON [dbo].[RetailEvent] 
(
	[EventComment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_PromotionalEvent] ON [dbo].[RetailEvent] 
(
	[PromotionalEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailEvent_MiscellaneousEvent] ON [dbo].[RetailEvent] 
(
	[MiscellaneousEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[SelfBilledCreditNote] Script Date: 2013-10-13 00:21z
A credit note created by the debtor in a self billing arrangement with a creditor; Self Billed Credit Note replaces Debit Note in such arrangements.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[SelfBilledCreditNote](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [TaxPointDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of the Self Billed Credit Note, used to indicate the point at which tax becomes applicable. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentCurrencyCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the default currency for this document. */
  [TaxCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for tax amounts in the Self Billed Credit Note. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for prices in the Self Billed Credit Note. */
  [PaymentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for payment in the Self Billed Credit Note. */
  [PaymentAlternativeCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the alternative currency used for payment in the Self Billed Credit Note. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting code, applied to the Self Billed Credit Note as a whole. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting code, applied to the Self Billed Credit Note as a whole, expressed as text. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Self Billed Credit Note Lines in this document. */
  [InvoicePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period (rather than a specific Invoice) associated with the Self Billed Credit Note. */
  [DiscrepancyResponse] [numeric](18,0) NULL, /* 0..n ASBIE Response ** A reason for the Self Billed Credit Note as a whole. */
  [OrderReference] [numeric](18,0) NULL, /* 0..1 ASBIE Order Reference ** The Order associated with this Self Billed Credit Note. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this document. */
  [DespatchDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Despatch Advice associated with this document. */
  [ReceiptDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Receipt Advice associated with this document. */
  [ContractDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a contract associated with this document. */
  [StatementDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Statement associated with this document. */
  [OriginatorDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an originator document associated with this document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [AccountingCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The accounting customer party. */
  [AccountingSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The accounting supplier party. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payee. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [TaxRepresentativeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The tax representative. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this document. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..n ASBIE Delivery Terms ** A set of delivery terms associated with this document. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..n ASBIE Payment Means ** Expected means of payment. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A set of payment terms associated with this document. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [TaxExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the tax currency. */
  [PricingExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the pricing currency. */
  [PaymentExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment currency. */
  [PaymentAlternativeExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment alternative currency. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [LegalMonetaryTotal] [numeric](18,0) NOT NULL, /* 1 ASBIE Monetary Total ** The total amount payable on the Self Billed Credit Note, including Allowances, Charges, and Taxes. */
  [CreditNoteLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Credit Note Line ** A Self Billed Credit Note Line. */
 CONSTRAINT [PK_SelfBilledCreditNote] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_UBLVersionID] ON [dbo].[SelfBilledCreditNote] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_CustomizationID] ON [dbo].[SelfBilledCreditNote] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_ProfileID] ON [dbo].[SelfBilledCreditNote] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_ProfileExecutionID] ON [dbo].[SelfBilledCreditNote] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_ID] ON [dbo].[SelfBilledCreditNote] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_CopyIndicator] ON [dbo].[SelfBilledCreditNote] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_UUID] ON [dbo].[SelfBilledCreditNote] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_IssueDate] ON [dbo].[SelfBilledCreditNote] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_IssueTime] ON [dbo].[SelfBilledCreditNote] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_TaxPointDate] ON [dbo].[SelfBilledCreditNote] 
(
	[TaxPointDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_Note] ON [dbo].[SelfBilledCreditNote] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_DocumentCurrencyCode] ON [dbo].[SelfBilledCreditNote] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_TaxCurrencyCode] ON [dbo].[SelfBilledCreditNote] 
(
	[TaxCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_PricingCurrencyCode] ON [dbo].[SelfBilledCreditNote] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_PaymentCurrencyCode] ON [dbo].[SelfBilledCreditNote] 
(
	[PaymentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_PaymentAlternativeCurrencyCode] ON [dbo].[SelfBilledCreditNote] 
(
	[PaymentAlternativeCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_AccountingCostCode] ON [dbo].[SelfBilledCreditNote] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_AccountingCost] ON [dbo].[SelfBilledCreditNote] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_LineCountNumeric] ON [dbo].[SelfBilledCreditNote] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_InvoicePeriod] ON [dbo].[SelfBilledCreditNote] 
(
	[InvoicePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_DiscrepancyResponse] ON [dbo].[SelfBilledCreditNote] 
(
	[DiscrepancyResponse] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_OrderReference] ON [dbo].[SelfBilledCreditNote] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_BillingReference] ON [dbo].[SelfBilledCreditNote] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_DespatchDocumentReference] ON [dbo].[SelfBilledCreditNote] 
(
	[DespatchDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_ReceiptDocumentReference] ON [dbo].[SelfBilledCreditNote] 
(
	[ReceiptDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_ContractDocumentReference] ON [dbo].[SelfBilledCreditNote] 
(
	[ContractDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_StatementDocumentReference] ON [dbo].[SelfBilledCreditNote] 
(
	[StatementDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_OriginatorDocumentReference] ON [dbo].[SelfBilledCreditNote] 
(
	[OriginatorDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_AdditionalDocumentReference] ON [dbo].[SelfBilledCreditNote] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_Signature] ON [dbo].[SelfBilledCreditNote] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_AccountingCustomerParty] ON [dbo].[SelfBilledCreditNote] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_AccountingSupplierParty] ON [dbo].[SelfBilledCreditNote] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_PayeeParty] ON [dbo].[SelfBilledCreditNote] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_BuyerCustomerParty] ON [dbo].[SelfBilledCreditNote] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_SellerSupplierParty] ON [dbo].[SelfBilledCreditNote] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_TaxRepresentativeParty] ON [dbo].[SelfBilledCreditNote] 
(
	[TaxRepresentativeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_Delivery] ON [dbo].[SelfBilledCreditNote] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_DeliveryTerms] ON [dbo].[SelfBilledCreditNote] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_PaymentMeans] ON [dbo].[SelfBilledCreditNote] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_PaymentTerms] ON [dbo].[SelfBilledCreditNote] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_AllowanceCharge] ON [dbo].[SelfBilledCreditNote] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_TaxExchangeRate] ON [dbo].[SelfBilledCreditNote] 
(
	[TaxExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_PricingExchangeRate] ON [dbo].[SelfBilledCreditNote] 
(
	[PricingExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_PaymentExchangeRate] ON [dbo].[SelfBilledCreditNote] 
(
	[PaymentExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_PaymentAlternativeExchangeRate] ON [dbo].[SelfBilledCreditNote] 
(
	[PaymentAlternativeExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_TaxTotal] ON [dbo].[SelfBilledCreditNote] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_LegalMonetaryTotal] ON [dbo].[SelfBilledCreditNote] 
(
	[LegalMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledCreditNote_CreditNoteLine] ON [dbo].[SelfBilledCreditNote] 
(
	[CreditNoteLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[SelfBilledInvoice] Script Date: 2013-10-13 00:21z
An Invoice document created by the Customer (rather than the Supplier) in a Self Billing relationship.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[SelfBilledInvoice](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [TaxPointDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of the invoice for tax purposes, in accordance with the applicable tax regulation. */
  [InvoiceTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of invoice. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [TaxCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for tax amounts in the Invoice. */
  [PricingCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for prices in the Invoice. */
  [PaymentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency used for payment in the Invoice. */
  [PaymentAlternativeCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the alternative currency used for payment in the Invoice. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** An accounting cost code, applied to the Invoice as a whole. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An accounting cost code, applied to the Invoice as a whole, expressed as text. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Invoice Lines in this document. */
  [InvoicePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period to which the Self Billed Invoice applies. */
  [OrderReference] [numeric](18,0) NULL, /* 0..1 ASBIE Order Reference ** A reference to the Order with which this Invoice is associated. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this document. */
  [ContractDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a contract associated with this document. */
  [DespatchDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Despatch Advice associated with this document. */
  [ReceiptDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Receipt Advice associated with this document. */
  [StatementDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a Statement associated with this document. */
  [OriginatorDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an originator document associated with this document. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [AccountingCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The accounting customer party. */
  [AccountingSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The accounting supplier party. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payee. */
  [TaxRepresentativeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The tax representative. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this document. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..n ASBIE Delivery Terms ** A set of delivery terms associated with this document. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Means ** Expected means of payment. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A set of payment terms associated with this document. */
  [PrepaidPayment] [numeric](18,0) NULL, /* 0..n ASBIE Payment ** A prepaid payment. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [TaxExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the tax currency. */
  [PricingExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the pricing currency. */
  [PaymentExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment currency. */
  [PaymentAlternativeExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate between the document currency and the payment alternative currency. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [LegalMonetaryTotal] [numeric](18,0) NOT NULL, /* 1 ASBIE Monetary Total ** A set of totals associated with this Invoice that are required for the Invoice to be a legal document. */
  [InvoiceLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Invoice Line ** A line describing an Invoice Item. */
 CONSTRAINT [PK_SelfBilledInvoice] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_UBLVersionID] ON [dbo].[SelfBilledInvoice] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_CustomizationID] ON [dbo].[SelfBilledInvoice] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_ProfileID] ON [dbo].[SelfBilledInvoice] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_ProfileExecutionID] ON [dbo].[SelfBilledInvoice] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_ID] ON [dbo].[SelfBilledInvoice] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_CopyIndicator] ON [dbo].[SelfBilledInvoice] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_UUID] ON [dbo].[SelfBilledInvoice] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_IssueDate] ON [dbo].[SelfBilledInvoice] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_IssueTime] ON [dbo].[SelfBilledInvoice] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_TaxPointDate] ON [dbo].[SelfBilledInvoice] 
(
	[TaxPointDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_InvoiceTypeCode] ON [dbo].[SelfBilledInvoice] 
(
	[InvoiceTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_Note] ON [dbo].[SelfBilledInvoice] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_DocumentCurrencyCode] ON [dbo].[SelfBilledInvoice] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_TaxCurrencyCode] ON [dbo].[SelfBilledInvoice] 
(
	[TaxCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_PricingCurrencyCode] ON [dbo].[SelfBilledInvoice] 
(
	[PricingCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_PaymentCurrencyCode] ON [dbo].[SelfBilledInvoice] 
(
	[PaymentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_PaymentAlternativeCurrencyCode] ON [dbo].[SelfBilledInvoice] 
(
	[PaymentAlternativeCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_AccountingCostCode] ON [dbo].[SelfBilledInvoice] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_AccountingCost] ON [dbo].[SelfBilledInvoice] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_LineCountNumeric] ON [dbo].[SelfBilledInvoice] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_InvoicePeriod] ON [dbo].[SelfBilledInvoice] 
(
	[InvoicePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_OrderReference] ON [dbo].[SelfBilledInvoice] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_BillingReference] ON [dbo].[SelfBilledInvoice] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_ContractDocumentReference] ON [dbo].[SelfBilledInvoice] 
(
	[ContractDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_DespatchDocumentReference] ON [dbo].[SelfBilledInvoice] 
(
	[DespatchDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_ReceiptDocumentReference] ON [dbo].[SelfBilledInvoice] 
(
	[ReceiptDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_StatementDocumentReference] ON [dbo].[SelfBilledInvoice] 
(
	[StatementDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_OriginatorDocumentReference] ON [dbo].[SelfBilledInvoice] 
(
	[OriginatorDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_AdditionalDocumentReference] ON [dbo].[SelfBilledInvoice] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_Signature] ON [dbo].[SelfBilledInvoice] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_AccountingCustomerParty] ON [dbo].[SelfBilledInvoice] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_AccountingSupplierParty] ON [dbo].[SelfBilledInvoice] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_BuyerCustomerParty] ON [dbo].[SelfBilledInvoice] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_SellerSupplierParty] ON [dbo].[SelfBilledInvoice] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_PayeeParty] ON [dbo].[SelfBilledInvoice] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_TaxRepresentativeParty] ON [dbo].[SelfBilledInvoice] 
(
	[TaxRepresentativeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_Delivery] ON [dbo].[SelfBilledInvoice] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_DeliveryTerms] ON [dbo].[SelfBilledInvoice] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_PaymentMeans] ON [dbo].[SelfBilledInvoice] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_PaymentTerms] ON [dbo].[SelfBilledInvoice] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_PrepaidPayment] ON [dbo].[SelfBilledInvoice] 
(
	[PrepaidPayment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_AllowanceCharge] ON [dbo].[SelfBilledInvoice] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_TaxExchangeRate] ON [dbo].[SelfBilledInvoice] 
(
	[TaxExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_PricingExchangeRate] ON [dbo].[SelfBilledInvoice] 
(
	[PricingExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_PaymentExchangeRate] ON [dbo].[SelfBilledInvoice] 
(
	[PaymentExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_PaymentAlternativeExchangeRate] ON [dbo].[SelfBilledInvoice] 
(
	[PaymentAlternativeExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_TaxTotal] ON [dbo].[SelfBilledInvoice] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_LegalMonetaryTotal] ON [dbo].[SelfBilledInvoice] 
(
	[LegalMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SelfBilledInvoice_InvoiceLine] ON [dbo].[SelfBilledInvoice] 
(
	[InvoiceLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Statement] Script Date: 2013-10-13 00:21z
A document used to report the status of orders, billing, and payment. This document is a statement of account, not a summary invoice.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Statement](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentCurrencyCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** The default currency for the Statement. */
  [TotalDebitAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total of all debit amounts for the Statement. */
  [TotalCreditAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total of all credit amounts for the Statement. */
  [TotalBalanceAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total amount for the Statement. */
  [LineCountNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of Statement Lines in the Statement. */
  [StatementTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of the Statement. */
  [StatementPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** A period to which the Statement applies. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [AccountingSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The accounting supplier party. */
  [AccountingCustomerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Customer Party ** The accounting customer party. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The originator. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payee. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..n ASBIE Payment Means ** Expected means of payment. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A set of payment terms associated with this document. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A discount or charge that applies to a price component. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total amount of a specific type of tax. */
  [StatementLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Statement Line ** A Statement Line. */
 CONSTRAINT [PK_Statement] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_UBLVersionID] ON [dbo].[Statement] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_CustomizationID] ON [dbo].[Statement] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_ProfileID] ON [dbo].[Statement] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_ProfileExecutionID] ON [dbo].[Statement] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_ID] ON [dbo].[Statement] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_CopyIndicator] ON [dbo].[Statement] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_UUID] ON [dbo].[Statement] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_IssueDate] ON [dbo].[Statement] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_IssueTime] ON [dbo].[Statement] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_Note] ON [dbo].[Statement] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_DocumentCurrencyCode] ON [dbo].[Statement] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_TotalDebitAmount] ON [dbo].[Statement] 
(
	[TotalDebitAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_TotalCreditAmount] ON [dbo].[Statement] 
(
	[TotalCreditAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_TotalBalanceAmount] ON [dbo].[Statement] 
(
	[TotalBalanceAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_LineCountNumeric] ON [dbo].[Statement] 
(
	[LineCountNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_StatementTypeCode] ON [dbo].[Statement] 
(
	[StatementTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_StatementPeriod] ON [dbo].[Statement] 
(
	[StatementPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_AdditionalDocumentReference] ON [dbo].[Statement] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_Signature] ON [dbo].[Statement] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_AccountingSupplierParty] ON [dbo].[Statement] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_AccountingCustomerParty] ON [dbo].[Statement] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_BuyerCustomerParty] ON [dbo].[Statement] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_SellerSupplierParty] ON [dbo].[Statement] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_OriginatorCustomerParty] ON [dbo].[Statement] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_PayeeParty] ON [dbo].[Statement] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_PaymentMeans] ON [dbo].[Statement] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_PaymentTerms] ON [dbo].[Statement] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_AllowanceCharge] ON [dbo].[Statement] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_TaxTotal] ON [dbo].[Statement] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Statement_StatementLine] ON [dbo].[Statement] 
(
	[StatementLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[StockAvailabilityReport] Script Date: 2013-10-13 00:21z
A report on the quantities of each item that are, or will be, in stock. This document is sent by a Seller (for example a producer) to a Buyer (for example a retailer).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[StockAvailabilityReport](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentCurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the default currency for this document. */
  [InventoryPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The inventory period covered by the Report. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SellerSupplierParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Supplier Party ** The seller. */
  [RetailerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The retailer. */
  [InventoryReportingParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party that will receive and use the Stock Availability Report (normally the branch for which the stock is reported). */
  [StockAvailabilityReportLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Stock Availability Report Line ** A line representing a particular item of sale and associated with a line in the Catalogue. */
 CONSTRAINT [PK_StockAvailabilityReport] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_UBLVersionID] ON [dbo].[StockAvailabilityReport] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_CustomizationID] ON [dbo].[StockAvailabilityReport] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_ProfileID] ON [dbo].[StockAvailabilityReport] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_ProfileExecutionID] ON [dbo].[StockAvailabilityReport] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_ID] ON [dbo].[StockAvailabilityReport] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_CopyIndicator] ON [dbo].[StockAvailabilityReport] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_UUID] ON [dbo].[StockAvailabilityReport] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_IssueDate] ON [dbo].[StockAvailabilityReport] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_IssueTime] ON [dbo].[StockAvailabilityReport] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_Note] ON [dbo].[StockAvailabilityReport] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_DocumentCurrencyCode] ON [dbo].[StockAvailabilityReport] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_InventoryPeriod] ON [dbo].[StockAvailabilityReport] 
(
	[InventoryPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_DocumentReference] ON [dbo].[StockAvailabilityReport] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_Signature] ON [dbo].[StockAvailabilityReport] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_SellerSupplierParty] ON [dbo].[StockAvailabilityReport] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_RetailerCustomerParty] ON [dbo].[StockAvailabilityReport] 
(
	[RetailerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_InventoryReportingParty] ON [dbo].[StockAvailabilityReport] 
(
	[InventoryReportingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReport_StockAvailabilityReportLine] ON [dbo].[StockAvailabilityReport] 
(
	[StockAvailabilityReportLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Tender] Script Date: 2013-10-13 00:21z
A document whereby an economic operator (the tenderer) makes a formal offer (the tender) to a contracting authority to execute an order for the supply or purchase of goods, or for the execution of work, according to the terms of a proposed contract.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Tender](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [TenderTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code to specify the type of tender (economical or objective criteria versus technical or subjective criteria) */
  [ContractFolderID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier, assigned by the sender, for the process file (i.e., record) to which this document belongs. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [ContractName] [numeric](18,0) NULL, /* 0..n BBIE Text ** Short title of a contract associated with this Tender. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period for which the Tender is valid. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [TendererParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The primary tenderer. */
  [TendererQualificationDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the tenderer qualification document that has been used to qualify the tenderer. */
  [SubcontractorParty] [numeric](18,0) NULL, /* 0..n ASBIE Party ** A subcontractor or other tenderer participating in the same Tender. */
  [ContractingParty] [numeric](18,0) NULL, /* 0..1 ASBIE Contracting Party ** The contracting party. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The party originating the Tender. */
  [TenderedProject] [numeric](18,0) NOT NULL, /* 1..n ASBIE Tendered Project ** A project with which this Tender is associated. A single Tender can be used to bid for one project, multiple projects, or the global project. */
 CONSTRAINT [PK_Tender] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_UBLVersionID] ON [dbo].[Tender] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_CustomizationID] ON [dbo].[Tender] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_ProfileID] ON [dbo].[Tender] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_ProfileExecutionID] ON [dbo].[Tender] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_ID] ON [dbo].[Tender] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_CopyIndicator] ON [dbo].[Tender] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_UUID] ON [dbo].[Tender] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_TenderTypeCode] ON [dbo].[Tender] 
(
	[TenderTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_ContractFolderID] ON [dbo].[Tender] 
(
	[ContractFolderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_IssueDate] ON [dbo].[Tender] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_IssueTime] ON [dbo].[Tender] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_ContractName] ON [dbo].[Tender] 
(
	[ContractName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_Note] ON [dbo].[Tender] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_ValidityPeriod] ON [dbo].[Tender] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_DocumentReference] ON [dbo].[Tender] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_Signature] ON [dbo].[Tender] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_TendererParty] ON [dbo].[Tender] 
(
	[TendererParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_TendererQualificationDocumentReference] ON [dbo].[Tender] 
(
	[TendererQualificationDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_SubcontractorParty] ON [dbo].[Tender] 
(
	[SubcontractorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_ContractingParty] ON [dbo].[Tender] 
(
	[ContractingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_OriginatorCustomerParty] ON [dbo].[Tender] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Tender_TenderedProject] ON [dbo].[Tender] 
(
	[TenderedProject] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TendererQualification] Script Date: 2013-10-13 00:21z
A document declaring the qualifications of a tenderer.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TendererQualification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [ContractFolderID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier, assigned by the sender, for the process file (i.e., record) to which this document belongs. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Indicates the current version of the Tenderer Qualification. */
  [PreviousVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the previous version of the Tenderer Qualification which is superceded by this version. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [TendererPartyQualification] [numeric](18,0) NOT NULL, /* 1..n ASBIE Tenderer Party Qualification ** A specific qualification of the Tenderer. */
  [ContractingParty] [numeric](18,0) NULL, /* 0..1 ASBIE Contracting Party ** The contracting party. */
  [Evidence] [numeric](18,0) NULL, /* 0..n ASBIE Evidence ** An evidentiary document supporting Tenderer qualifications. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
 CONSTRAINT [PK_TendererQualification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_UBLVersionID] ON [dbo].[TendererQualification] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_CustomizationID] ON [dbo].[TendererQualification] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_ProfileID] ON [dbo].[TendererQualification] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_ProfileExecutionID] ON [dbo].[TendererQualification] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_ID] ON [dbo].[TendererQualification] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_CopyIndicator] ON [dbo].[TendererQualification] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_UUID] ON [dbo].[TendererQualification] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_ContractFolderID] ON [dbo].[TendererQualification] 
(
	[ContractFolderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_IssueDate] ON [dbo].[TendererQualification] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_IssueTime] ON [dbo].[TendererQualification] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_Note] ON [dbo].[TendererQualification] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_VersionID] ON [dbo].[TendererQualification] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_PreviousVersionID] ON [dbo].[TendererQualification] 
(
	[PreviousVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_Signature] ON [dbo].[TendererQualification] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_TendererPartyQualification] ON [dbo].[TendererQualification] 
(
	[TendererPartyQualification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_ContractingParty] ON [dbo].[TendererQualification] 
(
	[ContractingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_Evidence] ON [dbo].[TendererQualification] 
(
	[Evidence] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualification_AdditionalDocumentReference] ON [dbo].[TendererQualification] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TendererQualificationResponse] Script Date: 2013-10-13 00:21z
A document issued by a procurement organization to notify an economic operator whether it has been admitted to or excluded from the tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TendererQualificationResponse](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [ContractFolderID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier, assigned by the sender, for the process file (i.e., record) to which this document belongs. */
  [ContractName] [numeric](18,0) NULL, /* 0..n BBIE Text ** Short title of a contract associated with this Tender. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this message. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this message. */
  [ResolutionDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A document (e.g., meeting minutes) relating to consideration of tenderer qualifications. */
  [QualificationResolution] [numeric](18,0) NOT NULL, /* 1..n ASBIE Qualification Resolution ** An association to the resolution that is being notified */
  [AppealTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Appeal Terms ** Terms of appeal for this tendering process. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
 CONSTRAINT [PK_TendererQualificationResponse] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_UBLVersionID] ON [dbo].[TendererQualificationResponse] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_CustomizationID] ON [dbo].[TendererQualificationResponse] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_ProfileID] ON [dbo].[TendererQualificationResponse] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_ProfileExecutionID] ON [dbo].[TendererQualificationResponse] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_ID] ON [dbo].[TendererQualificationResponse] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_CopyIndicator] ON [dbo].[TendererQualificationResponse] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_UUID] ON [dbo].[TendererQualificationResponse] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_ContractFolderID] ON [dbo].[TendererQualificationResponse] 
(
	[ContractFolderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_ContractName] ON [dbo].[TendererQualificationResponse] 
(
	[ContractName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_IssueDate] ON [dbo].[TendererQualificationResponse] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_IssueTime] ON [dbo].[TendererQualificationResponse] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_Note] ON [dbo].[TendererQualificationResponse] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_SenderParty] ON [dbo].[TendererQualificationResponse] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_ReceiverParty] ON [dbo].[TendererQualificationResponse] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_ResolutionDocumentReference] ON [dbo].[TendererQualificationResponse] 
(
	[ResolutionDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_QualificationResolution] ON [dbo].[TendererQualificationResponse] 
(
	[QualificationResolution] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_AppealTerms] ON [dbo].[TendererQualificationResponse] 
(
	[AppealTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationResponse_Signature] ON [dbo].[TendererQualificationResponse] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TenderReceipt] Script Date: 2013-10-13 00:21z
A document sent by a contracting party to an economic operator acknowledging receipt of a Tender.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TenderReceipt](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [ContractFolderID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier, assigned by the sender, for the process file (i.e., record) to which this document belongs. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [ContractName] [numeric](18,0) NULL, /* 0..n BBIE Text ** Short title of a contract associated with this Tender. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [RegisteredDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which the Tender Receipt was created. */
  [RegisteredTime] [numeric](18,0) NOT NULL, /* 1 BBIE Time ** The time, assigned by the sender, at which the Tender Receipt was created. */
  [TenderDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a received Tender. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this document. */
 CONSTRAINT [PK_TenderReceipt] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_UBLVersionID] ON [dbo].[TenderReceipt] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_CustomizationID] ON [dbo].[TenderReceipt] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_ProfileID] ON [dbo].[TenderReceipt] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_ProfileExecutionID] ON [dbo].[TenderReceipt] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_ID] ON [dbo].[TenderReceipt] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_CopyIndicator] ON [dbo].[TenderReceipt] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_UUID] ON [dbo].[TenderReceipt] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_ContractFolderID] ON [dbo].[TenderReceipt] 
(
	[ContractFolderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_IssueDate] ON [dbo].[TenderReceipt] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_IssueTime] ON [dbo].[TenderReceipt] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_ContractName] ON [dbo].[TenderReceipt] 
(
	[ContractName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_Note] ON [dbo].[TenderReceipt] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_RegisteredDate] ON [dbo].[TenderReceipt] 
(
	[RegisteredDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_RegisteredTime] ON [dbo].[TenderReceipt] 
(
	[RegisteredTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_TenderDocumentReference] ON [dbo].[TenderReceipt] 
(
	[TenderDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_Signature] ON [dbo].[TenderReceipt] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_SenderParty] ON [dbo].[TenderReceipt] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderReceipt_ReceiverParty] ON [dbo].[TenderReceipt] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TradeItemLocationProfile] Script Date: 2013-10-13 00:21z
A document specifying trade item attributes relating to replenishment policies.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TradeItemLocationProfile](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [ProfileStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of this Trade Item Location Profile. */
  [Period] [numeric](18,0) NOT NULL, /* 1 ASBIE Period ** An association to Period. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The sender. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The receiver. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller. */
  [ItemManagementProfile] [numeric](18,0) NOT NULL, /* 1..n ASBIE Item Management Profile ** A profile specifying replenishment policies for a particular trade item. */
 CONSTRAINT [PK_TradeItemLocationProfile] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_UBLVersionID] ON [dbo].[TradeItemLocationProfile] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_CustomizationID] ON [dbo].[TradeItemLocationProfile] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_ProfileID] ON [dbo].[TradeItemLocationProfile] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_ProfileExecutionID] ON [dbo].[TradeItemLocationProfile] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_ID] ON [dbo].[TradeItemLocationProfile] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_CopyIndicator] ON [dbo].[TradeItemLocationProfile] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_UUID] ON [dbo].[TradeItemLocationProfile] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_IssueDate] ON [dbo].[TradeItemLocationProfile] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_IssueTime] ON [dbo].[TradeItemLocationProfile] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_Note] ON [dbo].[TradeItemLocationProfile] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_ProfileStatusCode] ON [dbo].[TradeItemLocationProfile] 
(
	[ProfileStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_Period] ON [dbo].[TradeItemLocationProfile] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_DocumentReference] ON [dbo].[TradeItemLocationProfile] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_Signature] ON [dbo].[TradeItemLocationProfile] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_SenderParty] ON [dbo].[TradeItemLocationProfile] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_ReceiverParty] ON [dbo].[TradeItemLocationProfile] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_BuyerCustomerParty] ON [dbo].[TradeItemLocationProfile] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_SellerSupplierParty] ON [dbo].[TradeItemLocationProfile] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeItemLocationProfile_ItemManagementProfile] ON [dbo].[TradeItemLocationProfile] 
(
	[ItemManagementProfile] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportationStatus] Script Date: 2013-10-13 00:21z
A document to circulate reports of transportation status or changes in status (events) among a group of participants.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportationStatus](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CarrierAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A reference number assigned by a carrier or its agent to identify a specific shipment, such as a booking reference number when cargo space is reserved prior to loading. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Text, assigned by the sender, that identifies this document to business users. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** A textual description of transportation status. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [ShippingOrderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A reference number for a shipping order. */
  [OtherInstruction] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An instruction regarding this message. */
  [TransportationStatusTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of status provided in a Transportation Status document. */
  [TransportExecutionStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the overall status of transport service execution. */
  [Consignment] [numeric](18,0) NULL, /* 0..n ASBIE Consignment ** A consignment associated with this Transportation Status report. */
  [TransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** An event associated with this Transportation Status report. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party sending this Transportation Status report. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving this Transportation Status report. */
  [TransportationStatusRequestDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the Transportation Status Request to which this report is a response. */
  [TransportExecutionPlanDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the Transport Execution Plan associated with the transport service whose status is being reported. */
  [UpdatedPickupTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** Update of the original plan regarding a pickup of goods. */
  [UpdatedDeliveryTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** Update of the original plan regarding a delivery. */
  [StatusLocation] [numeric](18,0) NULL, /* 0..n ASBIE Location ** Locations associated with this Transportation Status report. */
  [StatusPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period for which status is provided. */
 CONSTRAINT [PK_TransportationStatus] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_UBLVersionID] ON [dbo].[TransportationStatus] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_CustomizationID] ON [dbo].[TransportationStatus] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_ProfileID] ON [dbo].[TransportationStatus] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_ProfileExecutionID] ON [dbo].[TransportationStatus] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_ID] ON [dbo].[TransportationStatus] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_CarrierAssignedID] ON [dbo].[TransportationStatus] 
(
	[CarrierAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_UUID] ON [dbo].[TransportationStatus] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_IssueDate] ON [dbo].[TransportationStatus] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_IssueTime] ON [dbo].[TransportationStatus] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_Name] ON [dbo].[TransportationStatus] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_Description] ON [dbo].[TransportationStatus] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_Note] ON [dbo].[TransportationStatus] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_ShippingOrderID] ON [dbo].[TransportationStatus] 
(
	[ShippingOrderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_OtherInstruction] ON [dbo].[TransportationStatus] 
(
	[OtherInstruction] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_TransportationStatusTypeCode] ON [dbo].[TransportationStatus] 
(
	[TransportationStatusTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_TransportExecutionStatusCode] ON [dbo].[TransportationStatus] 
(
	[TransportExecutionStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_Consignment] ON [dbo].[TransportationStatus] 
(
	[Consignment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_TransportEvent] ON [dbo].[TransportationStatus] 
(
	[TransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_DocumentReference] ON [dbo].[TransportationStatus] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_Signature] ON [dbo].[TransportationStatus] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_SenderParty] ON [dbo].[TransportationStatus] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_ReceiverParty] ON [dbo].[TransportationStatus] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_TransportationStatusRequestDocumentReference] ON [dbo].[TransportationStatus] 
(
	[TransportationStatusRequestDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_TransportExecutionPlanDocumentReference] ON [dbo].[TransportationStatus] 
(
	[TransportExecutionPlanDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_UpdatedPickupTransportEvent] ON [dbo].[TransportationStatus] 
(
	[UpdatedPickupTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_UpdatedDeliveryTransportEvent] ON [dbo].[TransportationStatus] 
(
	[UpdatedDeliveryTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_StatusLocation] ON [dbo].[TransportationStatus] 
(
	[StatusLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatus_StatusPeriod] ON [dbo].[TransportationStatus] 
(
	[StatusPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportationStatusRequest] Script Date: 2013-10-13 00:21z
A document requesting a Transportation Status report.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportationStatusRequest](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CarrierAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A reference number assigned by a carrier or its agent to identify a specific shipment, such as a booking reference number when cargo space is reserved prior to loading. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Text, assigned by the sender, that identifies this document to business users. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** A textual description of the document instance. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [ShippingOrderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A reference number for a shipping order. */
  [OtherInstruction] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An instruction regarding this message. */
  [TransportationStatusTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of status requested in a Transportation Status document. */
  [SenderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving this document. */
  [TransportExecutionPlanDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the Transport Execution Plan associated with the transport service for which status is requested. */
  [Consignment] [numeric](18,0) NULL, /* 0..n ASBIE Consignment ** A consignment regarding which status is requested. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [RequestedStatusLocation] [numeric](18,0) NULL, /* 0..n ASBIE Location ** A location for which status is requested. */
  [RequestedStatusPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period for which status is requested. */
 CONSTRAINT [PK_TransportationStatusRequest] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_UBLVersionID] ON [dbo].[TransportationStatusRequest] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_CustomizationID] ON [dbo].[TransportationStatusRequest] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_ProfileID] ON [dbo].[TransportationStatusRequest] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_ProfileExecutionID] ON [dbo].[TransportationStatusRequest] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_ID] ON [dbo].[TransportationStatusRequest] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_CarrierAssignedID] ON [dbo].[TransportationStatusRequest] 
(
	[CarrierAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_UUID] ON [dbo].[TransportationStatusRequest] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_IssueDate] ON [dbo].[TransportationStatusRequest] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_IssueTime] ON [dbo].[TransportationStatusRequest] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_Name] ON [dbo].[TransportationStatusRequest] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_Description] ON [dbo].[TransportationStatusRequest] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_Note] ON [dbo].[TransportationStatusRequest] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_ShippingOrderID] ON [dbo].[TransportationStatusRequest] 
(
	[ShippingOrderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_OtherInstruction] ON [dbo].[TransportationStatusRequest] 
(
	[OtherInstruction] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_TransportationStatusTypeCode] ON [dbo].[TransportationStatusRequest] 
(
	[TransportationStatusTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_SenderParty] ON [dbo].[TransportationStatusRequest] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_ReceiverParty] ON [dbo].[TransportationStatusRequest] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_TransportExecutionPlanDocumentReference] ON [dbo].[TransportationStatusRequest] 
(
	[TransportExecutionPlanDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_Consignment] ON [dbo].[TransportationStatusRequest] 
(
	[Consignment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_DocumentReference] ON [dbo].[TransportationStatusRequest] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_Signature] ON [dbo].[TransportationStatusRequest] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_RequestedStatusLocation] ON [dbo].[TransportationStatusRequest] 
(
	[RequestedStatusLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationStatusRequest_RequestedStatusPeriod] ON [dbo].[TransportationStatusRequest] 
(
	[RequestedStatusPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportExecutionPlan] Script Date: 2013-10-13 00:21z
A document used in the negotiation of a transport service between a transport user and a transport service provider.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportExecutionPlan](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Indicates the current version of the Transport Execution Plan. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [DocumentStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of the Transport Execution Plan (updated, cancelled, confirmed, etc.) */
  [DocumentStatusReasonCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying a reason associated with the status of a Transport Execution Plan. */
  [DocumentStatusReasonDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** A reason for the status assigned to the Transport Execution Plan, expressed in text. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [TransportUserRemarks] [numeric](18,0) NULL, /* 0..n BBIE Text ** Remarks from the transport user regarding the transport operations referred to in the Transport Execution Plan. */
  [TransportServiceProviderRemarks] [numeric](18,0) NULL, /* 0..n BBIE Text ** Remarks from the transport service provider regarding the transport operations referred to in the Transport Execution Plan. */
  [SenderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party sending this document (can be either the transport user or the transport service provider). */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving this document (can be either the transport user or the transport service provider). */
  [TransportUserParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party requesting the transport service from a transport service provider. */
  [TransportServiceProviderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party offering the transport service based upon a request from a transport user. */
  [BillToParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** Describes the party that will pay for the transport service(s) provided in a Transport Execution Plan */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [TransportExecutionPlanRequestDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a Transport Execution Plan Request. */
  [TransportExecutionPlanDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to an original Transport Execution Plan. */
  [TransportServiceDescriptionDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the Transport Service Description, which is used by a transport service provider to announce transport services to transport users (buyers). */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [TransportContract] [numeric](18,0) NULL, /* 0..1 ASBIE Contract ** A contract related to the Transport Execution Plan. */
  [TransportServiceProviderResponseRequiredPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** Describes the deadline for when the Transport Service Provider will have to respond to a Transport Execution Plan . */
  [TransportUserResponseRequiredPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** Describes the deadline for when the Transport User will have to respond to a Transport Execution Plan suggested by a Transport Service Provider. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period during which the Transport Execution Plan is valid. */
  [MainTransportationService] [numeric](18,0) NULL, /* 0..1 ASBIE Transportation Service ** Description of the main transportation service referenced in the Transport Execution Plan. */
  [AdditionalTransportationService] [numeric](18,0) NULL, /* 0..n ASBIE Transportation Service ** A description of an additional transportation service referenced in the Transport Execution Plan. */
  [ServiceStartTimePeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period within which the service must begin. */
  [ServiceEndTimePeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which the service must be completed. */
  [FromLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location of origin of the transport service referenced in the Transport Execution Plan. */
  [ToLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The destination location for the transport service referenced in the Transport Execution Plan. */
  [AtLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location of a transport service (e.g., terminal handling service) that does not require transport movement. */
  [TransportExecutionTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Execution Terms ** A description of terms and conditions related to the Transport Execution Plan. */
  [Consignment] [numeric](18,0) NOT NULL, /* 1..n ASBIE Consignment ** A description of an identifiable collection of goods items to be transported between the consignor and the consignee. This information may be defined within a transport contract. A consignment may comprise more than one shipment (e.g., when consolidated by a freight forwarder). */
 CONSTRAINT [PK_TransportExecutionPlan] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_UBLVersionID] ON [dbo].[TransportExecutionPlan] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_CustomizationID] ON [dbo].[TransportExecutionPlan] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_ProfileID] ON [dbo].[TransportExecutionPlan] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_ProfileExecutionID] ON [dbo].[TransportExecutionPlan] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_ID] ON [dbo].[TransportExecutionPlan] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_VersionID] ON [dbo].[TransportExecutionPlan] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_CopyIndicator] ON [dbo].[TransportExecutionPlan] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_UUID] ON [dbo].[TransportExecutionPlan] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_IssueDate] ON [dbo].[TransportExecutionPlan] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_IssueTime] ON [dbo].[TransportExecutionPlan] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_DocumentStatusCode] ON [dbo].[TransportExecutionPlan] 
(
	[DocumentStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_DocumentStatusReasonCode] ON [dbo].[TransportExecutionPlan] 
(
	[DocumentStatusReasonCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_DocumentStatusReasonDescription] ON [dbo].[TransportExecutionPlan] 
(
	[DocumentStatusReasonDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_Note] ON [dbo].[TransportExecutionPlan] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_TransportUserRemarks] ON [dbo].[TransportExecutionPlan] 
(
	[TransportUserRemarks] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_TransportServiceProviderRemarks] ON [dbo].[TransportExecutionPlan] 
(
	[TransportServiceProviderRemarks] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_SenderParty] ON [dbo].[TransportExecutionPlan] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_ReceiverParty] ON [dbo].[TransportExecutionPlan] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_TransportUserParty] ON [dbo].[TransportExecutionPlan] 
(
	[TransportUserParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_TransportServiceProviderParty] ON [dbo].[TransportExecutionPlan] 
(
	[TransportServiceProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_BillToParty] ON [dbo].[TransportExecutionPlan] 
(
	[BillToParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_Signature] ON [dbo].[TransportExecutionPlan] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_TransportExecutionPlanRequestDocumentReference] ON [dbo].[TransportExecutionPlan] 
(
	[TransportExecutionPlanRequestDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_TransportExecutionPlanDocumentReference] ON [dbo].[TransportExecutionPlan] 
(
	[TransportExecutionPlanDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_TransportServiceDescriptionDocumentReference] ON [dbo].[TransportExecutionPlan] 
(
	[TransportServiceDescriptionDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_AdditionalDocumentReference] ON [dbo].[TransportExecutionPlan] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_TransportContract] ON [dbo].[TransportExecutionPlan] 
(
	[TransportContract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_TransportServiceProviderResponseRequiredPeriod] ON [dbo].[TransportExecutionPlan] 
(
	[TransportServiceProviderResponseRequiredPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_TransportUserResponseRequiredPeriod] ON [dbo].[TransportExecutionPlan] 
(
	[TransportUserResponseRequiredPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_ValidityPeriod] ON [dbo].[TransportExecutionPlan] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_MainTransportationService] ON [dbo].[TransportExecutionPlan] 
(
	[MainTransportationService] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_AdditionalTransportationService] ON [dbo].[TransportExecutionPlan] 
(
	[AdditionalTransportationService] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_ServiceStartTimePeriod] ON [dbo].[TransportExecutionPlan] 
(
	[ServiceStartTimePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_ServiceEndTimePeriod] ON [dbo].[TransportExecutionPlan] 
(
	[ServiceEndTimePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_FromLocation] ON [dbo].[TransportExecutionPlan] 
(
	[FromLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_ToLocation] ON [dbo].[TransportExecutionPlan] 
(
	[ToLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_AtLocation] ON [dbo].[TransportExecutionPlan] 
(
	[AtLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_TransportExecutionTerms] ON [dbo].[TransportExecutionPlan] 
(
	[TransportExecutionTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlan_Consignment] ON [dbo].[TransportExecutionPlan] 
(
	[Consignment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportExecutionPlanRequest] Script Date: 2013-10-13 00:21z
A document sent by a transport user to request a transport service from a transport service provider.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportExecutionPlanRequest](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the current version of the Transport Execution Plan Request. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [DocumentStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of the Transport Execution Plan Request. */
  [DocumentStatusReasonCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying a reason associated with the status of the Transport Execution Plan Request. */
  [DocumentStatusReasonDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** A reason associated with the status of the Transport Execution Plan Request. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [TransportUserRemarks] [numeric](18,0) NULL, /* 0..n BBIE Text ** Remarks from the transport user regarding the transport operations referenced in the Transport Execution Plan Request. */
  [SenderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party sending the Transport Execution Plan Request. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving the Transport Execution Plan Request. */
  [TransportUserParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party requesting the transport services referenced in the Transport Execution Plan Request. */
  [TransportServiceProviderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party providing the transport services referenced in the Transport Execution Plan Request. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that will pay for the transport service(s) referred to in a Transport Execution Plan. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [TransportExecutionPlanDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to an original Transport Execution Plan Document. */
  [TransportServiceDescriptionDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the Transport Service Description, which is used by a transport service provider to announce transport services to transport users (buyers). */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [TransportContract] [numeric](18,0) NULL, /* 0..1 ASBIE Contract ** A potential contract related to the Transport Execution Plan Request. */
  [TransportServiceProviderResponseDeadlinePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A deadline for a response from the Transport Service Provider to this Transport Execution Plan Request. */
  [MainTransportationService] [numeric](18,0) NULL, /* 0..1 ASBIE Transportation Service ** A description of the main transportation service referenced in the Transport Execution Plan Request. */
  [AdditionalTransportationService] [numeric](18,0) NULL, /* 0..n ASBIE Transportation Service ** A description of an additional transportation service referenced in the Transport Execution Plan Request. */
  [ServiceStartTimePeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period within which the services referred to in the Transport Execution Plan Request must begin. */
  [ServiceEndTimePeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which the services referred to in the Transport Execution Plan Request must be completed. */
  [FromLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location of origin of the transport service referenced in the Transport Execution Plan Request. */
  [ToLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The destination location for the transport service referenced in the Transport Execution Plan Request. */
  [AtLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location of a transport service (e.g., terminal handling service) that does not require transport movement. */
  [TransportExecutionTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Execution Terms ** A description of terms and conditions related to the Transport Execution Plan Request. */
  [Consignment] [numeric](18,0) NOT NULL, /* 1..n ASBIE Consignment ** A description of an identifiable collection of goods items to be transported between the consignor and the consignee. This information may be defined within a transport contract. A consignment may comprise more than one shipment (e.g., when consolidated by a freight forwarder). */
 CONSTRAINT [PK_TransportExecutionPlanRequest] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_UBLVersionID] ON [dbo].[TransportExecutionPlanRequest] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_CustomizationID] ON [dbo].[TransportExecutionPlanRequest] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_ProfileID] ON [dbo].[TransportExecutionPlanRequest] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_ProfileExecutionID] ON [dbo].[TransportExecutionPlanRequest] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_ID] ON [dbo].[TransportExecutionPlanRequest] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_VersionID] ON [dbo].[TransportExecutionPlanRequest] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_CopyIndicator] ON [dbo].[TransportExecutionPlanRequest] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_UUID] ON [dbo].[TransportExecutionPlanRequest] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_IssueDate] ON [dbo].[TransportExecutionPlanRequest] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_IssueTime] ON [dbo].[TransportExecutionPlanRequest] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_DocumentStatusCode] ON [dbo].[TransportExecutionPlanRequest] 
(
	[DocumentStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_DocumentStatusReasonCode] ON [dbo].[TransportExecutionPlanRequest] 
(
	[DocumentStatusReasonCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_DocumentStatusReasonDescription] ON [dbo].[TransportExecutionPlanRequest] 
(
	[DocumentStatusReasonDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_Note] ON [dbo].[TransportExecutionPlanRequest] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_TransportUserRemarks] ON [dbo].[TransportExecutionPlanRequest] 
(
	[TransportUserRemarks] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_SenderParty] ON [dbo].[TransportExecutionPlanRequest] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_ReceiverParty] ON [dbo].[TransportExecutionPlanRequest] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_TransportUserParty] ON [dbo].[TransportExecutionPlanRequest] 
(
	[TransportUserParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_TransportServiceProviderParty] ON [dbo].[TransportExecutionPlanRequest] 
(
	[TransportServiceProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_PayeeParty] ON [dbo].[TransportExecutionPlanRequest] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_Signature] ON [dbo].[TransportExecutionPlanRequest] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_TransportExecutionPlanDocumentReference] ON [dbo].[TransportExecutionPlanRequest] 
(
	[TransportExecutionPlanDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_TransportServiceDescriptionDocumentReference] ON [dbo].[TransportExecutionPlanRequest] 
(
	[TransportServiceDescriptionDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_AdditionalDocumentReference] ON [dbo].[TransportExecutionPlanRequest] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_TransportContract] ON [dbo].[TransportExecutionPlanRequest] 
(
	[TransportContract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_TransportServiceProviderResponseDeadlinePeriod] ON [dbo].[TransportExecutionPlanRequest] 
(
	[TransportServiceProviderResponseDeadlinePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_MainTransportationService] ON [dbo].[TransportExecutionPlanRequest] 
(
	[MainTransportationService] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_AdditionalTransportationService] ON [dbo].[TransportExecutionPlanRequest] 
(
	[AdditionalTransportationService] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_ServiceStartTimePeriod] ON [dbo].[TransportExecutionPlanRequest] 
(
	[ServiceStartTimePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_ServiceEndTimePeriod] ON [dbo].[TransportExecutionPlanRequest] 
(
	[ServiceEndTimePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_FromLocation] ON [dbo].[TransportExecutionPlanRequest] 
(
	[FromLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_ToLocation] ON [dbo].[TransportExecutionPlanRequest] 
(
	[ToLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_AtLocation] ON [dbo].[TransportExecutionPlanRequest] 
(
	[AtLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_TransportExecutionTerms] ON [dbo].[TransportExecutionPlanRequest] 
(
	[TransportExecutionTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionPlanRequest_Consignment] ON [dbo].[TransportExecutionPlanRequest] 
(
	[Consignment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportProgressStatus] Script Date: 2013-10-13 00:21z
A document sent from a Transportation Network Manager to a Transport Service Provider giving the status of the whereabouts and schedule of the transport means involved in a transport service.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportProgressStatus](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NOT NULL, /* 1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [StatusAvailableIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether transport progress information is available. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party sending the Transport Progress Status. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving the Transport Progress Status. */
  [SourceIssuerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that is the source of the Transport Progress Status. */
  [TransportProgressStatusRequestDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the Transport Progress Status Request document to which this status report is a response. */
  [TransportMeans] [numeric](18,0) NOT NULL, /* 1 ASBIE Transport Means ** The transport means by which the current transport service is effectuated. */
  [TransportSchedule] [numeric](18,0) NULL, /* 0..n ASBIE Transport Schedule ** Describes the status and schedule of the transport means operating the transport service as well as the current location of the transport means. */
 CONSTRAINT [PK_TransportProgressStatus] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_UBLVersionID] ON [dbo].[TransportProgressStatus] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_CustomizationID] ON [dbo].[TransportProgressStatus] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_ProfileID] ON [dbo].[TransportProgressStatus] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_ProfileExecutionID] ON [dbo].[TransportProgressStatus] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_ID] ON [dbo].[TransportProgressStatus] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_CopyIndicator] ON [dbo].[TransportProgressStatus] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_UUID] ON [dbo].[TransportProgressStatus] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_IssueDate] ON [dbo].[TransportProgressStatus] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_IssueTime] ON [dbo].[TransportProgressStatus] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_Note] ON [dbo].[TransportProgressStatus] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_StatusAvailableIndicator] ON [dbo].[TransportProgressStatus] 
(
	[StatusAvailableIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_Signature] ON [dbo].[TransportProgressStatus] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_SenderParty] ON [dbo].[TransportProgressStatus] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_ReceiverParty] ON [dbo].[TransportProgressStatus] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_SourceIssuerParty] ON [dbo].[TransportProgressStatus] 
(
	[SourceIssuerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_TransportProgressStatusRequestDocumentReference] ON [dbo].[TransportProgressStatus] 
(
	[TransportProgressStatusRequestDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_TransportMeans] ON [dbo].[TransportProgressStatus] 
(
	[TransportMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatus_TransportSchedule] ON [dbo].[TransportProgressStatus] 
(
	[TransportSchedule] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportProgressStatusRequest] Script Date: 2013-10-13 00:21z
A document sent from a transport service provider to a transportation network manager requesting a Transport Progress Status.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportProgressStatusRequest](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NOT NULL, /* 1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party sending the Transport Progress Status Request. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving the Transport Progress Status Request. */
  [TransportMeans] [numeric](18,0) NOT NULL, /* 1 ASBIE Transport Means ** The transport means by which the current transport service is effectuated and for which status is requested. */
  [StatusLocation] [numeric](18,0) NULL, /* 0..n ASBIE Location ** A location for which status is requested. */
 CONSTRAINT [PK_TransportProgressStatusRequest] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_UBLVersionID] ON [dbo].[TransportProgressStatusRequest] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_CustomizationID] ON [dbo].[TransportProgressStatusRequest] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_ProfileID] ON [dbo].[TransportProgressStatusRequest] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_ProfileExecutionID] ON [dbo].[TransportProgressStatusRequest] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_ID] ON [dbo].[TransportProgressStatusRequest] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_CopyIndicator] ON [dbo].[TransportProgressStatusRequest] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_UUID] ON [dbo].[TransportProgressStatusRequest] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_IssueDate] ON [dbo].[TransportProgressStatusRequest] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_IssueTime] ON [dbo].[TransportProgressStatusRequest] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_Note] ON [dbo].[TransportProgressStatusRequest] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_Signature] ON [dbo].[TransportProgressStatusRequest] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_SenderParty] ON [dbo].[TransportProgressStatusRequest] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_ReceiverParty] ON [dbo].[TransportProgressStatusRequest] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_TransportMeans] ON [dbo].[TransportProgressStatusRequest] 
(
	[TransportMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportProgressStatusRequest_StatusLocation] ON [dbo].[TransportProgressStatusRequest] 
(
	[StatusLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportServiceDescription] Script Date: 2013-10-13 00:21z
A document sent by a transport service provider to announce the availability of a transport service.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportServiceDescription](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [ServiceName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** A name, assigned by the Transport Service Provider, for the service being announced. */
  [ResponseCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying a response related to the Transport Service Description. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party sending the Transport Service Description. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving the Transport Service Description. */
  [TransportServiceDescriptionRequestDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A Transport Service Description Request to which this Transport Service Description is a response. */
  [TransportServiceProviderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The transport service provider. */
  [ServiceChargePaymentTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Terms ** The terms of payment under which the transport service would be provided. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** A period during which this Transport Service Description is valid. */
  [TransportationService] [numeric](18,0) NULL, /* 0..n ASBIE Transportation Service ** A transportation service announced in this Transport Service Description. */
 CONSTRAINT [PK_TransportServiceDescription] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_UBLVersionID] ON [dbo].[TransportServiceDescription] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_CustomizationID] ON [dbo].[TransportServiceDescription] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_ProfileID] ON [dbo].[TransportServiceDescription] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_ProfileExecutionID] ON [dbo].[TransportServiceDescription] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_ID] ON [dbo].[TransportServiceDescription] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_CopyIndicator] ON [dbo].[TransportServiceDescription] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_UUID] ON [dbo].[TransportServiceDescription] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_IssueDate] ON [dbo].[TransportServiceDescription] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_IssueTime] ON [dbo].[TransportServiceDescription] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_Note] ON [dbo].[TransportServiceDescription] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_ServiceName] ON [dbo].[TransportServiceDescription] 
(
	[ServiceName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_ResponseCode] ON [dbo].[TransportServiceDescription] 
(
	[ResponseCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_Signature] ON [dbo].[TransportServiceDescription] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_SenderParty] ON [dbo].[TransportServiceDescription] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_ReceiverParty] ON [dbo].[TransportServiceDescription] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_TransportServiceDescriptionRequestDocumentReference] ON [dbo].[TransportServiceDescription] 
(
	[TransportServiceDescriptionRequestDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_TransportServiceProviderParty] ON [dbo].[TransportServiceDescription] 
(
	[TransportServiceProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_ServiceChargePaymentTerms] ON [dbo].[TransportServiceDescription] 
(
	[ServiceChargePaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_ValidityPeriod] ON [dbo].[TransportServiceDescription] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescription_TransportationService] ON [dbo].[TransportServiceDescription] 
(
	[TransportationService] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportServiceDescriptionRequest] Script Date: 2013-10-13 00:21z
A document requesting a Transport Service Description, sent from a party with a transport demand (transport user) to a party providing transport services (transport service provider).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportServiceDescriptionRequest](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NOT NULL, /* 1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [ServiceInformationPreferenceCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the category of service information requested to be provided in the Transport Service Description. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party sending the Transport Service Description Request. */
  [ReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party receiving the Transport Service Description Request. */
  [TransportServiceProviderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The transport service provider. */
  [TransportationService] [numeric](18,0) NOT NULL, /* 1..n ASBIE Transportation Service ** A transportation service about which information is requested. */
 CONSTRAINT [PK_TransportServiceDescriptionRequest] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_UBLVersionID] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_CustomizationID] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_ProfileID] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_ProfileExecutionID] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_ID] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_CopyIndicator] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_UUID] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_IssueDate] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_IssueTime] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_Note] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_ServiceInformationPreferenceCode] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[ServiceInformationPreferenceCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_Signature] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_SenderParty] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_ReceiverParty] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_TransportServiceProviderParty] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[TransportServiceProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportServiceDescriptionRequest_TransportationService] ON [dbo].[TransportServiceDescriptionRequest] 
(
	[TransportationService] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[UnawardedNotification] Script Date: 2013-10-13 00:21z
A document communicating to a tenderer that the contract has been awarded to different tenderer.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[UnawardedNotification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [ContractFolderID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier, assigned by the sender, for the process file (i.e., record) to which this document belongs. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [ContractName] [numeric](18,0) NULL, /* 0..n BBIE Text ** The name, expressed as text, of this procurement project. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this document. */
  [MinutesDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a set of minutes associated with this award. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. It can be used to include annex documents such as the minutes of the awarding process meetings. */
  [TenderResult] [numeric](18,0) NOT NULL, /* 1..n ASBIE Tender Result ** An association to the Tender Result being notified */
  [AppealTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Appeal Terms ** Terms of appeal for this tendering process. */
 CONSTRAINT [PK_UnawardedNotification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_UBLVersionID] ON [dbo].[UnawardedNotification] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_CustomizationID] ON [dbo].[UnawardedNotification] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_ProfileID] ON [dbo].[UnawardedNotification] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_ProfileExecutionID] ON [dbo].[UnawardedNotification] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_ID] ON [dbo].[UnawardedNotification] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_CopyIndicator] ON [dbo].[UnawardedNotification] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_UUID] ON [dbo].[UnawardedNotification] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_ContractFolderID] ON [dbo].[UnawardedNotification] 
(
	[ContractFolderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_IssueDate] ON [dbo].[UnawardedNotification] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_IssueTime] ON [dbo].[UnawardedNotification] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_ContractName] ON [dbo].[UnawardedNotification] 
(
	[ContractName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_Note] ON [dbo].[UnawardedNotification] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_Signature] ON [dbo].[UnawardedNotification] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_SenderParty] ON [dbo].[UnawardedNotification] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_ReceiverParty] ON [dbo].[UnawardedNotification] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_MinutesDocumentReference] ON [dbo].[UnawardedNotification] 
(
	[MinutesDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_AdditionalDocumentReference] ON [dbo].[UnawardedNotification] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_TenderResult] ON [dbo].[UnawardedNotification] 
(
	[TenderResult] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnawardedNotification_AppealTerms] ON [dbo].[UnawardedNotification] 
(
	[AppealTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[UtilityStatement] Script Date: 2013-10-13 00:21z
A supplement to an Invoice or Credit Note, containing information on the consumption of services provided by utility suppliers to private and public customers, including electricity, gas, water, and telephone services.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[UtilityStatement](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether this document is a copy (true) or not (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [UtilityStatementTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the type of Utility Statement. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [DocumentCurrencyCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the default currency for this document. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting cost code, applied to the UtilityStatement. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting cost code, applied to the UtilityStatement, expressed as text. */
  [ParentDocumentReference] [numeric](18,0) NOT NULL, /* 1 ASBIE Document Reference ** A reference to the parent Invoice or Credit Note. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document associated with this document. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
  [SenderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party sending this document. */
  [ReceiverParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party receiving this document. */
  [CustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer, if different from the receiver of the document. */
  [SubscriberParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The subscriber (user or receiver of the service), if different from the buyer and from the party receiving this document. */
  [MainOnAccountPayment] [numeric](18,0) NULL, /* 0..n ASBIE On Account Payment ** A payment on an account. */
  [SubscriberConsumption] [numeric](18,0) NULL, /* 0..n ASBIE Subscriber Consumption ** A utility statement for a particular consumption point. */
 CONSTRAINT [PK_UtilityStatement] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_UBLVersionID] ON [dbo].[UtilityStatement] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_CustomizationID] ON [dbo].[UtilityStatement] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_ProfileID] ON [dbo].[UtilityStatement] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_ProfileExecutionID] ON [dbo].[UtilityStatement] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_ID] ON [dbo].[UtilityStatement] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_CopyIndicator] ON [dbo].[UtilityStatement] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_UUID] ON [dbo].[UtilityStatement] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_IssueDate] ON [dbo].[UtilityStatement] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_IssueTime] ON [dbo].[UtilityStatement] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_UtilityStatementTypeCode] ON [dbo].[UtilityStatement] 
(
	[UtilityStatementTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_Note] ON [dbo].[UtilityStatement] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_DocumentCurrencyCode] ON [dbo].[UtilityStatement] 
(
	[DocumentCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_AccountingCostCode] ON [dbo].[UtilityStatement] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_AccountingCost] ON [dbo].[UtilityStatement] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_ParentDocumentReference] ON [dbo].[UtilityStatement] 
(
	[ParentDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_AdditionalDocumentReference] ON [dbo].[UtilityStatement] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_Signature] ON [dbo].[UtilityStatement] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_SenderParty] ON [dbo].[UtilityStatement] 
(
	[SenderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_ReceiverParty] ON [dbo].[UtilityStatement] 
(
	[ReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_CustomerParty] ON [dbo].[UtilityStatement] 
(
	[CustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_SubscriberParty] ON [dbo].[UtilityStatement] 
(
	[SubscriberParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_MainOnAccountPayment] ON [dbo].[UtilityStatement] 
(
	[MainOnAccountPayment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityStatement_SubscriberConsumption] ON [dbo].[UtilityStatement] 
(
	[SubscriberConsumption] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Waybill] Script Date: 2013-10-13 00:21z
A transport document describing a shipment It is issued by the party who undertakes to provide transportation services, or undertakes to arrange for their provision, to the party who gives instructions for the transportation services (shipper, consignor, etc.). It states the instructions for the beneficiary and may contain the details of the transportation, charges, and terms and conditions under which the transportation service is provided.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Waybill](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UBLVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the earliest version of the UBL 2 schema for this document type that defines all of the elements that might be encountered in the current instance. */
  [CustomizationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined customization of UBL for a specific use. */
  [ProfileID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a user-defined profile of the customization of UBL being used. */
  [ProfileExecutionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies an instance of executing a profile, to associate all transactions in a collaboration. */
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this document, assigned by the sender. */
  [CarrierAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier (in the form of a reference number) assigned by a carrier or its agent to identify a specific shipment. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for an instance of this document. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender, on which this document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender, at which this document was issued. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Text, assigned by the sender, that identifies this document to business users. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the contents of the Waybill. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this document, conveying information that is not contained explicitly in other structures. */
  [ShippingOrderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier (in the form of a reference number) of the Shipping Order or Forwarding Instruction associated with this shipment. */
  [AdValoremIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** A term used in commerce in reference to certain duties, called ad valorem duties, which are levied on commodities at certain rates per centum on their value. */
  [DeclaredCarriageValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** Value declared by the shipper or his agent solely for the purpose of varying the carrier's level of liability from that provided in the contract of carriage in case of loss or damage to goods or delayed delivery. */
  [OtherInstruction] [numeric](18,0) NULL, /* 0..n BBIE Text ** Other free-text instructions related to the shipment to the forwarders or carriers. This should only be used where such information cannot be represented in other structured information entities within the document. */
  [ConsignorParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party consigning goods, as stipulated in the transport contract by the party ordering transport. */
  [CarrierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party providing the transport of goods between named points. */
  [FreightForwarderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A party combining individual smaller consignments into a single larger shipment (a so-called consolidated consignment or shipment) that is sent to a counterpart who mirrors the consolidator's activity by dividing the consolidated consignment into its original components. */
  [Shipment] [numeric](18,0) NOT NULL, /* 1 ASBIE Shipment ** A description of the shipment. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to another document associated with this document. */
  [ExchangeRate] [numeric](18,0) NULL, /* 0..n ASBIE Exchange Rate ** Information about the rate of exchange (conversion) between two currencies. */
  [DocumentDistribution] [numeric](18,0) NULL, /* 0..n ASBIE Document Distribution ** A list of interested parties to whom this document is distributed. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this document. */
 CONSTRAINT [PK_Waybill] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_UBLVersionID] ON [dbo].[Waybill] 
(
	[UBLVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_CustomizationID] ON [dbo].[Waybill] 
(
	[CustomizationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_ProfileID] ON [dbo].[Waybill] 
(
	[ProfileID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_ProfileExecutionID] ON [dbo].[Waybill] 
(
	[ProfileExecutionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_ID] ON [dbo].[Waybill] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_CarrierAssignedID] ON [dbo].[Waybill] 
(
	[CarrierAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_UUID] ON [dbo].[Waybill] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_IssueDate] ON [dbo].[Waybill] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_IssueTime] ON [dbo].[Waybill] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_Name] ON [dbo].[Waybill] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_Description] ON [dbo].[Waybill] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_Note] ON [dbo].[Waybill] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_ShippingOrderID] ON [dbo].[Waybill] 
(
	[ShippingOrderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_AdValoremIndicator] ON [dbo].[Waybill] 
(
	[AdValoremIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_DeclaredCarriageValueAmount] ON [dbo].[Waybill] 
(
	[DeclaredCarriageValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_OtherInstruction] ON [dbo].[Waybill] 
(
	[OtherInstruction] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_ConsignorParty] ON [dbo].[Waybill] 
(
	[ConsignorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_CarrierParty] ON [dbo].[Waybill] 
(
	[CarrierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_FreightForwarderParty] ON [dbo].[Waybill] 
(
	[FreightForwarderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_Shipment] ON [dbo].[Waybill] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_DocumentReference] ON [dbo].[Waybill] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_ExchangeRate] ON [dbo].[Waybill] 
(
	[ExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_DocumentDistribution] ON [dbo].[Waybill] 
(
	[DocumentDistribution] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Waybill_Signature] ON [dbo].[Waybill] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ActivityDataLine] Script Date: 2013-10-13 00:21z
A class to associate a time period and locations (activity data) with an item for inventory planning purposes.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ActivityDataLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this activity data line. */
  [SupplyChainActivityTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the type of supply chain activity. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer of the item. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller of the item. */
  [ActivityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which the activity is realized. */
  [ActivityOriginLocation] [numeric](18,0) NOT NULL, /* 1 ASBIE Location ** Either the location where the movement of goods is observed or the location from which the goods are moved. */
  [ActivityFinalLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location to which the goods are moved. */
  [SalesItem] [numeric](18,0) NOT NULL, /* 1..n ASBIE Sales Item ** Sales information for an item to which this line applies. */
 CONSTRAINT [PK_ActivityDataLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ActivityDataLine_ID] ON [dbo].[ActivityDataLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ActivityDataLine_SupplyChainActivityTypeCode] ON [dbo].[ActivityDataLine] 
(
	[SupplyChainActivityTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ActivityDataLine_BuyerCustomerParty] ON [dbo].[ActivityDataLine] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ActivityDataLine_SellerSupplierParty] ON [dbo].[ActivityDataLine] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ActivityDataLine_ActivityPeriod] ON [dbo].[ActivityDataLine] 
(
	[ActivityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ActivityDataLine_ActivityOriginLocation] ON [dbo].[ActivityDataLine] 
(
	[ActivityOriginLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ActivityDataLine_ActivityFinalLocation] ON [dbo].[ActivityDataLine] 
(
	[ActivityFinalLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ActivityDataLine_SalesItem] ON [dbo].[ActivityDataLine] 
(
	[SalesItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ActivityProperty] Script Date: 2013-10-13 00:21z
A class to define a name/value pair for a property of an inventory planning activity.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ActivityProperty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Name] [numeric](18,0) NOT NULL, /* 1 BBIE Name ** The name of this activity property. */
  [Value] [numeric](18,0) NOT NULL, /* 1 BBIE Text ** The value of this activity property. */
 CONSTRAINT [PK_ActivityProperty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ActivityProperty_Name] ON [dbo].[ActivityProperty] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ActivityProperty_Value] ON [dbo].[ActivityProperty] 
(
	[Value] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Address] Script Date: 2013-10-13 00:21z
A class to define common information related to an address.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Address](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this address within an agreed scheme of address identifiers. */
  [AddressTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A mutually agreed code signifying the type of this address. */
  [AddressFormatCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A mutually agreed code signifying the format of this address. */
  [Postbox] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A post office box number registered for postal delivery by a postal service provider. */
  [Floor] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An identifiable floor of a building. */
  [Room] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An identifiable room, suite, or apartment of a building. */
  [StreetName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of the street, road, avenue, way, etc. to which the number of the building is attached. */
  [AdditionalStreetName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** An additional street name used to further clarify the address. */
  [BlockName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of the block (an area surrounded by streets and usually containing several buildings) in which this address is located. */
  [BuildingName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of a building. */
  [BuildingNumber] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The number of a building within the street. */
  [InhouseMail] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The specific identifable location within a building where mail is delivered. */
  [Department] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The department of the addressee. */
  [MarkAttention] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The name, expressed as text, of a person or department in an organization to whose attention incoming mail is directed; corresponds to the printed forms "for the attention of", "FAO", and ATTN:". */
  [MarkCare] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The name, expressed as text, of a person or organization at this address into whose care incoming mail is entrusted; corresponds to the printed forms "care of" and "c/o". */
  [PlotIdentification] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An identifier (e.g., a parcel number) for the piece of land associated with this address. */
  [CitySubdivisionName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of the subdivision of a city, town, or village in which this address is located, such as the name of its district or borough. */
  [CityName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of a city, town, or village. */
  [PostalZone] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The postal identifier for this address according to the relevant national postal service, such as a ZIP code or Post Code. */
  [CountrySubentity] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The political or administrative division of a country in which this address is located, such as the name of its county, province, or state, expressed as text. */
  [CountrySubentityCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The political or administrative division of a country in which this address is located, such as a county, province, or state, expressed as a code (typically nationally agreed). */
  [Region] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The recognized geographic or economic region or group of countries in which this address is located. */
  [District] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The district or geographical division of a country or region in which this address is located. */
  [TimezoneOffset] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The time zone in which this address is located (as an offset from Universal Coordinated Time (UTC)) at the time of exchange. */
  [AddressLine] [numeric](18,0) NULL, /* 0..n ASBIE Address Line ** An unstructured address line. */
  [Country] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country in which this address is situated. */
  [LocationCoordinate] [numeric](18,0) NULL, /* 0..n ASBIE Location Coordinate ** The geographical coordinates of this address. */
 CONSTRAINT [PK_Address] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_ID] ON [dbo].[Address] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_AddressTypeCode] ON [dbo].[Address] 
(
	[AddressTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_AddressFormatCode] ON [dbo].[Address] 
(
	[AddressFormatCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_Postbox] ON [dbo].[Address] 
(
	[Postbox] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_Floor] ON [dbo].[Address] 
(
	[Floor] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_Room] ON [dbo].[Address] 
(
	[Room] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_StreetName] ON [dbo].[Address] 
(
	[StreetName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_AdditionalStreetName] ON [dbo].[Address] 
(
	[AdditionalStreetName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_BlockName] ON [dbo].[Address] 
(
	[BlockName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_BuildingName] ON [dbo].[Address] 
(
	[BuildingName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_BuildingNumber] ON [dbo].[Address] 
(
	[BuildingNumber] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_InhouseMail] ON [dbo].[Address] 
(
	[InhouseMail] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_Department] ON [dbo].[Address] 
(
	[Department] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_MarkAttention] ON [dbo].[Address] 
(
	[MarkAttention] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_MarkCare] ON [dbo].[Address] 
(
	[MarkCare] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_PlotIdentification] ON [dbo].[Address] 
(
	[PlotIdentification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_CitySubdivisionName] ON [dbo].[Address] 
(
	[CitySubdivisionName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_CityName] ON [dbo].[Address] 
(
	[CityName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_PostalZone] ON [dbo].[Address] 
(
	[PostalZone] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_CountrySubentity] ON [dbo].[Address] 
(
	[CountrySubentity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_CountrySubentityCode] ON [dbo].[Address] 
(
	[CountrySubentityCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_Region] ON [dbo].[Address] 
(
	[Region] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_District] ON [dbo].[Address] 
(
	[District] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_TimezoneOffset] ON [dbo].[Address] 
(
	[TimezoneOffset] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_AddressLine] ON [dbo].[Address] 
(
	[AddressLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_Country] ON [dbo].[Address] 
(
	[Country] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Address_LocationCoordinate] ON [dbo].[Address] 
(
	[LocationCoordinate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[AddressLine] Script Date: 2013-10-13 00:21z
A class to define an unstructured address line.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[AddressLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Line] [numeric](18,0) NOT NULL, /* 1 BBIE Text ** An address line expressed as unstructured text. */
 CONSTRAINT [PK_AddressLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AddressLine_Line] ON [dbo].[AddressLine] 
(
	[Line] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[AirTransport] Script Date: 2013-10-13 00:21z
A class to identify a specific aircraft used for transportation.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[AirTransport](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [AircraftID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifer for a specific aircraft. */
 CONSTRAINT [PK_AirTransport] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AirTransport_AircraftID] ON [dbo].[AirTransport] 
(
	[AircraftID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[AllowanceCharge] Script Date: 2013-10-13 00:21z
A class to describe information about a charge or discount as applied to a price component.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[AllowanceCharge](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this allowance or charge. */
  [ChargeIndicator] [numeric](18,0) NOT NULL, /* 1 BBIE Indicator ** An indicator that this AllowanceCharge describes a charge (true) or a discount (false). */
  [AllowanceChargeReasonCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A mutually agreed code signifying the reason for this allowance or charge. */
  [AllowanceChargeReason] [numeric](18,0) NULL, /* 0..n BBIE Text ** The reason for this allowance or charge. */
  [MultiplierFactorNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** A number by which the base amount is multiplied to calculate the actual amount of this allowance or charge. */
  [PrepaidIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this allowance or charge is prepaid (true) or not (false). */
  [SequenceNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** A number indicating the order of this allowance or charge in the sequence of calculations applied when there are multiple allowances or charges. */
  [Amount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The monetary amount of this allowance or charge to be applied. */
  [BaseAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount to which the multiplier factor is applied in calculating the amount of this allowance or charge. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The accounting cost centre used by the buyer to account for this allowance or charge, expressed as a code. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The accounting cost centre used by the buyer to account for this allowance or charge, expressed as text. */
  [PerUnitAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The allowance or charge per item; the total allowance or charge is calculated by multiplying the per unit amount by the quantity of items, either at the level of the individual transaction line or for the total number of items in the document, depending on the context in which it appears. */
  [TaxCategory] [numeric](18,0) NULL, /* 0..n ASBIE Tax Category ** A tax category applicable to this allowance or charge. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..1 ASBIE Tax Total ** The total of all the taxes applicable to this allowance or charge. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..n ASBIE Payment Means ** A means of payment for this allowance or charge. */
 CONSTRAINT [PK_AllowanceCharge] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_ID] ON [dbo].[AllowanceCharge] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_ChargeIndicator] ON [dbo].[AllowanceCharge] 
(
	[ChargeIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_AllowanceChargeReasonCode] ON [dbo].[AllowanceCharge] 
(
	[AllowanceChargeReasonCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_AllowanceChargeReason] ON [dbo].[AllowanceCharge] 
(
	[AllowanceChargeReason] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_MultiplierFactorNumeric] ON [dbo].[AllowanceCharge] 
(
	[MultiplierFactorNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_PrepaidIndicator] ON [dbo].[AllowanceCharge] 
(
	[PrepaidIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_SequenceNumeric] ON [dbo].[AllowanceCharge] 
(
	[SequenceNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_Amount] ON [dbo].[AllowanceCharge] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_BaseAmount] ON [dbo].[AllowanceCharge] 
(
	[BaseAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_AccountingCostCode] ON [dbo].[AllowanceCharge] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_AccountingCost] ON [dbo].[AllowanceCharge] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_PerUnitAmount] ON [dbo].[AllowanceCharge] 
(
	[PerUnitAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_TaxCategory] ON [dbo].[AllowanceCharge] 
(
	[TaxCategory] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_TaxTotal] ON [dbo].[AllowanceCharge] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AllowanceCharge_PaymentMeans] ON [dbo].[AllowanceCharge] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[AppealTerms] Script Date: 2013-10-13 00:21z
A class to describe the terms and conditions, set by the contracting authority, under which an appeal can be lodged for a tender award.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[AppealTerms](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the terms of an appeal. */
  [PresentationPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which an appeal can be presented. */
  [AppealInformationParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party presenting the information for an appeal. */
  [AppealReceiverParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party to whom an appeal should be presented. */
  [MediationParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that has been appointed to mediate any appeal. */
 CONSTRAINT [PK_AppealTerms] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AppealTerms_Description] ON [dbo].[AppealTerms] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AppealTerms_PresentationPeriod] ON [dbo].[AppealTerms] 
(
	[PresentationPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AppealTerms_AppealInformationParty] ON [dbo].[AppealTerms] 
(
	[AppealInformationParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AppealTerms_AppealReceiverParty] ON [dbo].[AppealTerms] 
(
	[AppealReceiverParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AppealTerms_MediationParty] ON [dbo].[AppealTerms] 
(
	[MediationParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Attachment] Script Date: 2013-10-13 00:21z
A class to describe an attached document. An attachment can refer to an external document or be included with the document being exchanged.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Attachment](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [EmbeddedDocumentBinaryObject] [numeric](18,0) NULL, /* 0..1 BBIE Binary Object ** A binary large object containing an attached document. */
  [ExternalReference] [numeric](18,0) NULL, /* 0..1 ASBIE External Reference ** A reference to an attached document that is external to the document(s) being exchanged. */
 CONSTRAINT [PK_Attachment] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Attachment_EmbeddedDocumentBinaryObject] ON [dbo].[Attachment] 
(
	[EmbeddedDocumentBinaryObject] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Attachment_ExternalReference] ON [dbo].[Attachment] 
(
	[ExternalReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[AuctionTerms] Script Date: 2013-10-13 00:21z
A class to describe the terms to be fulfilled by tenderers if an auction is to be executed before the awarding of a tender.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[AuctionTerms](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [AuctionConstraintIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether an electronic auction will be used before the awarding of a contract (true) or not (false). */
  [JustificationDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing a justification for the use of an auction in awarding the tender. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text for tenderers describing terms governing the auction. */
  [ProcessDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the auction process. */
  [ConditionsDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the conditions under which the tenderers will be able to bid as part of the auction. */
  [ElectronicDeviceDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing an electronic device used for the auction, including associated connectivity specifications. */
  [AuctionURI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The Uniform Resource Identifier (URI) of the electronic device used for the auction. */
 CONSTRAINT [PK_AuctionTerms] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AuctionTerms_AuctionConstraintIndicator] ON [dbo].[AuctionTerms] 
(
	[AuctionConstraintIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AuctionTerms_JustificationDescription] ON [dbo].[AuctionTerms] 
(
	[JustificationDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AuctionTerms_Description] ON [dbo].[AuctionTerms] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AuctionTerms_ProcessDescription] ON [dbo].[AuctionTerms] 
(
	[ProcessDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AuctionTerms_ConditionsDescription] ON [dbo].[AuctionTerms] 
(
	[ConditionsDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AuctionTerms_ElectronicDeviceDescription] ON [dbo].[AuctionTerms] 
(
	[ElectronicDeviceDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AuctionTerms_AuctionURI] ON [dbo].[AuctionTerms] 
(
	[AuctionURI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[AwardingCriterion] Script Date: 2013-10-13 00:21z
A class to define a criterion from the contracting party that will be taken into account when awarding a contract. An awarding criterion can be objective, when it can be evaluated following a formula, or subjective, when human analysis is required.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[AwardingCriterion](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies a specific awarding criterion. */
  [AwardingCriterionTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code used to define this awarding criterion.  */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** A description of the awarding criterion. */
  [WeightNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** A number defining the comparative weighting assigned to this awarding criterion, to enable formulaic evaluation. */
  [Weight] [numeric](18,0) NULL, /* 0..n BBIE Text ** A description of the comparative weighting for this awarding criterion. */
  [CalculationExpression] [numeric](18,0) NULL, /* 0..n BBIE Text ** The mathematical expression that will be used to evaluate this criterion. */
  [CalculationExpressionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code identifying the mathematical expression that will be used to evaluate this criterion. */
  [MinimumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The minimum quantity for an awarding criterion. */
  [MaximumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The maximum quantity for an awarding criterion. */
  [MinimumAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The minimum monetary amount for an awarding criterion. */
  [MaximumAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The maximum monetary amount for an awarding criterion. */
  [MinimumImprovementBid] [numeric](18,0) NULL, /* 0..n BBIE Text ** Describes the minimum improvement bid for this awarding criterion when used in an auction. */
  [SubordinateAwardingCriterion] [numeric](18,0) NULL, /* 0..n ASBIE Awarding Criterion ** Defines any subsidiary awarding criterion. */
 CONSTRAINT [PK_AwardingCriterion] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_ID] ON [dbo].[AwardingCriterion] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_AwardingCriterionTypeCode] ON [dbo].[AwardingCriterion] 
(
	[AwardingCriterionTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_Description] ON [dbo].[AwardingCriterion] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_WeightNumeric] ON [dbo].[AwardingCriterion] 
(
	[WeightNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_Weight] ON [dbo].[AwardingCriterion] 
(
	[Weight] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_CalculationExpression] ON [dbo].[AwardingCriterion] 
(
	[CalculationExpression] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_CalculationExpressionCode] ON [dbo].[AwardingCriterion] 
(
	[CalculationExpressionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_MinimumQuantity] ON [dbo].[AwardingCriterion] 
(
	[MinimumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_MaximumQuantity] ON [dbo].[AwardingCriterion] 
(
	[MaximumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_MinimumAmount] ON [dbo].[AwardingCriterion] 
(
	[MinimumAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_MaximumAmount] ON [dbo].[AwardingCriterion] 
(
	[MaximumAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_MinimumImprovementBid] ON [dbo].[AwardingCriterion] 
(
	[MinimumImprovementBid] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterion_SubordinateAwardingCriterion] ON [dbo].[AwardingCriterion] 
(
	[SubordinateAwardingCriterion] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[AwardingCriterionResponse] Script Date: 2013-10-13 00:21z
Defines the response for an awarding criterion from the tendering party.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[AwardingCriterionResponse](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identification of this awarding criterion response. */
  [AwardingCriterionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifer of the awarding criterion being referred to. */
  [AwardingCriterionDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Describes the awarding criterion. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Describes the awarding criterion response. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Specifies the quantity tendered for this awarding criterion. */
  [Amount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** Specifies the monetary amount tendered for this awarding criterion. */
  [SubordinateAwardingCriterionResponse] [numeric](18,0) NULL, /* 0..n ASBIE Awarding Criterion Response ** Defines responses to any subsidiary awarding criterion. */
 CONSTRAINT [PK_AwardingCriterionResponse] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterionResponse_ID] ON [dbo].[AwardingCriterionResponse] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterionResponse_AwardingCriterionID] ON [dbo].[AwardingCriterionResponse] 
(
	[AwardingCriterionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterionResponse_AwardingCriterionDescription] ON [dbo].[AwardingCriterionResponse] 
(
	[AwardingCriterionDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterionResponse_Description] ON [dbo].[AwardingCriterionResponse] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterionResponse_Quantity] ON [dbo].[AwardingCriterionResponse] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterionResponse_Amount] ON [dbo].[AwardingCriterionResponse] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingCriterionResponse_SubordinateAwardingCriterionResponse] ON [dbo].[AwardingCriterionResponse] 
(
	[SubordinateAwardingCriterionResponse] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[AwardingTerms] Script Date: 2013-10-13 00:21z
A class to define the terms for awarding a contract.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[AwardingTerms](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [WeightingAlgorithmCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the weighting algorithm for awarding criteria. When multiple awarding criteria is used, different weighting and choices management algorithms based upon scores and weights of all award criteria can be used. An algorithm for weighting criteria shall be reported in the call for tenders document. It is used to determine how to perform the final management of tenders based on the results in each of the established award criteria */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing terms under which the contract is to be awarded. */
  [TechnicalCommitteeDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the committee of experts evaluating the subjective criteria for awarding the contract. */
  [LowTendersDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the exclusion criterion for abnormally low tenders. */
  [PrizeIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether a prize will be awarded (true) or not (false). */
  [PrizeDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Number and value of the prizes to be awarded. */
  [PaymentDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Details of payments to all participants. */
  [FollowupContractIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates if any service contract following the contest will be awarded to the winner or one of the winners of the contest (true) or not (false). */
  [BindingOnBuyerIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates if the decision is binding on the buyer (true) or not (false).  */
  [AwardingCriterion] [numeric](18,0) NULL, /* 0..n ASBIE Awarding Criterion ** Defines a criterion for awarding this tender. */
  [TechnicalCommitteePerson] [numeric](18,0) NULL, /* 0..n ASBIE Person ** A member of a committee of experts evaluating the subjective criteria for awarding the contract. */
 CONSTRAINT [PK_AwardingTerms] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingTerms_WeightingAlgorithmCode] ON [dbo].[AwardingTerms] 
(
	[WeightingAlgorithmCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingTerms_Description] ON [dbo].[AwardingTerms] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingTerms_TechnicalCommitteeDescription] ON [dbo].[AwardingTerms] 
(
	[TechnicalCommitteeDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingTerms_LowTendersDescription] ON [dbo].[AwardingTerms] 
(
	[LowTendersDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingTerms_PrizeIndicator] ON [dbo].[AwardingTerms] 
(
	[PrizeIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingTerms_PrizeDescription] ON [dbo].[AwardingTerms] 
(
	[PrizeDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingTerms_PaymentDescription] ON [dbo].[AwardingTerms] 
(
	[PaymentDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingTerms_FollowupContractIndicator] ON [dbo].[AwardingTerms] 
(
	[FollowupContractIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingTerms_BindingOnBuyerIndicator] ON [dbo].[AwardingTerms] 
(
	[BindingOnBuyerIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingTerms_AwardingCriterion] ON [dbo].[AwardingTerms] 
(
	[AwardingCriterion] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_AwardingTerms_TechnicalCommitteePerson] ON [dbo].[AwardingTerms] 
(
	[TechnicalCommitteePerson] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[BillingReference] Script Date: 2013-10-13 00:21z
A class to define a reference to a billing document.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[BillingReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [InvoiceDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to an invoice. */
  [SelfBilledInvoiceDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a self billed invoice. */
  [CreditNoteDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a credit note. */
  [SelfBilledCreditNoteDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a self billed credit note. */
  [DebitNoteDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a debit note. */
  [ReminderDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a billing reminder. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to an additional document. */
  [BillingReferenceLine] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference Line ** A reference to a transaction line in the billing document. */
 CONSTRAINT [PK_BillingReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillingReference_InvoiceDocumentReference] ON [dbo].[BillingReference] 
(
	[InvoiceDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillingReference_SelfBilledInvoiceDocumentReference] ON [dbo].[BillingReference] 
(
	[SelfBilledInvoiceDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillingReference_CreditNoteDocumentReference] ON [dbo].[BillingReference] 
(
	[CreditNoteDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillingReference_SelfBilledCreditNoteDocumentReference] ON [dbo].[BillingReference] 
(
	[SelfBilledCreditNoteDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillingReference_DebitNoteDocumentReference] ON [dbo].[BillingReference] 
(
	[DebitNoteDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillingReference_ReminderDocumentReference] ON [dbo].[BillingReference] 
(
	[ReminderDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillingReference_AdditionalDocumentReference] ON [dbo].[BillingReference] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillingReference_BillingReferenceLine] ON [dbo].[BillingReference] 
(
	[BillingReferenceLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[BillingReferenceLine] Script Date: 2013-10-13 00:21z
A class to define a reference to a transaction line in a billing document.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[BillingReferenceLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this transaction line in a billing document. */
  [Amount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount of the transaction line, including any allowances and charges but excluding taxes. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** An allowance or charge applicable to the transaction line. */
 CONSTRAINT [PK_BillingReferenceLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillingReferenceLine_ID] ON [dbo].[BillingReferenceLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillingReferenceLine_Amount] ON [dbo].[BillingReferenceLine] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BillingReferenceLine_AllowanceCharge] ON [dbo].[BillingReferenceLine] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Branch] Script Date: 2013-10-13 00:21z
A class to describe a branch or a division of an organization.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Branch](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this branch or division of an organization. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this branch or division of an organization. */
  [FinancialInstitution] [numeric](18,0) NULL, /* 0..1 ASBIE Financial Institution ** The financial institution that this branch belongs to (if applicable). */
  [Address] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The address of this branch or division. */
 CONSTRAINT [PK_Branch] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Branch_ID] ON [dbo].[Branch] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Branch_Name] ON [dbo].[Branch] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Branch_FinancialInstitution] ON [dbo].[Branch] 
(
	[FinancialInstitution] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Branch_Address] ON [dbo].[Branch] 
(
	[Address] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[BudgetAccount] Script Date: 2013-10-13 00:21z
A class to define a budget account.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[BudgetAccount](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the budget account, typically an internal accounting reference. */
  [BudgetYearNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of the year for this budget account, e.g. 2012 */
  [RequiredClassificationScheme] [numeric](18,0) NULL, /* 0..1 ASBIE Classification Scheme ** A classification scheme required for this budget account. */
 CONSTRAINT [PK_BudgetAccount] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BudgetAccount_ID] ON [dbo].[BudgetAccount] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BudgetAccount_BudgetYearNumeric] ON [dbo].[BudgetAccount] 
(
	[BudgetYearNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BudgetAccount_RequiredClassificationScheme] ON [dbo].[BudgetAccount] 
(
	[RequiredClassificationScheme] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[BudgetAccountLine] Script Date: 2013-10-13 00:21z
A class to define a budget account line.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[BudgetAccountLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this budget account line. */
  [TotalAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total monetary amount for this budget account line. */
  [BudgetAccount] [numeric](18,0) NULL, /* 0..n ASBIE Budget Account ** An account covering this budget account line. */
 CONSTRAINT [PK_BudgetAccountLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BudgetAccountLine_ID] ON [dbo].[BudgetAccountLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BudgetAccountLine_TotalAmount] ON [dbo].[BudgetAccountLine] 
(
	[TotalAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_BudgetAccountLine_BudgetAccount] ON [dbo].[BudgetAccountLine] 
(
	[BudgetAccount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Capability] Script Date: 2013-10-13 00:21z
A class to describe a specific capability of an organization.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Capability](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [CapabilityTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** This class can be used as Financial or Technical capabilities. For instance, "Turnover" or "Qualified Engineers" are two possible codes. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this capability. */
  [ValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** A monetary amount as a measure of this capability. */
  [ValueQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** A quantity as a measure of this capability. */
  [EvidenceSupplied] [numeric](18,0) NULL, /* 0..n ASBIE Evidence Supplied ** The evidence that supports the capability claim. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period of time for which this capability is (or has been) valid. */
 CONSTRAINT [PK_Capability] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Capability_CapabilityTypeCode] ON [dbo].[Capability] 
(
	[CapabilityTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Capability_Description] ON [dbo].[Capability] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Capability_ValueAmount] ON [dbo].[Capability] 
(
	[ValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Capability_ValueQuantity] ON [dbo].[Capability] 
(
	[ValueQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Capability_EvidenceSupplied] ON [dbo].[Capability] 
(
	[EvidenceSupplied] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Capability_ValidityPeriod] ON [dbo].[Capability] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CardAccount] Script Date: 2013-10-13 00:21z
A class to define a credit card, debit card, or charge card account.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CardAccount](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [PrimaryAccountNumberID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier of the card (e.g., the Primary Account Number (PAN)). */
  [NetworkID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the financial service network provider of the card. */
  [CardTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A mutually agreed code signifying the type of card. Examples of types are "debit", "credit" and "purchasing" */
  [ValidityStartDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date from which the card is valid. */
  [ExpiryDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which the card expires. */
  [IssuerID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the institution issuing the card. */
  [IssueNumberID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the card, specified by the issuer. */
  [CV2ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the Card Verification Value (often found on the reverse of the card itself). */
  [CardChipCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A mutually agreed code to distinguish between CHIP and MAG STRIPE cards. */
  [ChipApplicationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier on the chip card for the application that provides the quoted information; an AID (application ID). */
  [HolderName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of the cardholder. */
 CONSTRAINT [PK_CardAccount] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CardAccount_PrimaryAccountNumberID] ON [dbo].[CardAccount] 
(
	[PrimaryAccountNumberID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CardAccount_NetworkID] ON [dbo].[CardAccount] 
(
	[NetworkID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CardAccount_CardTypeCode] ON [dbo].[CardAccount] 
(
	[CardTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CardAccount_ValidityStartDate] ON [dbo].[CardAccount] 
(
	[ValidityStartDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CardAccount_ExpiryDate] ON [dbo].[CardAccount] 
(
	[ExpiryDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CardAccount_IssuerID] ON [dbo].[CardAccount] 
(
	[IssuerID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CardAccount_IssueNumberID] ON [dbo].[CardAccount] 
(
	[IssueNumberID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CardAccount_CV2ID] ON [dbo].[CardAccount] 
(
	[CV2ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CardAccount_CardChipCode] ON [dbo].[CardAccount] 
(
	[CardChipCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CardAccount_ChipApplicationID] ON [dbo].[CardAccount] 
(
	[ChipApplicationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CardAccount_HolderName] ON [dbo].[CardAccount] 
(
	[HolderName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CatalogueItemSpecificationUpdateLine] Script Date: 2013-10-13 00:21z
A class to define a line describing the transaction that updates the specification of an item in a catalogue.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CatalogueItemSpecificationUpdateLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the line to be updated in a catalogue. */
  [ContractorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The customer responsible for the contract associated with the catalogue item. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller/supplier responsible for the contract associated with the catalogue item. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** The catalogue item to be updated. */
 CONSTRAINT [PK_CatalogueItemSpecificationUpdateLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdateLine_ID] ON [dbo].[CatalogueItemSpecificationUpdateLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdateLine_ContractorCustomerParty] ON [dbo].[CatalogueItemSpecificationUpdateLine] 
(
	[ContractorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdateLine_SellerSupplierParty] ON [dbo].[CatalogueItemSpecificationUpdateLine] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueItemSpecificationUpdateLine_Item] ON [dbo].[CatalogueItemSpecificationUpdateLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CatalogueLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Catalogue describing a purchasable item.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CatalogueLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the line in the catalogue. */
  [ActionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the action required to synchronize this catalogue line. Recommend codes (delete, update, add) */
  [LifeCycleStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the life cycle status of this catalogue line. Examples are pre-order, end of production */
  [ContractSubdivision] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A subdivision of a contract or tender covering this catalogue line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [OrderableIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this catalogue line describes an orderable item (true) or is included for reference purposes only (false). */
  [OrderableUnit] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A textual description of the units in which the item described in this catalogue line can be ordered. */
  [ContentUnitQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The numeric quantity of the ordering unit (and units of measure) of the catalogue line. */
  [OrderQuantityIncrementNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of items that can set the order quantity increments. */
  [MinimumOrderQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The minimum amount of the item described in this catalogue line that can be ordered. */
  [MaximumOrderQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The maximum amount of the item described in this catalogue line that can be ordered. */
  [WarrantyInformation] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text about a warranty (provided by WarrantyParty) for the good or service described in this catalogue line. */
  [PackLevelCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A mutually agreed code signifying the level of packaging associated with the item described in this catalogue line. */
  [ContractorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The customer responsible for the contract with which this catalogue line is associated. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller/supplier responsible for the contract with which this catalogue line is associated. */
  [WarrantyParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party responsible for any warranty associated with the item described in this catalogue line. */
  [WarrantyValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period for which a warranty associated with the item in this catalogue line is valid. */
  [LineValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period for which the information in this catalogue line is valid. */
  [ItemComparison] [numeric](18,0) NULL, /* 0..n ASBIE Item Comparison ** A combination of price and quantity used to provide price comparisons based on different sizes of order. */
  [ComponentRelatedItem] [numeric](18,0) NULL, /* 0..n ASBIE Related Item ** An item that may be a component of the item in this catalogue line. */
  [AccessoryRelatedItem] [numeric](18,0) NULL, /* 0..n ASBIE Related Item ** An item that may be an optional accessory of the item in this catalogue line. */
  [RequiredRelatedItem] [numeric](18,0) NULL, /* 0..n ASBIE Related Item ** An item that may be required for the item in this catalogue line. */
  [ReplacementRelatedItem] [numeric](18,0) NULL, /* 0..n ASBIE Related Item ** An item that may be a replacement for the item in this catalogue line. */
  [ComplementaryRelatedItem] [numeric](18,0) NULL, /* 0..n ASBIE Related Item ** An item that may complement the item in this catalogue line. */
  [ReplacedRelatedItem] [numeric](18,0) NULL, /* 0..n ASBIE Related Item ** An item in an existing catalogue that is being replaced by the item in this catalogue line. */
  [RequiredItemLocationQuantity] [numeric](18,0) NULL, /* 0..n ASBIE Item Location Quantity ** Properties of the item in this catalogue line that are dependent on location and quantity. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this catalogue line. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** A specification of the item itself. */
  [KeywordItemProperty] [numeric](18,0) NULL, /* 0..n ASBIE Item Property ** A property of the item in this catalogue line. */
  [CallForTendersLineReference] [numeric](18,0) NULL, /* 0..1 ASBIE Line Reference ** Reference to a Line on a Call For Tenders document. */
  [CallForTendersDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A class defining references to a Call For Tenders document. */
 CONSTRAINT [PK_CatalogueLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_ID] ON [dbo].[CatalogueLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_ActionCode] ON [dbo].[CatalogueLine] 
(
	[ActionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_LifeCycleStatusCode] ON [dbo].[CatalogueLine] 
(
	[LifeCycleStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_ContractSubdivision] ON [dbo].[CatalogueLine] 
(
	[ContractSubdivision] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_Note] ON [dbo].[CatalogueLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_OrderableIndicator] ON [dbo].[CatalogueLine] 
(
	[OrderableIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_OrderableUnit] ON [dbo].[CatalogueLine] 
(
	[OrderableUnit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_ContentUnitQuantity] ON [dbo].[CatalogueLine] 
(
	[ContentUnitQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_OrderQuantityIncrementNumeric] ON [dbo].[CatalogueLine] 
(
	[OrderQuantityIncrementNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_MinimumOrderQuantity] ON [dbo].[CatalogueLine] 
(
	[MinimumOrderQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_MaximumOrderQuantity] ON [dbo].[CatalogueLine] 
(
	[MaximumOrderQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_WarrantyInformation] ON [dbo].[CatalogueLine] 
(
	[WarrantyInformation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_PackLevelCode] ON [dbo].[CatalogueLine] 
(
	[PackLevelCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_ContractorCustomerParty] ON [dbo].[CatalogueLine] 
(
	[ContractorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_SellerSupplierParty] ON [dbo].[CatalogueLine] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_WarrantyParty] ON [dbo].[CatalogueLine] 
(
	[WarrantyParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_WarrantyValidityPeriod] ON [dbo].[CatalogueLine] 
(
	[WarrantyValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_LineValidityPeriod] ON [dbo].[CatalogueLine] 
(
	[LineValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_ItemComparison] ON [dbo].[CatalogueLine] 
(
	[ItemComparison] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_ComponentRelatedItem] ON [dbo].[CatalogueLine] 
(
	[ComponentRelatedItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_AccessoryRelatedItem] ON [dbo].[CatalogueLine] 
(
	[AccessoryRelatedItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_RequiredRelatedItem] ON [dbo].[CatalogueLine] 
(
	[RequiredRelatedItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_ReplacementRelatedItem] ON [dbo].[CatalogueLine] 
(
	[ReplacementRelatedItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_ComplementaryRelatedItem] ON [dbo].[CatalogueLine] 
(
	[ComplementaryRelatedItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_ReplacedRelatedItem] ON [dbo].[CatalogueLine] 
(
	[ReplacedRelatedItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_RequiredItemLocationQuantity] ON [dbo].[CatalogueLine] 
(
	[RequiredItemLocationQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_DocumentReference] ON [dbo].[CatalogueLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_Item] ON [dbo].[CatalogueLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_KeywordItemProperty] ON [dbo].[CatalogueLine] 
(
	[KeywordItemProperty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_CallForTendersLineReference] ON [dbo].[CatalogueLine] 
(
	[CallForTendersLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueLine_CallForTendersDocumentReference] ON [dbo].[CatalogueLine] 
(
	[CallForTendersDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CataloguePricingUpdateLine] Script Date: 2013-10-13 00:21z
A class to define a line describing a pricing update to a catalogue line.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CataloguePricingUpdateLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the catalogue line to be updated. */
  [ContractorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The customer responsible for the contract associated with the catalogue line being updated. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller/supplier responsible for the contract associated with the catalogue line being updated. */
  [RequiredItemLocationQuantity] [numeric](18,0) NULL, /* 0..n ASBIE Item Location Quantity ** Updated properties of the item in this catalogue line that are dependent on location and quantity. */
 CONSTRAINT [PK_CataloguePricingUpdateLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdateLine_ID] ON [dbo].[CataloguePricingUpdateLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdateLine_ContractorCustomerParty] ON [dbo].[CataloguePricingUpdateLine] 
(
	[ContractorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdateLine_SellerSupplierParty] ON [dbo].[CataloguePricingUpdateLine] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CataloguePricingUpdateLine_RequiredItemLocationQuantity] ON [dbo].[CataloguePricingUpdateLine] 
(
	[RequiredItemLocationQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CatalogueReference] Script Date: 2013-10-13 00:21z
A class to define a reference to a catalogue.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CatalogueReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for a specific catalogue. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for a specific catalogue. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which the catalogue was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which the catalogue was issued. */
  [RevisionDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which the information in the catalogue was last revised. */
  [RevisionTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which the information in the catalogue was last revised. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the catalogue. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the current version of the catalogue. */
  [PreviousVersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the previous version of the catalogue that is superseded by this version. */
 CONSTRAINT [PK_CatalogueReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueReference_ID] ON [dbo].[CatalogueReference] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueReference_UUID] ON [dbo].[CatalogueReference] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueReference_IssueDate] ON [dbo].[CatalogueReference] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueReference_IssueTime] ON [dbo].[CatalogueReference] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueReference_RevisionDate] ON [dbo].[CatalogueReference] 
(
	[RevisionDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueReference_RevisionTime] ON [dbo].[CatalogueReference] 
(
	[RevisionTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueReference_Note] ON [dbo].[CatalogueReference] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueReference_Description] ON [dbo].[CatalogueReference] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueReference_VersionID] ON [dbo].[CatalogueReference] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueReference_PreviousVersionID] ON [dbo].[CatalogueReference] 
(
	[PreviousVersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CatalogueRequestLine] Script Date: 2013-10-13 00:21z
A class to define a line describing a request for a catalogue line.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CatalogueRequestLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the requested catalogue line. */
  [ContractSubdivision] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A subdivision of a contract or tender covering the line being requested. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [LineValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period for which the information in the requested catalogue line is valid. */
  [RequiredItemLocationQuantity] [numeric](18,0) NULL, /* 0..n ASBIE Item Location Quantity ** Properties of the item in the requested catalogue line that are dependent on location and quantity. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** The item associated with the requested catalogue line. */
 CONSTRAINT [PK_CatalogueRequestLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequestLine_ID] ON [dbo].[CatalogueRequestLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequestLine_ContractSubdivision] ON [dbo].[CatalogueRequestLine] 
(
	[ContractSubdivision] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequestLine_Note] ON [dbo].[CatalogueRequestLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequestLine_LineValidityPeriod] ON [dbo].[CatalogueRequestLine] 
(
	[LineValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequestLine_RequiredItemLocationQuantity] ON [dbo].[CatalogueRequestLine] 
(
	[RequiredItemLocationQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CatalogueRequestLine_Item] ON [dbo].[CatalogueRequestLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Certificate] Script Date: 2013-10-13 00:21z
A class to define a certificate applied to the item. Certificated can be a requirement to sell goods or services in a jurisdiction.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Certificate](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this certificate. */
  [CertificateTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** The type of this certificate, expressed as a code. The type specifies what array it belongs to, e.g.. Environmental, security, health improvement etc. */
  [CertificateType] [numeric](18,0) NOT NULL, /* 1 BBIE Text ** The type of this certificate, expressed as a code. The type specifies what array it belongs to, e.g.. Environmental, security, health improvement etc. */
  [Remarks] [numeric](18,0) NULL, /* 0..n BBIE Text ** Remarks by the applicant for this certificate. */
  [IssuerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The authorized organization that issued this certificate, the provider of the certificate. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document relevant to this certificate or an application for this certificate. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this certificate. */
 CONSTRAINT [PK_Certificate] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Certificate_ID] ON [dbo].[Certificate] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Certificate_CertificateTypeCode] ON [dbo].[Certificate] 
(
	[CertificateTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Certificate_CertificateType] ON [dbo].[Certificate] 
(
	[CertificateType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Certificate_Remarks] ON [dbo].[Certificate] 
(
	[Remarks] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Certificate_IssuerParty] ON [dbo].[Certificate] 
(
	[IssuerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Certificate_DocumentReference] ON [dbo].[Certificate] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Certificate_Signature] ON [dbo].[Certificate] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CertificateOfOriginApplication] Script Date: 2013-10-13 00:21z
A class to define an application for a Certificate of Origin (CoO).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CertificateOfOriginApplication](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ReferenceID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for a reference as part of the CoO application. */
  [CertificateType] [numeric](18,0) NOT NULL, /* 1 BBIE Text ** The type of CoO being applied for (Ordinary, Re-export, Commonwealth Preferential, etc.). */
  [ApplicationStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of the application (revision, replacement, etc.). */
  [OriginalJobID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** The latest job number given to the CoO application. This is used by the system to keep track of amendments to or cancellation of any earlier applications. */
  [PreviousJobID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the previous job used in case the application requires query or change. */
  [Remarks] [numeric](18,0) NULL, /* 0..n BBIE Text ** Remarks by the applicant for the CoO. */
  [Shipment] [numeric](18,0) NOT NULL, /* 1 ASBIE Shipment ** The shipment of goods covered by the CoO. */
  [EndorserParty] [numeric](18,0) NOT NULL, /* 1..n ASBIE Endorser Party ** A party providing an endorsement to the CoO. */
  [PreparationParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party (individual, group, or body) that prepared this CoO application. */
  [IssuerParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The organization authorized to issue the CoO requested by this application. */
  [ExporterParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party making an export declaration, or on behalf of which the export declaration is made, and that is the owner of the goods or has similar right of disposal over them at the time when the declaration is accepted. */
  [ImporterParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party making an import declaration, or on behalf of which a customs clearing agent or other authorized person makes an import declaration. This may include a person who has possession of the goods or to whom the goods are consigned. */
  [IssuingCountry] [numeric](18,0) NOT NULL, /* 1 ASBIE Country ** The country where the requested CoO will be issued. */
  [DocumentDistribution] [numeric](18,0) NULL, /* 0..n ASBIE Document Distribution ** An interested party to which the CoO is to be distributed. */
  [SupportingDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document supporting this application. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this application. */
 CONSTRAINT [PK_CertificateOfOriginApplication] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_ReferenceID] ON [dbo].[CertificateOfOriginApplication] 
(
	[ReferenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_CertificateType] ON [dbo].[CertificateOfOriginApplication] 
(
	[CertificateType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_ApplicationStatusCode] ON [dbo].[CertificateOfOriginApplication] 
(
	[ApplicationStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_OriginalJobID] ON [dbo].[CertificateOfOriginApplication] 
(
	[OriginalJobID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_PreviousJobID] ON [dbo].[CertificateOfOriginApplication] 
(
	[PreviousJobID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_Remarks] ON [dbo].[CertificateOfOriginApplication] 
(
	[Remarks] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_Shipment] ON [dbo].[CertificateOfOriginApplication] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_EndorserParty] ON [dbo].[CertificateOfOriginApplication] 
(
	[EndorserParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_PreparationParty] ON [dbo].[CertificateOfOriginApplication] 
(
	[PreparationParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_IssuerParty] ON [dbo].[CertificateOfOriginApplication] 
(
	[IssuerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_ExporterParty] ON [dbo].[CertificateOfOriginApplication] 
(
	[ExporterParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_ImporterParty] ON [dbo].[CertificateOfOriginApplication] 
(
	[ImporterParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_IssuingCountry] ON [dbo].[CertificateOfOriginApplication] 
(
	[IssuingCountry] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_DocumentDistribution] ON [dbo].[CertificateOfOriginApplication] 
(
	[DocumentDistribution] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_SupportingDocumentReference] ON [dbo].[CertificateOfOriginApplication] 
(
	[SupportingDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CertificateOfOriginApplication_Signature] ON [dbo].[CertificateOfOriginApplication] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ClassificationCategory] Script Date: 2013-10-13 00:21z
A class to define a category within a classification scheme.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ClassificationCategory](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this category within the classification scheme. */
  [CodeValue] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The value of a code used to identify this category within the classification scheme. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this category. */
  [CategorizesClassificationCategory] [numeric](18,0) NULL, /* 0..n ASBIE Classification Category ** A recursive description of a subcategory of this category. */
 CONSTRAINT [PK_ClassificationCategory] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationCategory_Name] ON [dbo].[ClassificationCategory] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationCategory_CodeValue] ON [dbo].[ClassificationCategory] 
(
	[CodeValue] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationCategory_Description] ON [dbo].[ClassificationCategory] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationCategory_CategorizesClassificationCategory] ON [dbo].[ClassificationCategory] 
(
	[CategorizesClassificationCategory] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ClassificationScheme] Script Date: 2013-10-13 00:21z
A class to define a classification scheme, such as a taxonomy for classifying goods or services.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ClassificationScheme](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this classification scheme. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this classification scheme. */
  [LastRevisionDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this classification scheme was last revised. */
  [LastRevisionTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this classification scheme was last revised. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this classification scheme. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this classification scheme. */
  [AgencyID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the agency that maintains this classification scheme. */
  [AgencyName] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The name of the agency that maintains the classification scheme. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the version of this classification scheme. */
  [URI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The Uniform Resource Identifier (URI) of the documentation for this classification scheme. */
  [SchemeURI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The Uniform Resource Identifier (URI) of this classification scheme. */
  [LanguageID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the language of this classification scheme. */
  [ClassificationCategory] [numeric](18,0) NOT NULL, /* 1..n ASBIE Classification Category ** A description of a category within this classification scheme. */
 CONSTRAINT [PK_ClassificationScheme] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_ID] ON [dbo].[ClassificationScheme] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_UUID] ON [dbo].[ClassificationScheme] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_LastRevisionDate] ON [dbo].[ClassificationScheme] 
(
	[LastRevisionDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_LastRevisionTime] ON [dbo].[ClassificationScheme] 
(
	[LastRevisionTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_Note] ON [dbo].[ClassificationScheme] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_Name] ON [dbo].[ClassificationScheme] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_Description] ON [dbo].[ClassificationScheme] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_AgencyID] ON [dbo].[ClassificationScheme] 
(
	[AgencyID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_AgencyName] ON [dbo].[ClassificationScheme] 
(
	[AgencyName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_VersionID] ON [dbo].[ClassificationScheme] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_URI] ON [dbo].[ClassificationScheme] 
(
	[URI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_SchemeURI] ON [dbo].[ClassificationScheme] 
(
	[SchemeURI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_LanguageID] ON [dbo].[ClassificationScheme] 
(
	[LanguageID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ClassificationScheme_ClassificationCategory] ON [dbo].[ClassificationScheme] 
(
	[ClassificationCategory] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Clause] Script Date: 2013-10-13 00:21z
A class to define a clause (a distinct article or provision) in a contract, treaty, will, or other formal or legal written document requiring compliance.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Clause](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this clause. */
  [Content] [numeric](18,0) NULL, /* 0..n BBIE Text ** The text of this clause. */
 CONSTRAINT [PK_Clause] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Clause_ID] ON [dbo].[Clause] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Clause_Content] ON [dbo].[Clause] 
(
	[Content] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CommodityClassification] Script Date: 2013-10-13 00:21z
A class to describe the classification of a commodity.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CommodityClassification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [NatureCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code defined by a specific maintenance agency signifying the high-level nature of the commodity. */
  [CargoTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A mutually agreed code signifying the type of cargo for purposes of commodity classification. */
  [CommodityCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The harmonized international commodity code for cross border and regulatory (customs and trade statistics) purposes. */
  [ItemClassificationCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the trade classification of the commodity. */
 CONSTRAINT [PK_CommodityClassification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CommodityClassification_NatureCode] ON [dbo].[CommodityClassification] 
(
	[NatureCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CommodityClassification_CargoTypeCode] ON [dbo].[CommodityClassification] 
(
	[CargoTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CommodityClassification_CommodityCode] ON [dbo].[CommodityClassification] 
(
	[CommodityCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CommodityClassification_ItemClassificationCode] ON [dbo].[CommodityClassification] 
(
	[ItemClassificationCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Communication] Script Date: 2013-10-13 00:21z
A class to describe a means of communication.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Communication](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ChannelCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The method of communication, expressed as a code. */
  [Channel] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The method of communication, expressed as text. */
  [Value] [numeric](18,0) NULL, /* 0..1 BBIE Text ** An identifying value (phone number, email address, etc.) for this channel of communication */
 CONSTRAINT [PK_Communication] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Communication_ChannelCode] ON [dbo].[Communication] 
(
	[ChannelCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Communication_Channel] ON [dbo].[Communication] 
(
	[Channel] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Communication_Value] ON [dbo].[Communication] 
(
	[Value] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CompletedTask] Script Date: 2013-10-13 00:21z
A class to describe the completion of a specific task in the tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CompletedTask](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [AnnualAverageAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The average monetary amount of a task such as this completed task. */
  [TotalTaskAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The actual total monetary amount of this completed task. */
  [PartyCapacityAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** A monetary amount corresponding to the financial capacity of the party that carried out this completed task. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this completed task. */
  [EvidenceSupplied] [numeric](18,0) NULL, /* 0..n ASBIE Evidence Supplied ** The evidence justifying a designation of "complete" for this task. */
  [Period] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period in which this completed task was performed. */
  [RecipientCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The original customer for this completed task. */
 CONSTRAINT [PK_CompletedTask] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CompletedTask_AnnualAverageAmount] ON [dbo].[CompletedTask] 
(
	[AnnualAverageAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CompletedTask_TotalTaskAmount] ON [dbo].[CompletedTask] 
(
	[TotalTaskAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CompletedTask_PartyCapacityAmount] ON [dbo].[CompletedTask] 
(
	[PartyCapacityAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CompletedTask_Description] ON [dbo].[CompletedTask] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CompletedTask_EvidenceSupplied] ON [dbo].[CompletedTask] 
(
	[EvidenceSupplied] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CompletedTask_Period] ON [dbo].[CompletedTask] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CompletedTask_RecipientCustomerParty] ON [dbo].[CompletedTask] 
(
	[RecipientCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Condition] Script Date: 2013-10-13 00:21z
A class to define a measurable condition of an object.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Condition](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [AttributeID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the attribute that applies to the condition. */
  [Measure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The measurement value. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the attribute that applies to the condition. */
  [MinimumMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The minimum value in a range of measurement for this condition. */
  [MaximumMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The maximum value in a range of measurement for this condition. */
 CONSTRAINT [PK_Condition] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Condition_AttributeID] ON [dbo].[Condition] 
(
	[AttributeID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Condition_Measure] ON [dbo].[Condition] 
(
	[Measure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Condition_Description] ON [dbo].[Condition] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Condition_MinimumMeasure] ON [dbo].[Condition] 
(
	[MinimumMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Condition_MaximumMeasure] ON [dbo].[Condition] 
(
	[MaximumMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Consignment] Script Date: 2013-10-13 00:21z
A class to describe an identifiable collection of one or more goods items to be transported between the consignor and the consignee. This information may be defined within a transport contract. A consignment may comprise more than one shipment (e.g., when consolidated by a freight forwarder).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Consignment](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier assigned to a collection of goods for both import and export. */
  [CarrierAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this consignment, assigned by the carrier. */
  [ConsigneeAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this consignment, assigned by the consignee. */
  [ConsignorAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this consignment, assigned by the consignor. */
  [FreightForwarderAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this consignment, assigned by the freight forwarder. */
  [BrokerAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this consignment, assigned by the broker. */
  [ContractedCarrierAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this consignment, assigned by the contracted carrier. */
  [PerformingCarrierAssignedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this consignment, assigned by the performing carrier. */
  [SummaryDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** A textual summary description of the consignment. */
  [TotalInvoiceAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total of all invoice amounts declared in this consignment. */
  [DeclaredCustomsValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total declared value for customs purposes of all the goods in this consignment, regardless of whether they are subject to the same customs procedure, tariff/statistical categorization, country information, or duty regime. */
  [TariffDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the tariff applied to this consignment. */
  [TariffCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the tariff applied to this consignment. */
  [InsurancePremiumAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount of the premium payable to an insurance company for insuring the goods contained in this consignment. */
  [GrossWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total declared weight of the goods in this consignment, including packaging but excluding the carrier's equipment. */
  [NetWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total net weight of all the goods items referred to as one consignment. */
  [NetNetWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total net weight of the goods in this consignment, exclusive of packaging. */
  [ChargeableWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The weight upon which a charge is to be based. */
  [GrossVolumeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total volume of the goods referred to as one consignment. */
  [NetVolumeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total net volume of all goods items referred to as one consignment. */
  [LoadingLengthMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total length in a means of transport or a piece of transport equipment which, given the width and height of the transport means, will accommodate all of the consignments in a single consolidation. */
  [Remarks] [numeric](18,0) NULL, /* 0..n BBIE Text ** Remarks concerning the complete consignment, to be printed on the transport document. */
  [HazardousRiskIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported goods in this consignment are subject to an international regulation concerning the carriage of dangerous goods (true) or not (false). */
  [AnimalFoodIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported goods in this consignment are animal foodstuffs (true) or not (false). */
  [HumanFoodIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported goods in this consignment are for human consumption (true) or not (false). */
  [LivestockIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported goods are livestock (true) or not (false). */
  [BulkCargoIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported goods in this consignment are bulk cargoes (true) or not (false). */
  [ContainerizedIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported goods in this consignment are containerized cargoes (true) or not (false). */
  [GeneralCargoIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported goods in this consignment are general cargoes (true) or not (false). */
  [SpecialSecurityIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported goods in this consignment require special security (true) or not (false). */
  [ThirdPartyPayerIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that this consignment will be paid for by a third party (true) or not (false). */
  [CarrierServiceInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Service instructions to the carrier, expressed as text. */
  [CustomsClearanceServiceInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Service instructions for customs clearance, expressed as text. */
  [ForwarderServiceInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Service instructions for the forwarder, expressed as text. */
  [SpecialServiceInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Special service instructions, expressed as text. */
  [SequenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A sequence identifier for this consignment. */
  [ShippingPriorityLevelCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the priority or level of service required for this consignment. */
  [HandlingCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The handling required for this consignment, expressed as a code. */
  [HandlingInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** The handling required for this consignment, expressed as text. */
  [Information] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this consignment, conveying information that is not contained explicitly in other structures. */
  [TotalGoodsItemQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total number of goods items in this consignment. */
  [TotalTransportHandlingUnitQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of pieces of transport handling equipment (pallets, boxes, cases, etc.) in this consignment. */
  [InsuranceValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount covered by insurance for this consignment. */
  [DeclaredForCarriageValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The value of this consignment, declared by the shipper or his agent solely for the purpose of varying the carrier's level of liability from that provided in the contract of carriage, in case of loss or damage to goods or delayed delivery. */
  [DeclaredStatisticsValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The value, declared for statistical purposes, of those goods in this consignment that have the same statistical heading. */
  [FreeOnBoardValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount that has to be or has been paid as calculated under the applicable trade delivery. */
  [SpecialInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Special instructions relating to this consignment. */
  [SplitConsignmentIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this consignment has been split in transit (true) or not (false). */
  [DeliveryInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** A set of delivery instructions relating to this consignment. */
  [ConsignmentQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The count in this consignment considering goods items, child consignments, shipments */
  [ConsolidatableIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this consignment can be consolidated (true) or not (false). */
  [HaulageInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Instructions regarding haulage of this consignment, expressed as text. */
  [LoadingSequenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the loading sequence of this consignment. */
  [ChildConsignmentQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of (consolidated) child consignments */
  [TotalPackagesQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total number of packages associated with a Consignment. */
  [ConsolidatedShipment] [numeric](18,0) NULL, /* 0..n ASBIE Shipment ** A consolidated shipment (a shipment created by an act of consolidation). */
  [CustomsDeclaration] [numeric](18,0) NULL, /* 0..n ASBIE Customs Declaration ** A class describing identifiers or references relating to customs procedures. */
  [RequestedPickupTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The pickup of this consignment requested by the party requesting a transportation service (the transport user). */
  [RequestedDeliveryTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The delivery of this consignment requested by the party requesting a transportation service (the transport user). */
  [PlannedPickupTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The pickup of this consignment planned by the party responsible for providing the transportation service (the transport service provider). */
  [PlannedDeliveryTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The delivery of this consignment planned by the party responsible for providing the transportation service (the transport service provider). */
  [Status] [numeric](18,0) NULL, /* 0..n ASBIE Status ** The status of a particular condition associated with this consignment. */
  [ChildConsignment] [numeric](18,0) NULL, /* 0..n ASBIE Consignment ** One of the child consignments of which a consolidated consignment is composed. */
  [ConsigneeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A party to which goods are consigned. */
  [ExporterParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that makes the export declaration, or on behalf of which the export declaration is made, and that is the owner of the goods in this consignment or has similar right of disposal over them at the time when the declaration is accepted. */
  [ConsignorParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party consigning goods, as stipulated in the transport contract by the party ordering transport. */
  [ImporterParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that makes an import declaration regarding this consignment, or on behalf of which a customs clearing agent or other authorized person makes an import declaration regarding this consignment. This may include a person who has possession of the goods or to whom the goods are consigned. */
  [CarrierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party providing the transport of goods in this consignment between named points. */
  [FreightForwarderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party combining individual smaller consignments into a single larger shipment (the consolidated shipment), which is sent to a counterpart that mirrors the consolidator's activity by dividing the consolidated consignment into its original components. */
  [NotifyParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party to be notified upon arrival of goods and when special occurrences (usually pre-defined) take place during a transportation service. */
  [OriginalDespatchParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The original despatch (sender) party for this consignment. */
  [FinalDeliveryParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The final delivery party for this consignment. */
  [PerformingCarrierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party performing the carriage of this consignment. */
  [SubstituteCarrierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A substitute party performing the carriage of this consignment. */
  [LogisticsOperatorParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The logistics operator party for this consignment. */
  [TransportAdvisorParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party providing transport advice this consignment. */
  [HazardousItemNotificationParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that would be notified of a hazardous item in this consignment. */
  [InsuranceParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party holding the insurance for this consignment. */
  [MortgageHolderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party holding the mortgage for this consignment. */
  [BillOfLadingHolderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party holding the bill of lading for this consignment. */
  [OriginalDepartureCountry] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country from which the goods in this consignment were originally exported, without any commercial transaction taking place in intermediate countries. */
  [FinalDestinationCountry] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country in which the goods in this consignment are to be delivered to the final consignee or buyer. */
  [TransitCountry] [numeric](18,0) NULL, /* 0..n ASBIE Country ** One of the countries through which goods or passengers in this consignment are routed between the country of original departure and the country of final destination. */
  [TransportContract] [numeric](18,0) NULL, /* 0..1 ASBIE Contract ** A transport contract relating to this consignment. */
  [TransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** A class describing a significant occurrence or happening related to the transportation of goods. */
  [OriginalDespatchTransportationService] [numeric](18,0) NULL, /* 0..1 ASBIE Transportation Service ** The service for pickup from the consignor under the transport contract for this consignment. */
  [FinalDeliveryTransportationService] [numeric](18,0) NULL, /* 0..1 ASBIE Transportation Service ** The service for delivery to the consignee under the transport contract for this consignment. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery Terms ** The conditions agreed upon between a seller and a buyer with regard to the delivery of goods and/or services (e.g., CIF, FOB, or EXW from the INCOTERMS Terms of Delivery). */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Terms ** The terms of payment between the parties (such as logistics service client, logistics service provider) in a transaction. */
  [CollectPaymentTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Terms ** The terms of payment that apply to the collection of this consignment. */
  [DisbursementPaymentTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Terms ** The terms of payment for disbursement. */
  [PrepaidPaymentTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Terms ** The terms of payment for prepayment. */
  [FreightAllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A cost incurred by the shipper in moving goods, by whatever means, from one place to another under the terms of the contract of carriage for this consignment. In addition to transport costs, this may include such elements as packing, documentation, loading, unloading, and insurance to the extent that they relate to the freight costs. */
  [ExtraAllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A charge for extra allowance. */
  [MainCarriageShipmentStage] [numeric](18,0) NULL, /* 0..n ASBIE Shipment Stage ** A shipment stage during main carriage. */
  [PreCarriageShipmentStage] [numeric](18,0) NULL, /* 0..n ASBIE Shipment Stage ** A shipment stage during precarriage (usually refers to movement activity that takes place prior to the container being loaded at a port of loading). */
  [OnCarriageShipmentStage] [numeric](18,0) NULL, /* 0..n ASBIE Shipment Stage ** A shipment stage during on-carriage (usually refers to movement activity that takes place after the container is discharged at a port of discharge). */
  [TransportHandlingUnit] [numeric](18,0) NULL, /* 0..n ASBIE Transport Handling Unit ** A transport handling unit used for loose and containerized goods. */
  [FirstArrivalPortLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The first arrival location in a transport. This would be a port for sea, an airport for air, a terminal for rail, or a border post for land crossing. */
  [LastExitPortLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The final exporting location in a transport. This would be a port for sea, an airport for air, a terminal for rail, or a border post for land crossing. */
 CONSTRAINT [PK_Consignment] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ID] ON [dbo].[Consignment] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_CarrierAssignedID] ON [dbo].[Consignment] 
(
	[CarrierAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ConsigneeAssignedID] ON [dbo].[Consignment] 
(
	[ConsigneeAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ConsignorAssignedID] ON [dbo].[Consignment] 
(
	[ConsignorAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_FreightForwarderAssignedID] ON [dbo].[Consignment] 
(
	[FreightForwarderAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_BrokerAssignedID] ON [dbo].[Consignment] 
(
	[BrokerAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ContractedCarrierAssignedID] ON [dbo].[Consignment] 
(
	[ContractedCarrierAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_PerformingCarrierAssignedID] ON [dbo].[Consignment] 
(
	[PerformingCarrierAssignedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_SummaryDescription] ON [dbo].[Consignment] 
(
	[SummaryDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_TotalInvoiceAmount] ON [dbo].[Consignment] 
(
	[TotalInvoiceAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_DeclaredCustomsValueAmount] ON [dbo].[Consignment] 
(
	[DeclaredCustomsValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_TariffDescription] ON [dbo].[Consignment] 
(
	[TariffDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_TariffCode] ON [dbo].[Consignment] 
(
	[TariffCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_InsurancePremiumAmount] ON [dbo].[Consignment] 
(
	[InsurancePremiumAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_GrossWeightMeasure] ON [dbo].[Consignment] 
(
	[GrossWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_NetWeightMeasure] ON [dbo].[Consignment] 
(
	[NetWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_NetNetWeightMeasure] ON [dbo].[Consignment] 
(
	[NetNetWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ChargeableWeightMeasure] ON [dbo].[Consignment] 
(
	[ChargeableWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_GrossVolumeMeasure] ON [dbo].[Consignment] 
(
	[GrossVolumeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_NetVolumeMeasure] ON [dbo].[Consignment] 
(
	[NetVolumeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_LoadingLengthMeasure] ON [dbo].[Consignment] 
(
	[LoadingLengthMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_Remarks] ON [dbo].[Consignment] 
(
	[Remarks] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_HazardousRiskIndicator] ON [dbo].[Consignment] 
(
	[HazardousRiskIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_AnimalFoodIndicator] ON [dbo].[Consignment] 
(
	[AnimalFoodIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_HumanFoodIndicator] ON [dbo].[Consignment] 
(
	[HumanFoodIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_LivestockIndicator] ON [dbo].[Consignment] 
(
	[LivestockIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_BulkCargoIndicator] ON [dbo].[Consignment] 
(
	[BulkCargoIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ContainerizedIndicator] ON [dbo].[Consignment] 
(
	[ContainerizedIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_GeneralCargoIndicator] ON [dbo].[Consignment] 
(
	[GeneralCargoIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_SpecialSecurityIndicator] ON [dbo].[Consignment] 
(
	[SpecialSecurityIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ThirdPartyPayerIndicator] ON [dbo].[Consignment] 
(
	[ThirdPartyPayerIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_CarrierServiceInstructions] ON [dbo].[Consignment] 
(
	[CarrierServiceInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_CustomsClearanceServiceInstructions] ON [dbo].[Consignment] 
(
	[CustomsClearanceServiceInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ForwarderServiceInstructions] ON [dbo].[Consignment] 
(
	[ForwarderServiceInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_SpecialServiceInstructions] ON [dbo].[Consignment] 
(
	[SpecialServiceInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_SequenceID] ON [dbo].[Consignment] 
(
	[SequenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ShippingPriorityLevelCode] ON [dbo].[Consignment] 
(
	[ShippingPriorityLevelCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_HandlingCode] ON [dbo].[Consignment] 
(
	[HandlingCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_HandlingInstructions] ON [dbo].[Consignment] 
(
	[HandlingInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_Information] ON [dbo].[Consignment] 
(
	[Information] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_TotalGoodsItemQuantity] ON [dbo].[Consignment] 
(
	[TotalGoodsItemQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_TotalTransportHandlingUnitQuantity] ON [dbo].[Consignment] 
(
	[TotalTransportHandlingUnitQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_InsuranceValueAmount] ON [dbo].[Consignment] 
(
	[InsuranceValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_DeclaredForCarriageValueAmount] ON [dbo].[Consignment] 
(
	[DeclaredForCarriageValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_DeclaredStatisticsValueAmount] ON [dbo].[Consignment] 
(
	[DeclaredStatisticsValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_FreeOnBoardValueAmount] ON [dbo].[Consignment] 
(
	[FreeOnBoardValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_SpecialInstructions] ON [dbo].[Consignment] 
(
	[SpecialInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_SplitConsignmentIndicator] ON [dbo].[Consignment] 
(
	[SplitConsignmentIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_DeliveryInstructions] ON [dbo].[Consignment] 
(
	[DeliveryInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ConsignmentQuantity] ON [dbo].[Consignment] 
(
	[ConsignmentQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ConsolidatableIndicator] ON [dbo].[Consignment] 
(
	[ConsolidatableIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_HaulageInstructions] ON [dbo].[Consignment] 
(
	[HaulageInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_LoadingSequenceID] ON [dbo].[Consignment] 
(
	[LoadingSequenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ChildConsignmentQuantity] ON [dbo].[Consignment] 
(
	[ChildConsignmentQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_TotalPackagesQuantity] ON [dbo].[Consignment] 
(
	[TotalPackagesQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ConsolidatedShipment] ON [dbo].[Consignment] 
(
	[ConsolidatedShipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_CustomsDeclaration] ON [dbo].[Consignment] 
(
	[CustomsDeclaration] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_RequestedPickupTransportEvent] ON [dbo].[Consignment] 
(
	[RequestedPickupTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_RequestedDeliveryTransportEvent] ON [dbo].[Consignment] 
(
	[RequestedDeliveryTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_PlannedPickupTransportEvent] ON [dbo].[Consignment] 
(
	[PlannedPickupTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_PlannedDeliveryTransportEvent] ON [dbo].[Consignment] 
(
	[PlannedDeliveryTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_Status] ON [dbo].[Consignment] 
(
	[Status] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ChildConsignment] ON [dbo].[Consignment] 
(
	[ChildConsignment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ConsigneeParty] ON [dbo].[Consignment] 
(
	[ConsigneeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ExporterParty] ON [dbo].[Consignment] 
(
	[ExporterParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ConsignorParty] ON [dbo].[Consignment] 
(
	[ConsignorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ImporterParty] ON [dbo].[Consignment] 
(
	[ImporterParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_CarrierParty] ON [dbo].[Consignment] 
(
	[CarrierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_FreightForwarderParty] ON [dbo].[Consignment] 
(
	[FreightForwarderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_NotifyParty] ON [dbo].[Consignment] 
(
	[NotifyParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_OriginalDespatchParty] ON [dbo].[Consignment] 
(
	[OriginalDespatchParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_FinalDeliveryParty] ON [dbo].[Consignment] 
(
	[FinalDeliveryParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_PerformingCarrierParty] ON [dbo].[Consignment] 
(
	[PerformingCarrierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_SubstituteCarrierParty] ON [dbo].[Consignment] 
(
	[SubstituteCarrierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_LogisticsOperatorParty] ON [dbo].[Consignment] 
(
	[LogisticsOperatorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_TransportAdvisorParty] ON [dbo].[Consignment] 
(
	[TransportAdvisorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_HazardousItemNotificationParty] ON [dbo].[Consignment] 
(
	[HazardousItemNotificationParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_InsuranceParty] ON [dbo].[Consignment] 
(
	[InsuranceParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_MortgageHolderParty] ON [dbo].[Consignment] 
(
	[MortgageHolderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_BillOfLadingHolderParty] ON [dbo].[Consignment] 
(
	[BillOfLadingHolderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_OriginalDepartureCountry] ON [dbo].[Consignment] 
(
	[OriginalDepartureCountry] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_FinalDestinationCountry] ON [dbo].[Consignment] 
(
	[FinalDestinationCountry] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_TransitCountry] ON [dbo].[Consignment] 
(
	[TransitCountry] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_TransportContract] ON [dbo].[Consignment] 
(
	[TransportContract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_TransportEvent] ON [dbo].[Consignment] 
(
	[TransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_OriginalDespatchTransportationService] ON [dbo].[Consignment] 
(
	[OriginalDespatchTransportationService] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_FinalDeliveryTransportationService] ON [dbo].[Consignment] 
(
	[FinalDeliveryTransportationService] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_DeliveryTerms] ON [dbo].[Consignment] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_PaymentTerms] ON [dbo].[Consignment] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_CollectPaymentTerms] ON [dbo].[Consignment] 
(
	[CollectPaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_DisbursementPaymentTerms] ON [dbo].[Consignment] 
(
	[DisbursementPaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_PrepaidPaymentTerms] ON [dbo].[Consignment] 
(
	[PrepaidPaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_FreightAllowanceCharge] ON [dbo].[Consignment] 
(
	[FreightAllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_ExtraAllowanceCharge] ON [dbo].[Consignment] 
(
	[ExtraAllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_MainCarriageShipmentStage] ON [dbo].[Consignment] 
(
	[MainCarriageShipmentStage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_PreCarriageShipmentStage] ON [dbo].[Consignment] 
(
	[PreCarriageShipmentStage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_OnCarriageShipmentStage] ON [dbo].[Consignment] 
(
	[OnCarriageShipmentStage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_TransportHandlingUnit] ON [dbo].[Consignment] 
(
	[TransportHandlingUnit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_FirstArrivalPortLocation] ON [dbo].[Consignment] 
(
	[FirstArrivalPortLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consignment_LastExitPortLocation] ON [dbo].[Consignment] 
(
	[LastExitPortLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Consumption] Script Date: 2013-10-13 00:21z
A class to describe the consumption of a utility.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Consumption](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [UtilityStatementTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code identifying the type of the Utility Statement required for this consumption. Explains the kind of utility the statement is about, e.g.. "gas", "electricity", "telephone" */
  [MainPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period of consumption. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** An allowance or charges that may apply with this consumption. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** The total of taxes for each tax type covering the consumption. */
  [EnergyWaterSupply] [numeric](18,0) NULL, /* 0..1 ASBIE Energy Water Supply ** The details of any energy or water consumption. */
  [TelecommunicationsSupply] [numeric](18,0) NULL, /* 0..1 ASBIE Telecommunications Supply ** The details of any telecommunications consumption. */
  [LegalMonetaryTotal] [numeric](18,0) NOT NULL, /* 1 ASBIE Monetary Total ** The total amount payable on this consumption, including any allowances, charges, or taxes. */
 CONSTRAINT [PK_Consumption] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consumption_UtilityStatementTypeCode] ON [dbo].[Consumption] 
(
	[UtilityStatementTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consumption_MainPeriod] ON [dbo].[Consumption] 
(
	[MainPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consumption_AllowanceCharge] ON [dbo].[Consumption] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consumption_TaxTotal] ON [dbo].[Consumption] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consumption_EnergyWaterSupply] ON [dbo].[Consumption] 
(
	[EnergyWaterSupply] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consumption_TelecommunicationsSupply] ON [dbo].[Consumption] 
(
	[TelecommunicationsSupply] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Consumption_LegalMonetaryTotal] ON [dbo].[Consumption] 
(
	[LegalMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ConsumptionAverage] Script Date: 2013-10-13 00:21z
A class to define an average consumption as a monetary amount.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ConsumptionAverage](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [AverageAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The average monetary amount of the consumption. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** A description of the average consumed. */
 CONSTRAINT [PK_ConsumptionAverage] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionAverage_AverageAmount] ON [dbo].[ConsumptionAverage] 
(
	[AverageAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionAverage_Description] ON [dbo].[ConsumptionAverage] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ConsumptionCorrection] Script Date: 2013-10-13 00:21z
The Statement of correction, for examples heating correction.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ConsumptionCorrection](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [CorrectionType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Statement for the correction type. */
  [CorrectionTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Statement at the code for the correction type. */
  [MeterNumber] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Statement for meter number. */
  [GasPressureQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Correction of the gas pressure. */
  [ActualTemperatureReductionQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Statement for the actuel heating correction temperature. */
  [NormalTemperatureReductionQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Statement for the standard for heating correction temperature. */
  [DifferenceTemperatureReductionQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Deviation from standard heating correction. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Description related to the corrections. */
  [CorrectionUnitAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** Correction per MWH per degree C. */
  [ConsumptionEnergyQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Your consumpt for district heating energy. */
  [ConsumptionWaterQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Your consumpt for district heating water. */
  [CorrectionAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** Your correction for heating correction. */
 CONSTRAINT [PK_ConsumptionCorrection] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_CorrectionType] ON [dbo].[ConsumptionCorrection] 
(
	[CorrectionType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_CorrectionTypeCode] ON [dbo].[ConsumptionCorrection] 
(
	[CorrectionTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_MeterNumber] ON [dbo].[ConsumptionCorrection] 
(
	[MeterNumber] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_GasPressureQuantity] ON [dbo].[ConsumptionCorrection] 
(
	[GasPressureQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_ActualTemperatureReductionQuantity] ON [dbo].[ConsumptionCorrection] 
(
	[ActualTemperatureReductionQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_NormalTemperatureReductionQuantity] ON [dbo].[ConsumptionCorrection] 
(
	[NormalTemperatureReductionQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_DifferenceTemperatureReductionQuantity] ON [dbo].[ConsumptionCorrection] 
(
	[DifferenceTemperatureReductionQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_Description] ON [dbo].[ConsumptionCorrection] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_CorrectionUnitAmount] ON [dbo].[ConsumptionCorrection] 
(
	[CorrectionUnitAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_ConsumptionEnergyQuantity] ON [dbo].[ConsumptionCorrection] 
(
	[ConsumptionEnergyQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_ConsumptionWaterQuantity] ON [dbo].[ConsumptionCorrection] 
(
	[ConsumptionWaterQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionCorrection_CorrectionAmount] ON [dbo].[ConsumptionCorrection] 
(
	[CorrectionAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ConsumptionHistory] Script Date: 2013-10-13 00:21z
A class to describe the measurement of a type of consumption during a particular period, used for the subscriber to get an overview of his consumption
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ConsumptionHistory](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [MeterNumber] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A text identifier for the meter measuring the consumption. */
  [Quantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The quantity consumed. */
  [Amount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount to be charged for the quantity consumed. */
  [ConsumptionLevelCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The consumption level, expressed as a code used explain the consumption quantity, e.g.. diversion from the normal. */
  [ConsumptionLevel] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The consumption level, expressed as text, used explain the consumption quantity, e.g.. diversion from the normal. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the consumption itself. */
  [Period] [numeric](18,0) NOT NULL, /* 1 ASBIE Period ** The period during which the consumption took place. */
 CONSTRAINT [PK_ConsumptionHistory] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionHistory_MeterNumber] ON [dbo].[ConsumptionHistory] 
(
	[MeterNumber] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionHistory_Quantity] ON [dbo].[ConsumptionHistory] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionHistory_Amount] ON [dbo].[ConsumptionHistory] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionHistory_ConsumptionLevelCode] ON [dbo].[ConsumptionHistory] 
(
	[ConsumptionLevelCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionHistory_ConsumptionLevel] ON [dbo].[ConsumptionHistory] 
(
	[ConsumptionLevel] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionHistory_Description] ON [dbo].[ConsumptionHistory] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionHistory_Period] ON [dbo].[ConsumptionHistory] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ConsumptionLine] Script Date: 2013-10-13 00:21z
A class to describe a line item for utility consumption. To specify more than one utility item, use separate consumption lines.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ConsumptionLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this consumption line. */
  [ParentDocumentLineReferenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the transaction line on a related document (such as an invoice) that covers this consumption line. */
  [InvoicedQuantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The quantity invoiced. */
  [LineExtensionAmount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The monetary amount, including discount, to be charged for this consumption line. */
  [Period] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period of time covered by this consumption line. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery of the utility item on this consumption line. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** An allowance or charge that applies to this consumption line. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** A total amount of taxes of a particular kind applicable to this consumption line. */
  [UtilityItem] [numeric](18,0) NOT NULL, /* 1 ASBIE Utility Item ** The utility item consumed. */
  [Price] [numeric](18,0) NULL, /* 0..1 ASBIE Price ** The price associated with this consumption line, expressed in a data structure containing multiple properties. */
  [UnstructuredPrice] [numeric](18,0) NULL, /* 0..1 ASBIE Unstructured Price ** The price associated with this consumption line expressed in a less structured form that includes just the amount and the time of use. */
 CONSTRAINT [PK_ConsumptionLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionLine_ID] ON [dbo].[ConsumptionLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionLine_ParentDocumentLineReferenceID] ON [dbo].[ConsumptionLine] 
(
	[ParentDocumentLineReferenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionLine_InvoicedQuantity] ON [dbo].[ConsumptionLine] 
(
	[InvoicedQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionLine_LineExtensionAmount] ON [dbo].[ConsumptionLine] 
(
	[LineExtensionAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionLine_Period] ON [dbo].[ConsumptionLine] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionLine_Delivery] ON [dbo].[ConsumptionLine] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionLine_AllowanceCharge] ON [dbo].[ConsumptionLine] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionLine_TaxTotal] ON [dbo].[ConsumptionLine] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionLine_UtilityItem] ON [dbo].[ConsumptionLine] 
(
	[UtilityItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionLine_Price] ON [dbo].[ConsumptionLine] 
(
	[Price] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionLine_UnstructuredPrice] ON [dbo].[ConsumptionLine] 
(
	[UnstructuredPrice] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ConsumptionPoint] Script Date: 2013-10-13 00:21z
A class to define the point of consumption for a utility, such as a meter.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ConsumptionPoint](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this point of consumption. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this consumption point. */
  [SubscriberID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the subscriber responsible for the consumption at this consumption point. */
  [SubscriberType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The type of subscriber, expressed as text. */
  [SubscriberTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of subscriber, expressed as a code. */
  [TotalDeliveredQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total quantity delivered, calculated at this consumption point. */
  [Address] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The address of this consumption point. */
  [WebSiteAccess] [numeric](18,0) NULL, /* 0..1 ASBIE Web Site Access ** Access information for the website of this consumption point. */
  [UtilityMeter] [numeric](18,0) NULL, /* 0..n ASBIE Meter ** A meter at this consumption point. */
 CONSTRAINT [PK_ConsumptionPoint] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionPoint_ID] ON [dbo].[ConsumptionPoint] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionPoint_Description] ON [dbo].[ConsumptionPoint] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionPoint_SubscriberID] ON [dbo].[ConsumptionPoint] 
(
	[SubscriberID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionPoint_SubscriberType] ON [dbo].[ConsumptionPoint] 
(
	[SubscriberType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionPoint_SubscriberTypeCode] ON [dbo].[ConsumptionPoint] 
(
	[SubscriberTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionPoint_TotalDeliveredQuantity] ON [dbo].[ConsumptionPoint] 
(
	[TotalDeliveredQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionPoint_Address] ON [dbo].[ConsumptionPoint] 
(
	[Address] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionPoint_WebSiteAccess] ON [dbo].[ConsumptionPoint] 
(
	[WebSiteAccess] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionPoint_UtilityMeter] ON [dbo].[ConsumptionPoint] 
(
	[UtilityMeter] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ConsumptionReport] Script Date: 2013-10-13 00:21z
A class to describe utility consumption, including details of the environment in which consumption takes place.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ConsumptionReport](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this consumption report. */
  [ConsumptionType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The type of consumption, expressed as text. */
  [ConsumptionTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of consumption, expressed as a code. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text reporting utility consumption. */
  [TotalConsumedQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total quantity consumed. */
  [BasicConsumedQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The basic quantity consumed, excluding additional consumption. */
  [ResidentOccupantsNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of people occupying the residence covered by this report. */
  [ConsumersEnergyLevelCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The level of energy consumed, compared to the average for this residence type and the number of people living in the residence, expressed as a code. */
  [ConsumersEnergyLevel] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The level of energy consumed, compared to the average for this residence type and the number of people living in the residence, expressed as text. */
  [ResidenceType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The type of residence (house, apartment, etc.) covered in this report, expressed as text. */
  [ResidenceTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of residence (house, apartment, etc.) covered in this report, expressed as a code. */
  [HeatingType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The type of heating in the residence covered in this report, expressed as text. */
  [HeatingTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of heating in the residence covered in this report, expressed as a code. */
  [Period] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period of consumption covered in this report. */
  [GuidanceDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a document providing an explanation of this kind of report. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to some other document (for example, this report in another format). */
  [ConsumptionReportReference] [numeric](18,0) NULL, /* 0..n ASBIE Consumption Report Reference ** A reference to a previous consumption report. */
  [ConsumptionHistory] [numeric](18,0) NULL, /* 0..n ASBIE Consumption History ** A report describing historical parameters relating to a specific instance of consumption. */
 CONSTRAINT [PK_ConsumptionReport] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_ID] ON [dbo].[ConsumptionReport] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_ConsumptionType] ON [dbo].[ConsumptionReport] 
(
	[ConsumptionType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_ConsumptionTypeCode] ON [dbo].[ConsumptionReport] 
(
	[ConsumptionTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_Description] ON [dbo].[ConsumptionReport] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_TotalConsumedQuantity] ON [dbo].[ConsumptionReport] 
(
	[TotalConsumedQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_BasicConsumedQuantity] ON [dbo].[ConsumptionReport] 
(
	[BasicConsumedQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_ResidentOccupantsNumeric] ON [dbo].[ConsumptionReport] 
(
	[ResidentOccupantsNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_ConsumersEnergyLevelCode] ON [dbo].[ConsumptionReport] 
(
	[ConsumersEnergyLevelCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_ConsumersEnergyLevel] ON [dbo].[ConsumptionReport] 
(
	[ConsumersEnergyLevel] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_ResidenceType] ON [dbo].[ConsumptionReport] 
(
	[ResidenceType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_ResidenceTypeCode] ON [dbo].[ConsumptionReport] 
(
	[ResidenceTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_HeatingType] ON [dbo].[ConsumptionReport] 
(
	[HeatingType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_HeatingTypeCode] ON [dbo].[ConsumptionReport] 
(
	[HeatingTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_Period] ON [dbo].[ConsumptionReport] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_GuidanceDocumentReference] ON [dbo].[ConsumptionReport] 
(
	[GuidanceDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_DocumentReference] ON [dbo].[ConsumptionReport] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_ConsumptionReportReference] ON [dbo].[ConsumptionReport] 
(
	[ConsumptionReportReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReport_ConsumptionHistory] ON [dbo].[ConsumptionReport] 
(
	[ConsumptionHistory] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ConsumptionReportReference] Script Date: 2013-10-13 00:21z
A class to define a reference to an earlier consumption report (e.g., last year's consumption).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ConsumptionReportReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ConsumptionReportID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the referenced consumption report. */
  [ConsumptionType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The reported consumption type, expressed as text. */
  [ConsumptionTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The reported consumption type, expressed as a code. */
  [TotalConsumedQuantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The total quantity consumed during the period of the referenced report. */
  [Period] [numeric](18,0) NOT NULL, /* 1 ASBIE Period ** The period of consumption covered by the referenced report. */
 CONSTRAINT [PK_ConsumptionReportReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReportReference_ConsumptionReportID] ON [dbo].[ConsumptionReportReference] 
(
	[ConsumptionReportID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReportReference_ConsumptionType] ON [dbo].[ConsumptionReportReference] 
(
	[ConsumptionType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReportReference_ConsumptionTypeCode] ON [dbo].[ConsumptionReportReference] 
(
	[ConsumptionTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReportReference_TotalConsumedQuantity] ON [dbo].[ConsumptionReportReference] 
(
	[TotalConsumedQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ConsumptionReportReference_Period] ON [dbo].[ConsumptionReportReference] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Contact] Script Date: 2013-10-13 00:21z
A class to describe a contactable person or department in an organization.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Contact](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this contact. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this contact. It is recommended that this be used for a functional name and not a personal name. */
  [Telephone] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The primary telephone number of this contact. */
  [Telefax] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The primary fax number of this contact. */
  [ElectronicMail] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The primary email address of this contact. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures; in particular, a textual description of the circumstances under which this contact can be used (e.g., "emergency" or "after hours"). */
  [OtherCommunication] [numeric](18,0) NULL, /* 0..n ASBIE Communication ** Another means of communication with this contact. */
 CONSTRAINT [PK_Contact] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contact_ID] ON [dbo].[Contact] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contact_Name] ON [dbo].[Contact] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contact_Telephone] ON [dbo].[Contact] 
(
	[Telephone] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contact_Telefax] ON [dbo].[Contact] 
(
	[Telefax] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contact_ElectronicMail] ON [dbo].[Contact] 
(
	[ElectronicMail] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contact_Note] ON [dbo].[Contact] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contact_OtherCommunication] ON [dbo].[Contact] 
(
	[OtherCommunication] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Contract] Script Date: 2013-10-13 00:21z
A class to describe a contract.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Contract](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this contract. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this contract was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this contract was issued. */
  [NominationDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** In a transportation contract, the deadline date by which the services referred to in the transport execution plan have to be booked. For example, if this service is a carrier service scheduled for Wednesday 16 February 2011 at 10 a.m. CET, the nomination date might be Tuesday15 February 2011. */
  [NominationTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** In a transportation contract, the deadline time by which the services referred to in the transport execution plan have to be booked. For example, if this service is a carrier service scheduled for Wednesday 16 February 2011 at 10 a.m. CET, the nomination date might be Tuesday15 February 2011 and the nomination time 4 p.m. at the latest. */
  [ContractTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of this contract, expressed as a code, such as "Cost plus award fee" and "Cost plus fixed fee" from UNCEFACT Contract Type code list. */
  [ContractType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The type of this contract, expressed as text, such as "Cost plus award fee" and "Cost plus fixed fee" from UNCEFACT Contract Type code list. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the current version of this contract. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this contract. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which this contract is valid. */
  [ContractDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a contract document. */
  [NominationPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** In a transportation contract, the period required to book the services specified in the contract before the services can begin. */
  [ContractualDelivery] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery ** In a transportation contract, the delivery of the services required to book the services specified in the contract. */
 CONSTRAINT [PK_Contract] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_ID] ON [dbo].[Contract] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_IssueDate] ON [dbo].[Contract] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_IssueTime] ON [dbo].[Contract] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_NominationDate] ON [dbo].[Contract] 
(
	[NominationDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_NominationTime] ON [dbo].[Contract] 
(
	[NominationTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_ContractTypeCode] ON [dbo].[Contract] 
(
	[ContractTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_ContractType] ON [dbo].[Contract] 
(
	[ContractType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_Note] ON [dbo].[Contract] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_VersionID] ON [dbo].[Contract] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_Description] ON [dbo].[Contract] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_ValidityPeriod] ON [dbo].[Contract] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_ContractDocumentReference] ON [dbo].[Contract] 
(
	[ContractDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_NominationPeriod] ON [dbo].[Contract] 
(
	[NominationPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Contract_ContractualDelivery] ON [dbo].[Contract] 
(
	[ContractualDelivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ContractExecutionRequirement] Script Date: 2013-10-13 00:21z
A class to describe a requirement for execution of a contract.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ContractExecutionRequirement](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Name] [numeric](18,0) NULL, /* 0..n BBIE Name ** A name for this requirement. */
  [ExecutionRequirementCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of party independent of its role. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this requirement. */
 CONSTRAINT [PK_ContractExecutionRequirement] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractExecutionRequirement_Name] ON [dbo].[ContractExecutionRequirement] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractExecutionRequirement_ExecutionRequirementCode] ON [dbo].[ContractExecutionRequirement] 
(
	[ExecutionRequirementCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractExecutionRequirement_Description] ON [dbo].[ContractExecutionRequirement] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ContractExtension] Script Date: 2013-10-13 00:21z
A class to describe possible extensions to a contract.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ContractExtension](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [OptionsDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** A description for the possible options that can be carried out during the execution of the contract. */
  [MinimumNumberNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The fixed minimum number of contract extensions or renewals. */
  [MaximumNumberNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The maximum allowed number of contract extensions. */
  [OptionValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which the option for extending the contract is available. */
  [Renewal] [numeric](18,0) NULL, /* 0..n ASBIE Renewal ** The period allowed for each contract extension. */
 CONSTRAINT [PK_ContractExtension] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractExtension_OptionsDescription] ON [dbo].[ContractExtension] 
(
	[OptionsDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractExtension_MinimumNumberNumeric] ON [dbo].[ContractExtension] 
(
	[MinimumNumberNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractExtension_MaximumNumberNumeric] ON [dbo].[ContractExtension] 
(
	[MaximumNumberNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractExtension_OptionValidityPeriod] ON [dbo].[ContractExtension] 
(
	[OptionValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractExtension_Renewal] ON [dbo].[ContractExtension] 
(
	[Renewal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ContractingActivity] Script Date: 2013-10-13 00:21z
The nature of the type of business of the organization.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ContractingActivity](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ActivityTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code specifying the nature of the type of business of the organization. */
  [ActivityType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The nature of the type of business of the organization, expressed as text. */
 CONSTRAINT [PK_ContractingActivity] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractingActivity_ActivityTypeCode] ON [dbo].[ContractingActivity] 
(
	[ActivityTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractingActivity_ActivityType] ON [dbo].[ContractingActivity] 
(
	[ActivityType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ContractingParty] Script Date: 2013-10-13 00:21z
A class to describe an individual, a group, or a body having a procurement role in a tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ContractingParty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [BuyerProfileURI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The buyer profile is typically located on a web site where the contracting party publishes its procurement opportunities */
  [ContractingPartyType] [numeric](18,0) NULL, /* 0..n ASBIE Contracting Party Type ** The type of contracting party that is independent of its role. */
  [ContractingActivity] [numeric](18,0) NULL, /* 0..n ASBIE Contracting Activity ** The nature of the type of business of the organization */
  [Party] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The contracting party itself. */
 CONSTRAINT [PK_ContractingParty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractingParty_BuyerProfileURI] ON [dbo].[ContractingParty] 
(
	[BuyerProfileURI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractingParty_ContractingPartyType] ON [dbo].[ContractingParty] 
(
	[ContractingPartyType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractingParty_ContractingActivity] ON [dbo].[ContractingParty] 
(
	[ContractingActivity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractingParty_Party] ON [dbo].[ContractingParty] 
(
	[Party] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ContractingPartyType] Script Date: 2013-10-13 00:21z
The type of contracting party that is independent of its role.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ContractingPartyType](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [PartyTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code specifying the type of party that is independent of its role. */
  [PartyType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The type of party that is independent of its role, expressed as text. */
 CONSTRAINT [PK_ContractingPartyType] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractingPartyType_PartyTypeCode] ON [dbo].[ContractingPartyType] 
(
	[PartyTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ContractingPartyType_PartyType] ON [dbo].[ContractingPartyType] 
(
	[PartyType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CorporateRegistrationScheme] Script Date: 2013-10-13 00:21z
A class to describe a scheme for corporate registration.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CorporateRegistrationScheme](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this registration scheme. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this registration scheme. */
  [CorporateRegistrationTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of this registration scheme. */
  [JurisdictionRegionAddress] [numeric](18,0) NULL, /* 0..n ASBIE Address ** A geographic area in which this registration scheme applies. */
 CONSTRAINT [PK_CorporateRegistrationScheme] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CorporateRegistrationScheme_ID] ON [dbo].[CorporateRegistrationScheme] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CorporateRegistrationScheme_Name] ON [dbo].[CorporateRegistrationScheme] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CorporateRegistrationScheme_CorporateRegistrationTypeCode] ON [dbo].[CorporateRegistrationScheme] 
(
	[CorporateRegistrationTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CorporateRegistrationScheme_JurisdictionRegionAddress] ON [dbo].[CorporateRegistrationScheme] 
(
	[JurisdictionRegionAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Country] Script Date: 2013-10-13 00:21z
A class to describe a country.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Country](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [IdentificationCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying this country. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this country. */
 CONSTRAINT [PK_Country] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Country_IdentificationCode] ON [dbo].[Country] 
(
	[IdentificationCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Country_Name] ON [dbo].[Country] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CreditAccount] Script Date: 2013-10-13 00:21z
A class to identify a credit account for sales on account.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CreditAccount](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [AccountID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this credit account. */
 CONSTRAINT [PK_CreditAccount] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditAccount_AccountID] ON [dbo].[CreditAccount] 
(
	[AccountID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CreditNoteLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Credit Note or Self Billed Credit Note.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CreditNoteLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this credit note line. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this credit note line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [CreditedQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of items credited in this credit note line. */
  [LineExtensionAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total amount for this credit note line, including allowance charges but exclusive of taxes. */
  [TaxPointDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of this credit note line, used to indicate the point at which tax becomes applicable. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting cost centre for this credit note line, expressed as a code. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting cost centre for this credit note line, expressed as text. */
  [PaymentPurposeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the business purpose for this payment. */
  [FreeOfChargeIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this credit note line is free of charge (true) or not (false). The default is false. */
  [InvoicePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** An invoice period to which this credit note line applies. */
  [OrderLineReference] [numeric](18,0) NULL, /* 0..n ASBIE Order Line Reference ** A reference to an order line associated with this credit note line. */
  [DiscrepancyResponse] [numeric](18,0) NULL, /* 0..n ASBIE Response ** A reason for the credit. */
  [DespatchLineReference] [numeric](18,0) NULL, /* 0..n ASBIE Line Reference ** A reference to a despatch line associated with this credit note line. */
  [ReceiptLineReference] [numeric](18,0) NULL, /* 0..n ASBIE Line Reference ** A reference to a receipt line associated with this credit note line. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this credit note line. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this credit note line. */
  [PricingReference] [numeric](18,0) NULL, /* 0..1 ASBIE Pricing Reference ** A reference to pricing and item location information associated with this credit note line. */
  [OriginatorParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party who originated the Order to which the Credit Note is related. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this credit note line. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A specification of payment terms associated with this credit note line. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** A total amount of taxes of a particular kind applicable to this credit note line. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** An allowance or charge associated with this credit note. */
  [Item] [numeric](18,0) NULL, /* 0..1 ASBIE Item ** The item associated with this credit note line. */
  [Price] [numeric](18,0) NULL, /* 0..1 ASBIE Price ** The price of the item associated with this credit note line. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..n ASBIE Delivery Terms ** Terms and conditions of a delivery associated with this credit note line. */
  [SubCreditNoteLine] [numeric](18,0) NULL, /* 0..n ASBIE Credit Note Line ** A class defining one or more Credit Note Lines detailing the credit note line. */
  [ItemPriceExtension] [numeric](18,0) NULL, /* 0..1 ASBIE Price Extension ** The price extension, calculated by multiplying the price per unit by the quantity of items on this credit note line. */
 CONSTRAINT [PK_CreditNoteLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_ID] ON [dbo].[CreditNoteLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_UUID] ON [dbo].[CreditNoteLine] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_Note] ON [dbo].[CreditNoteLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_CreditedQuantity] ON [dbo].[CreditNoteLine] 
(
	[CreditedQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_LineExtensionAmount] ON [dbo].[CreditNoteLine] 
(
	[LineExtensionAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_TaxPointDate] ON [dbo].[CreditNoteLine] 
(
	[TaxPointDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_AccountingCostCode] ON [dbo].[CreditNoteLine] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_AccountingCost] ON [dbo].[CreditNoteLine] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_PaymentPurposeCode] ON [dbo].[CreditNoteLine] 
(
	[PaymentPurposeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_FreeOfChargeIndicator] ON [dbo].[CreditNoteLine] 
(
	[FreeOfChargeIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_InvoicePeriod] ON [dbo].[CreditNoteLine] 
(
	[InvoicePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_OrderLineReference] ON [dbo].[CreditNoteLine] 
(
	[OrderLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_DiscrepancyResponse] ON [dbo].[CreditNoteLine] 
(
	[DiscrepancyResponse] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_DespatchLineReference] ON [dbo].[CreditNoteLine] 
(
	[DespatchLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_ReceiptLineReference] ON [dbo].[CreditNoteLine] 
(
	[ReceiptLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_BillingReference] ON [dbo].[CreditNoteLine] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_DocumentReference] ON [dbo].[CreditNoteLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_PricingReference] ON [dbo].[CreditNoteLine] 
(
	[PricingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_OriginatorParty] ON [dbo].[CreditNoteLine] 
(
	[OriginatorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_Delivery] ON [dbo].[CreditNoteLine] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_PaymentTerms] ON [dbo].[CreditNoteLine] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_TaxTotal] ON [dbo].[CreditNoteLine] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_AllowanceCharge] ON [dbo].[CreditNoteLine] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_Item] ON [dbo].[CreditNoteLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_Price] ON [dbo].[CreditNoteLine] 
(
	[Price] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_DeliveryTerms] ON [dbo].[CreditNoteLine] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_SubCreditNoteLine] ON [dbo].[CreditNoteLine] 
(
	[SubCreditNoteLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CreditNoteLine_ItemPriceExtension] ON [dbo].[CreditNoteLine] 
(
	[ItemPriceExtension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CustomerParty] Script Date: 2013-10-13 00:21z
A class to describe a customer party.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CustomerParty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [CustomerAssignedAccountID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the customer's account, assigned by the customer itself. */
  [SupplierAssignedAccountID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the customer's account, assigned by the supplier. */
  [AdditionalAccountID] [numeric](18,0) NULL, /* 0..n BBIE Identifier ** An identifier for the customer's account, assigned by a third party. */
  [Party] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The customer party itself. */
  [DeliveryContact] [numeric](18,0) NULL, /* 0..1 ASBIE Contact ** A customer contact for deliveries. */
  [AccountingContact] [numeric](18,0) NULL, /* 0..1 ASBIE Contact ** A customer contact for accounting. */
  [BuyerContact] [numeric](18,0) NULL, /* 0..1 ASBIE Contact ** A customer contact for purchasing. */
 CONSTRAINT [PK_CustomerParty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CustomerParty_CustomerAssignedAccountID] ON [dbo].[CustomerParty] 
(
	[CustomerAssignedAccountID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CustomerParty_SupplierAssignedAccountID] ON [dbo].[CustomerParty] 
(
	[SupplierAssignedAccountID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CustomerParty_AdditionalAccountID] ON [dbo].[CustomerParty] 
(
	[AdditionalAccountID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CustomerParty_Party] ON [dbo].[CustomerParty] 
(
	[Party] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CustomerParty_DeliveryContact] ON [dbo].[CustomerParty] 
(
	[DeliveryContact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CustomerParty_AccountingContact] ON [dbo].[CustomerParty] 
(
	[AccountingContact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CustomerParty_BuyerContact] ON [dbo].[CustomerParty] 
(
	[BuyerContact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[CustomsDeclaration] Script Date: 2013-10-13 00:21z
A class describing identifiers or references relating to customs procedures.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CustomsDeclaration](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier associated with customs related procedures. */
  [IssuerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** Describes the party issuing the customs declaration. */
 CONSTRAINT [PK_CustomsDeclaration] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CustomsDeclaration_ID] ON [dbo].[CustomsDeclaration] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_CustomsDeclaration_IssuerParty] ON [dbo].[CustomsDeclaration] 
(
	[IssuerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DebitNoteLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Debit Note.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DebitNoteLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this debit note line. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this debit note line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [DebitedQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of Items debited in this debit note line. */
  [LineExtensionAmount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The total amount for this debit note line, including allowance charges but net of taxes. */
  [TaxPointDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of this debit note line, used to indicate the point at which tax becomes applicable. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting cost centre for this debit note line, expressed as a code. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting cost centre for this debit note line, expressed as text. */
  [PaymentPurposeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the business purpose for this payment. */
  [DiscrepancyResponse] [numeric](18,0) NULL, /* 0..n ASBIE Response ** A reason for the debit. */
  [DespatchLineReference] [numeric](18,0) NULL, /* 0..n ASBIE Line Reference ** A reference to a despatch line associated with this debit note line. */
  [ReceiptLineReference] [numeric](18,0) NULL, /* 0..n ASBIE Line Reference ** A reference to a receipt line associated with this debit note line. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this debit note line. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this debit note line. */
  [PricingReference] [numeric](18,0) NULL, /* 0..1 ASBIE Pricing Reference ** A reference to pricing and item location information associated with this debit note line. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this debit note line. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** A total amount of taxes of a particular kind applicable to this debit note line. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** An allowance or charge associated with this debit note. */
  [Item] [numeric](18,0) NULL, /* 0..1 ASBIE Item ** The item associated with this debit note line. */
  [Price] [numeric](18,0) NULL, /* 0..1 ASBIE Price ** The price of the item associated with this debit note line. */
  [SubDebitNoteLine] [numeric](18,0) NULL, /* 0..n ASBIE Debit Note Line ** A recursive description of a debit note line subsidiary to this debit note line. */
 CONSTRAINT [PK_DebitNoteLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_ID] ON [dbo].[DebitNoteLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_UUID] ON [dbo].[DebitNoteLine] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_Note] ON [dbo].[DebitNoteLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_DebitedQuantity] ON [dbo].[DebitNoteLine] 
(
	[DebitedQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_LineExtensionAmount] ON [dbo].[DebitNoteLine] 
(
	[LineExtensionAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_TaxPointDate] ON [dbo].[DebitNoteLine] 
(
	[TaxPointDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_AccountingCostCode] ON [dbo].[DebitNoteLine] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_AccountingCost] ON [dbo].[DebitNoteLine] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_PaymentPurposeCode] ON [dbo].[DebitNoteLine] 
(
	[PaymentPurposeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_DiscrepancyResponse] ON [dbo].[DebitNoteLine] 
(
	[DiscrepancyResponse] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_DespatchLineReference] ON [dbo].[DebitNoteLine] 
(
	[DespatchLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_ReceiptLineReference] ON [dbo].[DebitNoteLine] 
(
	[ReceiptLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_BillingReference] ON [dbo].[DebitNoteLine] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_DocumentReference] ON [dbo].[DebitNoteLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_PricingReference] ON [dbo].[DebitNoteLine] 
(
	[PricingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_Delivery] ON [dbo].[DebitNoteLine] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_TaxTotal] ON [dbo].[DebitNoteLine] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_AllowanceCharge] ON [dbo].[DebitNoteLine] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_Item] ON [dbo].[DebitNoteLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_Price] ON [dbo].[DebitNoteLine] 
(
	[Price] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DebitNoteLine_SubDebitNoteLine] ON [dbo].[DebitNoteLine] 
(
	[SubDebitNoteLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Declaration] Script Date: 2013-10-13 00:21z
A class to describe a declaration by an economic operator of certain characteristics or capabilities in fulfilment of requirements specified in a call for tenders.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Declaration](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Name] [numeric](18,0) NULL, /* 0..n BBIE Name ** The name of this declaration. */
  [DeclarationTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of this declaration. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this declaration. */
  [EvidenceSupplied] [numeric](18,0) NULL, /* 0..n ASBIE Evidence Supplied ** The evidence supporting this declaration. */
 CONSTRAINT [PK_Declaration] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Declaration_Name] ON [dbo].[Declaration] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Declaration_DeclarationTypeCode] ON [dbo].[Declaration] 
(
	[DeclarationTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Declaration_Description] ON [dbo].[Declaration] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Declaration_EvidenceSupplied] ON [dbo].[Declaration] 
(
	[EvidenceSupplied] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Delivery] Script Date: 2013-10-13 00:21z
A class to describe a delivery.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Delivery](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this delivery. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of items, child consignments, shipments in this delivery. */
  [MinimumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The minimum quantity of items, child consignments, shipments in this delivery. */
  [MaximumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The maximum quantity of items, child consignments, shipments in this delivery. */
  [ActualDeliveryDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The actual date of delivery. */
  [ActualDeliveryTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The actual time of delivery. */
  [LatestDeliveryDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The latest date of delivery allowed by the buyer. */
  [LatestDeliveryTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The latest time of delivery allowed by the buyer. */
  [ReleaseID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier used for approval of access to delivery locations (e.g., port terminals). */
  [TrackingID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The delivery Tracking ID (for transport tracking). */
  [DeliveryAddress] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The delivery address. */
  [DeliveryLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The delivery location. */
  [AlternativeDeliveryLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** An alternative delivery location. */
  [RequestedDeliveryPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period requested for delivery. */
  [PromisedDeliveryPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period promised for delivery. */
  [EstimatedDeliveryPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period estimated for delivery. */
  [CarrierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party responsible for delivering the goods. */
  [DeliveryParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party to whom the goods are delivered. */
  [NotifyParty] [numeric](18,0) NULL, /* 0..n ASBIE Party ** A party to be notified of this delivery. */
  [Despatch] [numeric](18,0) NULL, /* 0..1 ASBIE Despatch ** The despatch (pickup) associated with this delivery. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..n ASBIE Delivery Terms ** Terms and conditions relating to the delivery. */
  [MinimumDeliveryUnit] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery Unit ** The minimum delivery unit for this delivery. */
  [MaximumDeliveryUnit] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery Unit ** The maximum delivery unit for this delivery. */
  [Shipment] [numeric](18,0) NULL, /* 0..1 ASBIE Shipment ** The shipment being delivered. */
 CONSTRAINT [PK_Delivery] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_ID] ON [dbo].[Delivery] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_Quantity] ON [dbo].[Delivery] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_MinimumQuantity] ON [dbo].[Delivery] 
(
	[MinimumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_MaximumQuantity] ON [dbo].[Delivery] 
(
	[MaximumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_ActualDeliveryDate] ON [dbo].[Delivery] 
(
	[ActualDeliveryDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_ActualDeliveryTime] ON [dbo].[Delivery] 
(
	[ActualDeliveryTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_LatestDeliveryDate] ON [dbo].[Delivery] 
(
	[LatestDeliveryDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_LatestDeliveryTime] ON [dbo].[Delivery] 
(
	[LatestDeliveryTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_ReleaseID] ON [dbo].[Delivery] 
(
	[ReleaseID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_TrackingID] ON [dbo].[Delivery] 
(
	[TrackingID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_DeliveryAddress] ON [dbo].[Delivery] 
(
	[DeliveryAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_DeliveryLocation] ON [dbo].[Delivery] 
(
	[DeliveryLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_AlternativeDeliveryLocation] ON [dbo].[Delivery] 
(
	[AlternativeDeliveryLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_RequestedDeliveryPeriod] ON [dbo].[Delivery] 
(
	[RequestedDeliveryPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_PromisedDeliveryPeriod] ON [dbo].[Delivery] 
(
	[PromisedDeliveryPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_EstimatedDeliveryPeriod] ON [dbo].[Delivery] 
(
	[EstimatedDeliveryPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_CarrierParty] ON [dbo].[Delivery] 
(
	[CarrierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_DeliveryParty] ON [dbo].[Delivery] 
(
	[DeliveryParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_NotifyParty] ON [dbo].[Delivery] 
(
	[NotifyParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_Despatch] ON [dbo].[Delivery] 
(
	[Despatch] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_DeliveryTerms] ON [dbo].[Delivery] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_MinimumDeliveryUnit] ON [dbo].[Delivery] 
(
	[MinimumDeliveryUnit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_MaximumDeliveryUnit] ON [dbo].[Delivery] 
(
	[MaximumDeliveryUnit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Delivery_Shipment] ON [dbo].[Delivery] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DeliveryTerms] Script Date: 2013-10-13 00:21z
A class for describing the terms and conditions applying to the delivery of goods.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DeliveryTerms](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this description of delivery terms. */
  [SpecialTerms] [numeric](18,0) NULL, /* 0..n BBIE Text ** A description of any terms or conditions relating to the delivery items. */
  [LossRiskResponsibilityCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code that identifies one of various responsibilities for loss risk in the execution of the delivery. */
  [LossRisk] [numeric](18,0) NULL, /* 0..n BBIE Text ** A description of responsibility for risk of loss in execution of the delivery, expressed as text. */
  [Amount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount covered by these delivery terms. */
  [DeliveryLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location for the contracted delivery. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..1 ASBIE Allowance Charge ** An allowance or charge covered by these delivery terms. */
 CONSTRAINT [PK_DeliveryTerms] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DeliveryTerms_ID] ON [dbo].[DeliveryTerms] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DeliveryTerms_SpecialTerms] ON [dbo].[DeliveryTerms] 
(
	[SpecialTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DeliveryTerms_LossRiskResponsibilityCode] ON [dbo].[DeliveryTerms] 
(
	[LossRiskResponsibilityCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DeliveryTerms_LossRisk] ON [dbo].[DeliveryTerms] 
(
	[LossRisk] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DeliveryTerms_Amount] ON [dbo].[DeliveryTerms] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DeliveryTerms_DeliveryLocation] ON [dbo].[DeliveryTerms] 
(
	[DeliveryLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DeliveryTerms_AllowanceCharge] ON [dbo].[DeliveryTerms] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DeliveryUnit] Script Date: 2013-10-13 00:21z
A class to describe a delivery unit.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DeliveryUnit](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [BatchQuantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The quantity of ordered Items that constitutes a batch for delivery purposes. */
  [ConsumerUnitQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of units in the Delivery Unit expressed in the units used by the consumer. */
  [HazardousRiskIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported goods are subject to an international regulation concerning the carriage of dangerous goods (true) or not (false). */
 CONSTRAINT [PK_DeliveryUnit] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DeliveryUnit_BatchQuantity] ON [dbo].[DeliveryUnit] 
(
	[BatchQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DeliveryUnit_ConsumerUnitQuantity] ON [dbo].[DeliveryUnit] 
(
	[ConsumerUnitQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DeliveryUnit_HazardousRiskIndicator] ON [dbo].[DeliveryUnit] 
(
	[HazardousRiskIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DependentPriceReference] Script Date: 2013-10-13 00:21z
A class to define the price of an item as a percentage of the price of a different item.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DependentPriceReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Percent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The percentage by which the price of the different item is multiplied to calculate the price of the item. */
  [LocationAddress] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The reference location for this dependent price reference. */
  [DependentLineReference] [numeric](18,0) NULL, /* 0..1 ASBIE Line Reference ** A reference to a line that the price is depended of. */
 CONSTRAINT [PK_DependentPriceReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DependentPriceReference_Percent] ON [dbo].[DependentPriceReference] 
(
	[Percent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DependentPriceReference_LocationAddress] ON [dbo].[DependentPriceReference] 
(
	[LocationAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DependentPriceReference_DependentLineReference] ON [dbo].[DependentPriceReference] 
(
	[DependentLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Despatch] Script Date: 2013-10-13 00:21z
A class to describe the despatching of goods (their pickup for delivery).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Despatch](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this despatch event. */
  [RequestedDespatchDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The despatch (pickup) date requested, normally by the buyer. */
  [RequestedDespatchTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The despatch (pickup) time requested, normally by the buyer. */
  [EstimatedDespatchDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The estimated despatch (pickup) date. */
  [EstimatedDespatchTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The estimated despatch (pickup) time. */
  [ActualDespatchDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The actual despatch (pickup) date. */
  [ActualDespatchTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The actual despatch (pickup) time. */
  [GuaranteedDespatchDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date guaranteed for the despatch (pickup). */
  [GuaranteedDespatchTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time guaranteed for the despatch (pickup). */
  [ReleaseID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the release of the despatch used as security control or cargo control (pick-up). */
  [Instructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing any special instructions applying to the despatch (pickup). */
  [DespatchAddress] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The address of the despatch (pickup). */
  [DespatchLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location of the despatch (pickup). */
  [DespatchParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party despatching the goods. */
  [CarrierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party carrying the goods. */
  [NotifyParty] [numeric](18,0) NULL, /* 0..n ASBIE Party ** A party to be notified of this despatch (pickup). */
  [Contact] [numeric](18,0) NULL, /* 0..1 ASBIE Contact ** The primary contact for this despatch (pickup). */
  [EstimatedDespatchPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period estimated for the despatch (pickup) of goods. */
  [RequestedDespatchPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period requested for the despatch (pickup) of goods. */
 CONSTRAINT [PK_Despatch] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_ID] ON [dbo].[Despatch] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_RequestedDespatchDate] ON [dbo].[Despatch] 
(
	[RequestedDespatchDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_RequestedDespatchTime] ON [dbo].[Despatch] 
(
	[RequestedDespatchTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_EstimatedDespatchDate] ON [dbo].[Despatch] 
(
	[EstimatedDespatchDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_EstimatedDespatchTime] ON [dbo].[Despatch] 
(
	[EstimatedDespatchTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_ActualDespatchDate] ON [dbo].[Despatch] 
(
	[ActualDespatchDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_ActualDespatchTime] ON [dbo].[Despatch] 
(
	[ActualDespatchTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_GuaranteedDespatchDate] ON [dbo].[Despatch] 
(
	[GuaranteedDespatchDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_GuaranteedDespatchTime] ON [dbo].[Despatch] 
(
	[GuaranteedDespatchTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_ReleaseID] ON [dbo].[Despatch] 
(
	[ReleaseID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_Instructions] ON [dbo].[Despatch] 
(
	[Instructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_DespatchAddress] ON [dbo].[Despatch] 
(
	[DespatchAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_DespatchLocation] ON [dbo].[Despatch] 
(
	[DespatchLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_DespatchParty] ON [dbo].[Despatch] 
(
	[DespatchParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_CarrierParty] ON [dbo].[Despatch] 
(
	[CarrierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_NotifyParty] ON [dbo].[Despatch] 
(
	[NotifyParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_Contact] ON [dbo].[Despatch] 
(
	[Contact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_EstimatedDespatchPeriod] ON [dbo].[Despatch] 
(
	[EstimatedDespatchPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Despatch_RequestedDespatchPeriod] ON [dbo].[Despatch] 
(
	[RequestedDespatchPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DespatchLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Despatch Advice.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DespatchLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this despatch line. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this despatch line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [LineStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of this despatch line with respect to its original state. */
  [DeliveredQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity despatched (picked up). */
  [BackorderQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity on back order at the supplier. */
  [BackorderReason] [numeric](18,0) NULL, /* 0..n BBIE Text ** The reason for the back order. */
  [OutstandingQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity outstanding (which will follow in a later despatch). */
  [OutstandingReason] [numeric](18,0) NULL, /* 0..n BBIE Text ** The reason for the outstanding quantity. */
  [OversupplyQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity over-supplied, i.e., the quantity over and above that ordered. */
  [OrderLineReference] [numeric](18,0) NOT NULL, /* 1..n ASBIE Order Line Reference ** A reference to an order line associated with this despatch line. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this despatch line. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** The item associated with this despatch line. */
  [Shipment] [numeric](18,0) NULL, /* 0..n ASBIE Shipment ** A shipment associated with this despatch line. */
 CONSTRAINT [PK_DespatchLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_ID] ON [dbo].[DespatchLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_UUID] ON [dbo].[DespatchLine] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_Note] ON [dbo].[DespatchLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_LineStatusCode] ON [dbo].[DespatchLine] 
(
	[LineStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_DeliveredQuantity] ON [dbo].[DespatchLine] 
(
	[DeliveredQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_BackorderQuantity] ON [dbo].[DespatchLine] 
(
	[BackorderQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_BackorderReason] ON [dbo].[DespatchLine] 
(
	[BackorderReason] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_OutstandingQuantity] ON [dbo].[DespatchLine] 
(
	[OutstandingQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_OutstandingReason] ON [dbo].[DespatchLine] 
(
	[OutstandingReason] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_OversupplyQuantity] ON [dbo].[DespatchLine] 
(
	[OversupplyQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_OrderLineReference] ON [dbo].[DespatchLine] 
(
	[OrderLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_DocumentReference] ON [dbo].[DespatchLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_Item] ON [dbo].[DespatchLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DespatchLine_Shipment] ON [dbo].[DespatchLine] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Dimension] Script Date: 2013-10-13 00:21z
A class to define a measurable dimension (length, mass, weight, volume, or area) of an item.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Dimension](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [AttributeID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the attribute to which the measure applies. */
  [Measure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The measurement value. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the measurement attribute. */
  [MinimumMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The minimum value in a range of measurement of this dimension. */
  [MaximumMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The maximum value in a range of measurement of this dimension. */
 CONSTRAINT [PK_Dimension] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Dimension_AttributeID] ON [dbo].[Dimension] 
(
	[AttributeID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Dimension_Measure] ON [dbo].[Dimension] 
(
	[Measure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Dimension_Description] ON [dbo].[Dimension] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Dimension_MinimumMeasure] ON [dbo].[Dimension] 
(
	[MinimumMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Dimension_MaximumMeasure] ON [dbo].[Dimension] 
(
	[MaximumMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DocumentDistribution] Script Date: 2013-10-13 00:21z
A class to describe the distribution of a document to an interested party.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DocumentDistribution](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [PrintQualifier] [numeric](18,0) NOT NULL, /* 1 BBIE Text ** Text describing the interested party's distribution rights. */
  [MaximumCopiesNumeric] [numeric](18,0) NOT NULL, /* 1 BBIE Numeric ** The maximum number of printed copies of the document that the interested party is allowed to make. */
  [Party] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The interested party to which the document should be distributed. */
 CONSTRAINT [PK_DocumentDistribution] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentDistribution_PrintQualifier] ON [dbo].[DocumentDistribution] 
(
	[PrintQualifier] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentDistribution_MaximumCopiesNumeric] ON [dbo].[DocumentDistribution] 
(
	[MaximumCopiesNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentDistribution_Party] ON [dbo].[DocumentDistribution] 
(
	[Party] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DocumentReference] Script Date: 2013-10-13 00:21z
A class to define a reference to a document.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DocumentReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the referenced document. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that the referenced document is a copy (true) or the original (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this document reference. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date, assigned by the sender of the referenced document, on which the document was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time, assigned by the sender of the referenced document, at which the document was issued. */
  [DocumentTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of document being referenced, expressed as a code. */
  [DocumentType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The type of document being referenced, expressed as text. */
  [XPath] [numeric](18,0) NULL, /* 0..n BBIE Text ** A reference to another place in the same XML document instance in which DocumentReference appears. */
  [LanguageID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the language used in the referenced document. */
  [LocaleCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the locale in which the language in the referenced document is used. */
  [VersionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the current version of the referenced document. */
  [DocumentStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of the reference document with respect to its original state. */
  [DocumentDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the referenced document. */
  [Attachment] [numeric](18,0) NULL, /* 0..1 ASBIE Attachment ** The referenced document as an attachment to the document from which it is referenced. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period for which this document reference is valid. */
  [IssuerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party who issued the referenced document. */
  [ResultOfVerification] [numeric](18,0) NULL, /* 0..1 ASBIE Result Of Verification ** The result of an attempt to verify a signature associated with the referenced document. */
 CONSTRAINT [PK_DocumentReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_ID] ON [dbo].[DocumentReference] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_CopyIndicator] ON [dbo].[DocumentReference] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_UUID] ON [dbo].[DocumentReference] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_IssueDate] ON [dbo].[DocumentReference] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_IssueTime] ON [dbo].[DocumentReference] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_DocumentTypeCode] ON [dbo].[DocumentReference] 
(
	[DocumentTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_DocumentType] ON [dbo].[DocumentReference] 
(
	[DocumentType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_XPath] ON [dbo].[DocumentReference] 
(
	[XPath] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_LanguageID] ON [dbo].[DocumentReference] 
(
	[LanguageID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_LocaleCode] ON [dbo].[DocumentReference] 
(
	[LocaleCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_VersionID] ON [dbo].[DocumentReference] 
(
	[VersionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_DocumentStatusCode] ON [dbo].[DocumentReference] 
(
	[DocumentStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_DocumentDescription] ON [dbo].[DocumentReference] 
(
	[DocumentDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_Attachment] ON [dbo].[DocumentReference] 
(
	[Attachment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_ValidityPeriod] ON [dbo].[DocumentReference] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_IssuerParty] ON [dbo].[DocumentReference] 
(
	[IssuerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentReference_ResultOfVerification] ON [dbo].[DocumentReference] 
(
	[ResultOfVerification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DocumentResponse] Script Date: 2013-10-13 00:21z
A class to describe an application-level response to a document.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DocumentResponse](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Response] [numeric](18,0) NOT NULL, /* 1 ASBIE Response ** A response to the document as a whole. */
  [DocumentReference] [numeric](18,0) NOT NULL, /* 1..n ASBIE Document Reference ** A referenced document. */
  [IssuerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that issued the document. */
  [RecipientParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party for which the document is intended. */
  [LineResponse] [numeric](18,0) NULL, /* 0..n ASBIE Line Response ** A response to a particular line in the document. */
 CONSTRAINT [PK_DocumentResponse] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentResponse_Response] ON [dbo].[DocumentResponse] 
(
	[Response] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentResponse_DocumentReference] ON [dbo].[DocumentResponse] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentResponse_IssuerParty] ON [dbo].[DocumentResponse] 
(
	[IssuerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentResponse_RecipientParty] ON [dbo].[DocumentResponse] 
(
	[RecipientParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_DocumentResponse_LineResponse] ON [dbo].[DocumentResponse] 
(
	[LineResponse] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Duty] Script Date: 2013-10-13 00:21z
The charging rate used for both call charging and time dependent charging
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Duty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Amount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The amount of this duty. */
  [Duty] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Text describing this duty. */
  [DutyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of this charge rate, expressed as a code. */
  [TaxCategory] [numeric](18,0) NULL, /* 0..1 ASBIE Tax Category ** The tax category applicable to this duty. */
 CONSTRAINT [PK_Duty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Duty_Amount] ON [dbo].[Duty] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Duty_Duty] ON [dbo].[Duty] 
(
	[Duty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Duty_DutyCode] ON [dbo].[Duty] 
(
	[DutyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Duty_TaxCategory] ON [dbo].[Duty] 
(
	[TaxCategory] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EconomicOperatorRole] Script Date: 2013-10-13 00:21z
A class to describe the tenderer contracting role.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EconomicOperatorRole](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [RoleCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code specifying the role of the party. */
  [RoleDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** A textual description of the party role. */
 CONSTRAINT [PK_EconomicOperatorRole] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EconomicOperatorRole_RoleCode] ON [dbo].[EconomicOperatorRole] 
(
	[RoleCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EconomicOperatorRole_RoleDescription] ON [dbo].[EconomicOperatorRole] 
(
	[RoleDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EconomicOperatorShortList] Script Date: 2013-10-13 00:21z
A class to provide information about the preselection of a short list of economic operators for consideration as possible candidates in a tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EconomicOperatorShortList](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [LimitationDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the criteria used to restrict the number of candidates. */
  [ExpectedQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of economic operators expected to be on the short list. */
  [MaximumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The maximum number of economic operators on the short list. */
  [MinimumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The minimum number of economic operators on the short list. */
  [PreSelectedParty] [numeric](18,0) NULL, /* 0..n ASBIE Party ** The parties pre-selected allowed to submit tenders in a negotiated procedure. Negotiated procedure is a type of procedure where the contracting authorities can set the parties to be invited in the procurement project */
 CONSTRAINT [PK_EconomicOperatorShortList] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EconomicOperatorShortList_LimitationDescription] ON [dbo].[EconomicOperatorShortList] 
(
	[LimitationDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EconomicOperatorShortList_ExpectedQuantity] ON [dbo].[EconomicOperatorShortList] 
(
	[ExpectedQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EconomicOperatorShortList_MaximumQuantity] ON [dbo].[EconomicOperatorShortList] 
(
	[MaximumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EconomicOperatorShortList_MinimumQuantity] ON [dbo].[EconomicOperatorShortList] 
(
	[MinimumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EconomicOperatorShortList_PreSelectedParty] ON [dbo].[EconomicOperatorShortList] 
(
	[PreSelectedParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EmissionCalculationMethod] Script Date: 2013-10-13 00:21z
A class to define how an environmental emission is calculated.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EmissionCalculationMethod](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [CalculationMethodCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the method used to calculate the emission. */
  [FullnessIndicationCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying whether a piece of transport equipment is full, partially full, or empty. This indication is used as a parameter when calculating the environmental emission. */
  [MeasurementFromLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** A start location from which an environmental emission is calculated. */
  [MeasurementToLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** An end location to which an environmental emission is calculated. */
 CONSTRAINT [PK_EmissionCalculationMethod] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EmissionCalculationMethod_CalculationMethodCode] ON [dbo].[EmissionCalculationMethod] 
(
	[CalculationMethodCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EmissionCalculationMethod_FullnessIndicationCode] ON [dbo].[EmissionCalculationMethod] 
(
	[FullnessIndicationCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EmissionCalculationMethod_MeasurementFromLocation] ON [dbo].[EmissionCalculationMethod] 
(
	[MeasurementFromLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EmissionCalculationMethod_MeasurementToLocation] ON [dbo].[EmissionCalculationMethod] 
(
	[MeasurementToLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Endorsement] Script Date: 2013-10-13 00:21z
A class to describe an endorsement of a document.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Endorsement](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [DocumentID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this endorsement. */
  [ApprovalStatus] [numeric](18,0) NOT NULL, /* 1 BBIE Text ** The status of this endorsement. */
  [Remarks] [numeric](18,0) NULL, /* 0..n BBIE Text ** Remarks provided by the endorsing party. */
  [EndorserParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Endorser Party ** The type of party providing this endorsement. */
  [Signature] [numeric](18,0) NULL, /* 0..n ASBIE Signature ** A signature applied to this endorsement. */
 CONSTRAINT [PK_Endorsement] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Endorsement_DocumentID] ON [dbo].[Endorsement] 
(
	[DocumentID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Endorsement_ApprovalStatus] ON [dbo].[Endorsement] 
(
	[ApprovalStatus] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Endorsement_Remarks] ON [dbo].[Endorsement] 
(
	[Remarks] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Endorsement_EndorserParty] ON [dbo].[Endorsement] 
(
	[EndorserParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Endorsement_Signature] ON [dbo].[Endorsement] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EndorserParty] Script Date: 2013-10-13 00:21z
A class to describe the party endorsing a document.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EndorserParty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [RoleCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code specifying the role of the party providing the endorsement (e.g., issuer, embassy, insurance, etc.). */
  [SequenceNumeric] [numeric](18,0) NOT NULL, /* 1 BBIE Numeric ** A number indicating the order of the endorsement provided by this party in the sequence in which endorsements are to be applied. */
  [Party] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party endorsing the application. */
  [SignatoryContact] [numeric](18,0) NOT NULL, /* 1 ASBIE Contact ** The individual representing the exporter who signs the Certificate of Origin application before submitting it to the issuer party. */
 CONSTRAINT [PK_EndorserParty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EndorserParty_RoleCode] ON [dbo].[EndorserParty] 
(
	[RoleCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EndorserParty_SequenceNumeric] ON [dbo].[EndorserParty] 
(
	[SequenceNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EndorserParty_Party] ON [dbo].[EndorserParty] 
(
	[Party] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EndorserParty_SignatoryContact] ON [dbo].[EndorserParty] 
(
	[SignatoryContact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EnergyTaxReport] Script Date: 2013-10-13 00:21z
A class to describe energy taxes.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EnergyTaxReport](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [TaxEnergyAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount of taxes (and duties). */
  [TaxEnergyOnAccountAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount of taxes (and duties) paid on account. */
  [TaxEnergyBalanceAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount of the balance of taxes owing. */
  [TaxScheme] [numeric](18,0) NOT NULL, /* 1 ASBIE Tax Scheme ** The relevant taxation scheme. */
 CONSTRAINT [PK_EnergyTaxReport] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnergyTaxReport_TaxEnergyAmount] ON [dbo].[EnergyTaxReport] 
(
	[TaxEnergyAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnergyTaxReport_TaxEnergyOnAccountAmount] ON [dbo].[EnergyTaxReport] 
(
	[TaxEnergyOnAccountAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnergyTaxReport_TaxEnergyBalanceAmount] ON [dbo].[EnergyTaxReport] 
(
	[TaxEnergyBalanceAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnergyTaxReport_TaxScheme] ON [dbo].[EnergyTaxReport] 
(
	[TaxScheme] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EnergyWaterSupply] Script Date: 2013-10-13 00:21z
A class to describe the supply (and therefore consumption) of an amount of energy or water.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EnergyWaterSupply](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ConsumptionReport] [numeric](18,0) NULL, /* 0..n ASBIE Consumption Report ** An amount of energy or water consumed. */
  [EnergyTaxReport] [numeric](18,0) NULL, /* 0..n ASBIE Energy Tax Report ** A tax on the consumption of energy or water. */
  [ConsumptionAverage] [numeric](18,0) NULL, /* 0..n ASBIE Consumption Average ** A consumption average. */
  [EnergyWaterConsumptionCorrection] [numeric](18,0) NULL, /* 0..n ASBIE Consumption Correction ** Describes any corrections or adjustments to the supply of energy or water. */
 CONSTRAINT [PK_EnergyWaterSupply] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnergyWaterSupply_ConsumptionReport] ON [dbo].[EnergyWaterSupply] 
(
	[ConsumptionReport] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnergyWaterSupply_EnergyTaxReport] ON [dbo].[EnergyWaterSupply] 
(
	[EnergyTaxReport] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnergyWaterSupply_ConsumptionAverage] ON [dbo].[EnergyWaterSupply] 
(
	[ConsumptionAverage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnergyWaterSupply_EnergyWaterConsumptionCorrection] ON [dbo].[EnergyWaterSupply] 
(
	[EnergyWaterConsumptionCorrection] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EnvironmentalEmission] Script Date: 2013-10-13 00:21z
A class to describe an environmental emission.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EnvironmentalEmission](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [EnvironmentalEmissionTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code specifying the type of environmental emission. */
  [ValueMeasure] [numeric](18,0) NOT NULL, /* 1 BBIE Measure ** A value measurement for the environmental emission. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this environmental emission. */
  [EmissionCalculationMethod] [numeric](18,0) NULL, /* 0..n ASBIE Emission Calculation Method ** A method used to calculate the amount of this emission. */
 CONSTRAINT [PK_EnvironmentalEmission] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnvironmentalEmission_EnvironmentalEmissionTypeCode] ON [dbo].[EnvironmentalEmission] 
(
	[EnvironmentalEmissionTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnvironmentalEmission_ValueMeasure] ON [dbo].[EnvironmentalEmission] 
(
	[ValueMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnvironmentalEmission_Description] ON [dbo].[EnvironmentalEmission] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EnvironmentalEmission_EmissionCalculationMethod] ON [dbo].[EnvironmentalEmission] 
(
	[EmissionCalculationMethod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EvaluationCriterion] Script Date: 2013-10-13 00:21z
A class defining the required criterion for a tenderer to be elligible in a tendering process. 
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EvaluationCriterion](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [EvaluationCriterionTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code that specifies the criterion; it may be financial, technical or organizational. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** A description of the criterion. */
  [ThresholdAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** Estimated monetary amount of the threshold for the criterion. */
  [ThresholdQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Estimated quantity of the threshold for the criterion. */
  [ExpressionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code identifying the expression that will be used to evaluate the criterion. */
  [Expression] [numeric](18,0) NULL, /* 0..n BBIE Text ** The expression that will be used to evaluate the criterion. */
  [DurationPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** Describes the period for which the evaluation criterion is valid. */
  [SuggestedEvidence] [numeric](18,0) NULL, /* 0..n ASBIE Evidence ** Describes any evidences that should be used to satisfy the criterion.  */
 CONSTRAINT [PK_EvaluationCriterion] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EvaluationCriterion_EvaluationCriterionTypeCode] ON [dbo].[EvaluationCriterion] 
(
	[EvaluationCriterionTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EvaluationCriterion_Description] ON [dbo].[EvaluationCriterion] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EvaluationCriterion_ThresholdAmount] ON [dbo].[EvaluationCriterion] 
(
	[ThresholdAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EvaluationCriterion_ThresholdQuantity] ON [dbo].[EvaluationCriterion] 
(
	[ThresholdQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EvaluationCriterion_ExpressionCode] ON [dbo].[EvaluationCriterion] 
(
	[ExpressionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EvaluationCriterion_Expression] ON [dbo].[EvaluationCriterion] 
(
	[Expression] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EvaluationCriterion_DurationPeriod] ON [dbo].[EvaluationCriterion] 
(
	[DurationPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EvaluationCriterion_SuggestedEvidence] ON [dbo].[EvaluationCriterion] 
(
	[SuggestedEvidence] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Event] Script Date: 2013-10-13 00:21z
A class to describe a significant occurrence relating to an object, process, or person.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Event](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [IdentificationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this event within an agreed event identification scheme. */
  [OccurrenceDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of this event. */
  [OccurrenceTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time of this event. */
  [TypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of this event. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this event. */
  [CompletionIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this event has been completed (true) or not (false). */
  [CurrentStatus] [numeric](18,0) NULL, /* 0..n ASBIE Status ** The current status of this event. */
  [Contact] [numeric](18,0) NULL, /* 0..n ASBIE Contact ** Contacts associated with this event. */
  [OccurenceLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location of this event. */
 CONSTRAINT [PK_Event] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Event_IdentificationID] ON [dbo].[Event] 
(
	[IdentificationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Event_OccurrenceDate] ON [dbo].[Event] 
(
	[OccurrenceDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Event_OccurrenceTime] ON [dbo].[Event] 
(
	[OccurrenceTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Event_TypeCode] ON [dbo].[Event] 
(
	[TypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Event_Description] ON [dbo].[Event] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Event_CompletionIndicator] ON [dbo].[Event] 
(
	[CompletionIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Event_CurrentStatus] ON [dbo].[Event] 
(
	[CurrentStatus] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Event_Contact] ON [dbo].[Event] 
(
	[Contact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Event_OccurenceLocation] ON [dbo].[Event] 
(
	[OccurenceLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EventComment] Script Date: 2013-10-13 00:21z
A class to define comments about a retail event.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EventComment](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Comment] [numeric](18,0) NOT NULL, /* 1 BBIE Text ** Text commenting on the event. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this comment was made. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this comment was made. */
 CONSTRAINT [PK_EventComment] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventComment_Comment] ON [dbo].[EventComment] 
(
	[Comment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventComment_IssueDate] ON [dbo].[EventComment] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventComment_IssueTime] ON [dbo].[EventComment] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EventLineItem] Script Date: 2013-10-13 00:21z
A class to define a line item describing the expected impacts associated with a retail event involving a specific product at a specific location.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EventLineItem](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [LineNumberNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of this event line item. */
  [ParticipatingLocationsLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location of the stores involved in the event described in this line item. */
  [RetailPlannedImpact] [numeric](18,0) NULL, /* 0..n ASBIE Retail Planned Impact ** A planned impact of the event described in this line item. */
  [SupplyItem] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** The product with which the event is associated. */
 CONSTRAINT [PK_EventLineItem] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventLineItem_LineNumberNumeric] ON [dbo].[EventLineItem] 
(
	[LineNumberNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventLineItem_ParticipatingLocationsLocation] ON [dbo].[EventLineItem] 
(
	[ParticipatingLocationsLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventLineItem_RetailPlannedImpact] ON [dbo].[EventLineItem] 
(
	[RetailPlannedImpact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventLineItem_SupplyItem] ON [dbo].[EventLineItem] 
(
	[SupplyItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EventTactic] Script Date: 2013-10-13 00:21z
A class defining a specific type of action or situation arranged by the Buyer or the Seller to promote the product or products.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EventTactic](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Comment] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Generic field to add additional information or to specify mutually defined eventTacticTypes that are not currently listed. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The currencies, units, etc. that describes what is need for the event or promotion Usage example: Number of pallets per store for a stack display */
  [EventTacticEnumeration] [numeric](18,0) NOT NULL, /* 1 ASBIE Event Tactic Enumeration ** The set of codes that describes this event tactic. */
  [Period] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period covered by this event tactic. */
 CONSTRAINT [PK_EventTactic] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventTactic_Comment] ON [dbo].[EventTactic] 
(
	[Comment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventTactic_Quantity] ON [dbo].[EventTactic] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventTactic_EventTacticEnumeration] ON [dbo].[EventTactic] 
(
	[EventTacticEnumeration] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventTactic_Period] ON [dbo].[EventTactic] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EventTacticEnumeration] Script Date: 2013-10-13 00:21z
A class to define a set of codes that describes a retail tactic.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EventTacticEnumeration](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ConsumerIncentiveTacticTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of consumer incentive. Examples include:Free Item, Temporary Price reduction */
  [DisplayTacticTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of display. Examples Include: ON_COUNTER_DISPLAY, FLOOR_GRAPHICS FLOOR_STACK_DISPLAY */
  [FeatureTacticTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying a special feature. Examples Include: BILLBOARD DIRECT_MAIL_AD, FLYER */
  [TradeItemPackingLabelingTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of trade item packing and labeling. Examples Include: BONUS_SIZE CO_BRANDED_TRADE_ITEM */
 CONSTRAINT [PK_EventTacticEnumeration] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventTacticEnumeration_ConsumerIncentiveTacticTypeCode] ON [dbo].[EventTacticEnumeration] 
(
	[ConsumerIncentiveTacticTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventTacticEnumeration_DisplayTacticTypeCode] ON [dbo].[EventTacticEnumeration] 
(
	[DisplayTacticTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventTacticEnumeration_FeatureTacticTypeCode] ON [dbo].[EventTacticEnumeration] 
(
	[FeatureTacticTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EventTacticEnumeration_TradeItemPackingLabelingTypeCode] ON [dbo].[EventTacticEnumeration] 
(
	[TradeItemPackingLabelingTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Evidence] Script Date: 2013-10-13 00:21z
A class to describe an item of evidentiary support for representations of capabilities or the ability to meet tendering requirements, which an economic operator must provide for acceptance into a tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Evidence](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this item of evidentiary support. */
  [EvidenceTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of evidence. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** The textual description for this Evidence. */
  [CandidateStatement] [numeric](18,0) NULL, /* 0..n BBIE Text ** Information about a candidate statement that the contracting authority accepts as a sufficient response. */
  [EvidenceIssuingParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A class to describe a party issuing an evidentiary document. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the evidentiary document. */
  [Language] [numeric](18,0) NULL, /* 0..1 ASBIE Language ** Information about a required translation to be part of the response, i.e. the language. */
 CONSTRAINT [PK_Evidence] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Evidence_ID] ON [dbo].[Evidence] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Evidence_EvidenceTypeCode] ON [dbo].[Evidence] 
(
	[EvidenceTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Evidence_Description] ON [dbo].[Evidence] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Evidence_CandidateStatement] ON [dbo].[Evidence] 
(
	[CandidateStatement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Evidence_EvidenceIssuingParty] ON [dbo].[Evidence] 
(
	[EvidenceIssuingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Evidence_DocumentReference] ON [dbo].[Evidence] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Evidence_Language] ON [dbo].[Evidence] 
(
	[Language] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[EvidenceSupplied] Script Date: 2013-10-13 00:21z
A reference to evidence.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[EvidenceSupplied](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** The identifier of the referenced evidence. */
 CONSTRAINT [PK_EvidenceSupplied] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_EvidenceSupplied_ID] ON [dbo].[EvidenceSupplied] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ExceptionCriteriaLine] Script Date: 2013-10-13 00:21z
A class to define a line in an ExceptionCriteria document that specifies a threshold for forecast variance, product activity, or performance history, the exceeding of which should trigger an exception message.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ExceptionCriteriaLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this exception criteria line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [ThresholdValueComparisonCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** Type of comparison to be carried out in reference to the set threshold." Allowed values are: EXCEEDS_EXCEPTION_VALUE FALLS_BELOW_EXCEPTION_VALUE */
  [ThresholdQuantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** A quantity beyond which an exception will be triggered. */
  [ExceptionStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying status specific to a shipment exception. */
  [CollaborationPriorityCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A collaboratively assigned code signifying priority of the Exception. Possible values are: HIGH, LOW, MEDIUM */
  [ExceptionResolutionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Coded representation of possible resolution methods". Possible values are: DEFAULT_TO_AVERAGE_OF_COMPARED_VALUES DEFAULT_TO_BUYERS_VALUE DEFAULT_TO_HIGH_VALUE DEFAULT_TO_LOW_VALUE DEFAULT_TO_SELLERS_VALUE MANUAL_RESOLUTION MUTUALLY_DEFINED */
  [SupplyChainActivityTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Establishes the criterion for one of the three types of exceptions. There can be three types of exception criteria: Operational, Metric and Forecast Exceptions. This will be set if this Exception is about an Operational Exception. Description could be: A code used to identify an operational exception. Possible values are: CANCELED_ORDERS EMERGENCY_ORDERS ON_HAND ORDERS RECEIPTS SALES SHIPMENTS */
  [PerformanceMetricTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying a measure of performance. */
  [EffectivePeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which this exception criteria line is in effect. */
  [SupplyItem] [numeric](18,0) NOT NULL, /* 1..n ASBIE Item ** The Trade Item that is the subject of the Exception Criterion. */
  [ForecastExceptionCriterionLine] [numeric](18,0) NULL, /* 0..1 ASBIE Forecast Exception Criterion Line ** Establishes the criterion for one of the three types of exceptions. This class provides the criterion for the kind of forecast exception, the identification of the purpose of the forecast, the source of data and the time basis criterion for the exception. */
 CONSTRAINT [PK_ExceptionCriteriaLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_ID] ON [dbo].[ExceptionCriteriaLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_Note] ON [dbo].[ExceptionCriteriaLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_ThresholdValueComparisonCode] ON [dbo].[ExceptionCriteriaLine] 
(
	[ThresholdValueComparisonCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_ThresholdQuantity] ON [dbo].[ExceptionCriteriaLine] 
(
	[ThresholdQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_ExceptionStatusCode] ON [dbo].[ExceptionCriteriaLine] 
(
	[ExceptionStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_CollaborationPriorityCode] ON [dbo].[ExceptionCriteriaLine] 
(
	[CollaborationPriorityCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_ExceptionResolutionCode] ON [dbo].[ExceptionCriteriaLine] 
(
	[ExceptionResolutionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_SupplyChainActivityTypeCode] ON [dbo].[ExceptionCriteriaLine] 
(
	[SupplyChainActivityTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_PerformanceMetricTypeCode] ON [dbo].[ExceptionCriteriaLine] 
(
	[PerformanceMetricTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_EffectivePeriod] ON [dbo].[ExceptionCriteriaLine] 
(
	[EffectivePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_SupplyItem] ON [dbo].[ExceptionCriteriaLine] 
(
	[SupplyItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionCriteriaLine_ForecastExceptionCriterionLine] ON [dbo].[ExceptionCriteriaLine] 
(
	[ForecastExceptionCriterionLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ExceptionNotificationLine] Script Date: 2013-10-13 00:21z
A class to define a line in an Exception Notification.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ExceptionNotificationLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this exception notification line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the exception. */
  [ExceptionStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying status specific to a shipment exception. */
  [CollaborationPriorityCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Priority of Exception. */
  [ResolutionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Coded representation of possible resolution methods". Possible values are: DEFAULT_TO_AVERAGE_OF_COMPARED_VALUES DEFAULT_TO_BUYERS_VALUE DEFAULT_TO_HIGH_VALUE DEFAULT_TO_LOW_VALUE DEFAULT_TO_SELLERS_VALUE MANUAL_RESOLUTION MUTUALLY_DEFINED */
  [ComparedValueMeasure] [numeric](18,0) NOT NULL, /* 1 BBIE Measure ** The value that was compared with the source value that resulted in the exception */
  [SourceValueMeasure] [numeric](18,0) NOT NULL, /* 1 BBIE Measure ** The value used as the basis of comparison */
  [VarianceQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The variance of a data item from an expected value during a particular time interval. */
  [SupplyChainActivityTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Establishes the criterion for one of the three types of exceptions: Operational, performance metric and forecast. This reports an exception notification about an operational exception. Description could be: A code used to identify an operational exception. Possible values are: CANCELED_ORDERS EMERGENCY_ORDERS ON_HAND ORDERS RECEIPTS SALES SHIPMENTS */
  [PerformanceMetricTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code used to identify a measure of performance. It defines the type of the Performance Metric on which an exception criteria is being defined */
  [ExceptionObservationPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period (start-end date) when this exception is observed */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to Exception Criteria document can be provided. */
  [ForecastException] [numeric](18,0) NULL, /* 0..1 ASBIE Forecast Exception ** A forecast accuracy or comparison exception. */
  [SupplyItem] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** The product associated with this exception notification line. */
 CONSTRAINT [PK_ExceptionNotificationLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_ID] ON [dbo].[ExceptionNotificationLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_Note] ON [dbo].[ExceptionNotificationLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_Description] ON [dbo].[ExceptionNotificationLine] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_ExceptionStatusCode] ON [dbo].[ExceptionNotificationLine] 
(
	[ExceptionStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_CollaborationPriorityCode] ON [dbo].[ExceptionNotificationLine] 
(
	[CollaborationPriorityCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_ResolutionCode] ON [dbo].[ExceptionNotificationLine] 
(
	[ResolutionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_ComparedValueMeasure] ON [dbo].[ExceptionNotificationLine] 
(
	[ComparedValueMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_SourceValueMeasure] ON [dbo].[ExceptionNotificationLine] 
(
	[SourceValueMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_VarianceQuantity] ON [dbo].[ExceptionNotificationLine] 
(
	[VarianceQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_SupplyChainActivityTypeCode] ON [dbo].[ExceptionNotificationLine] 
(
	[SupplyChainActivityTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_PerformanceMetricTypeCode] ON [dbo].[ExceptionNotificationLine] 
(
	[PerformanceMetricTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_ExceptionObservationPeriod] ON [dbo].[ExceptionNotificationLine] 
(
	[ExceptionObservationPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_DocumentReference] ON [dbo].[ExceptionNotificationLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_ForecastException] ON [dbo].[ExceptionNotificationLine] 
(
	[ForecastException] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExceptionNotificationLine_SupplyItem] ON [dbo].[ExceptionNotificationLine] 
(
	[SupplyItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ExchangeRate] Script Date: 2013-10-13 00:21z
A class to define an exchange rate.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ExchangeRate](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [SourceCurrencyCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** The reference currency for this exchange rate; the currency from which the exchange is being made. */
  [SourceCurrencyBaseRate] [numeric](18,0) NULL, /* 0..1 BBIE Rate ** In the case of a source currency with denominations of small value, the unit base. */
  [TargetCurrencyCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** The target currency for this exchange rate; the currency to which the exchange is being made. */
  [TargetCurrencyBaseRate] [numeric](18,0) NULL, /* 0..1 BBIE Rate ** In the case of a target currency with denominations of small value, the unit base. */
  [ExchangeMarketID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the currency exchange market used as the source of this exchange rate. */
  [CalculationRate] [numeric](18,0) NULL, /* 0..1 BBIE Rate ** The factor applied to the source currency to calculate the target currency. */
  [MathematicOperatorCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying whether the calculation rate is a multiplier or a divisor. */
  [Date] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which the exchange rate was established. */
  [ForeignExchangeContract] [numeric](18,0) NULL, /* 0..1 ASBIE Contract ** A contract for foreign exchange. */
 CONSTRAINT [PK_ExchangeRate] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExchangeRate_SourceCurrencyCode] ON [dbo].[ExchangeRate] 
(
	[SourceCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExchangeRate_SourceCurrencyBaseRate] ON [dbo].[ExchangeRate] 
(
	[SourceCurrencyBaseRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExchangeRate_TargetCurrencyCode] ON [dbo].[ExchangeRate] 
(
	[TargetCurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExchangeRate_TargetCurrencyBaseRate] ON [dbo].[ExchangeRate] 
(
	[TargetCurrencyBaseRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExchangeRate_ExchangeMarketID] ON [dbo].[ExchangeRate] 
(
	[ExchangeMarketID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExchangeRate_CalculationRate] ON [dbo].[ExchangeRate] 
(
	[CalculationRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExchangeRate_MathematicOperatorCode] ON [dbo].[ExchangeRate] 
(
	[MathematicOperatorCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExchangeRate_Date] ON [dbo].[ExchangeRate] 
(
	[Date] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExchangeRate_ForeignExchangeContract] ON [dbo].[ExchangeRate] 
(
	[ForeignExchangeContract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ExternalReference] Script Date: 2013-10-13 00:21z
A class to describe an external object, such as a document stored at a remote location.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ExternalReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [URI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The Uniform Resource Identifier (URI) that identifies the external object as an Internet resource. */
  [DocumentHash] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A hash value for the externally stored object. */
  [HashAlgorithmMethod] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A hash algorithm used to calculate the hash value of the externally stored object. */
  [ExpiryDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which availability of the resource can no longer be relied upon. */
  [ExpiryTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time after which availability of the resource can no longer be relied upon. */
  [MimeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the mime type of the external object. */
  [FormatCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the format of the external object. */
  [EncodingCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the encoding/decoding algorithm used with the external object. */
  [CharacterSetCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the character set of an external document. */
  [FileName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The file name of the external object. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the external object. */
 CONSTRAINT [PK_ExternalReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExternalReference_URI] ON [dbo].[ExternalReference] 
(
	[URI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExternalReference_DocumentHash] ON [dbo].[ExternalReference] 
(
	[DocumentHash] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExternalReference_HashAlgorithmMethod] ON [dbo].[ExternalReference] 
(
	[HashAlgorithmMethod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExternalReference_ExpiryDate] ON [dbo].[ExternalReference] 
(
	[ExpiryDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExternalReference_ExpiryTime] ON [dbo].[ExternalReference] 
(
	[ExpiryTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExternalReference_MimeCode] ON [dbo].[ExternalReference] 
(
	[MimeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExternalReference_FormatCode] ON [dbo].[ExternalReference] 
(
	[FormatCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExternalReference_EncodingCode] ON [dbo].[ExternalReference] 
(
	[EncodingCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExternalReference_CharacterSetCode] ON [dbo].[ExternalReference] 
(
	[CharacterSetCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExternalReference_FileName] ON [dbo].[ExternalReference] 
(
	[FileName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ExternalReference_Description] ON [dbo].[ExternalReference] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[FinancialAccount] Script Date: 2013-10-13 00:21z
A class to describe a financial account.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[FinancialAccount](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The identifier for this financial account; the bank account number. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this financial account. */
  [AliasName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** An alias for the name of this financial account, to be used in place of the actual account name for security reasons. */
  [AccountTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of this financial account. */
  [AccountFormatCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the format of this financial account. */
  [CurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency in which this financial account is held. */
  [PaymentNote] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text applying to the Payment for the owner of this account. */
  [FinancialInstitutionBranch] [numeric](18,0) NULL, /* 0..1 ASBIE Branch ** The branch of the financial institution associated with this financial account. */
  [Country] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country in which the holder of the financial account is domiciled. */
 CONSTRAINT [PK_FinancialAccount] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialAccount_ID] ON [dbo].[FinancialAccount] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialAccount_Name] ON [dbo].[FinancialAccount] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialAccount_AliasName] ON [dbo].[FinancialAccount] 
(
	[AliasName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialAccount_AccountTypeCode] ON [dbo].[FinancialAccount] 
(
	[AccountTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialAccount_AccountFormatCode] ON [dbo].[FinancialAccount] 
(
	[AccountFormatCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialAccount_CurrencyCode] ON [dbo].[FinancialAccount] 
(
	[CurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialAccount_PaymentNote] ON [dbo].[FinancialAccount] 
(
	[PaymentNote] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialAccount_FinancialInstitutionBranch] ON [dbo].[FinancialAccount] 
(
	[FinancialInstitutionBranch] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialAccount_Country] ON [dbo].[FinancialAccount] 
(
	[Country] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[FinancialGuarantee] Script Date: 2013-10-13 00:21z
A class to describe the bond guarantee of a tenderer or bid submitter's actual entry into a contract in the event that it is the successful bidder.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[FinancialGuarantee](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [GuaranteeTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the type of financial guarantee. For instance "Provisional Guarantee" or "Final Guarantee" */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this financial guarantee. */
  [LiabilityAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount of liability in this financial guarantee. */
  [AmountRate] [numeric](18,0) NULL, /* 0..1 BBIE Rate ** The rate used to calculate the amount of liability in this financial guarantee. */
  [ConstitutionPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during the tendering process to which this financial guarantee has to be settled. */
 CONSTRAINT [PK_FinancialGuarantee] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialGuarantee_GuaranteeTypeCode] ON [dbo].[FinancialGuarantee] 
(
	[GuaranteeTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialGuarantee_Description] ON [dbo].[FinancialGuarantee] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialGuarantee_LiabilityAmount] ON [dbo].[FinancialGuarantee] 
(
	[LiabilityAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialGuarantee_AmountRate] ON [dbo].[FinancialGuarantee] 
(
	[AmountRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialGuarantee_ConstitutionPeriod] ON [dbo].[FinancialGuarantee] 
(
	[ConstitutionPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[FinancialInstitution] Script Date: 2013-10-13 00:21z
A class to describe a financial institution.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[FinancialInstitution](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this financial institution. It is recommended that the ISO 9362 Bank Identification Code (BIC) be used as the ID. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this financial institution. */
  [Address] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The address of this financial institution. */
 CONSTRAINT [PK_FinancialInstitution] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialInstitution_ID] ON [dbo].[FinancialInstitution] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialInstitution_Name] ON [dbo].[FinancialInstitution] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FinancialInstitution_Address] ON [dbo].[FinancialInstitution] 
(
	[Address] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ForecastException] Script Date: 2013-10-13 00:21z
As explained in Exception Criteria Line: Three types of exception criteria can be defined, Operational, Metric or Forecast Exceptions. This class provides criteria for forecast exception type: the identification of the purpose of the forecast, the source of data and the time basis criteria for the exception.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ForecastException](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ForecastPurposeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** It is either Sales forecast or Order Forecast. Definition can be changed like: "The purpose of the Forecast (either sales or order), about which an exception criteria is being defined". */
  [ForecastTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the type of forecast. Example of values are:BASE PROMOTIONAL SEASONAL TOTAL */
  [IssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date on which the forecast was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which the forecast was issued. */
  [DataSourceCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the partner who provides this information. */
  [ComparisonDataCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the partner providing the information in this forecast exception. */
  [ComparisonForecastIssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this comparison forecast was issued. */
  [ComparisonForecastIssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this comparison forecast was issued. */
 CONSTRAINT [PK_ForecastException] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastException_ForecastPurposeCode] ON [dbo].[ForecastException] 
(
	[ForecastPurposeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastException_ForecastTypeCode] ON [dbo].[ForecastException] 
(
	[ForecastTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastException_IssueDate] ON [dbo].[ForecastException] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastException_IssueTime] ON [dbo].[ForecastException] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastException_DataSourceCode] ON [dbo].[ForecastException] 
(
	[DataSourceCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastException_ComparisonDataCode] ON [dbo].[ForecastException] 
(
	[ComparisonDataCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastException_ComparisonForecastIssueTime] ON [dbo].[ForecastException] 
(
	[ComparisonForecastIssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastException_ComparisonForecastIssueDate] ON [dbo].[ForecastException] 
(
	[ComparisonForecastIssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ForecastExceptionCriterionLine] Script Date: 2013-10-13 00:21z
Establishes the criterion for one of the three types of exceptions. This class provides criteria for the kind of forecast exception, the identification of the purpose of the forecast, the source of data and the time basis criterion for the exception.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ForecastExceptionCriterionLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ForecastPurposeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A description of the purpose for the forecast that is assigned to each forecast data item exception criterion. */
  [ForecastTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A description of a Forecast selected from a list. */
  [ComparisonDataSourceCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** If it is a forecast comparison exception, this value indicates the other source of information. */
  [DataSourceCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** Indication of the partner who provides the information. */
  [TimeDeltaDaysQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Time basis in days for the Exception. */
 CONSTRAINT [PK_ForecastExceptionCriterionLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastExceptionCriterionLine_ForecastPurposeCode] ON [dbo].[ForecastExceptionCriterionLine] 
(
	[ForecastPurposeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastExceptionCriterionLine_ForecastTypeCode] ON [dbo].[ForecastExceptionCriterionLine] 
(
	[ForecastTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastExceptionCriterionLine_ComparisonDataSourceCode] ON [dbo].[ForecastExceptionCriterionLine] 
(
	[ComparisonDataSourceCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastExceptionCriterionLine_DataSourceCode] ON [dbo].[ForecastExceptionCriterionLine] 
(
	[DataSourceCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastExceptionCriterionLine_TimeDeltaDaysQuantity] ON [dbo].[ForecastExceptionCriterionLine] 
(
	[TimeDeltaDaysQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ForecastLine] Script Date: 2013-10-13 00:21z
Detailed information about a particular Forecast Line within a Forecast Document
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ForecastLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this forecast line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [FrozenDocumentIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that the status of the forecast is modifiable (true) or not (false). */
  [ForecastTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the type of forecast. Examples: BASE PROMOTIONAL SEASONAL TOTAL */
  [ForecastPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period to which the forecast applies. */
  [SalesItem] [numeric](18,0) NULL, /* 0..1 ASBIE Sales Item ** Sales information for the item to which this line applies. */
 CONSTRAINT [PK_ForecastLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastLine_ID] ON [dbo].[ForecastLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastLine_Note] ON [dbo].[ForecastLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastLine_FrozenDocumentIndicator] ON [dbo].[ForecastLine] 
(
	[FrozenDocumentIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastLine_ForecastTypeCode] ON [dbo].[ForecastLine] 
(
	[ForecastTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastLine_ForecastPeriod] ON [dbo].[ForecastLine] 
(
	[ForecastPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastLine_SalesItem] ON [dbo].[ForecastLine] 
(
	[SalesItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ForecastRevisionLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Forecast Revision describing a revision to a line in a Forecast.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ForecastRevisionLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this forecast revision line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the revision to this line. */
  [RevisedForecastLineID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the revised forecast line. */
  [SourceForecastIssueDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date on which the forecast modified by this revision was generated or created. */
  [SourceForecastIssueTime] [numeric](18,0) NOT NULL, /* 1 BBIE Time ** The time at which the forecast modified by this revision was generated or created. */
  [AdjustmentReasonCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the reason for the adjustment specified in this forecast revision line. */
  [ForecastPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period to which this forecast revision line applies. */
  [SalesItem] [numeric](18,0) NULL, /* 0..1 ASBIE Sales Item ** Sales information for the item to which this line applies. */
 CONSTRAINT [PK_ForecastRevisionLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevisionLine_ID] ON [dbo].[ForecastRevisionLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevisionLine_Note] ON [dbo].[ForecastRevisionLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevisionLine_Description] ON [dbo].[ForecastRevisionLine] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevisionLine_RevisedForecastLineID] ON [dbo].[ForecastRevisionLine] 
(
	[RevisedForecastLineID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevisionLine_SourceForecastIssueDate] ON [dbo].[ForecastRevisionLine] 
(
	[SourceForecastIssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevisionLine_SourceForecastIssueTime] ON [dbo].[ForecastRevisionLine] 
(
	[SourceForecastIssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevisionLine_AdjustmentReasonCode] ON [dbo].[ForecastRevisionLine] 
(
	[AdjustmentReasonCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevisionLine_ForecastPeriod] ON [dbo].[ForecastRevisionLine] 
(
	[ForecastPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ForecastRevisionLine_SalesItem] ON [dbo].[ForecastRevisionLine] 
(
	[SalesItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[FrameworkAgreement] Script Date: 2013-10-13 00:21z
A class to describe a tendering framework agreement.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[FrameworkAgreement](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ExpectedOperatorQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of economic operators expected to participate in this framework agreement. */
  [MaximumOperatorQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The maximum number of economic operators allowed to participate in this framework agreement. */
  [Justification] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the justification for this framework agreement. */
  [Frequency] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the frequency with which subsequent contracts will be awarded. */
  [DurationPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which this framework agreement applies. */
  [SubsequentProcessTenderRequirement] [numeric](18,0) NULL, /* 0..n ASBIE Tender Requirement ** A tender requirement intended for consumption by downstream tendering processes derived from the establishment of this framework agreement. */
 CONSTRAINT [PK_FrameworkAgreement] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FrameworkAgreement_ExpectedOperatorQuantity] ON [dbo].[FrameworkAgreement] 
(
	[ExpectedOperatorQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FrameworkAgreement_MaximumOperatorQuantity] ON [dbo].[FrameworkAgreement] 
(
	[MaximumOperatorQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FrameworkAgreement_Justification] ON [dbo].[FrameworkAgreement] 
(
	[Justification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FrameworkAgreement_Frequency] ON [dbo].[FrameworkAgreement] 
(
	[Frequency] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FrameworkAgreement_DurationPeriod] ON [dbo].[FrameworkAgreement] 
(
	[DurationPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_FrameworkAgreement_SubsequentProcessTenderRequirement] ON [dbo].[FrameworkAgreement] 
(
	[SubsequentProcessTenderRequirement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[GoodsItem] Script Date: 2013-10-13 00:21z
A class to describe a separately identifiable quantity of goods of a single product type.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[GoodsItem](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this goods item. */
  [SequenceNumberID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A sequence number differentiating a specific goods item within a consignment. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this goods item to identify it for customs, statistical, or transport purposes. */
  [HazardousRiskIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported goods item is subject to an international regulation concerning the carriage of dangerous goods (true) or not (false). */
  [DeclaredCustomsValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total declared value for customs purposes of the goods item. */
  [DeclaredForCarriageValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The value of this goods item, declared by the shipper or his agent solely for the purpose of varying the carrier's level of liability from that provided in the contract of carriage, in case of loss or damage to goods or delayed delivery. */
  [DeclaredStatisticsValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total declared value of all the goods items in the same consignment with this goods item that have the same statistical heading. */
  [FreeOnBoardValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount that has to be or has been paid as calculated under the applicable trade delivery. */
  [InsuranceValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount covered by insurance for this goods item. */
  [ValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount on which a duty, tax, or fee will be assessed. */
  [GrossWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The weight of this goods item, including packing and packaging but excluding the carrier's equipment. */
  [NetWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The weight of this goods item, excluding packing but including packaging that normally accompanies the goods. */
  [NetNetWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total weight of this goods item, excluding all packing and packaging. */
  [ChargeableWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The weight on which a charge is to be based. */
  [GrossVolumeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The volume of this goods item, normally calculated by multiplying its maximum length, width, and height. */
  [NetVolumeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The volume contained by a goods item, excluding the volume of any packaging material. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of units making up this goods item. */
  [PreferenceCriterionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the treatment preference for this goods item according to international trading agreements. */
  [RequiredCustomsID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for a set of tariff codes required to specify a type of goods for customs, transport, statistical, or other regulatory purposes. */
  [CustomsStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code assigned by customs to signify the status of this goods item. */
  [CustomsTariffQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Quantity of the units in this goods item as required by customs for tariff, statistical, or fiscal purposes. */
  [CustomsImportClassifiedIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this goods item has been classified for import by customs (true) or not (false). */
  [ChargeableQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of units in the goods item to which charges apply. */
  [ReturnableQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of units in the goods item that may be returned. */
  [TraceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for use in tracing this goods item, such as the EPC number used in RFID. */
  [Item] [numeric](18,0) NULL, /* 0..n ASBIE Item ** Product information relating to a goods item. */
  [GoodsItemContainer] [numeric](18,0) NULL, /* 0..n ASBIE Goods Item Container ** The transporting of a goods item in a unit of transport equipment (e.g., container). */
  [FreightAllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A cost incurred by the shipper in moving goods, by whatever means, from one place to another under the terms of the contract of carriage. In addition to transport costs, this may include such elements as packing, documentation, loading, unloading, and insurance to the extent that they relate to the freight costs. */
  [InvoiceLine] [numeric](18,0) NULL, /* 0..n ASBIE Invoice Line ** Information about an invoice line relating to this goods item. */
  [Temperature] [numeric](18,0) NULL, /* 0..n ASBIE Temperature ** The temperature of the goods item. */
  [ContainedGoodsItem] [numeric](18,0) NULL, /* 0..n ASBIE Goods Item ** A goods item contained in this goods item. */
  [OriginAddress] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The region in which the goods have been produced or manufactured, according to criteria laid down for the purposes of application of the customs tariff, or of quantitative restrictions, or of any other measure related to trade. */
  [Delivery] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery ** The delivery of this goods item. */
  [Pickup] [numeric](18,0) NULL, /* 0..1 ASBIE Pickup ** The pickup of this goods item. */
  [Despatch] [numeric](18,0) NULL, /* 0..1 ASBIE Despatch ** The despatch of this goods item. */
  [MeasurementDimension] [numeric](18,0) NULL, /* 0..n ASBIE Dimension ** A measurable dimension (length, mass, weight, or volume) of this goods item. */
  [ContainingPackage] [numeric](18,0) NULL, /* 0..n ASBIE Package ** A package containing this goods item. */
  [ShipmentDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a shipping document associated with this goods item. */
  [MinimumTemperature] [numeric](18,0) NULL, /* 0..1 ASBIE Temperature ** Information about minimum temperature. */
  [MaximumTemperature] [numeric](18,0) NULL, /* 0..1 ASBIE Temperature ** Information about maximum temperature. */
 CONSTRAINT [PK_GoodsItem] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_ID] ON [dbo].[GoodsItem] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_SequenceNumberID] ON [dbo].[GoodsItem] 
(
	[SequenceNumberID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_Description] ON [dbo].[GoodsItem] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_HazardousRiskIndicator] ON [dbo].[GoodsItem] 
(
	[HazardousRiskIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_DeclaredCustomsValueAmount] ON [dbo].[GoodsItem] 
(
	[DeclaredCustomsValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_DeclaredForCarriageValueAmount] ON [dbo].[GoodsItem] 
(
	[DeclaredForCarriageValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_DeclaredStatisticsValueAmount] ON [dbo].[GoodsItem] 
(
	[DeclaredStatisticsValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_FreeOnBoardValueAmount] ON [dbo].[GoodsItem] 
(
	[FreeOnBoardValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_InsuranceValueAmount] ON [dbo].[GoodsItem] 
(
	[InsuranceValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_ValueAmount] ON [dbo].[GoodsItem] 
(
	[ValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_GrossWeightMeasure] ON [dbo].[GoodsItem] 
(
	[GrossWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_NetWeightMeasure] ON [dbo].[GoodsItem] 
(
	[NetWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_NetNetWeightMeasure] ON [dbo].[GoodsItem] 
(
	[NetNetWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_ChargeableWeightMeasure] ON [dbo].[GoodsItem] 
(
	[ChargeableWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_GrossVolumeMeasure] ON [dbo].[GoodsItem] 
(
	[GrossVolumeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_NetVolumeMeasure] ON [dbo].[GoodsItem] 
(
	[NetVolumeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_Quantity] ON [dbo].[GoodsItem] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_PreferenceCriterionCode] ON [dbo].[GoodsItem] 
(
	[PreferenceCriterionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_RequiredCustomsID] ON [dbo].[GoodsItem] 
(
	[RequiredCustomsID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_CustomsStatusCode] ON [dbo].[GoodsItem] 
(
	[CustomsStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_CustomsTariffQuantity] ON [dbo].[GoodsItem] 
(
	[CustomsTariffQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_CustomsImportClassifiedIndicator] ON [dbo].[GoodsItem] 
(
	[CustomsImportClassifiedIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_ChargeableQuantity] ON [dbo].[GoodsItem] 
(
	[ChargeableQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_ReturnableQuantity] ON [dbo].[GoodsItem] 
(
	[ReturnableQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_TraceID] ON [dbo].[GoodsItem] 
(
	[TraceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_Item] ON [dbo].[GoodsItem] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_GoodsItemContainer] ON [dbo].[GoodsItem] 
(
	[GoodsItemContainer] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_FreightAllowanceCharge] ON [dbo].[GoodsItem] 
(
	[FreightAllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_InvoiceLine] ON [dbo].[GoodsItem] 
(
	[InvoiceLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_Temperature] ON [dbo].[GoodsItem] 
(
	[Temperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_ContainedGoodsItem] ON [dbo].[GoodsItem] 
(
	[ContainedGoodsItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_OriginAddress] ON [dbo].[GoodsItem] 
(
	[OriginAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_Delivery] ON [dbo].[GoodsItem] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_Pickup] ON [dbo].[GoodsItem] 
(
	[Pickup] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_Despatch] ON [dbo].[GoodsItem] 
(
	[Despatch] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_MeasurementDimension] ON [dbo].[GoodsItem] 
(
	[MeasurementDimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_ContainingPackage] ON [dbo].[GoodsItem] 
(
	[ContainingPackage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_ShipmentDocumentReference] ON [dbo].[GoodsItem] 
(
	[ShipmentDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_MinimumTemperature] ON [dbo].[GoodsItem] 
(
	[MinimumTemperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItem_MaximumTemperature] ON [dbo].[GoodsItem] 
(
	[MaximumTemperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[GoodsItemContainer] Script Date: 2013-10-13 00:21z
A class defining how goods items are split across transport equipment.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[GoodsItemContainer](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this goods item container. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of goods items loaded into or onto one piece of transport equipment as a total consignment or part of a consignment. */
  [TransportEquipment] [numeric](18,0) NULL, /* 0..n ASBIE Transport Equipment ** A piece of transport equipment used to contain a single goods item. */
 CONSTRAINT [PK_GoodsItemContainer] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemContainer_ID] ON [dbo].[GoodsItemContainer] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemContainer_Quantity] ON [dbo].[GoodsItemContainer] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_GoodsItemContainer_TransportEquipment] ON [dbo].[GoodsItemContainer] 
(
	[TransportEquipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[HazardousGoodsTransit] Script Date: 2013-10-13 00:21z
A class to describe hazardous goods in transit.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[HazardousGoodsTransit](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [TransportEmergencyCardCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** An identifier for a transport emergency card describing the actions to be taken in an emergency in transporting the hazardous goods. It may be the identity number of a hazardous emergency response plan assigned by the appropriate authority. */
  [PackingCriteriaCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the packaging requirement for transportation of the hazardous goods as assigned by IATA, IMDB, ADR, RID etc. */
  [HazardousRegulationCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the set of legal regulations governing the transportation of the hazardous goods. */
  [InhalationToxicityZoneCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the Inhalation Toxicity Hazard Zone for the hazardous goods, as defined by the US Department of Transportation. */
  [TransportAuthorizationCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying authorization for the transportation of hazardous cargo. */
  [MaximumTemperature] [numeric](18,0) NULL, /* 0..1 ASBIE Temperature ** The maximum temperature at which the hazardous goods can safely be transported. */
  [MinimumTemperature] [numeric](18,0) NULL, /* 0..1 ASBIE Temperature ** The minimum temperature at which the hazardous goods can safely be transported. */
 CONSTRAINT [PK_HazardousGoodsTransit] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousGoodsTransit_TransportEmergencyCardCode] ON [dbo].[HazardousGoodsTransit] 
(
	[TransportEmergencyCardCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousGoodsTransit_PackingCriteriaCode] ON [dbo].[HazardousGoodsTransit] 
(
	[PackingCriteriaCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousGoodsTransit_HazardousRegulationCode] ON [dbo].[HazardousGoodsTransit] 
(
	[HazardousRegulationCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousGoodsTransit_InhalationToxicityZoneCode] ON [dbo].[HazardousGoodsTransit] 
(
	[InhalationToxicityZoneCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousGoodsTransit_TransportAuthorizationCode] ON [dbo].[HazardousGoodsTransit] 
(
	[TransportAuthorizationCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousGoodsTransit_MaximumTemperature] ON [dbo].[HazardousGoodsTransit] 
(
	[MaximumTemperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousGoodsTransit_MinimumTemperature] ON [dbo].[HazardousGoodsTransit] 
(
	[MinimumTemperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[HazardousItem] Script Date: 2013-10-13 00:21z
A class to describe a hazardous item.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[HazardousItem](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this hazardous item. */
  [PlacardNotation] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Text of the placard notation corresponding to the hazard class of this hazardous item. Can also be the hazard identification number of the orange placard (upper part) required on the means of transport. */
  [PlacardEndorsement] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Text of the placard endorsement that is to be shown on the shipping papers for this hazardous item. Can also be used for the number of the orange placard (lower part) required on the means of transport. */
  [AdditionalInformation] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text providing further information about the hazardous substance. */
  [UNDGCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The UN code for this kind of hazardous item. */
  [EmergencyProceduresCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the emergency procedures for this hazardous item. */
  [MedicalFirstAidGuideCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying a medical first aid guide appropriate to this hazardous item. */
  [TechnicalName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The full technical name of a specific hazardous substance contained in this goods item. */
  [CategoryName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of the category of hazard that applies to the Item. */
  [HazardousCategoryCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying a kind of hazard for a material. */
  [UpperOrangeHazardPlacardID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The number for the upper part of the orange hazard placard required on the means of transport. */
  [LowerOrangeHazardPlacardID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The number for the lower part of the orange hazard placard required on the means of transport. */
  [MarkingID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier to the marking of the Hazardous Item */
  [HazardClassID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the hazard class applicable to this hazardous item as defined by the relevant regulation authority (e.g., the IMDG Class Number of the SOLAS Convention of IMO and the ADR/RID Class Number for the road/rail environment). */
  [NetWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The net weight of this hazardous item, excluding packaging. */
  [NetVolumeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The volume of this hazardous item, excluding packaging and transport equipment. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of goods items in this hazardous item that are hazardous. */
  [ContactParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The individual, group, or body to be contacted in case of a hazardous incident associated with this item. */
  [SecondaryHazard] [numeric](18,0) NULL, /* 0..n ASBIE Secondary Hazard ** A secondary hazard associated with this hazardous item. */
  [HazardousGoodsTransit] [numeric](18,0) NULL, /* 0..n ASBIE Hazardous Goods Transit ** Information related to the transit of this kind of hazardous goods. */
  [EmergencyTemperature] [numeric](18,0) NULL, /* 0..1 ASBIE Temperature ** The threshold temperature at which emergency procedures apply in the handling of temperature-controlled goods. */
  [FlashpointTemperature] [numeric](18,0) NULL, /* 0..1 ASBIE Temperature ** The flashpoint temperature of this hazardous item; i.e., the lowest temperature at which vapors above a volatile combustible substance ignite in air when exposed to flame. */
  [AdditionalTemperature] [numeric](18,0) NULL, /* 0..n ASBIE Temperature ** Another temperature relevant to the handling of this hazardous item. */
 CONSTRAINT [PK_HazardousItem] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_ID] ON [dbo].[HazardousItem] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_PlacardNotation] ON [dbo].[HazardousItem] 
(
	[PlacardNotation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_PlacardEndorsement] ON [dbo].[HazardousItem] 
(
	[PlacardEndorsement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_AdditionalInformation] ON [dbo].[HazardousItem] 
(
	[AdditionalInformation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_UNDGCode] ON [dbo].[HazardousItem] 
(
	[UNDGCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_EmergencyProceduresCode] ON [dbo].[HazardousItem] 
(
	[EmergencyProceduresCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_MedicalFirstAidGuideCode] ON [dbo].[HazardousItem] 
(
	[MedicalFirstAidGuideCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_TechnicalName] ON [dbo].[HazardousItem] 
(
	[TechnicalName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_CategoryName] ON [dbo].[HazardousItem] 
(
	[CategoryName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_HazardousCategoryCode] ON [dbo].[HazardousItem] 
(
	[HazardousCategoryCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_UpperOrangeHazardPlacardID] ON [dbo].[HazardousItem] 
(
	[UpperOrangeHazardPlacardID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_LowerOrangeHazardPlacardID] ON [dbo].[HazardousItem] 
(
	[LowerOrangeHazardPlacardID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_MarkingID] ON [dbo].[HazardousItem] 
(
	[MarkingID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_HazardClassID] ON [dbo].[HazardousItem] 
(
	[HazardClassID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_NetWeightMeasure] ON [dbo].[HazardousItem] 
(
	[NetWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_NetVolumeMeasure] ON [dbo].[HazardousItem] 
(
	[NetVolumeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_Quantity] ON [dbo].[HazardousItem] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_ContactParty] ON [dbo].[HazardousItem] 
(
	[ContactParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_SecondaryHazard] ON [dbo].[HazardousItem] 
(
	[SecondaryHazard] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_HazardousGoodsTransit] ON [dbo].[HazardousItem] 
(
	[HazardousGoodsTransit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_EmergencyTemperature] ON [dbo].[HazardousItem] 
(
	[EmergencyTemperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_FlashpointTemperature] ON [dbo].[HazardousItem] 
(
	[FlashpointTemperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_HazardousItem_AdditionalTemperature] ON [dbo].[HazardousItem] 
(
	[AdditionalTemperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ImmobilizedSecurity] Script Date: 2013-10-13 00:21z
A class to describe an immobilized security to be used as a guarantee.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ImmobilizedSecurity](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ImmobilizationCertificateID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the certificate of this immobilized security. */
  [SecurityID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the security being immobilized. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this immobilized security was issued. */
  [FaceValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The value of the security on the day it was immobilized. */
  [MarketValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The current market value of the immobilized security. */
  [SharesNumberQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of shares immobilized. */
  [IssuerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party issuing the immobilized security certificate. */
 CONSTRAINT [PK_ImmobilizedSecurity] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ImmobilizedSecurity_ImmobilizationCertificateID] ON [dbo].[ImmobilizedSecurity] 
(
	[ImmobilizationCertificateID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ImmobilizedSecurity_SecurityID] ON [dbo].[ImmobilizedSecurity] 
(
	[SecurityID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ImmobilizedSecurity_IssueDate] ON [dbo].[ImmobilizedSecurity] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ImmobilizedSecurity_FaceValueAmount] ON [dbo].[ImmobilizedSecurity] 
(
	[FaceValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ImmobilizedSecurity_MarketValueAmount] ON [dbo].[ImmobilizedSecurity] 
(
	[MarketValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ImmobilizedSecurity_SharesNumberQuantity] ON [dbo].[ImmobilizedSecurity] 
(
	[SharesNumberQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ImmobilizedSecurity_IssuerParty] ON [dbo].[ImmobilizedSecurity] 
(
	[IssuerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[InstructionForReturnsLine] Script Date: 2013-10-13 00:21z
A class to define a line in an Instruction for Returns.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[InstructionForReturnsLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this instruction for returns line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [Quantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The quantity of goods being returned. */
  [ManufacturerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The manufacturer of the goods being returned. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** A description of the item being returned. */
 CONSTRAINT [PK_InstructionForReturnsLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturnsLine_ID] ON [dbo].[InstructionForReturnsLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturnsLine_Note] ON [dbo].[InstructionForReturnsLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturnsLine_Quantity] ON [dbo].[InstructionForReturnsLine] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturnsLine_ManufacturerParty] ON [dbo].[InstructionForReturnsLine] 
(
	[ManufacturerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InstructionForReturnsLine_Item] ON [dbo].[InstructionForReturnsLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[InventoryReportLine] Script Date: 2013-10-13 00:21z
A class to define a line in an Inventory Report.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[InventoryReportLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this inventory report line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [Quantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The quantity of the item reported that is currently in stock. */
  [InventoryValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The value of the quantity of the item reported that is currently in stock. */
  [AvailabilityDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date from which the goods will be available. If not present, the goods are available now. */
  [AvailabilityStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the item's level of availability. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** The item associated with this inventory report line. */
  [InventoryLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location of the reported quantity of goods. */
 CONSTRAINT [PK_InventoryReportLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReportLine_ID] ON [dbo].[InventoryReportLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReportLine_Note] ON [dbo].[InventoryReportLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReportLine_Quantity] ON [dbo].[InventoryReportLine] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReportLine_InventoryValueAmount] ON [dbo].[InventoryReportLine] 
(
	[InventoryValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReportLine_AvailabilityDate] ON [dbo].[InventoryReportLine] 
(
	[AvailabilityDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReportLine_AvailabilityStatusCode] ON [dbo].[InventoryReportLine] 
(
	[AvailabilityStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReportLine_Item] ON [dbo].[InventoryReportLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InventoryReportLine_InventoryLocation] ON [dbo].[InventoryReportLine] 
(
	[InventoryLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[InvoiceLine] Script Date: 2013-10-13 00:21z
A class to define a line in an Invoice.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[InvoiceLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this invoice line. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this invoice line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [InvoicedQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity (of items) on this invoice line. */
  [LineExtensionAmount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The total amount for this invoice line, including allowance charges but net of taxes. */
  [TaxPointDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of this invoice line, used to indicate the point at which tax becomes applicable. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting cost centre for this invoice line, expressed as a code. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting cost centre for this invoice line, expressed as text. */
  [PaymentPurposeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the business purpose for this payment. */
  [FreeOfChargeIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this invoice line is free of charge (true) or not (false). The default is false. */
  [InvoicePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** An invoice period to which this invoice line applies. */
  [OrderLineReference] [numeric](18,0) NULL, /* 0..n ASBIE Order Line Reference ** A reference to an order line associated with this invoice line. */
  [DespatchLineReference] [numeric](18,0) NULL, /* 0..n ASBIE Line Reference ** A reference to a despatch line associated with this invoice line. */
  [ReceiptLineReference] [numeric](18,0) NULL, /* 0..n ASBIE Line Reference ** A reference to a receipt line associated with this invoice line. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this invoice line. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this invoice line. */
  [PricingReference] [numeric](18,0) NULL, /* 0..1 ASBIE Pricing Reference ** A reference to pricing and item location information associated with this invoice line. */
  [OriginatorParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party who originated the Order to which the Invoice is related. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this invoice line. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A specification of payment terms associated with this invoice line. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** An allowance or charge associated with this invoice line. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** A total amount of taxes of a particular kind applicable to this invoice line. */
  [WithholdingTaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** A reference to a TaxTotal class describing the amount that has been withhold by the authorities, e.g. if the creditor is in dept because of non paid taxes. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** The item associated with this invoice line. */
  [Price] [numeric](18,0) NULL, /* 0..1 ASBIE Price ** The price of the item associated with this invoice line. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery Terms ** Terms and conditions of the delivery associated with this invoice line. */
  [SubInvoiceLine] [numeric](18,0) NULL, /* 0..n ASBIE Invoice Line ** An invoice line subsidiary to this invoice line. */
  [ItemPriceExtension] [numeric](18,0) NULL, /* 0..1 ASBIE Price Extension ** The price extension, calculated by multiplying the price per unit by the quantity of items on this invoice line. */
 CONSTRAINT [PK_InvoiceLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_ID] ON [dbo].[InvoiceLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_UUID] ON [dbo].[InvoiceLine] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_Note] ON [dbo].[InvoiceLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_InvoicedQuantity] ON [dbo].[InvoiceLine] 
(
	[InvoicedQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_LineExtensionAmount] ON [dbo].[InvoiceLine] 
(
	[LineExtensionAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_TaxPointDate] ON [dbo].[InvoiceLine] 
(
	[TaxPointDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_AccountingCostCode] ON [dbo].[InvoiceLine] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_AccountingCost] ON [dbo].[InvoiceLine] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_PaymentPurposeCode] ON [dbo].[InvoiceLine] 
(
	[PaymentPurposeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_FreeOfChargeIndicator] ON [dbo].[InvoiceLine] 
(
	[FreeOfChargeIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_InvoicePeriod] ON [dbo].[InvoiceLine] 
(
	[InvoicePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_OrderLineReference] ON [dbo].[InvoiceLine] 
(
	[OrderLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_DespatchLineReference] ON [dbo].[InvoiceLine] 
(
	[DespatchLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_ReceiptLineReference] ON [dbo].[InvoiceLine] 
(
	[ReceiptLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_BillingReference] ON [dbo].[InvoiceLine] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_DocumentReference] ON [dbo].[InvoiceLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_PricingReference] ON [dbo].[InvoiceLine] 
(
	[PricingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_OriginatorParty] ON [dbo].[InvoiceLine] 
(
	[OriginatorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_Delivery] ON [dbo].[InvoiceLine] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_PaymentTerms] ON [dbo].[InvoiceLine] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_AllowanceCharge] ON [dbo].[InvoiceLine] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_TaxTotal] ON [dbo].[InvoiceLine] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_WithholdingTaxTotal] ON [dbo].[InvoiceLine] 
(
	[WithholdingTaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_Item] ON [dbo].[InvoiceLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_Price] ON [dbo].[InvoiceLine] 
(
	[Price] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_DeliveryTerms] ON [dbo].[InvoiceLine] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_SubInvoiceLine] ON [dbo].[InvoiceLine] 
(
	[SubInvoiceLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_InvoiceLine_ItemPriceExtension] ON [dbo].[InvoiceLine] 
(
	[ItemPriceExtension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Item] Script Date: 2013-10-13 00:21z
A class to describe an item of trade. It includes a generic description applicable to all examples of the item together with optional subsidiary descriptions of any number of actual instances of the type.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Item](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this item. */
  [PackQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The unit packaging quantity; the number of subunits making up this item. */
  [PackSizeNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of items in a pack of this item. */
  [CatalogueIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this item was ordered from a catalogue (true) or not (false). */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** A short name optionally given to this item, such as a name from a catalogue, as distinct from a description. */
  [HazardousRiskIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported item, as delivered, is subject to an international regulation concerning the carriage of dangerous goods (true) or not (false). */
  [AdditionalInformation] [numeric](18,0) NULL, /* 0..n BBIE Text ** Further details regarding this item (e.g., the URL of a relevant web page). */
  [Keyword] [numeric](18,0) NULL, /* 0..n BBIE Text ** A keyword (search string) for this item, assigned by the seller party. Can also be a synonym for the name of the item. */
  [BrandName] [numeric](18,0) NULL, /* 0..n BBIE Name ** A brand name of this item. */
  [ModelName] [numeric](18,0) NULL, /* 0..n BBIE Name ** A model name of this item. */
  [BuyersItemIdentification] [numeric](18,0) NULL, /* 0..1 ASBIE Item Identification ** Identifying information for this item, assigned by the buyer. */
  [SellersItemIdentification] [numeric](18,0) NULL, /* 0..1 ASBIE Item Identification ** Identifying information for this item, assigned by the seller. */
  [ManufacturersItemIdentification] [numeric](18,0) NULL, /* 0..n ASBIE Item Identification ** Identifying information for this item, assigned by the manufacturer. */
  [StandardItemIdentification] [numeric](18,0) NULL, /* 0..1 ASBIE Item Identification ** Identifying information for this item, assigned according to a standard system. */
  [CatalogueItemIdentification] [numeric](18,0) NULL, /* 0..1 ASBIE Item Identification ** Identifying information for this item, assigned according to a cataloguing system. */
  [AdditionalItemIdentification] [numeric](18,0) NULL, /* 0..n ASBIE Item Identification ** An additional identifier for this item. */
  [CatalogueDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the catalogue in which this item appears. */
  [ItemSpecificationDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a specification document for this item. */
  [OriginCountry] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country of origin of this item. */
  [CommodityClassification] [numeric](18,0) NULL, /* 0..n ASBIE Commodity Classification ** A classification of this item according to a specific system for classifying commodities. */
  [TransactionConditions] [numeric](18,0) NULL, /* 0..n ASBIE Transaction Conditions ** A set of sales conditions applying to this item. */
  [HazardousItem] [numeric](18,0) NULL, /* 0..n ASBIE Hazardous Item ** Information pertaining to this item as a hazardous item. */
  [ClassifiedTaxCategory] [numeric](18,0) NULL, /* 0..n ASBIE Tax Category ** A tax category applicable to this item. */
  [AdditionalItemProperty] [numeric](18,0) NULL, /* 0..n ASBIE Item Property ** An additional property of this item. */
  [ManufacturerParty] [numeric](18,0) NULL, /* 0..n ASBIE Party ** The manufacturer of this item. */
  [InformationContentProviderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party responsible for specification of this item. */
  [OriginAddress] [numeric](18,0) NULL, /* 0..n ASBIE Address ** A region (not country) of origin of this item. */
  [ItemInstance] [numeric](18,0) NULL, /* 0..n ASBIE Item Instance ** A trackable, unique instantiation of this item. */
  [Certificate] [numeric](18,0) NULL, /* 0..n ASBIE Certificate ** A certificate associated with this item. */
  [Dimension] [numeric](18,0) NULL, /* 0..n ASBIE Dimension ** One of the measurable dimensions (length, mass, weight, or volume) of this item. */
 CONSTRAINT [PK_Item] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_Description] ON [dbo].[Item] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_PackQuantity] ON [dbo].[Item] 
(
	[PackQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_PackSizeNumeric] ON [dbo].[Item] 
(
	[PackSizeNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_CatalogueIndicator] ON [dbo].[Item] 
(
	[CatalogueIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_Name] ON [dbo].[Item] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_HazardousRiskIndicator] ON [dbo].[Item] 
(
	[HazardousRiskIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_AdditionalInformation] ON [dbo].[Item] 
(
	[AdditionalInformation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_Keyword] ON [dbo].[Item] 
(
	[Keyword] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_BrandName] ON [dbo].[Item] 
(
	[BrandName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_ModelName] ON [dbo].[Item] 
(
	[ModelName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_BuyersItemIdentification] ON [dbo].[Item] 
(
	[BuyersItemIdentification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_SellersItemIdentification] ON [dbo].[Item] 
(
	[SellersItemIdentification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_ManufacturersItemIdentification] ON [dbo].[Item] 
(
	[ManufacturersItemIdentification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_StandardItemIdentification] ON [dbo].[Item] 
(
	[StandardItemIdentification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_CatalogueItemIdentification] ON [dbo].[Item] 
(
	[CatalogueItemIdentification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_AdditionalItemIdentification] ON [dbo].[Item] 
(
	[AdditionalItemIdentification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_CatalogueDocumentReference] ON [dbo].[Item] 
(
	[CatalogueDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_ItemSpecificationDocumentReference] ON [dbo].[Item] 
(
	[ItemSpecificationDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_OriginCountry] ON [dbo].[Item] 
(
	[OriginCountry] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_CommodityClassification] ON [dbo].[Item] 
(
	[CommodityClassification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_TransactionConditions] ON [dbo].[Item] 
(
	[TransactionConditions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_HazardousItem] ON [dbo].[Item] 
(
	[HazardousItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_ClassifiedTaxCategory] ON [dbo].[Item] 
(
	[ClassifiedTaxCategory] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_AdditionalItemProperty] ON [dbo].[Item] 
(
	[AdditionalItemProperty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_ManufacturerParty] ON [dbo].[Item] 
(
	[ManufacturerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_InformationContentProviderParty] ON [dbo].[Item] 
(
	[InformationContentProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_OriginAddress] ON [dbo].[Item] 
(
	[OriginAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_ItemInstance] ON [dbo].[Item] 
(
	[ItemInstance] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_Certificate] ON [dbo].[Item] 
(
	[Certificate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Item_Dimension] ON [dbo].[Item] 
(
	[Dimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ItemComparison] Script Date: 2013-10-13 00:21z
A class to provide information about price and quantity of an item for use in price comparisons based on price, quantity, or measurements.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ItemComparison](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [PriceAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The price for the Item Comparison */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity for which this comparison is valid. */
 CONSTRAINT [PK_ItemComparison] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemComparison_PriceAmount] ON [dbo].[ItemComparison] 
(
	[PriceAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemComparison_Quantity] ON [dbo].[ItemComparison] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ItemIdentification] Script Date: 2013-10-13 00:21z
A class for assigning identifying information to an item.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ItemIdentification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the item. */
  [ExtendedID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An extended identifier for the item that identifies the item with specific properties, e.g., Item 123 = Chair / Item 123 Ext 45 = brown chair. Two chairs can have the same item number, but one is brown. The other is white. */
  [BarcodeSymbologyID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for a system of barcodes. */
  [PhysicalAttribute] [numeric](18,0) NULL, /* 0..n ASBIE Physical Attribute ** A physical attribute of the item. */
  [MeasurementDimension] [numeric](18,0) NULL, /* 0..n ASBIE Dimension ** A measurable dimension (length, mass, weight, or volume) of the item. */
  [IssuerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that issued this item identification. */
 CONSTRAINT [PK_ItemIdentification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemIdentification_ID] ON [dbo].[ItemIdentification] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemIdentification_ExtendedID] ON [dbo].[ItemIdentification] 
(
	[ExtendedID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemIdentification_BarcodeSymbologyID] ON [dbo].[ItemIdentification] 
(
	[BarcodeSymbologyID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemIdentification_PhysicalAttribute] ON [dbo].[ItemIdentification] 
(
	[PhysicalAttribute] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemIdentification_MeasurementDimension] ON [dbo].[ItemIdentification] 
(
	[MeasurementDimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemIdentification_IssuerParty] ON [dbo].[ItemIdentification] 
(
	[IssuerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ItemInformationRequestLine] Script Date: 2013-10-13 00:21z
A class to define a line in an Item Information Request asking a trading partner for item information.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ItemInformationRequestLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [TimeFrequencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the frequency with which item information should be sent to the requester. */
  [SupplyChainActivityTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code used to identify the type of supply chain activity about which information request is issued. Examples: CANCELED_ORDERS EMERGENCY_ORDERS ON_HAND ORDERS */
  [ForecastTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The information request can be either about supply chain activity or about forecasts or about performance metrics, so it should be optional */
  [PerformanceMetricTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying a measure of performance. */
  [Period] [numeric](18,0) NOT NULL, /* 1..n ASBIE Period ** A period for which this information is requested. */
  [SalesItem] [numeric](18,0) NOT NULL, /* 1..n ASBIE Sales Item ** Sales information for the item to which this line applies. */
 CONSTRAINT [PK_ItemInformationRequestLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequestLine_TimeFrequencyCode] ON [dbo].[ItemInformationRequestLine] 
(
	[TimeFrequencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequestLine_SupplyChainActivityTypeCode] ON [dbo].[ItemInformationRequestLine] 
(
	[SupplyChainActivityTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequestLine_ForecastTypeCode] ON [dbo].[ItemInformationRequestLine] 
(
	[ForecastTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequestLine_PerformanceMetricTypeCode] ON [dbo].[ItemInformationRequestLine] 
(
	[PerformanceMetricTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequestLine_Period] ON [dbo].[ItemInformationRequestLine] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInformationRequestLine_SalesItem] ON [dbo].[ItemInformationRequestLine] 
(
	[SalesItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ItemInstance] Script Date: 2013-10-13 00:21z
A class to describe a specific, trackable instance of an item.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ItemInstance](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ProductTraceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier used for tracing this item instance, such as the EPC number used in RFID. */
  [ManufactureDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this item instance was manufactured. */
  [ManufactureTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this item instance was manufactured. */
  [BestBeforeDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date before which it is best to use this item instance. */
  [RegistrationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The registration identifier of this item instance. */
  [SerialID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The serial number of this item instance. */
  [AdditionalItemProperty] [numeric](18,0) NULL, /* 0..n ASBIE Item Property ** An additional property of this item instance. */
  [LotIdentification] [numeric](18,0) NULL, /* 0..1 ASBIE Lot Identification ** The lot identifier of this item instance (the identifier that allows recall of the item if necessary). */
 CONSTRAINT [PK_ItemInstance] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInstance_ProductTraceID] ON [dbo].[ItemInstance] 
(
	[ProductTraceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInstance_ManufactureDate] ON [dbo].[ItemInstance] 
(
	[ManufactureDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInstance_ManufactureTime] ON [dbo].[ItemInstance] 
(
	[ManufactureTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInstance_BestBeforeDate] ON [dbo].[ItemInstance] 
(
	[BestBeforeDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInstance_RegistrationID] ON [dbo].[ItemInstance] 
(
	[RegistrationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInstance_SerialID] ON [dbo].[ItemInstance] 
(
	[SerialID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInstance_AdditionalItemProperty] ON [dbo].[ItemInstance] 
(
	[AdditionalItemProperty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemInstance_LotIdentification] ON [dbo].[ItemInstance] 
(
	[LotIdentification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ItemLocationQuantity] Script Date: 2013-10-13 00:21z
A class for information about pricing structure, lead time, and location associated with an item.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ItemLocationQuantity](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [LeadTimeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The lead time, i.e., the time taken from the time at which an item is ordered to the time of its delivery. */
  [MinimumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The minimum quantity that can be ordered to qualify for a specific price. */
  [MaximumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The maximum quantity that can be ordered to qualify for a specific price. */
  [HazardousRiskIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that the transported item, as delivered, in the stated quantity to the stated location, is subject to an international regulation concerning the carriage of dangerous goods (true) or not (false). */
  [TradingRestrictions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing trade restrictions on the quantity of this item or on the item itself. */
  [ApplicableTerritoryAddress] [numeric](18,0) NULL, /* 0..n ASBIE Address ** The applicable sales territory. */
  [Price] [numeric](18,0) NULL, /* 0..1 ASBIE Price ** The price associated with the given location. */
  [DeliveryUnit] [numeric](18,0) NULL, /* 0..n ASBIE Delivery Unit ** A delivery unit in which the item is located. */
  [ApplicableTaxCategory] [numeric](18,0) NULL, /* 0..n ASBIE Tax Category ** A tax category applicable to this item location quantity. */
  [Package] [numeric](18,0) NULL, /* 0..1 ASBIE Package ** The package to which this price applies. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** An allowance or charge associated with this item location quantity. */
  [DependentPriceReference] [numeric](18,0) NULL, /* 0..1 ASBIE Dependent Price Reference ** The price of the item as a percentage of the price of some other item. */
 CONSTRAINT [PK_ItemLocationQuantity] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_LeadTimeMeasure] ON [dbo].[ItemLocationQuantity] 
(
	[LeadTimeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_MinimumQuantity] ON [dbo].[ItemLocationQuantity] 
(
	[MinimumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_MaximumQuantity] ON [dbo].[ItemLocationQuantity] 
(
	[MaximumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_HazardousRiskIndicator] ON [dbo].[ItemLocationQuantity] 
(
	[HazardousRiskIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_TradingRestrictions] ON [dbo].[ItemLocationQuantity] 
(
	[TradingRestrictions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_ApplicableTerritoryAddress] ON [dbo].[ItemLocationQuantity] 
(
	[ApplicableTerritoryAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_Price] ON [dbo].[ItemLocationQuantity] 
(
	[Price] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_DeliveryUnit] ON [dbo].[ItemLocationQuantity] 
(
	[DeliveryUnit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_ApplicableTaxCategory] ON [dbo].[ItemLocationQuantity] 
(
	[ApplicableTaxCategory] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_Package] ON [dbo].[ItemLocationQuantity] 
(
	[Package] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_AllowanceCharge] ON [dbo].[ItemLocationQuantity] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemLocationQuantity_DependentPriceReference] ON [dbo].[ItemLocationQuantity] 
(
	[DependentPriceReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ItemManagementProfile] Script Date: 2013-10-13 00:21z
A class to define a management profile for an item.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ItemManagementProfile](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [FrozenPeriodDaysNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of days in the future that an order forecast quantity automatically becomes a confirmed order for a product. */
  [MinimumInventoryQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of the item that should trigger a replenishment order to avoid depleting the safety stock. */
  [MultipleOrderQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The order quantity multiples in which the product may be ordered. */
  [OrderIntervalDaysNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of days between regular replenishment orders for the product. */
  [ReplenishmentOwnerDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** The trading partner maintaining this item management profile. */
  [TargetServicePercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The Unit Service Level the trading partners expect to be maintained, expressed as a percentage. Unite Service Level (USL) is a term used in Inventory Management, which is sometimes known as "fill rate", counts the average number of units short expressed as the percentage of the order quantity. */
  [TargetInventoryQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The target inventory quantity. */
  [EffectivePeriod] [numeric](18,0) NOT NULL, /* 1 ASBIE Period ** The period during which this profile is effective. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** The item associated with this item management profile. */
  [ItemLocationQuantity] [numeric](18,0) NULL, /* 0..1 ASBIE Item Location Quantity ** A set of location-specific properties (e.g., price and quantity) associated with the item. */
 CONSTRAINT [PK_ItemManagementProfile] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemManagementProfile_FrozenPeriodDaysNumeric] ON [dbo].[ItemManagementProfile] 
(
	[FrozenPeriodDaysNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemManagementProfile_MinimumInventoryQuantity] ON [dbo].[ItemManagementProfile] 
(
	[MinimumInventoryQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemManagementProfile_MultipleOrderQuantity] ON [dbo].[ItemManagementProfile] 
(
	[MultipleOrderQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemManagementProfile_OrderIntervalDaysNumeric] ON [dbo].[ItemManagementProfile] 
(
	[OrderIntervalDaysNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemManagementProfile_ReplenishmentOwnerDescription] ON [dbo].[ItemManagementProfile] 
(
	[ReplenishmentOwnerDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemManagementProfile_TargetServicePercent] ON [dbo].[ItemManagementProfile] 
(
	[TargetServicePercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemManagementProfile_TargetInventoryQuantity] ON [dbo].[ItemManagementProfile] 
(
	[TargetInventoryQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemManagementProfile_EffectivePeriod] ON [dbo].[ItemManagementProfile] 
(
	[EffectivePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemManagementProfile_Item] ON [dbo].[ItemManagementProfile] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemManagementProfile_ItemLocationQuantity] ON [dbo].[ItemManagementProfile] 
(
	[ItemLocationQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ItemProperty] Script Date: 2013-10-13 00:21z
A class to describe a specific property of an item.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ItemProperty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this property of an item. */
  [Name] [numeric](18,0) NOT NULL, /* 1 BBIE Name ** The name of this item property. */
  [NameCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The name of this item property, expressed as a code. */
  [TestMethod] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The method of testing the value of this item property. */
  [Value] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The value of this item property, expressed as text. */
  [ValueQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The value of this item property, expressed as a quantity. */
  [ValueQualifier] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text qualifying the value of the property. */
  [ImportanceCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the importance of this property in using it to describe a related Item. */
  [ListValue] [numeric](18,0) NULL, /* 0..n BBIE Text ** The value expressed as a text in case the property is a value in a list. For example, a colour. */
  [UsabilityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which this item property is valid. */
  [ItemPropertyGroup] [numeric](18,0) NULL, /* 0..n ASBIE Item Property Group ** A description of the property group to which this item property belongs. */
  [RangeDimension] [numeric](18,0) NULL, /* 0..1 ASBIE Dimension ** The range of values for the dimensions of this property. */
  [ItemPropertyRange] [numeric](18,0) NULL, /* 0..1 ASBIE Item Property Range ** A range of values for this item property. */
 CONSTRAINT [PK_ItemProperty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_ID] ON [dbo].[ItemProperty] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_Name] ON [dbo].[ItemProperty] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_NameCode] ON [dbo].[ItemProperty] 
(
	[NameCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_TestMethod] ON [dbo].[ItemProperty] 
(
	[TestMethod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_Value] ON [dbo].[ItemProperty] 
(
	[Value] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_ValueQuantity] ON [dbo].[ItemProperty] 
(
	[ValueQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_ValueQualifier] ON [dbo].[ItemProperty] 
(
	[ValueQualifier] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_ImportanceCode] ON [dbo].[ItemProperty] 
(
	[ImportanceCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_ListValue] ON [dbo].[ItemProperty] 
(
	[ListValue] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_UsabilityPeriod] ON [dbo].[ItemProperty] 
(
	[UsabilityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_ItemPropertyGroup] ON [dbo].[ItemProperty] 
(
	[ItemPropertyGroup] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_RangeDimension] ON [dbo].[ItemProperty] 
(
	[RangeDimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemProperty_ItemPropertyRange] ON [dbo].[ItemProperty] 
(
	[ItemPropertyRange] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ItemPropertyGroup] Script Date: 2013-10-13 00:21z
A class to describe a property group or classification.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ItemPropertyGroup](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this group of item properties. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this item property group. */
  [ImportanceCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the importance of this property group in using it to describe a required Item. */
 CONSTRAINT [PK_ItemPropertyGroup] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemPropertyGroup_ID] ON [dbo].[ItemPropertyGroup] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemPropertyGroup_Name] ON [dbo].[ItemPropertyGroup] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemPropertyGroup_ImportanceCode] ON [dbo].[ItemPropertyGroup] 
(
	[ImportanceCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ItemPropertyRange] Script Date: 2013-10-13 00:21z
A class to describe a range of values for an item property.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ItemPropertyRange](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [MinimumValue] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The minimum value in this range of values. */
  [MaximumValue] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The maximum value in this range of values. */
 CONSTRAINT [PK_ItemPropertyRange] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemPropertyRange_MinimumValue] ON [dbo].[ItemPropertyRange] 
(
	[MinimumValue] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ItemPropertyRange_MaximumValue] ON [dbo].[ItemPropertyRange] 
(
	[MaximumValue] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Language] Script Date: 2013-10-13 00:21z
A class to describe a language.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Language](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this language. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this language. */
  [LocaleCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the locale in which this language is used. */
 CONSTRAINT [PK_Language] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Language_ID] ON [dbo].[Language] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Language_Name] ON [dbo].[Language] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Language_LocaleCode] ON [dbo].[Language] 
(
	[LocaleCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[LineItem] Script Date: 2013-10-13 00:21z
A class to describe a line item.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[LineItem](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this line item, assigned by the buyer. */
  [SalesOrderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this line item, assigned by the seller. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this line item. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [LineStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of this line item with respect to its original state. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of items associated with this line item. */
  [LineExtensionAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total amount for this line item, including allowance charges but net of taxes. */
  [TotalTaxAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total tax amount for this line item. */
  [MinimumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The minimum quantity of the item associated with this line. */
  [MaximumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The maximum quantity of the item associated with this line. */
  [MinimumBackorderQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The minimum back order quantity of the item associated with this line (where back order is allowed). */
  [MaximumBackorderQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The maximum back order quantity of the item associated with this line (where back order is allowed). */
  [InspectionMethodCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the inspection requirements for the item associated with this line item. */
  [PartialDeliveryIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that a partial delivery is allowed (true) or not (false). */
  [BackOrderAllowedIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that back order is allowed (true) or not (false). */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting cost centre for this line item, expressed as a code. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting cost centre for this line item, expressed as text. */
  [WarrantyInformation] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing a warranty (provided by WarrantyParty) for the good or service described in this line item. */
  [Delivery] [numeric](18,0) NULL, /* 0..n ASBIE Delivery ** A delivery associated with this line item. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery Terms ** Terms and conditions of the delivery associated with this line item. */
  [OriginatorParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party who originated the Order associated with this line item. */
  [OrderedShipment] [numeric](18,0) NULL, /* 0..n ASBIE Ordered Shipment ** An ordered shipment associated with this line item. */
  [PricingReference] [numeric](18,0) NULL, /* 0..1 ASBIE Pricing Reference ** A reference to pricing and item location information associated with this line item. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** An allowance or charge associated with this line item. */
  [Price] [numeric](18,0) NULL, /* 0..1 ASBIE Price ** The price of the item of trade associated with this line item. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** The item of trade associated with this line item. */
  [SubLineItem] [numeric](18,0) NULL, /* 0..n ASBIE Line Item ** The subsidiary line items that constitute the main line item, such as in a bill of materials. */
  [WarrantyValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which the warranty associated with this line item is valid. */
  [WarrantyParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party responsible for any warranty associated with this line item. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** A total amount of taxes of a particular kind applicable to this item. */
  [ItemPriceExtension] [numeric](18,0) NULL, /* 0..1 ASBIE Price Extension ** The price extension, calculated by multiplying the price per unit by the quantity of items. */
  [LineReference] [numeric](18,0) NULL, /* 0..n ASBIE Line Reference ** A reference to a line in a document associated with this line item. */
 CONSTRAINT [PK_LineItem] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_ID] ON [dbo].[LineItem] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_SalesOrderID] ON [dbo].[LineItem] 
(
	[SalesOrderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_UUID] ON [dbo].[LineItem] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_Note] ON [dbo].[LineItem] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_LineStatusCode] ON [dbo].[LineItem] 
(
	[LineStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_Quantity] ON [dbo].[LineItem] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_LineExtensionAmount] ON [dbo].[LineItem] 
(
	[LineExtensionAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_TotalTaxAmount] ON [dbo].[LineItem] 
(
	[TotalTaxAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_MinimumQuantity] ON [dbo].[LineItem] 
(
	[MinimumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_MaximumQuantity] ON [dbo].[LineItem] 
(
	[MaximumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_MinimumBackorderQuantity] ON [dbo].[LineItem] 
(
	[MinimumBackorderQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_MaximumBackorderQuantity] ON [dbo].[LineItem] 
(
	[MaximumBackorderQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_InspectionMethodCode] ON [dbo].[LineItem] 
(
	[InspectionMethodCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_PartialDeliveryIndicator] ON [dbo].[LineItem] 
(
	[PartialDeliveryIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_BackOrderAllowedIndicator] ON [dbo].[LineItem] 
(
	[BackOrderAllowedIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_AccountingCostCode] ON [dbo].[LineItem] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_AccountingCost] ON [dbo].[LineItem] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_WarrantyInformation] ON [dbo].[LineItem] 
(
	[WarrantyInformation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_Delivery] ON [dbo].[LineItem] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_DeliveryTerms] ON [dbo].[LineItem] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_OriginatorParty] ON [dbo].[LineItem] 
(
	[OriginatorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_OrderedShipment] ON [dbo].[LineItem] 
(
	[OrderedShipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_PricingReference] ON [dbo].[LineItem] 
(
	[PricingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_AllowanceCharge] ON [dbo].[LineItem] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_Price] ON [dbo].[LineItem] 
(
	[Price] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_Item] ON [dbo].[LineItem] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_SubLineItem] ON [dbo].[LineItem] 
(
	[SubLineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_WarrantyValidityPeriod] ON [dbo].[LineItem] 
(
	[WarrantyValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_WarrantyParty] ON [dbo].[LineItem] 
(
	[WarrantyParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_TaxTotal] ON [dbo].[LineItem] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_ItemPriceExtension] ON [dbo].[LineItem] 
(
	[ItemPriceExtension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineItem_LineReference] ON [dbo].[LineItem] 
(
	[LineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[LineReference] Script Date: 2013-10-13 00:21z
A class to define a reference to a line in a document.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[LineReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [LineID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** Identifies the referenced line in the document. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this line reference. */
  [LineStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of the referenced line with respect to its original state. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the document containing the referenced line. */
 CONSTRAINT [PK_LineReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineReference_LineID] ON [dbo].[LineReference] 
(
	[LineID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineReference_UUID] ON [dbo].[LineReference] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineReference_LineStatusCode] ON [dbo].[LineReference] 
(
	[LineStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineReference_DocumentReference] ON [dbo].[LineReference] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[LineResponse] Script Date: 2013-10-13 00:21z
A class to describe responses to a line in a document.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[LineResponse](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [LineReference] [numeric](18,0) NOT NULL, /* 1 ASBIE Line Reference ** A reference to the line being responded to. */
  [Response] [numeric](18,0) NOT NULL, /* 1..n ASBIE Response ** A response to the referenced line. */
 CONSTRAINT [PK_LineResponse] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineResponse_LineReference] ON [dbo].[LineResponse] 
(
	[LineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LineResponse_Response] ON [dbo].[LineResponse] 
(
	[Response] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Location] Script Date: 2013-10-13 00:21z
A class to describe a location.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Location](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this location, e.g., the EAN Location Number, GLN. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this location. */
  [Conditions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text describing the physical conditions of the location. */
  [CountrySubentity] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A territorial division of a country, such as a county or state, expressed as text. */
  [CountrySubentityCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A territorial division of a country, such as a county or state, expressed as a code. */
  [LocationTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of location. */
  [InformationURI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The Uniform Resource Identifier (URI) of a document providing information about this location. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this location. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period during which this location can be used (e.g., for delivery). */
  [Address] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The address of this location. */
  [SubsidiaryLocation] [numeric](18,0) NULL, /* 0..n ASBIE Location ** A location subsidiary to this location. */
  [LocationCoordinate] [numeric](18,0) NULL, /* 0..n ASBIE Location Coordinate ** The geographical coordinates of this location. */
 CONSTRAINT [PK_Location] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_ID] ON [dbo].[Location] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_Description] ON [dbo].[Location] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_Conditions] ON [dbo].[Location] 
(
	[Conditions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_CountrySubentity] ON [dbo].[Location] 
(
	[CountrySubentity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_CountrySubentityCode] ON [dbo].[Location] 
(
	[CountrySubentityCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_LocationTypeCode] ON [dbo].[Location] 
(
	[LocationTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_InformationURI] ON [dbo].[Location] 
(
	[InformationURI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_Name] ON [dbo].[Location] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_ValidityPeriod] ON [dbo].[Location] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_Address] ON [dbo].[Location] 
(
	[Address] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_SubsidiaryLocation] ON [dbo].[Location] 
(
	[SubsidiaryLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Location_LocationCoordinate] ON [dbo].[Location] 
(
	[LocationCoordinate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[LocationCoordinate] Script Date: 2013-10-13 00:21z
A class for defining a set of geographical coordinates (apparently misnamed).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[LocationCoordinate](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [CoordinateSystemCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the location system used. */
  [LatitudeDegreesMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The degree component of a latitude measured in degrees and minutes. */
  [LatitudeMinutesMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The minutes component of a latitude measured in degrees and minutes (modulo 60). */
  [LatitudeDirectionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the direction of latitude measurement from the equator (north or south). */
  [LongitudeDegreesMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The degree component of a longitude measured in degrees and minutes. */
  [LongitudeMinutesMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The minutes component of a longitude measured in degrees and minutes (modulo 60). */
  [LongitudeDirectionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the direction of longitude measurement from the prime meridian (east or west). */
  [AltitudeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The altitude of the location. */
 CONSTRAINT [PK_LocationCoordinate] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LocationCoordinate_CoordinateSystemCode] ON [dbo].[LocationCoordinate] 
(
	[CoordinateSystemCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LocationCoordinate_LatitudeDegreesMeasure] ON [dbo].[LocationCoordinate] 
(
	[LatitudeDegreesMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LocationCoordinate_LatitudeMinutesMeasure] ON [dbo].[LocationCoordinate] 
(
	[LatitudeMinutesMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LocationCoordinate_LatitudeDirectionCode] ON [dbo].[LocationCoordinate] 
(
	[LatitudeDirectionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LocationCoordinate_LongitudeDegreesMeasure] ON [dbo].[LocationCoordinate] 
(
	[LongitudeDegreesMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LocationCoordinate_LongitudeMinutesMeasure] ON [dbo].[LocationCoordinate] 
(
	[LongitudeMinutesMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LocationCoordinate_LongitudeDirectionCode] ON [dbo].[LocationCoordinate] 
(
	[LongitudeDirectionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LocationCoordinate_AltitudeMeasure] ON [dbo].[LocationCoordinate] 
(
	[AltitudeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[LotIdentification] Script Date: 2013-10-13 00:21z
A class for defining a lot identifier (the identifier of a set of item instances that would be used in case of a recall of that item).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[LotIdentification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [LotNumberID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the lot. */
  [ExpiryDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The expiry date of the lot. */
  [AdditionalItemProperty] [numeric](18,0) NULL, /* 0..n ASBIE Item Property ** An additional property of the lot. */
 CONSTRAINT [PK_LotIdentification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LotIdentification_LotNumberID] ON [dbo].[LotIdentification] 
(
	[LotNumberID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LotIdentification_ExpiryDate] ON [dbo].[LotIdentification] 
(
	[ExpiryDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_LotIdentification_AdditionalItemProperty] ON [dbo].[LotIdentification] 
(
	[AdditionalItemProperty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[MaritimeTransport] Script Date: 2013-10-13 00:21z
A class to describe a vessel used for transport by water (including sea, river, and canal).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[MaritimeTransport](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [VesselID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for a specific vessel. */
  [VesselName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of the vessel. */
  [RadioCallSignID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The radio call sign of the vessel. */
  [ShipsRequirements] [numeric](18,0) NULL, /* 0..n BBIE Text ** Information about what services a vessel will require when it arrives at a port, such as refueling, maintenance, waste disposal etc. */
  [GrossTonnageMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** Gross tonnage is calculated by measuring a ship's volume (from keel to funnel, to the outside of the hull framing) and applying a mathematical formula and is used to determine things such as a ship's manning regulations, safety rules, registration fees and port dues. */
  [NetTonnageMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** Net tonnage is calculated by measuring a ship's internal volume and applying a mathematical formula and is used to calculate the port duties. */
  [RegistryCertificateDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** The certificate issued to the ship by the ships registry in a given flag state. */
  [RegistryPortLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The port in which a vessel is registered or permanently based. */
 CONSTRAINT [PK_MaritimeTransport] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MaritimeTransport_VesselID] ON [dbo].[MaritimeTransport] 
(
	[VesselID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MaritimeTransport_VesselName] ON [dbo].[MaritimeTransport] 
(
	[VesselName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MaritimeTransport_RadioCallSignID] ON [dbo].[MaritimeTransport] 
(
	[RadioCallSignID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MaritimeTransport_ShipsRequirements] ON [dbo].[MaritimeTransport] 
(
	[ShipsRequirements] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MaritimeTransport_GrossTonnageMeasure] ON [dbo].[MaritimeTransport] 
(
	[GrossTonnageMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MaritimeTransport_NetTonnageMeasure] ON [dbo].[MaritimeTransport] 
(
	[NetTonnageMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MaritimeTransport_RegistryCertificateDocumentReference] ON [dbo].[MaritimeTransport] 
(
	[RegistryCertificateDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MaritimeTransport_RegistryPortLocation] ON [dbo].[MaritimeTransport] 
(
	[RegistryPortLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Meter] Script Date: 2013-10-13 00:21z
A class to describe a meter and its readings.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Meter](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [MeterNumber] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The meter number, expressed as text. */
  [MeterName] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The name of this meter, which serves as an identifier to distinguish a main meter from a submeter. */
  [MeterConstant] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The factor by which readings of this meter must be multiplied to calculate consumption, expressed as text. */
  [MeterConstantCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the formula to be used in applying the meter constant. */
  [TotalDeliveredQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity delivered; the total quantity consumed as calculated from the meter readings. */
  [MeterReading] [numeric](18,0) NULL, /* 0..n ASBIE Meter Reading ** A reading of this meter. */
  [MeterProperty] [numeric](18,0) NULL, /* 0..n ASBIE Meter Property ** A property of this meter. */
 CONSTRAINT [PK_Meter] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Meter_MeterNumber] ON [dbo].[Meter] 
(
	[MeterNumber] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Meter_MeterName] ON [dbo].[Meter] 
(
	[MeterName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Meter_MeterConstant] ON [dbo].[Meter] 
(
	[MeterConstant] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Meter_MeterConstantCode] ON [dbo].[Meter] 
(
	[MeterConstantCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Meter_TotalDeliveredQuantity] ON [dbo].[Meter] 
(
	[TotalDeliveredQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Meter_MeterReading] ON [dbo].[Meter] 
(
	[MeterReading] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Meter_MeterProperty] ON [dbo].[Meter] 
(
	[MeterProperty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[MeterProperty] Script Date: 2013-10-13 00:21z
The name of this meter property.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[MeterProperty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this meter property, expressed as a code. */
  [NameCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The value of this meter property, expressed as text. */
  [Value] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The value of this meter property, expressed as a quantity. */
  [ValueQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The value of this meter property, expressed as a quantity. */
  [ValueQualifier] [numeric](18,0) NULL, /* 0..n BBIE Text ** An additional value to qualify the value of the meter */
 CONSTRAINT [PK_MeterProperty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterProperty_Name] ON [dbo].[MeterProperty] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterProperty_NameCode] ON [dbo].[MeterProperty] 
(
	[NameCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterProperty_Value] ON [dbo].[MeterProperty] 
(
	[Value] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterProperty_ValueQuantity] ON [dbo].[MeterProperty] 
(
	[ValueQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterProperty_ValueQualifier] ON [dbo].[MeterProperty] 
(
	[ValueQualifier] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[MeterReading] Script Date: 2013-10-13 00:21z
A class to describe a meter reading.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[MeterReading](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this meter reading. */
  [MeterReadingType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The type of this meter reading, expressed as text. */
  [MeterReadingTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of this meter reading, expressed as a code. */
  [PreviousMeterReadingDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date of the previous meter reading. */
  [PreviousMeterQuantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The quantity of the previous meter reading. */
  [LatestMeterReadingDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date of the latest meter reading. */
  [LatestMeterQuantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The quantity of the latest meter reading. */
  [PreviousMeterReadingMethod] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The method used for the previous meter reading, expressed as text. */
  [PreviousMeterReadingMethodCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The method used for the previous meter reading, expressed as a code. */
  [LatestMeterReadingMethod] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The method used for the latest meter reading, expressed as text. */
  [LatestMeterReadingMethodCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The method used for the latest meter reading, expressed as a code. */
  [MeterReadingComments] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text containing comments on this meter reading. */
  [DeliveredQuantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** Consumption in the period from PreviousMeterReadingDate to LatestMeterReadingDate. */
 CONSTRAINT [PK_MeterReading] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_ID] ON [dbo].[MeterReading] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_MeterReadingType] ON [dbo].[MeterReading] 
(
	[MeterReadingType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_MeterReadingTypeCode] ON [dbo].[MeterReading] 
(
	[MeterReadingTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_PreviousMeterReadingDate] ON [dbo].[MeterReading] 
(
	[PreviousMeterReadingDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_PreviousMeterQuantity] ON [dbo].[MeterReading] 
(
	[PreviousMeterQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_LatestMeterReadingDate] ON [dbo].[MeterReading] 
(
	[LatestMeterReadingDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_LatestMeterQuantity] ON [dbo].[MeterReading] 
(
	[LatestMeterQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_PreviousMeterReadingMethod] ON [dbo].[MeterReading] 
(
	[PreviousMeterReadingMethod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_PreviousMeterReadingMethodCode] ON [dbo].[MeterReading] 
(
	[PreviousMeterReadingMethodCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_LatestMeterReadingMethod] ON [dbo].[MeterReading] 
(
	[LatestMeterReadingMethod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_LatestMeterReadingMethodCode] ON [dbo].[MeterReading] 
(
	[LatestMeterReadingMethodCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_MeterReadingComments] ON [dbo].[MeterReading] 
(
	[MeterReadingComments] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MeterReading_DeliveredQuantity] ON [dbo].[MeterReading] 
(
	[DeliveredQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[MiscellaneousEvent] Script Date: 2013-10-13 00:21z
A class to describe a miscellaneous event associated with a retail event.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[MiscellaneousEvent](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [MiscellaneousEventTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the type of this miscellaneous event. Examples are: ASSORTMENT_CHARGE DISASTER FORECAST_DECREASE FORECAST_INCREASE FREIGHT_FLOW_ALLOCATION INVENTORY_POLICY_CHANGE LOCATION_CLOSING LOCATION_OPENING OTHER OUT_OF_STOCK PACKAGING_LABELING_CHANGE PRICE_DECREASE PRICE_INCREASE STORE_FORMAT_OR_PLANOGRAM_CHANGE TEST_MARKET WEATHER */
  [EventLineItem] [numeric](18,0) NOT NULL, /* 1..n ASBIE Event Line Item ** An event line item for this miscellaneous retail event. */
 CONSTRAINT [PK_MiscellaneousEvent] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MiscellaneousEvent_MiscellaneousEventTypeCode] ON [dbo].[MiscellaneousEvent] 
(
	[MiscellaneousEventTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MiscellaneousEvent_EventLineItem] ON [dbo].[MiscellaneousEvent] 
(
	[EventLineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[MonetaryTotal] Script Date: 2013-10-13 00:21z
A class to define a monetary total.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[MonetaryTotal](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [LineExtensionAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount of an extended transaction line, net of tax and settlement discounts, but inclusive of any applicable rounding amount. */
  [TaxExclusiveAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount of an extended transaction line, exclusive of taxes. */
  [TaxInclusiveAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount including taxes; the sum of payable amount and prepaid amount. */
  [AllowanceTotalAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total monetary amount of all allowances. */
  [ChargeTotalAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total monetary amount of all charges. */
  [PrepaidAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total prepaid monetary amount. */
  [PayableRoundingAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The rounding amount (positive or negative) added to produce the line extension amount. */
  [PayableAmount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The amount of the monetary total to be paid. */
  [PayableAlternativeAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount of the monetary total to be paid, expressed in an alternative currency. */
 CONSTRAINT [PK_MonetaryTotal] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MonetaryTotal_LineExtensionAmount] ON [dbo].[MonetaryTotal] 
(
	[LineExtensionAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MonetaryTotal_TaxExclusiveAmount] ON [dbo].[MonetaryTotal] 
(
	[TaxExclusiveAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MonetaryTotal_TaxInclusiveAmount] ON [dbo].[MonetaryTotal] 
(
	[TaxInclusiveAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MonetaryTotal_AllowanceTotalAmount] ON [dbo].[MonetaryTotal] 
(
	[AllowanceTotalAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MonetaryTotal_ChargeTotalAmount] ON [dbo].[MonetaryTotal] 
(
	[ChargeTotalAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MonetaryTotal_PrepaidAmount] ON [dbo].[MonetaryTotal] 
(
	[PrepaidAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MonetaryTotal_PayableRoundingAmount] ON [dbo].[MonetaryTotal] 
(
	[PayableRoundingAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MonetaryTotal_PayableAmount] ON [dbo].[MonetaryTotal] 
(
	[PayableAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_MonetaryTotal_PayableAlternativeAmount] ON [dbo].[MonetaryTotal] 
(
	[PayableAlternativeAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[NotificationRequirement] Script Date: 2013-10-13 00:21z
A class to describe a notification requirement.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[NotificationRequirement](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [NotificationTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the type of notification (e.g., pickup status). */
  [PostEventNotificationDurationMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The length of time between the occurrence of a given event and the issuance of a notification. */
  [PreEventNotificationDurationMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The length of time to elapse between the issuance of a notification and the occurrence of the event it relates to. */
  [NotifyParty] [numeric](18,0) NULL, /* 0..n ASBIE Party ** A party to be notified. */
  [NotificationPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period during which a notification should be issued. */
  [NotificationLocation] [numeric](18,0) NULL, /* 0..n ASBIE Location ** A location at which a notification should be issued. */
 CONSTRAINT [PK_NotificationRequirement] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_NotificationRequirement_NotificationTypeCode] ON [dbo].[NotificationRequirement] 
(
	[NotificationTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_NotificationRequirement_PostEventNotificationDurationMeasure] ON [dbo].[NotificationRequirement] 
(
	[PostEventNotificationDurationMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_NotificationRequirement_PreEventNotificationDurationMeasure] ON [dbo].[NotificationRequirement] 
(
	[PreEventNotificationDurationMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_NotificationRequirement_NotifyParty] ON [dbo].[NotificationRequirement] 
(
	[NotifyParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_NotificationRequirement_NotificationPeriod] ON [dbo].[NotificationRequirement] 
(
	[NotificationPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_NotificationRequirement_NotificationLocation] ON [dbo].[NotificationRequirement] 
(
	[NotificationLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[OnAccountPayment] Script Date: 2013-10-13 00:21z
A scheduled prepayment (on-account payment) for a estimated utility consumption
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[OnAccountPayment](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [EstimatedConsumedQuantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The estimated consumed quantity covered by the payment. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [PaymentTerms] [numeric](18,0) NOT NULL, /* 1..n ASBIE Payment Terms ** A specification of payment terms associated with this payment. */
 CONSTRAINT [PK_OnAccountPayment] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OnAccountPayment_EstimatedConsumedQuantity] ON [dbo].[OnAccountPayment] 
(
	[EstimatedConsumedQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OnAccountPayment_Note] ON [dbo].[OnAccountPayment] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OnAccountPayment_PaymentTerms] ON [dbo].[OnAccountPayment] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[OrderLine] Script Date: 2013-10-13 00:21z
A class to define a line in an order document (e.g., Order, Order Change, or Order Response) describing an item being ordered.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[OrderLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [SubstitutionStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the substitution status of the item on this order line. The order line may indicate that the substitute is proposed by the buyer (in Order) or by the seller (in Order Response) or that a substitution has been made by the seller (in Order Response). */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [LineItem] [numeric](18,0) NOT NULL, /* 1 ASBIE Line Item ** The line item itself. */
  [SellerProposedSubstituteLineItem] [numeric](18,0) NULL, /* 0..n ASBIE Line Item ** In Order Response, a line item proposed by the seller describing a product that might substitute for the product described in this order line. */
  [SellerSubstitutedLineItem] [numeric](18,0) NULL, /* 0..n ASBIE Line Item ** In Order Response, a line item that has replaced the original order line item. The specified quantity and pricing may differ from those in the original line item, but when a line item is substituted by the seller, it is assumed that other information, such as shipment details, will remain the same. */
  [BuyerProposedSubstituteLineItem] [numeric](18,0) NULL, /* 0..n ASBIE Line Item ** A description of an item proposed by the buyer as a possible alternative to the item associated with this order line. */
  [CatalogueLineReference] [numeric](18,0) NULL, /* 0..1 ASBIE Line Reference ** A reference to a catalogue line associated with this order line. */
  [QuotationLineReference] [numeric](18,0) NULL, /* 0..1 ASBIE Line Reference ** A reference to a quotation line associated with this order line. */
  [OrderLineReference] [numeric](18,0) NULL, /* 0..n ASBIE Order Line Reference ** A reference to another order line, such as in a replacement order or another line on the same order that is related. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this order line. */
 CONSTRAINT [PK_OrderLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLine_SubstitutionStatusCode] ON [dbo].[OrderLine] 
(
	[SubstitutionStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLine_Note] ON [dbo].[OrderLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLine_LineItem] ON [dbo].[OrderLine] 
(
	[LineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLine_SellerProposedSubstituteLineItem] ON [dbo].[OrderLine] 
(
	[SellerProposedSubstituteLineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLine_SellerSubstitutedLineItem] ON [dbo].[OrderLine] 
(
	[SellerSubstitutedLineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLine_BuyerProposedSubstituteLineItem] ON [dbo].[OrderLine] 
(
	[BuyerProposedSubstituteLineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLine_CatalogueLineReference] ON [dbo].[OrderLine] 
(
	[CatalogueLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLine_QuotationLineReference] ON [dbo].[OrderLine] 
(
	[QuotationLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLine_OrderLineReference] ON [dbo].[OrderLine] 
(
	[OrderLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLine_DocumentReference] ON [dbo].[OrderLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[OrderLineReference] Script Date: 2013-10-13 00:21z
A class to define a reference to an order line.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[OrderLineReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [LineID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the referenced order line, assigned by the buyer. */
  [SalesOrderLineID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the referenced order line, assigned by the seller. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this order line reference. */
  [LineStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the status of the referenced order line with respect to its original state. */
  [OrderReference] [numeric](18,0) NULL, /* 0..1 ASBIE Order Reference ** A reference to the Order containing the referenced order line. */
 CONSTRAINT [PK_OrderLineReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLineReference_LineID] ON [dbo].[OrderLineReference] 
(
	[LineID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLineReference_SalesOrderLineID] ON [dbo].[OrderLineReference] 
(
	[SalesOrderLineID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLineReference_UUID] ON [dbo].[OrderLineReference] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLineReference_LineStatusCode] ON [dbo].[OrderLineReference] 
(
	[LineStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderLineReference_OrderReference] ON [dbo].[OrderLineReference] 
(
	[OrderReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[OrderReference] Script Date: 2013-10-13 00:21z
A class to define a reference to an Order.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[OrderReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this order reference, assigned by the buyer. */
  [SalesOrderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this order reference, assigned by the seller. */
  [CopyIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether the referenced Order is a copy (true) or the original (false). */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this order reference. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which the referenced Order was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which the referenced Order was issued. */
  [CustomerReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Text used for tagging purchasing card transactions. */
  [OrderTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of the referenced Order. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A document associated with this reference to an Order. */
 CONSTRAINT [PK_OrderReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderReference_ID] ON [dbo].[OrderReference] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderReference_SalesOrderID] ON [dbo].[OrderReference] 
(
	[SalesOrderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderReference_CopyIndicator] ON [dbo].[OrderReference] 
(
	[CopyIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderReference_UUID] ON [dbo].[OrderReference] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderReference_IssueDate] ON [dbo].[OrderReference] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderReference_IssueTime] ON [dbo].[OrderReference] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderReference_CustomerReference] ON [dbo].[OrderReference] 
(
	[CustomerReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderReference_OrderTypeCode] ON [dbo].[OrderReference] 
(
	[OrderTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderReference_DocumentReference] ON [dbo].[OrderReference] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[OrderedShipment] Script Date: 2013-10-13 00:21z
A class to describe an ordered shipment.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[OrderedShipment](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Shipment] [numeric](18,0) NOT NULL, /* 1 ASBIE Shipment ** The ordered shipment. */
  [Package] [numeric](18,0) NULL, /* 0..n ASBIE Package ** A package in this ordered shipment. */
 CONSTRAINT [PK_OrderedShipment] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderedShipment_Shipment] ON [dbo].[OrderedShipment] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_OrderedShipment_Package] ON [dbo].[OrderedShipment] 
(
	[Package] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Package] Script Date: 2013-10-13 00:21z
A class to describe a package.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Package](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this package. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of items contained in this package. */
  [ReturnableMaterialIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that the packaging material is returnable (true) or not (false). */
  [PackageLevelCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying a level of packaging. */
  [PackagingTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying a type of packaging. */
  [PackingMaterial] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the packaging material. */
  [TraceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for use in tracing this package, such as the EPC number used in RFID. */
  [ContainedPackage] [numeric](18,0) NULL, /* 0..n ASBIE Package ** A package contained within this package. */
  [ContainingTransportEquipment] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Equipment ** The piece of transport equipment containing this package. */
  [GoodsItem] [numeric](18,0) NULL, /* 0..n ASBIE Goods Item ** A goods item included in this package. */
  [MeasurementDimension] [numeric](18,0) NULL, /* 0..n ASBIE Dimension ** A measurable dimension (length, mass, weight, or volume) of this package. */
  [DeliveryUnit] [numeric](18,0) NULL, /* 0..n ASBIE Delivery Unit ** A delivery unit within this package. */
  [Delivery] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery ** The delivery of this package. */
  [Pickup] [numeric](18,0) NULL, /* 0..1 ASBIE Pickup ** The pickup of this package. */
  [Despatch] [numeric](18,0) NULL, /* 0..1 ASBIE Despatch ** The despatch of this package. */
 CONSTRAINT [PK_Package] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_ID] ON [dbo].[Package] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_Quantity] ON [dbo].[Package] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_ReturnableMaterialIndicator] ON [dbo].[Package] 
(
	[ReturnableMaterialIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_PackageLevelCode] ON [dbo].[Package] 
(
	[PackageLevelCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_PackagingTypeCode] ON [dbo].[Package] 
(
	[PackagingTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_PackingMaterial] ON [dbo].[Package] 
(
	[PackingMaterial] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_TraceID] ON [dbo].[Package] 
(
	[TraceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_ContainedPackage] ON [dbo].[Package] 
(
	[ContainedPackage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_ContainingTransportEquipment] ON [dbo].[Package] 
(
	[ContainingTransportEquipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_GoodsItem] ON [dbo].[Package] 
(
	[GoodsItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_MeasurementDimension] ON [dbo].[Package] 
(
	[MeasurementDimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_DeliveryUnit] ON [dbo].[Package] 
(
	[DeliveryUnit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_Delivery] ON [dbo].[Package] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_Pickup] ON [dbo].[Package] 
(
	[Pickup] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Package_Despatch] ON [dbo].[Package] 
(
	[Despatch] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Party] Script Date: 2013-10-13 00:21z
A class to describe an organization, sub-organization, or individual fulfilling a role in a business process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Party](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [MarkCareIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this party is "care of" (c/o) (true) or not (false). */
  [MarkAttentionIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this party is "for the attention of" (FAO) (true) or not (false). */
  [WebsiteURI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The Uniform Resource Identifier (URI) that identifies this party's web site; i.e., the web site's Uniform Resource Locator (URL). */
  [LogoReferenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this party's logo. */
  [EndpointID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the end point of the routing service (e.g., EAN Location Number, GLN). */
  [IndustryClassificationCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** This party's Industry Classification Code. */
  [PartyIdentification] [numeric](18,0) NULL, /* 0..n ASBIE Party Identification ** An identifier for this party. */
  [PartyName] [numeric](18,0) NULL, /* 0..n ASBIE Party Name ** A name for this party. */
  [Language] [numeric](18,0) NULL, /* 0..1 ASBIE Language ** The language associated with this party. */
  [PostalAddress] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The party's postal address. */
  [PhysicalLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The physical location of this party. */
  [PartyTaxScheme] [numeric](18,0) NULL, /* 0..n ASBIE Party Tax Scheme ** A tax scheme applying to this party. */
  [PartyLegalEntity] [numeric](18,0) NULL, /* 0..n ASBIE Party Legal Entity ** A description of this party as a legal entity. */
  [Contact] [numeric](18,0) NULL, /* 0..1 ASBIE Contact ** The primary contact for this party. */
  [Person] [numeric](18,0) NULL, /* 0..n ASBIE Person ** A person associated with this party. */
  [AgentParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A party who acts as an agent for this party. */
  [ServiceProviderParty] [numeric](18,0) NULL, /* 0..n ASBIE Service Provider Party ** A party providing a service to this party. */
  [PowerOfAttorney] [numeric](18,0) NULL, /* 0..n ASBIE Power Of Attorney ** A power of attorney associated with this party. */
  [FinancialAccount] [numeric](18,0) NULL, /* 0..1 ASBIE Financial Account ** The financial account associated with this party. */
 CONSTRAINT [PK_Party] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_MarkCareIndicator] ON [dbo].[Party] 
(
	[MarkCareIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_MarkAttentionIndicator] ON [dbo].[Party] 
(
	[MarkAttentionIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_WebsiteURI] ON [dbo].[Party] 
(
	[WebsiteURI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_LogoReferenceID] ON [dbo].[Party] 
(
	[LogoReferenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_EndpointID] ON [dbo].[Party] 
(
	[EndpointID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_IndustryClassificationCode] ON [dbo].[Party] 
(
	[IndustryClassificationCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_PartyIdentification] ON [dbo].[Party] 
(
	[PartyIdentification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_PartyName] ON [dbo].[Party] 
(
	[PartyName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_Language] ON [dbo].[Party] 
(
	[Language] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_PostalAddress] ON [dbo].[Party] 
(
	[PostalAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_PhysicalLocation] ON [dbo].[Party] 
(
	[PhysicalLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_PartyTaxScheme] ON [dbo].[Party] 
(
	[PartyTaxScheme] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_PartyLegalEntity] ON [dbo].[Party] 
(
	[PartyLegalEntity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_Contact] ON [dbo].[Party] 
(
	[Contact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_Person] ON [dbo].[Party] 
(
	[Person] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_AgentParty] ON [dbo].[Party] 
(
	[AgentParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_ServiceProviderParty] ON [dbo].[Party] 
(
	[ServiceProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_PowerOfAttorney] ON [dbo].[Party] 
(
	[PowerOfAttorney] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Party_FinancialAccount] ON [dbo].[Party] 
(
	[FinancialAccount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PartyIdentification] Script Date: 2013-10-13 00:21z
A class to define an identifier for a party.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PartyIdentification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the party. */
 CONSTRAINT [PK_PartyIdentification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyIdentification_ID] ON [dbo].[PartyIdentification] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PartyLegalEntity] Script Date: 2013-10-13 00:21z
A class to describe a party as a legal entity.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PartyLegalEntity](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [RegistrationName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of the party as registered with the relevant legal authority. */
  [CompanyID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the party as registered within a company registration scheme. */
  [RegistrationDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The registration date of the CompanyID. */
  [RegistrationExpirationDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date upon which a registration expires (e.g., registration for an import/export license). */
  [CompanyLegalFormCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the party's legal status. */
  [CompanyLegalForm] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The company legal status, expressed as a text. */
  [SoleProprietorshipIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that the company is owned and controlled by one person (true) or not (false). */
  [CompanyLiquidationStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the party's liquidation status. */
  [CorporateStockAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The number of shares in the capital stock of a corporation. */
  [FullyPaidSharesIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that all shares of corporate stock have been paid by shareholders (true) or not (false). */
  [RegistrationAddress] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The registered address of the party within a corporate registration scheme. */
  [CorporateRegistrationScheme] [numeric](18,0) NULL, /* 0..1 ASBIE Corporate Registration Scheme ** The corporate registration scheme used to register the party. */
  [HeadOfficeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The head office of the legal entity */
  [ShareholderParty] [numeric](18,0) NULL, /* 0..n ASBIE Shareholder Party ** A party owning shares in this legal entity. */
 CONSTRAINT [PK_PartyLegalEntity] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_RegistrationName] ON [dbo].[PartyLegalEntity] 
(
	[RegistrationName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_CompanyID] ON [dbo].[PartyLegalEntity] 
(
	[CompanyID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_RegistrationDate] ON [dbo].[PartyLegalEntity] 
(
	[RegistrationDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_RegistrationExpirationDate] ON [dbo].[PartyLegalEntity] 
(
	[RegistrationExpirationDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_CompanyLegalFormCode] ON [dbo].[PartyLegalEntity] 
(
	[CompanyLegalFormCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_CompanyLegalForm] ON [dbo].[PartyLegalEntity] 
(
	[CompanyLegalForm] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_SoleProprietorshipIndicator] ON [dbo].[PartyLegalEntity] 
(
	[SoleProprietorshipIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_CompanyLiquidationStatusCode] ON [dbo].[PartyLegalEntity] 
(
	[CompanyLiquidationStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_CorporateStockAmount] ON [dbo].[PartyLegalEntity] 
(
	[CorporateStockAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_FullyPaidSharesIndicator] ON [dbo].[PartyLegalEntity] 
(
	[FullyPaidSharesIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_RegistrationAddress] ON [dbo].[PartyLegalEntity] 
(
	[RegistrationAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_CorporateRegistrationScheme] ON [dbo].[PartyLegalEntity] 
(
	[CorporateRegistrationScheme] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_HeadOfficeParty] ON [dbo].[PartyLegalEntity] 
(
	[HeadOfficeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyLegalEntity_ShareholderParty] ON [dbo].[PartyLegalEntity] 
(
	[ShareholderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PartyName] Script Date: 2013-10-13 00:21z
A class for defining the name of a party.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PartyName](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Name] [numeric](18,0) NOT NULL, /* 1 BBIE Name ** The name of the party. */
 CONSTRAINT [PK_PartyName] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyName_Name] ON [dbo].[PartyName] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PartyTaxScheme] Script Date: 2013-10-13 00:21z
A class to describe a taxation scheme applying to a party.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PartyTaxScheme](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [RegistrationName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of the party as registered with the relevant fiscal authority. */
  [CompanyID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the party assigned for tax purposes by the taxation authority. */
  [TaxLevelCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the tax level applicable to the party within this taxation scheme. */
  [ExemptionReasonCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A reason for the party's exemption from tax, expressed as a code. */
  [ExemptionReason] [numeric](18,0) NULL, /* 0..n BBIE Text ** A reason for the party's exemption from tax, expressed as text. */
  [RegistrationAddress] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The address of the party as registered for tax purposes. */
  [TaxScheme] [numeric](18,0) NOT NULL, /* 1 ASBIE Tax Scheme ** The taxation scheme applicable to the party. */
 CONSTRAINT [PK_PartyTaxScheme] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyTaxScheme_RegistrationName] ON [dbo].[PartyTaxScheme] 
(
	[RegistrationName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyTaxScheme_CompanyID] ON [dbo].[PartyTaxScheme] 
(
	[CompanyID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyTaxScheme_TaxLevelCode] ON [dbo].[PartyTaxScheme] 
(
	[TaxLevelCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyTaxScheme_ExemptionReasonCode] ON [dbo].[PartyTaxScheme] 
(
	[ExemptionReasonCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyTaxScheme_ExemptionReason] ON [dbo].[PartyTaxScheme] 
(
	[ExemptionReason] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyTaxScheme_RegistrationAddress] ON [dbo].[PartyTaxScheme] 
(
	[RegistrationAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PartyTaxScheme_TaxScheme] ON [dbo].[PartyTaxScheme] 
(
	[TaxScheme] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Payment] Script Date: 2013-10-13 00:21z
A class to describe a payment.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Payment](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this payment. */
  [PaidAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount of this payment. */
  [ReceivedDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this payment was received. */
  [PaidDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this payment was made. */
  [PaidTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this payment was made. */
  [InstructionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the payment instruction. */
 CONSTRAINT [PK_Payment] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Payment_ID] ON [dbo].[Payment] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Payment_PaidAmount] ON [dbo].[Payment] 
(
	[PaidAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Payment_ReceivedDate] ON [dbo].[Payment] 
(
	[ReceivedDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Payment_PaidDate] ON [dbo].[Payment] 
(
	[PaidDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Payment_PaidTime] ON [dbo].[Payment] 
(
	[PaidTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Payment_InstructionID] ON [dbo].[Payment] 
(
	[InstructionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PaymentMandate] Script Date: 2013-10-13 00:21z
A class to describe a payment mandate.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PaymentMandate](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this payment mandate. */
  [MandateTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of this payment mandate. */
  [MaximumPaymentInstructionsNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of maximum payment instructions allowed within the validity period. */
  [MaximumPaidAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The maximum amount to be paid within a single instruction. */
  [SignatureID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for a signature applied by a signatory party. */
  [PayerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payer party (if different from the debtor). */
  [PayerFinancialAccount] [numeric](18,0) NULL, /* 0..1 ASBIE Financial Account ** The payer's financial account. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which this mandate is valid. */
  [PaymentReversalPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period of the reverse payment. */
  [Clause] [numeric](18,0) NULL, /* 0..n ASBIE Clause ** A clause applicable to this payment mandate. */
 CONSTRAINT [PK_PaymentMandate] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMandate_ID] ON [dbo].[PaymentMandate] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMandate_MandateTypeCode] ON [dbo].[PaymentMandate] 
(
	[MandateTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMandate_MaximumPaymentInstructionsNumeric] ON [dbo].[PaymentMandate] 
(
	[MaximumPaymentInstructionsNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMandate_MaximumPaidAmount] ON [dbo].[PaymentMandate] 
(
	[MaximumPaidAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMandate_SignatureID] ON [dbo].[PaymentMandate] 
(
	[SignatureID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMandate_PayerParty] ON [dbo].[PaymentMandate] 
(
	[PayerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMandate_PayerFinancialAccount] ON [dbo].[PaymentMandate] 
(
	[PayerFinancialAccount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMandate_ValidityPeriod] ON [dbo].[PaymentMandate] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMandate_PaymentReversalPeriod] ON [dbo].[PaymentMandate] 
(
	[PaymentReversalPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMandate_Clause] ON [dbo].[PaymentMandate] 
(
	[Clause] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PaymentMeans] Script Date: 2013-10-13 00:21z
A class to describe a means of payment.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PaymentMeans](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this means of payment. */
  [PaymentMeansCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the type of this means of payment. */
  [PaymentDueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which payment is due for this means of payment. */
  [PaymentChannelCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the payment channel for this means of payment. */
  [InstructionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the payment instruction. */
  [InstructionNote] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [PaymentID] [numeric](18,0) NULL, /* 0..n BBIE Identifier ** An identifier for a payment made using this means of payment. */
  [CardAccount] [numeric](18,0) NULL, /* 0..1 ASBIE Card Account ** A credit card, debit card, or charge card account that constitutes this means of payment. */
  [PayerFinancialAccount] [numeric](18,0) NULL, /* 0..1 ASBIE Financial Account ** The payer's financial account. */
  [PayeeFinancialAccount] [numeric](18,0) NULL, /* 0..1 ASBIE Financial Account ** The payee's financial account. */
  [CreditAccount] [numeric](18,0) NULL, /* 0..1 ASBIE Credit Account ** A credit account associated with this means of payment. */
  [PaymentMandate] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Mandate ** The payment mandate associated with this means of payment. */
  [TradeFinancing] [numeric](18,0) NULL, /* 0..1 ASBIE Trade Financing ** A trade finance agreement applicable to this means of payment. */
 CONSTRAINT [PK_PaymentMeans] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_ID] ON [dbo].[PaymentMeans] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_PaymentMeansCode] ON [dbo].[PaymentMeans] 
(
	[PaymentMeansCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_PaymentDueDate] ON [dbo].[PaymentMeans] 
(
	[PaymentDueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_PaymentChannelCode] ON [dbo].[PaymentMeans] 
(
	[PaymentChannelCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_InstructionID] ON [dbo].[PaymentMeans] 
(
	[InstructionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_InstructionNote] ON [dbo].[PaymentMeans] 
(
	[InstructionNote] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_PaymentID] ON [dbo].[PaymentMeans] 
(
	[PaymentID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_CardAccount] ON [dbo].[PaymentMeans] 
(
	[CardAccount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_PayerFinancialAccount] ON [dbo].[PaymentMeans] 
(
	[PayerFinancialAccount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_PayeeFinancialAccount] ON [dbo].[PaymentMeans] 
(
	[PayeeFinancialAccount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_CreditAccount] ON [dbo].[PaymentMeans] 
(
	[CreditAccount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_PaymentMandate] ON [dbo].[PaymentMeans] 
(
	[PaymentMandate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentMeans_TradeFinancing] ON [dbo].[PaymentMeans] 
(
	[TradeFinancing] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PaymentTerms] Script Date: 2013-10-13 00:21z
A class to describe a set of payment terms.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PaymentTerms](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this set of payment terms. */
  [PaymentMeansID] [numeric](18,0) NULL, /* 0..n BBIE Identifier ** An identifier for a means of payment associated with these payment terms. */
  [PrepaidPaymentReferenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for a reference to a prepaid payment. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [ReferenceEventCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the event during which these terms are offered. */
  [SettlementDiscountPercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The percentage for the settlement discount that is offered for payment under these payment terms. */
  [PenaltySurchargePercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The penalty for payment after the settlement period, expressed as a percentage of the payment. */
  [PaymentPercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The part of a payment, expressed as a percent, relevant for these payment terms. */
  [Amount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount covered by these payment terms. */
  [SettlementDiscountAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount of a settlement discount offered for payment under these payment terms. */
  [PenaltyAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount of the penalty for payment after the settlement period. */
  [PaymentTermsDetailsURI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The Uniform Resource Identifier (URI) of a document providing additional details regarding these payment terms. */
  [PaymentDueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The due date for these payment terms. */
  [InstallmentDueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The due date for an installment payment for these payment terms. */
  [InvoicingPartyReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A reference to the payment terms used by the invoicing party. This may have been requested of the payer by the payee to accompany its remittance. */
  [SettlementPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which settlement may occur. */
  [PenaltyPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which penalties may apply. */
  [ExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The currency exchange rate for purposes of these payment terms. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which these payment terms are valid. */
 CONSTRAINT [PK_PaymentTerms] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_ID] ON [dbo].[PaymentTerms] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_PaymentMeansID] ON [dbo].[PaymentTerms] 
(
	[PaymentMeansID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_PrepaidPaymentReferenceID] ON [dbo].[PaymentTerms] 
(
	[PrepaidPaymentReferenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_Note] ON [dbo].[PaymentTerms] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_ReferenceEventCode] ON [dbo].[PaymentTerms] 
(
	[ReferenceEventCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_SettlementDiscountPercent] ON [dbo].[PaymentTerms] 
(
	[SettlementDiscountPercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_PenaltySurchargePercent] ON [dbo].[PaymentTerms] 
(
	[PenaltySurchargePercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_PaymentPercent] ON [dbo].[PaymentTerms] 
(
	[PaymentPercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_Amount] ON [dbo].[PaymentTerms] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_SettlementDiscountAmount] ON [dbo].[PaymentTerms] 
(
	[SettlementDiscountAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_PenaltyAmount] ON [dbo].[PaymentTerms] 
(
	[PenaltyAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_PaymentTermsDetailsURI] ON [dbo].[PaymentTerms] 
(
	[PaymentTermsDetailsURI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_PaymentDueDate] ON [dbo].[PaymentTerms] 
(
	[PaymentDueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_InstallmentDueDate] ON [dbo].[PaymentTerms] 
(
	[InstallmentDueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_InvoicingPartyReference] ON [dbo].[PaymentTerms] 
(
	[InvoicingPartyReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_SettlementPeriod] ON [dbo].[PaymentTerms] 
(
	[SettlementPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_PenaltyPeriod] ON [dbo].[PaymentTerms] 
(
	[PenaltyPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_ExchangeRate] ON [dbo].[PaymentTerms] 
(
	[ExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PaymentTerms_ValidityPeriod] ON [dbo].[PaymentTerms] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PerformanceDataLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Performance History.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PerformanceDataLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this performance data line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [PerformanceValueQuantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The value of the reported attribute. */
  [PerformanceMetricTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the measure of performance applicable to the reported attribute. */
  [Period] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period to which this performance data line applies. */
  [Item] [numeric](18,0) NULL, /* 0..1 ASBIE Item ** The item whose performance is reported in this data line. */
 CONSTRAINT [PK_PerformanceDataLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PerformanceDataLine_ID] ON [dbo].[PerformanceDataLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PerformanceDataLine_Note] ON [dbo].[PerformanceDataLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PerformanceDataLine_PerformanceValueQuantity] ON [dbo].[PerformanceDataLine] 
(
	[PerformanceValueQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PerformanceDataLine_PerformanceMetricTypeCode] ON [dbo].[PerformanceDataLine] 
(
	[PerformanceMetricTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PerformanceDataLine_Period] ON [dbo].[PerformanceDataLine] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PerformanceDataLine_Item] ON [dbo].[PerformanceDataLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Period] Script Date: 2013-10-13 00:21z
A class to describe a period of time.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Period](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [StartDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this period begins. */
  [StartTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this period begins. */
  [EndDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this period ends. */
  [EndTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this period ends. */
  [DurationMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The duration of this period, expressed as an ISO 8601 code. */
  [DescriptionCode] [numeric](18,0) NULL, /* 0..n BBIE Code ** A description of this period, expressed as a code. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** A description of this period, expressed as text. */
 CONSTRAINT [PK_Period] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Period_StartDate] ON [dbo].[Period] 
(
	[StartDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Period_StartTime] ON [dbo].[Period] 
(
	[StartTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Period_EndDate] ON [dbo].[Period] 
(
	[EndDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Period_EndTime] ON [dbo].[Period] 
(
	[EndTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Period_DurationMeasure] ON [dbo].[Period] 
(
	[DurationMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Period_DescriptionCode] ON [dbo].[Period] 
(
	[DescriptionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Period_Description] ON [dbo].[Period] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Person] Script Date: 2013-10-13 00:21z
A class to describe a person.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Person](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this person. */
  [FirstName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** This person's given name. */
  [FamilyName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** This person's family name. */
  [Title] [numeric](18,0) NULL, /* 0..1 BBIE Text ** This person's title of address (e.g., Mr, Ms, Dr, Sir). */
  [MiddleName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** This person's middle name(s) or initials. */
  [OtherName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** This person's second family name. */
  [NameSuffix] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A suffix to this person's name (e.g., PhD, OBE, Jr). */
  [JobTitle] [numeric](18,0) NULL, /* 0..1 BBIE Text ** This person's job title (for a particular role) within an organization. */
  [NationalityID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this person's nationality. */
  [GenderCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code (e.g., ISO 5218) signifying the gender of this person. */
  [BirthDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** This person's date of birth. */
  [BirthplaceName] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The name of the place where this person was born, expressed as text. */
  [OrganizationDepartment] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The department or subdivision of an organization that this person belongs to (in a particular role). */
  [Contact] [numeric](18,0) NULL, /* 0..1 ASBIE Contact ** Contact information for this person. */
  [FinancialAccount] [numeric](18,0) NULL, /* 0..1 ASBIE Financial Account ** The financial account associated with this person. */
  [IdentityDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document that can precisely identify this person (e.g., a driver's license). */
  [ResidenceAddress] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** This person's address of residence. */
 CONSTRAINT [PK_Person] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_ID] ON [dbo].[Person] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_FirstName] ON [dbo].[Person] 
(
	[FirstName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_FamilyName] ON [dbo].[Person] 
(
	[FamilyName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_Title] ON [dbo].[Person] 
(
	[Title] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_MiddleName] ON [dbo].[Person] 
(
	[MiddleName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_OtherName] ON [dbo].[Person] 
(
	[OtherName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_NameSuffix] ON [dbo].[Person] 
(
	[NameSuffix] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_JobTitle] ON [dbo].[Person] 
(
	[JobTitle] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_NationalityID] ON [dbo].[Person] 
(
	[NationalityID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_GenderCode] ON [dbo].[Person] 
(
	[GenderCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_BirthDate] ON [dbo].[Person] 
(
	[BirthDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_BirthplaceName] ON [dbo].[Person] 
(
	[BirthplaceName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_OrganizationDepartment] ON [dbo].[Person] 
(
	[OrganizationDepartment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_Contact] ON [dbo].[Person] 
(
	[Contact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_FinancialAccount] ON [dbo].[Person] 
(
	[FinancialAccount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_IdentityDocumentReference] ON [dbo].[Person] 
(
	[IdentityDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Person_ResidenceAddress] ON [dbo].[Person] 
(
	[ResidenceAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PhysicalAttribute] Script Date: 2013-10-13 00:21z
A class to describe a physical attribute.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PhysicalAttribute](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [AttributeID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this physical attribute. */
  [PositionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the position of this physical attribute. */
  [DescriptionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A description of the physical attribute, expressed as a code. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** A description of the physical attribute, expressed as text. */
 CONSTRAINT [PK_PhysicalAttribute] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PhysicalAttribute_AttributeID] ON [dbo].[PhysicalAttribute] 
(
	[AttributeID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PhysicalAttribute_PositionCode] ON [dbo].[PhysicalAttribute] 
(
	[PositionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PhysicalAttribute_DescriptionCode] ON [dbo].[PhysicalAttribute] 
(
	[DescriptionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PhysicalAttribute_Description] ON [dbo].[PhysicalAttribute] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Pickup] Script Date: 2013-10-13 00:21z
A class to describe a pickup for delivery.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Pickup](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this pickup. */
  [ActualPickupDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The actual pickup date. */
  [ActualPickupTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The actual pickup time. */
  [EarliestPickupDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The earliest pickup date. */
  [EarliestPickupTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The earliest pickup time. */
  [LatestPickupDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The latest pickup date. */
  [LatestPickupTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The latest pickup time. */
  [PickupLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The pickup location. */
  [PickupParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party responsible for picking up a delivery. */
 CONSTRAINT [PK_Pickup] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Pickup_ID] ON [dbo].[Pickup] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Pickup_ActualPickupDate] ON [dbo].[Pickup] 
(
	[ActualPickupDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Pickup_ActualPickupTime] ON [dbo].[Pickup] 
(
	[ActualPickupTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Pickup_EarliestPickupDate] ON [dbo].[Pickup] 
(
	[EarliestPickupDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Pickup_EarliestPickupTime] ON [dbo].[Pickup] 
(
	[EarliestPickupTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Pickup_LatestPickupDate] ON [dbo].[Pickup] 
(
	[LatestPickupDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Pickup_LatestPickupTime] ON [dbo].[Pickup] 
(
	[LatestPickupTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Pickup_PickupLocation] ON [dbo].[Pickup] 
(
	[PickupLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Pickup_PickupParty] ON [dbo].[Pickup] 
(
	[PickupParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PowerOfAttorney] Script Date: 2013-10-13 00:21z
A class to describe a power of attorney.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PowerOfAttorney](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this power of attorney. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this power of attorney was issued. */
  [IssueTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this power of attorney was issued. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this power of attorney. */
  [NotaryParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party notarizing this power of attorney. */
  [AgentParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party who acts as an agent or fiduciary for the principal and who holds this power of attorney on behalf of the principal. */
  [WitnessParty] [numeric](18,0) NULL, /* 0..n ASBIE Party ** An association to a WitnessParty. */
  [MandateDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a mandate associated with this power of attorney. */
 CONSTRAINT [PK_PowerOfAttorney] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PowerOfAttorney_ID] ON [dbo].[PowerOfAttorney] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PowerOfAttorney_IssueDate] ON [dbo].[PowerOfAttorney] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PowerOfAttorney_IssueTime] ON [dbo].[PowerOfAttorney] 
(
	[IssueTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PowerOfAttorney_Description] ON [dbo].[PowerOfAttorney] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PowerOfAttorney_NotaryParty] ON [dbo].[PowerOfAttorney] 
(
	[NotaryParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PowerOfAttorney_AgentParty] ON [dbo].[PowerOfAttorney] 
(
	[AgentParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PowerOfAttorney_WitnessParty] ON [dbo].[PowerOfAttorney] 
(
	[WitnessParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PowerOfAttorney_MandateDocumentReference] ON [dbo].[PowerOfAttorney] 
(
	[MandateDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Price] Script Date: 2013-10-13 00:21z
A class to describe a price, expressed in a data structure containing multiple properties (compare with UnstructuredPrice).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Price](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [PriceAmount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The amount of the price. */
  [BaseQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity at which this price applies. */
  [PriceChangeReason] [numeric](18,0) NULL, /* 0..n BBIE Text ** A reason for a price change. */
  [PriceTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of price, expressed as a code. */
  [PriceType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The type of price, expressed as text. */
  [OrderableUnitFactorRate] [numeric](18,0) NULL, /* 0..1 BBIE Rate ** The factor by which the base price unit can be converted to the orderable unit. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period during which this price is valid. */
  [PriceList] [numeric](18,0) NULL, /* 0..1 ASBIE Price List ** Information about a price list applicable to this price. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** An allowance or charge associated with this price. */
  [PricingExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The exchange rate applicable to this price, if it differs from the exchange rate applicable to the document as a whole. */
 CONSTRAINT [PK_Price] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Price_PriceAmount] ON [dbo].[Price] 
(
	[PriceAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Price_BaseQuantity] ON [dbo].[Price] 
(
	[BaseQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Price_PriceChangeReason] ON [dbo].[Price] 
(
	[PriceChangeReason] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Price_PriceTypeCode] ON [dbo].[Price] 
(
	[PriceTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Price_PriceType] ON [dbo].[Price] 
(
	[PriceType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Price_OrderableUnitFactorRate] ON [dbo].[Price] 
(
	[OrderableUnitFactorRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Price_ValidityPeriod] ON [dbo].[Price] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Price_PriceList] ON [dbo].[Price] 
(
	[PriceList] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Price_AllowanceCharge] ON [dbo].[Price] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Price_PricingExchangeRate] ON [dbo].[Price] 
(
	[PricingExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PriceExtension] Script Date: 2013-10-13 00:21z
A class to describe a price extension, calculated by multiplying the price per unit by the quantity of items.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PriceExtension](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Amount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The amount of this price extension. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** A total amount of taxes of a particular kind applicable to this price extension. */
 CONSTRAINT [PK_PriceExtension] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriceExtension_Amount] ON [dbo].[PriceExtension] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriceExtension_TaxTotal] ON [dbo].[PriceExtension] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PriceList] Script Date: 2013-10-13 00:21z
A class to describe a price list.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PriceList](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this price list. */
  [StatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying whether this price list is an original, copy, revision, or cancellation. */
  [ValidityPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period during which this price list is valid. */
  [PreviousPriceList] [numeric](18,0) NULL, /* 0..1 ASBIE Price List ** The previous price list. */
 CONSTRAINT [PK_PriceList] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriceList_ID] ON [dbo].[PriceList] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriceList_StatusCode] ON [dbo].[PriceList] 
(
	[StatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriceList_ValidityPeriod] ON [dbo].[PriceList] 
(
	[ValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PriceList_PreviousPriceList] ON [dbo].[PriceList] 
(
	[PreviousPriceList] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PricingReference] Script Date: 2013-10-13 00:21z
A reference to the basis for pricing. This may be based on a catalogue or a quoted amount from a price list and include some alternative pricing conditions.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PricingReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [OriginalItemLocationQuantity] [numeric](18,0) NULL, /* 0..1 ASBIE Item Location Quantity ** An original set of location-specific properties (e.g., price and quantity) associated with this item. */
  [AlternativeConditionPrice] [numeric](18,0) NULL, /* 0..n ASBIE Price ** The price expressed in terms other than the actual price, e.g., the list price v. the contracted price, or the price in bags v. the price in kilos, or the list price in bags v. the contracted price in kilos. */
 CONSTRAINT [PK_PricingReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PricingReference_OriginalItemLocationQuantity] ON [dbo].[PricingReference] 
(
	[OriginalItemLocationQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PricingReference_AlternativeConditionPrice] ON [dbo].[PricingReference] 
(
	[AlternativeConditionPrice] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ProcessJustification] Script Date: 2013-10-13 00:21z
A class to describe a justification for the choice of tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ProcessJustification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [PreviousCancellationReasonCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of the previous tendering process (which is now being cancelled). */
  [ProcessReasonCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The reason why the contracting authority has followed a particular tendering procedure for the awarding of a contract, expressed as a code. */
  [ProcessReason] [numeric](18,0) NULL, /* 0..n BBIE Text ** The reason why the contracting authority has followed a particular tendering procedure for the awarding of a contract, expressed as text. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text providing justification for the selection of this process. */
 CONSTRAINT [PK_ProcessJustification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcessJustification_PreviousCancellationReasonCode] ON [dbo].[ProcessJustification] 
(
	[PreviousCancellationReasonCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcessJustification_ProcessReasonCode] ON [dbo].[ProcessJustification] 
(
	[ProcessReasonCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcessJustification_ProcessReason] ON [dbo].[ProcessJustification] 
(
	[ProcessReason] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcessJustification_Description] ON [dbo].[ProcessJustification] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ProcurementProject] Script Date: 2013-10-13 00:21z
A class to describe a project to procure goods, works, or services.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ProcurementProject](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this procurement project. */
  [Name] [numeric](18,0) NOT NULL, /* 1..n BBIE Name ** A name of this procurement project. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this procurement project. */
  [ProcurementTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of procurement project (e.g., goods, works, services). */
  [ProcurementSubTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the subcategory of the type of work for this project (e.g., land surveying, IT consulting). */
  [QualityControlCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The indication of whether or not the control quality is included in the works project. */
  [RequiredFeeAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount of the reimbursement fee for concession procurement projects. */
  [FeeDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the reimbursement fee for concession procurement projects. */
  [RequestedDeliveryDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The requested delivery date for this procurement project. */
  [EstimatedOverallContractQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The estimated overall quantity for this procurement project. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text applying to the Procurement Project. This element may contain additional information about the lot/contract that is not contained explicitly in another structure. */
  [RequestedTenderTotal] [numeric](18,0) NULL, /* 0..1 ASBIE Requested Tender Total ** Budget monetary amounts for the project as whole. */
  [MainCommodityClassification] [numeric](18,0) NULL, /* 0..1 ASBIE Commodity Classification ** An association to the main classification category for the deliverable requested. */
  [AdditionalCommodityClassification] [numeric](18,0) NULL, /* 0..n ASBIE Commodity Classification ** An association to additional classification categories for the deliverable requested. */
  [RealizedLocation] [numeric](18,0) NULL, /* 0..n ASBIE Location ** A place where this procurement project will be physically realized. */
  [PlannedPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which this procurement project is planned to take place. */
  [ContractExtension] [numeric](18,0) NULL, /* 0..1 ASBIE Contract Extension ** The contract extension for this tendering process. */
  [RequestForTenderLine] [numeric](18,0) NULL, /* 0..n ASBIE Request For Tender Line ** A good or service this project is intended to procure. */
 CONSTRAINT [PK_ProcurementProject] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_ID] ON [dbo].[ProcurementProject] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_Name] ON [dbo].[ProcurementProject] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_Description] ON [dbo].[ProcurementProject] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_ProcurementTypeCode] ON [dbo].[ProcurementProject] 
(
	[ProcurementTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_ProcurementSubTypeCode] ON [dbo].[ProcurementProject] 
(
	[ProcurementSubTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_QualityControlCode] ON [dbo].[ProcurementProject] 
(
	[QualityControlCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_RequiredFeeAmount] ON [dbo].[ProcurementProject] 
(
	[RequiredFeeAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_FeeDescription] ON [dbo].[ProcurementProject] 
(
	[FeeDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_RequestedDeliveryDate] ON [dbo].[ProcurementProject] 
(
	[RequestedDeliveryDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_EstimatedOverallContractQuantity] ON [dbo].[ProcurementProject] 
(
	[EstimatedOverallContractQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_Note] ON [dbo].[ProcurementProject] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_RequestedTenderTotal] ON [dbo].[ProcurementProject] 
(
	[RequestedTenderTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_MainCommodityClassification] ON [dbo].[ProcurementProject] 
(
	[MainCommodityClassification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_AdditionalCommodityClassification] ON [dbo].[ProcurementProject] 
(
	[AdditionalCommodityClassification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_RealizedLocation] ON [dbo].[ProcurementProject] 
(
	[RealizedLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_PlannedPeriod] ON [dbo].[ProcurementProject] 
(
	[PlannedPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_ContractExtension] ON [dbo].[ProcurementProject] 
(
	[ContractExtension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProject_RequestForTenderLine] ON [dbo].[ProcurementProject] 
(
	[RequestForTenderLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ProcurementProjectLot] Script Date: 2013-10-13 00:21z
A class to describe one of the parts of a procurement project that is being subdivided to allow the contracting party to award different lots to different economic operators under different contracts.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ProcurementProjectLot](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this procurement project lot. */
  [TenderingTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Tendering Terms ** Tendering terms for this procurement project lot. */
  [ProcurementProject] [numeric](18,0) NULL, /* 0..1 ASBIE Procurement Project ** A description of the procurement project to be divided. */
 CONSTRAINT [PK_ProcurementProjectLot] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProjectLot_ID] ON [dbo].[ProcurementProjectLot] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProjectLot_TenderingTerms] ON [dbo].[ProcurementProjectLot] 
(
	[TenderingTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProcurementProjectLot_ProcurementProject] ON [dbo].[ProcurementProjectLot] 
(
	[ProcurementProject] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ProjectReference] Script Date: 2013-10-13 00:21z
A class to define a reference to a procurement project.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ProjectReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the referenced project. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for the referenced project. */
  [IssueDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which the referenced project was issued. */
  [WorkPhaseReference] [numeric](18,0) NULL, /* 0..n ASBIE Work Phase Reference ** A specific phase of work in the referenced project. */
 CONSTRAINT [PK_ProjectReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProjectReference_ID] ON [dbo].[ProjectReference] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProjectReference_UUID] ON [dbo].[ProjectReference] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProjectReference_IssueDate] ON [dbo].[ProjectReference] 
(
	[IssueDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ProjectReference_WorkPhaseReference] ON [dbo].[ProjectReference] 
(
	[WorkPhaseReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PromotionalEvent] Script Date: 2013-10-13 00:21z
Agree can be renamed as PromotionalEvents
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PromotionalEvent](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [PromotionalEventTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the type of this promotional event. Examples can be: Holiday, Seasonal Event, Store Closing, Trade Item Introduction */
  [SubmissionDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which a proposal for this promotional event was submitted. */
  [FirstShipmentAvailibilityDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The first day that products will be available to ship from buyer to seller if the proposal for this promotional event is accepted. */
  [LatestProposalAcceptanceDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The deadline for acceptance of this promotional event. */
  [PromotionalSpecification] [numeric](18,0) NOT NULL, /* 1..n ASBIE Promotional Specification ** A specification for a promotional event. */
 CONSTRAINT [PK_PromotionalEvent] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PromotionalEvent_PromotionalEventTypeCode] ON [dbo].[PromotionalEvent] 
(
	[PromotionalEventTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PromotionalEvent_SubmissionDate] ON [dbo].[PromotionalEvent] 
(
	[SubmissionDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PromotionalEvent_FirstShipmentAvailibilityDate] ON [dbo].[PromotionalEvent] 
(
	[FirstShipmentAvailibilityDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PromotionalEvent_LatestProposalAcceptanceDate] ON [dbo].[PromotionalEvent] 
(
	[LatestProposalAcceptanceDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PromotionalEvent_PromotionalSpecification] ON [dbo].[PromotionalEvent] 
(
	[PromotionalSpecification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PromotionalEventLineItem] Script Date: 2013-10-13 00:21z
A class to describe a line item associated with a promotional event.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PromotionalEventLineItem](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Amount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The amount associated with this promotional event line item. */
  [EventLineItem] [numeric](18,0) NOT NULL, /* 1 ASBIE Event Line Item ** A line item describing the expected impacts associated with this promotional event for a specific product at a specific location. */
 CONSTRAINT [PK_PromotionalEventLineItem] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PromotionalEventLineItem_Amount] ON [dbo].[PromotionalEventLineItem] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PromotionalEventLineItem_EventLineItem] ON [dbo].[PromotionalEventLineItem] 
(
	[EventLineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[PromotionalSpecification] Script Date: 2013-10-13 00:21z
A class to describe a promotional event as a set of item locations that share a set of promotional tactics.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PromotionalSpecification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [SpecificationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this promotional specification. */
  [PromotionalEventLineItem] [numeric](18,0) NOT NULL, /* 1..n ASBIE Promotional Event Line Item ** A line item for a promotional event involving a specific product at a specific location; it describes the expected impacts associated with the event and specifies the promotional price of the item." */
  [EventTactic] [numeric](18,0) NULL, /* 0..n ASBIE Event Tactic ** An event tactic associated with this promotion. */
 CONSTRAINT [PK_PromotionalSpecification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PromotionalSpecification_SpecificationID] ON [dbo].[PromotionalSpecification] 
(
	[SpecificationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PromotionalSpecification_PromotionalEventLineItem] ON [dbo].[PromotionalSpecification] 
(
	[PromotionalEventLineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_PromotionalSpecification_EventTactic] ON [dbo].[PromotionalSpecification] 
(
	[EventTactic] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[QualificationResolution] Script Date: 2013-10-13 00:21z
A class to describe the acceptance or rejection of an economic operator in a tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[QualificationResolution](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [AdmissionCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** An indicator that the economic operator has been accepted into the tendering process (true) or rejected from the tendering process (false). */
  [ExclusionReason] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing a reason for an exclusion from the tendering process. */
  [Resolution] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this qualification resolution. */
  [ResolutionDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date on which this qualification resolution was formalized. */
  [ResolutionTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this qualification resolution was formalized. */
  [ProcurementProjectLot] [numeric](18,0) NULL, /* 0..1 ASBIE Procurement Project Lot ** The Procurement project lot to which this tenderer is accepted or rejected. */
 CONSTRAINT [PK_QualificationResolution] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualificationResolution_AdmissionCode] ON [dbo].[QualificationResolution] 
(
	[AdmissionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualificationResolution_ExclusionReason] ON [dbo].[QualificationResolution] 
(
	[ExclusionReason] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualificationResolution_Resolution] ON [dbo].[QualificationResolution] 
(
	[Resolution] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualificationResolution_ResolutionDate] ON [dbo].[QualificationResolution] 
(
	[ResolutionDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualificationResolution_ResolutionTime] ON [dbo].[QualificationResolution] 
(
	[ResolutionTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualificationResolution_ProcurementProjectLot] ON [dbo].[QualificationResolution] 
(
	[ProcurementProjectLot] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[QualifyingParty] Script Date: 2013-10-13 00:21z
A class to describe the distinctive features or characteristics qualifying an economic operator to be a party in a tendering process (e.g., number of employees, number of operating units, type of business, technical and financial capabilities, completed projects).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[QualifyingParty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ParticipationPercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The extent to which this party is expected to participate in the tendering process, expressed as a percentage. */
  [PersonalSituation] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the personal situation of the qualifying party. */
  [OperatingYearsQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of years that this qualifying party has been in operation. */
  [EmployeeQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of people employed by this qualifying party. */
  [BusinessClassificationEvidenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for an item of evidence to support the classification of this qualifying party. */
  [BusinessIdentityEvidenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for an item of evidence to support the business identity of this qualifying party. */
  [TendererRoleCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code stating the Tenderer Role. */
  [BusinessClassificationScheme] [numeric](18,0) NULL, /* 0..1 ASBIE Classification Scheme ** The classification scheme used for the business profile. */
  [TechnicalCapability] [numeric](18,0) NULL, /* 0..n ASBIE Capability ** A technical capability of this qualifying party. */
  [FinancialCapability] [numeric](18,0) NULL, /* 0..n ASBIE Capability ** A financial capability of this qualifying party. */
  [CompletedTask] [numeric](18,0) NULL, /* 0..n ASBIE Completed Task ** A former task completed by this qualifying party. */
  [Declaration] [numeric](18,0) NULL, /* 0..n ASBIE Declaration ** A declaration by this qualifying party. of certain characteristics or capabilities in fulfilment of requirements specified in a call for tenders. */
  [Party] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The qualifying party itself. */
  [EconomicOperatorRole] [numeric](18,0) NULL, /* 0..1 ASBIE Economic Operator Role ** A class to describe the tenderer contracting role. */
 CONSTRAINT [PK_QualifyingParty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_ParticipationPercent] ON [dbo].[QualifyingParty] 
(
	[ParticipationPercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_PersonalSituation] ON [dbo].[QualifyingParty] 
(
	[PersonalSituation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_OperatingYearsQuantity] ON [dbo].[QualifyingParty] 
(
	[OperatingYearsQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_EmployeeQuantity] ON [dbo].[QualifyingParty] 
(
	[EmployeeQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_BusinessClassificationEvidenceID] ON [dbo].[QualifyingParty] 
(
	[BusinessClassificationEvidenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_BusinessIdentityEvidenceID] ON [dbo].[QualifyingParty] 
(
	[BusinessIdentityEvidenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_TendererRoleCode] ON [dbo].[QualifyingParty] 
(
	[TendererRoleCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_BusinessClassificationScheme] ON [dbo].[QualifyingParty] 
(
	[BusinessClassificationScheme] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_TechnicalCapability] ON [dbo].[QualifyingParty] 
(
	[TechnicalCapability] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_FinancialCapability] ON [dbo].[QualifyingParty] 
(
	[FinancialCapability] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_CompletedTask] ON [dbo].[QualifyingParty] 
(
	[CompletedTask] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_Declaration] ON [dbo].[QualifyingParty] 
(
	[Declaration] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_Party] ON [dbo].[QualifyingParty] 
(
	[Party] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QualifyingParty_EconomicOperatorRole] ON [dbo].[QualifyingParty] 
(
	[EconomicOperatorRole] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[QuotationLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Quotation.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[QuotationLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this quotation line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of the item quoted. */
  [LineExtensionAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total amount for this quotation line, including allowance charges but net of taxes. */
  [TotalTaxAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total tax amount for this quotation line. */
  [RequestForQuotationLineID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the line in the Request for Quotation to which this line is a response. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this quotation line. */
  [LineItem] [numeric](18,0) NOT NULL, /* 1 ASBIE Line Item ** The item that is the subject of this quotation line. */
  [SellerProposedSubstituteLineItem] [numeric](18,0) NULL, /* 0..n ASBIE Line Item ** An item proposed by the seller as a substitute for the item that is the subject of this quotation line. */
  [AlternativeLineItem] [numeric](18,0) NULL, /* 0..n ASBIE Line Item ** An item proposed by the seller as an alternative to the item that is the subject of this quotation line. */
  [RequestLineReference] [numeric](18,0) NULL, /* 0..1 ASBIE Line Reference ** A reference to the line in the Request for Quotation to which this line is a response. */
 CONSTRAINT [PK_QuotationLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QuotationLine_ID] ON [dbo].[QuotationLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QuotationLine_Note] ON [dbo].[QuotationLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QuotationLine_Quantity] ON [dbo].[QuotationLine] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QuotationLine_LineExtensionAmount] ON [dbo].[QuotationLine] 
(
	[LineExtensionAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QuotationLine_TotalTaxAmount] ON [dbo].[QuotationLine] 
(
	[TotalTaxAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QuotationLine_RequestForQuotationLineID] ON [dbo].[QuotationLine] 
(
	[RequestForQuotationLineID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QuotationLine_DocumentReference] ON [dbo].[QuotationLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QuotationLine_LineItem] ON [dbo].[QuotationLine] 
(
	[LineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QuotationLine_SellerProposedSubstituteLineItem] ON [dbo].[QuotationLine] 
(
	[SellerProposedSubstituteLineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QuotationLine_AlternativeLineItem] ON [dbo].[QuotationLine] 
(
	[AlternativeLineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_QuotationLine_RequestLineReference] ON [dbo].[QuotationLine] 
(
	[RequestLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[RailTransport] Script Date: 2013-10-13 00:21z
A class defining details about a train wagon used as a means of transport.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RailTransport](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [TrainID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the train used as the means of transport. */
  [RailCarID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the rail car on the train used as the means of transport. */
 CONSTRAINT [PK_RailTransport] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RailTransport_TrainID] ON [dbo].[RailTransport] 
(
	[TrainID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RailTransport_RailCarID] ON [dbo].[RailTransport] 
(
	[RailCarID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ReceiptLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Receipt Advice.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ReceiptLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this receipt line. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this receipt line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [ReceivedQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity received. */
  [ShortQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity received short; the difference between the quantity reported despatched and the quantity actually received. */
  [ShortageActionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the action that the delivery party wishes the despatch party to take as the result of a shortage. */
  [RejectedQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity rejected. */
  [RejectReasonCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The reason for a rejection, expressed as a code. */
  [RejectReason] [numeric](18,0) NULL, /* 0..n BBIE Text ** The reason for a rejection, expressed as text. */
  [RejectActionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the action that the delivery party wishes the despatch party to take as the result of a rejection. */
  [QuantityDiscrepancyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of a discrepancy in quantity. */
  [OversupplyQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity over-supplied, i.e., the quantity over and above the quantity ordered. */
  [ReceivedDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which the goods or services were received. */
  [TimingComplaintCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A complaint about the timing of delivery, expressed as a code. */
  [TimingComplaint] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A complaint about the timing of delivery, expressed as text. */
  [OrderLineReference] [numeric](18,0) NULL, /* 0..1 ASBIE Order Line Reference ** A reference to the order line associated with this receipt line. */
  [DespatchLineReference] [numeric](18,0) NULL, /* 0..n ASBIE Line Reference ** A reference to a despatch line associated with this receipt line. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this receipt line. */
  [Item] [numeric](18,0) NULL, /* 0..n ASBIE Item ** An item associated with this receipt line. */
  [Shipment] [numeric](18,0) NULL, /* 0..n ASBIE Shipment ** A shipment associated with this receipt line. */
 CONSTRAINT [PK_ReceiptLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_ID] ON [dbo].[ReceiptLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_UUID] ON [dbo].[ReceiptLine] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_Note] ON [dbo].[ReceiptLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_ReceivedQuantity] ON [dbo].[ReceiptLine] 
(
	[ReceivedQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_ShortQuantity] ON [dbo].[ReceiptLine] 
(
	[ShortQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_ShortageActionCode] ON [dbo].[ReceiptLine] 
(
	[ShortageActionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_RejectedQuantity] ON [dbo].[ReceiptLine] 
(
	[RejectedQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_RejectReasonCode] ON [dbo].[ReceiptLine] 
(
	[RejectReasonCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_RejectReason] ON [dbo].[ReceiptLine] 
(
	[RejectReason] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_RejectActionCode] ON [dbo].[ReceiptLine] 
(
	[RejectActionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_QuantityDiscrepancyCode] ON [dbo].[ReceiptLine] 
(
	[QuantityDiscrepancyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_OversupplyQuantity] ON [dbo].[ReceiptLine] 
(
	[OversupplyQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_ReceivedDate] ON [dbo].[ReceiptLine] 
(
	[ReceivedDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_TimingComplaintCode] ON [dbo].[ReceiptLine] 
(
	[TimingComplaintCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_TimingComplaint] ON [dbo].[ReceiptLine] 
(
	[TimingComplaint] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_OrderLineReference] ON [dbo].[ReceiptLine] 
(
	[OrderLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_DespatchLineReference] ON [dbo].[ReceiptLine] 
(
	[DespatchLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_DocumentReference] ON [dbo].[ReceiptLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_Item] ON [dbo].[ReceiptLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceiptLine_Shipment] ON [dbo].[ReceiptLine] 
(
	[Shipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Regulation] Script Date: 2013-10-13 00:21z
A class to describe a regulation.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Regulation](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Name] [numeric](18,0) NOT NULL, /* 1 BBIE Name ** A name for this regulation. */
  [LegalReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Text describing a legal reference. */
  [OntologyURI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The Uniform Resource Identifier (URI) of an ontology related to this regulation. */
 CONSTRAINT [PK_Regulation] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Regulation_Name] ON [dbo].[Regulation] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Regulation_LegalReference] ON [dbo].[Regulation] 
(
	[LegalReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Regulation_OntologyURI] ON [dbo].[Regulation] 
(
	[OntologyURI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[RelatedItem] Script Date: 2013-10-13 00:21z
A class to describe the relationship to an item different from the item associated with the item line in which RelatedItem is used.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RelatedItem](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the related item. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity that applies to the relationship. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the relationship. */
 CONSTRAINT [PK_RelatedItem] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RelatedItem_ID] ON [dbo].[RelatedItem] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RelatedItem_Quantity] ON [dbo].[RelatedItem] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RelatedItem_Description] ON [dbo].[RelatedItem] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ReminderLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Reminder document.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ReminderLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this reminder line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this reminder line. */
  [BalanceBroughtForwardIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that this reminder line contains a balance brought forward (true) or does not (false). */
  [DebitLineAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount debited on this reminder line. */
  [CreditLineAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount credited on this reminder line. */
  [AccountingCostCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The buyer's accounting cost centre for this reminder line, expressed as a code. */
  [AccountingCost] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The buyer's accounting cost centre for this reminder line, expressed as text. */
  [PenaltySurchargePercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The penalty for late payment, expressed as a percentage. */
  [Amount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount on this reminder line. */
  [PaymentPurposeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the business purpose for this payment. */
  [ReminderPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period to which this reminder line applies. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this reminder line. */
  [ExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The rate of exchange between the currency of the Reminder and the currency of the document described in the BillingReference. */
 CONSTRAINT [PK_ReminderLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_ID] ON [dbo].[ReminderLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_Note] ON [dbo].[ReminderLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_UUID] ON [dbo].[ReminderLine] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_BalanceBroughtForwardIndicator] ON [dbo].[ReminderLine] 
(
	[BalanceBroughtForwardIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_DebitLineAmount] ON [dbo].[ReminderLine] 
(
	[DebitLineAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_CreditLineAmount] ON [dbo].[ReminderLine] 
(
	[CreditLineAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_AccountingCostCode] ON [dbo].[ReminderLine] 
(
	[AccountingCostCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_AccountingCost] ON [dbo].[ReminderLine] 
(
	[AccountingCost] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_PenaltySurchargePercent] ON [dbo].[ReminderLine] 
(
	[PenaltySurchargePercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_Amount] ON [dbo].[ReminderLine] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_PaymentPurposeCode] ON [dbo].[ReminderLine] 
(
	[PaymentPurposeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_ReminderPeriod] ON [dbo].[ReminderLine] 
(
	[ReminderPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_BillingReference] ON [dbo].[ReminderLine] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReminderLine_ExchangeRate] ON [dbo].[ReminderLine] 
(
	[ExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[RemittanceAdviceLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Remittance Advice.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RemittanceAdviceLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this remittance advice line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this remittance advice line. */
  [DebitLineAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount debited on this remittance advice line. */
  [CreditLineAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount credited on this remittance advice line. */
  [BalanceAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary balance associated with this remittance advice line. */
  [PaymentPurposeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the business purpose for this payment. */
  [InvoicingPartyReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A reference to the order for payment used by the invoicing party. This may have been requested of the payer by the payee to accompany its remittance. */
  [AccountingSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The Accounting Supplier Party related to the remittance information reported on this Remittance Advice Line. */
  [AccountingCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The Accounting Customer Party related to the remittance information reported on this Remittance Advice Line. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer associated with this remittance advice line. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller/supplier associated with this remittance advice line. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The originating party. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payee. */
  [InvoicePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** An invoice period to which this remittance advice line applies. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this remittance advice line. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this remittance advice line. */
  [ExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The rate of exchange between the currency of the Remittance Advice and the currency of the document described in the BillingReference. */
 CONSTRAINT [PK_RemittanceAdviceLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_ID] ON [dbo].[RemittanceAdviceLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_Note] ON [dbo].[RemittanceAdviceLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_UUID] ON [dbo].[RemittanceAdviceLine] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_DebitLineAmount] ON [dbo].[RemittanceAdviceLine] 
(
	[DebitLineAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_CreditLineAmount] ON [dbo].[RemittanceAdviceLine] 
(
	[CreditLineAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_BalanceAmount] ON [dbo].[RemittanceAdviceLine] 
(
	[BalanceAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_PaymentPurposeCode] ON [dbo].[RemittanceAdviceLine] 
(
	[PaymentPurposeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_InvoicingPartyReference] ON [dbo].[RemittanceAdviceLine] 
(
	[InvoicingPartyReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_AccountingSupplierParty] ON [dbo].[RemittanceAdviceLine] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_AccountingCustomerParty] ON [dbo].[RemittanceAdviceLine] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_BuyerCustomerParty] ON [dbo].[RemittanceAdviceLine] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_SellerSupplierParty] ON [dbo].[RemittanceAdviceLine] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_OriginatorCustomerParty] ON [dbo].[RemittanceAdviceLine] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_PayeeParty] ON [dbo].[RemittanceAdviceLine] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_InvoicePeriod] ON [dbo].[RemittanceAdviceLine] 
(
	[InvoicePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_BillingReference] ON [dbo].[RemittanceAdviceLine] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_DocumentReference] ON [dbo].[RemittanceAdviceLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RemittanceAdviceLine_ExchangeRate] ON [dbo].[RemittanceAdviceLine] 
(
	[ExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Renewal] Script Date: 2013-10-13 00:21z
A class to describe the renewal of a commercial arrangement, such as a contract or licence fee.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Renewal](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Amount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount of this renewal. */
  [Period] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period for which the arrangement is now valid */
 CONSTRAINT [PK_Renewal] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Renewal_Amount] ON [dbo].[Renewal] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Renewal_Period] ON [dbo].[Renewal] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[RequestForQuotationLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Request for Quotation.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RequestForQuotationLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this line in the request for quotation. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this line in the request for quotation. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [OptionalLineItemIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication whether this line is optional (true) or not (false) for purposes of this request for quotation. */
  [PrivacyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the level of confidentiality of this request for quotation line. */
  [SecurityClassificationCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the security classification of this request for quotation line. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A document associated with this request for quotation line. */
  [LineItem] [numeric](18,0) NOT NULL, /* 1 ASBIE Line Item ** A description of the item for which a quotation is requested. */
 CONSTRAINT [PK_RequestForQuotationLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotationLine_ID] ON [dbo].[RequestForQuotationLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotationLine_UUID] ON [dbo].[RequestForQuotationLine] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotationLine_Note] ON [dbo].[RequestForQuotationLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotationLine_OptionalLineItemIndicator] ON [dbo].[RequestForQuotationLine] 
(
	[OptionalLineItemIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotationLine_PrivacyCode] ON [dbo].[RequestForQuotationLine] 
(
	[PrivacyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotationLine_SecurityClassificationCode] ON [dbo].[RequestForQuotationLine] 
(
	[SecurityClassificationCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotationLine_DocumentReference] ON [dbo].[RequestForQuotationLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForQuotationLine_LineItem] ON [dbo].[RequestForQuotationLine] 
(
	[LineItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[RequestForTenderLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Request for Tender describing an item of goods or a service solicited in the Request for Tender.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RequestForTenderLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this request for tender line. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this request for tender line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of the item for which a tender is requested in this line. */
  [MinimumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The minimum quantity of the item associated with this request for tender line. */
  [MaximumQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The maximum quantity of the item associated with this request for tender line. */
  [TaxIncludedIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether the amounts are taxes included (true) or not (false). */
  [MinimumAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The minimum amount allowed for this deliverable. */
  [MaximumAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The maximum amount allowed for this deliverable. */
  [EstimatedAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The estimated total amount of the deliverable. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this request for tender line. */
  [DeliveryPeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** An applicable period for the deliverable or set of deliverables in this tendering process. */
  [RequiredItemLocationQuantity] [numeric](18,0) NULL, /* 0..n ASBIE Item Location Quantity ** Properties of the item specified in this request for tender line that are dependent on location and quantity. */
  [WarrantyValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which a warranty to be associated with this request for tender line must apply. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** An item for which a tender is requested. */
  [SubRequestForTenderLine] [numeric](18,0) NULL, /* 0..n ASBIE Request For Tender Line ** A subsidiary request for tender line. */
 CONSTRAINT [PK_RequestForTenderLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_ID] ON [dbo].[RequestForTenderLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_UUID] ON [dbo].[RequestForTenderLine] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_Note] ON [dbo].[RequestForTenderLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_Quantity] ON [dbo].[RequestForTenderLine] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_MinimumQuantity] ON [dbo].[RequestForTenderLine] 
(
	[MinimumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_MaximumQuantity] ON [dbo].[RequestForTenderLine] 
(
	[MaximumQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_TaxIncludedIndicator] ON [dbo].[RequestForTenderLine] 
(
	[TaxIncludedIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_MinimumAmount] ON [dbo].[RequestForTenderLine] 
(
	[MinimumAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_MaximumAmount] ON [dbo].[RequestForTenderLine] 
(
	[MaximumAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_EstimatedAmount] ON [dbo].[RequestForTenderLine] 
(
	[EstimatedAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_DocumentReference] ON [dbo].[RequestForTenderLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_DeliveryPeriod] ON [dbo].[RequestForTenderLine] 
(
	[DeliveryPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_RequiredItemLocationQuantity] ON [dbo].[RequestForTenderLine] 
(
	[RequiredItemLocationQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_WarrantyValidityPeriod] ON [dbo].[RequestForTenderLine] 
(
	[WarrantyValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_Item] ON [dbo].[RequestForTenderLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestForTenderLine_SubRequestForTenderLine] ON [dbo].[RequestForTenderLine] 
(
	[SubRequestForTenderLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[RequestedTenderTotal] Script Date: 2013-10-13 00:21z
A class defining budgeted monetary amounts.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RequestedTenderTotal](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [EstimatedOverallContractAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The estimated overall monetary amount of a contract. */
  [TotalAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount of the total budget including net amount, taxes, and material and instalment costs.  */
  [TaxIncludedIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether the amounts are taxes included (true) or not (false). */
  [MinimumAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The minimum monetary amount of the budget. */
  [MaximumAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The maximum monetary amount of the budget. */
  [MonetaryScope] [numeric](18,0) NULL, /* 0..n BBIE Text ** A description of the monetary scope of the budget. */
  [AverageSubsequentContractAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The average monetary amount for the subsequent contracts following this budget amount. */
  [ApplicableTaxCategory] [numeric](18,0) NULL, /* 0..n ASBIE Tax Category ** Describes the categories of taxes that apply to the budget amount. */
 CONSTRAINT [PK_RequestedTenderTotal] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestedTenderTotal_EstimatedOverallContractAmount] ON [dbo].[RequestedTenderTotal] 
(
	[EstimatedOverallContractAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestedTenderTotal_TotalAmount] ON [dbo].[RequestedTenderTotal] 
(
	[TotalAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestedTenderTotal_TaxIncludedIndicator] ON [dbo].[RequestedTenderTotal] 
(
	[TaxIncludedIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestedTenderTotal_MinimumAmount] ON [dbo].[RequestedTenderTotal] 
(
	[MinimumAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestedTenderTotal_MaximumAmount] ON [dbo].[RequestedTenderTotal] 
(
	[MaximumAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestedTenderTotal_MonetaryScope] ON [dbo].[RequestedTenderTotal] 
(
	[MonetaryScope] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestedTenderTotal_AverageSubsequentContractAmount] ON [dbo].[RequestedTenderTotal] 
(
	[AverageSubsequentContractAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RequestedTenderTotal_ApplicableTaxCategory] ON [dbo].[RequestedTenderTotal] 
(
	[ApplicableTaxCategory] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Response] Script Date: 2013-10-13 00:21z
A class to describe an application-level response to a document.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Response](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ReferenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the section (or line) of the document to which this response applies. */
  [ResponseCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of response. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this response. */
  [EffectiveDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date upon which this response is valid. */
  [EffectiveTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this response is valid. */
  [Status] [numeric](18,0) NULL, /* 0..n ASBIE Status ** A status report associated with this response. */
 CONSTRAINT [PK_Response] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Response_ReferenceID] ON [dbo].[Response] 
(
	[ReferenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Response_ResponseCode] ON [dbo].[Response] 
(
	[ResponseCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Response_Description] ON [dbo].[Response] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Response_EffectiveDate] ON [dbo].[Response] 
(
	[EffectiveDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Response_EffectiveTime] ON [dbo].[Response] 
(
	[EffectiveTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Response_Status] ON [dbo].[Response] 
(
	[Status] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ResultOfVerification] Script Date: 2013-10-13 00:21z
A class to describe the result of an attempt to verify a signature.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ResultOfVerification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ValidatorID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the organization, person, service, or server that verified the signature. */
  [ValidationResultCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the result of the verification. */
  [ValidationDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date upon which verification took place. */
  [ValidationTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which verification took place. */
  [ValidateProcess] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The verification process. */
  [ValidateTool] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The tool used to verify the signature. */
  [ValidateToolVersion] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The version of the tool used to verify the signature. */
  [SignatoryParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The signing party. */
 CONSTRAINT [PK_ResultOfVerification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ResultOfVerification_ValidatorID] ON [dbo].[ResultOfVerification] 
(
	[ValidatorID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ResultOfVerification_ValidationResultCode] ON [dbo].[ResultOfVerification] 
(
	[ValidationResultCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ResultOfVerification_ValidationDate] ON [dbo].[ResultOfVerification] 
(
	[ValidationDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ResultOfVerification_ValidationTime] ON [dbo].[ResultOfVerification] 
(
	[ValidationTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ResultOfVerification_ValidateProcess] ON [dbo].[ResultOfVerification] 
(
	[ValidateProcess] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ResultOfVerification_ValidateTool] ON [dbo].[ResultOfVerification] 
(
	[ValidateTool] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ResultOfVerification_ValidateToolVersion] ON [dbo].[ResultOfVerification] 
(
	[ValidateToolVersion] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ResultOfVerification_SignatoryParty] ON [dbo].[ResultOfVerification] 
(
	[SignatoryParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[RetailPlannedImpact] Script Date: 2013-10-13 00:21z
A class to describe a planned effect of a retail event (e.g., a promotion or a change in inventory policy) upon supply or demand.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RetailPlannedImpact](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Amount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** Estimated monetary value of the planned event as an impact */
  [ForecastPurposeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** It will have impact on either Sales forecast or Order Forecast */
  [ForecastTypeCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the type of forecast. Examples of values are: BASE PROMOTIONAL SEASONAL TOTAL */
  [Period] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period to which this impact applies. */
 CONSTRAINT [PK_RetailPlannedImpact] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailPlannedImpact_Amount] ON [dbo].[RetailPlannedImpact] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailPlannedImpact_ForecastPurposeCode] ON [dbo].[RetailPlannedImpact] 
(
	[ForecastPurposeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailPlannedImpact_ForecastTypeCode] ON [dbo].[RetailPlannedImpact] 
(
	[ForecastTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RetailPlannedImpact_Period] ON [dbo].[RetailPlannedImpact] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[RoadTransport] Script Date: 2013-10-13 00:21z
A class for identifying a vehicle used for road transport.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RoadTransport](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [LicensePlateID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** The license plate identifier of this vehicle. */
 CONSTRAINT [PK_RoadTransport] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_RoadTransport_LicensePlateID] ON [dbo].[RoadTransport] 
(
	[LicensePlateID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[SalesItem] Script Date: 2013-10-13 00:21z
A class to describe information related to an item in a sales context
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[SalesItem](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Quantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The quantity the given information are related to */
  [ActivityProperty] [numeric](18,0) NULL, /* 0..n ASBIE Activity Property ** A class to describe the activity (for example "sales", "movement", ...) related to the item. */
  [TaxExclusivePrice] [numeric](18,0) NULL, /* 0..n ASBIE Price ** A price for this sales item, exclusive of tax. */
  [TaxInclusivePrice] [numeric](18,0) NULL, /* 0..n ASBIE Price ** A price for this sales item, including tax. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** The sales item itself. */
 CONSTRAINT [PK_SalesItem] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SalesItem_Quantity] ON [dbo].[SalesItem] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SalesItem_ActivityProperty] ON [dbo].[SalesItem] 
(
	[ActivityProperty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SalesItem_TaxExclusivePrice] ON [dbo].[SalesItem] 
(
	[TaxExclusivePrice] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SalesItem_TaxInclusivePrice] ON [dbo].[SalesItem] 
(
	[TaxInclusivePrice] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SalesItem_Item] ON [dbo].[SalesItem] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[SecondaryHazard] Script Date: 2013-10-13 00:21z
A class to describe a secondary hazard associated with a hazardous item.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[SecondaryHazard](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this secondary hazard. */
  [PlacardNotation] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Text of the placard notation corresponding to the hazard class of this secondary hazard. Can also be the hazard identification number of the orange placard (upper part) required on the means of transport. */
  [PlacardEndorsement] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Text of the placard endorsement for this secondary hazard that is to be shown on the shipping papers for a hazardous item. Can also be used for the number of the orange placard (lower part) required on the means of transport. */
  [EmergencyProceduresCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the emergency procedures for this secondary hazard. */
  [Extension] [numeric](18,0) NULL, /* 0..n BBIE Text ** Additional information about the hazardous substance, which can be used (for example) to specify the type of regulatory requirements that apply to this secondary hazard. */
 CONSTRAINT [PK_SecondaryHazard] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SecondaryHazard_ID] ON [dbo].[SecondaryHazard] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SecondaryHazard_PlacardNotation] ON [dbo].[SecondaryHazard] 
(
	[PlacardNotation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SecondaryHazard_PlacardEndorsement] ON [dbo].[SecondaryHazard] 
(
	[PlacardEndorsement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SecondaryHazard_EmergencyProceduresCode] ON [dbo].[SecondaryHazard] 
(
	[EmergencyProceduresCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SecondaryHazard_Extension] ON [dbo].[SecondaryHazard] 
(
	[Extension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ServiceFrequency] Script Date: 2013-10-13 00:21z
A class to specify which day of the week a transport service is operational.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ServiceFrequency](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [WeekDayCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A day of the week, expressed as code. */
 CONSTRAINT [PK_ServiceFrequency] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ServiceFrequency_WeekDayCode] ON [dbo].[ServiceFrequency] 
(
	[WeekDayCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ServiceProviderParty] Script Date: 2013-10-13 00:21z
A class to describe a party contracting to provide services, such as transportation, finance, etc.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ServiceProviderParty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this service provider. */
  [ServiceTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of service provided, expressed as a code. */
  [ServiceType] [numeric](18,0) NULL, /* 0..n BBIE Text ** The type of service provided, expressed as text. */
  [Party] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The party providing the service. */
  [SellerContact] [numeric](18,0) NULL, /* 0..1 ASBIE Contact ** The contact for the service provider. */
 CONSTRAINT [PK_ServiceProviderParty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ServiceProviderParty_ID] ON [dbo].[ServiceProviderParty] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ServiceProviderParty_ServiceTypeCode] ON [dbo].[ServiceProviderParty] 
(
	[ServiceTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ServiceProviderParty_ServiceType] ON [dbo].[ServiceProviderParty] 
(
	[ServiceType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ServiceProviderParty_Party] ON [dbo].[ServiceProviderParty] 
(
	[Party] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ServiceProviderParty_SellerContact] ON [dbo].[ServiceProviderParty] 
(
	[SellerContact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ShareholderParty] Script Date: 2013-10-13 00:21z
A class to describe a shareholder party.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ShareholderParty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [PartecipationPercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The shareholder participation, expressed as a percentage. */
  [Party] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The shareholder party. */
 CONSTRAINT [PK_ShareholderParty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShareholderParty_PartecipationPercent] ON [dbo].[ShareholderParty] 
(
	[PartecipationPercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShareholderParty_Party] ON [dbo].[ShareholderParty] 
(
	[Party] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Shipment] Script Date: 2013-10-13 00:21z
A class defining an identifiable collection of one or more goods items to be transported between the seller party and the buyer party. This information may be defined within a commercial contract. A shipment can be transported in different consignments (e.g., split for logistical purposes).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Shipment](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this shipment. */
  [ShippingPriorityLevelCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the priority or level of service required for this shipment. */
  [HandlingCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The handling required for this shipment, expressed as a code. */
  [HandlingInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** The handling required for this shipment, expressed as text. */
  [Information] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text pertinent to this shipment, conveying information that is not contained explicitly in other structures. */
  [GrossWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total gross weight of a shipment; the weight of the goods plus packaging plus transport equipment. */
  [NetWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The net weight of this shipment, excluding packaging. */
  [NetNetWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total net weight of this shipment, excluding packaging and transport equipment. */
  [GrossVolumeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total volume of the goods in this shipment, including packaging. */
  [NetVolumeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The total volume of the goods in this shipment, excluding packaging and transport equipment. */
  [TotalGoodsItemQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total number of goods items in this shipment. */
  [TotalTransportHandlingUnitQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of pieces of transport handling equipment (pallets, boxes, cases, etc.) in this shipment. */
  [InsuranceValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount covered by insurance for this shipment. */
  [DeclaredCustomsValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total declared value for customs purposes of those goods in this shipment that are subject to the same customs procedure and have the same tariff/statistical heading, country information, and duty regime. */
  [DeclaredForCarriageValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The value of this shipment, declared by the shipper or his agent solely for the purpose of varying the carrier's level of liability from that provided in the contract of carriage, in case of loss or damage to goods or delayed delivery. */
  [DeclaredStatisticsValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The value, declared for statistical purposes, of those goods in this shipment that have the same statistical heading. */
  [FreeOnBoardValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount that has to be or has been paid as calculated under the applicable trade delivery. */
  [SpecialInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Special instructions relating to this shipment. */
  [DeliveryInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Delivery instructions relating to this shipment. */
  [SplitConsignmentIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that the consignment has been split in transit (true) or not (false). */
  [ConsignmentQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total number of consignments within this shipment. */
  [Consignment] [numeric](18,0) NULL, /* 0..n ASBIE Consignment ** A consignment covering this shipment. */
  [GoodsItem] [numeric](18,0) NULL, /* 0..n ASBIE Goods Item ** A goods item included in this shipment. */
  [ShipmentStage] [numeric](18,0) NULL, /* 0..n ASBIE Shipment Stage ** A stage in the transport movement of this shipment. */
  [Delivery] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery ** The delivery of this shipment. */
  [TransportHandlingUnit] [numeric](18,0) NULL, /* 0..n ASBIE Transport Handling Unit ** A transport handling unit associated with this shipment. */
  [ReturnAddress] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The address to which a shipment should be returned. */
  [OriginAddress] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The region in which the goods have been produced or manufactured, according to criteria laid down for the purposes of application of the customs tariff, or of quantitative restrictions, or of any other measure related to trade. */
  [FirstArrivalPortLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The first arrival location of a shipment. This would be a port for sea, an airport for air, a terminal for rail, or a border post for land crossing. */
  [LastExitPortLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The final exporting location for a shipment. This would be a port for sea, an airport for air, a terminal for rail, or a border post for land crossing. */
  [ExportCountry] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country from which the goods were originally exported, without any commercial transaction taking place in intermediate countries. */
  [FreightAllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A cost incurred by the shipper in moving goods, by whatever means, from one place to another under the terms of the contract of carriage. In addition to transport costs, this may include such elements as packing, documentation, loading, unloading, and insurance to the extent that they relate to the freight costs. */
 CONSTRAINT [PK_Shipment] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_ID] ON [dbo].[Shipment] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_ShippingPriorityLevelCode] ON [dbo].[Shipment] 
(
	[ShippingPriorityLevelCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_HandlingCode] ON [dbo].[Shipment] 
(
	[HandlingCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_HandlingInstructions] ON [dbo].[Shipment] 
(
	[HandlingInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_Information] ON [dbo].[Shipment] 
(
	[Information] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_GrossWeightMeasure] ON [dbo].[Shipment] 
(
	[GrossWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_NetWeightMeasure] ON [dbo].[Shipment] 
(
	[NetWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_NetNetWeightMeasure] ON [dbo].[Shipment] 
(
	[NetNetWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_GrossVolumeMeasure] ON [dbo].[Shipment] 
(
	[GrossVolumeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_NetVolumeMeasure] ON [dbo].[Shipment] 
(
	[NetVolumeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_TotalGoodsItemQuantity] ON [dbo].[Shipment] 
(
	[TotalGoodsItemQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_TotalTransportHandlingUnitQuantity] ON [dbo].[Shipment] 
(
	[TotalTransportHandlingUnitQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_InsuranceValueAmount] ON [dbo].[Shipment] 
(
	[InsuranceValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_DeclaredCustomsValueAmount] ON [dbo].[Shipment] 
(
	[DeclaredCustomsValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_DeclaredForCarriageValueAmount] ON [dbo].[Shipment] 
(
	[DeclaredForCarriageValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_DeclaredStatisticsValueAmount] ON [dbo].[Shipment] 
(
	[DeclaredStatisticsValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_FreeOnBoardValueAmount] ON [dbo].[Shipment] 
(
	[FreeOnBoardValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_SpecialInstructions] ON [dbo].[Shipment] 
(
	[SpecialInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_DeliveryInstructions] ON [dbo].[Shipment] 
(
	[DeliveryInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_SplitConsignmentIndicator] ON [dbo].[Shipment] 
(
	[SplitConsignmentIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_ConsignmentQuantity] ON [dbo].[Shipment] 
(
	[ConsignmentQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_Consignment] ON [dbo].[Shipment] 
(
	[Consignment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_GoodsItem] ON [dbo].[Shipment] 
(
	[GoodsItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_ShipmentStage] ON [dbo].[Shipment] 
(
	[ShipmentStage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_Delivery] ON [dbo].[Shipment] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_TransportHandlingUnit] ON [dbo].[Shipment] 
(
	[TransportHandlingUnit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_ReturnAddress] ON [dbo].[Shipment] 
(
	[ReturnAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_OriginAddress] ON [dbo].[Shipment] 
(
	[OriginAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_FirstArrivalPortLocation] ON [dbo].[Shipment] 
(
	[FirstArrivalPortLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_LastExitPortLocation] ON [dbo].[Shipment] 
(
	[LastExitPortLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_ExportCountry] ON [dbo].[Shipment] 
(
	[ExportCountry] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Shipment_FreightAllowanceCharge] ON [dbo].[Shipment] 
(
	[FreightAllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[ShipmentStage] Script Date: 2013-10-13 00:21z
A class to describe one stage of movement in a transport of goods.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ShipmentStage](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this shipment stage. */
  [TransportModeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the method of transport used for this shipment stage. */
  [TransportMeansTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the kind of transport means (truck, vessel, etc.) used for this shipment stage. */
  [TransitDirectionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the direction of transit in this shipment stage. */
  [PreCarriageIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this stage takes place before the main carriage of the shipment (true) or not (false). */
  [OnCarriageIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this stage takes place after the main carriage of the shipment (true) or not (false). */
  [EstimatedDeliveryDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The estimated date of delivery in this shipment stage. */
  [EstimatedDeliveryTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The estimated time of delivery in this shipment stage. */
  [RequiredDeliveryDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The delivery date required by the buyer in this shipment stage. */
  [RequiredDeliveryTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The delivery time required by the buyer in this shipment stage. */
  [LoadingSequenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the loading sequence (of consignments) associated with this shipment stage. */
  [SuccessiveSequenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** Identifies the successive loading sequence (of consignments) associated with a shipment stage. */
  [Instructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text of instructions applicable to a shipment stage. */
  [DemurrageInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text of instructions relating to demurrage (the case in which a vessel is prevented from loading or discharging cargo within the stipulated laytime). */
  [CrewQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total number of crew aboard a transport means. */
  [PassengerQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total number of passengers aboard a transport means. */
  [TransitPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which this shipment stage actually took place. */
  [CarrierParty] [numeric](18,0) NULL, /* 0..n ASBIE Party ** A carrier party responsible for this shipment stage. */
  [TransportMeans] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Means ** The means of transport used in this shipment stage. */
  [LoadingPortLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location of loading for a shipment stage. */
  [UnloadingPortLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location of unloading for a shipment stage. */
  [TransshipPortLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location of transshipment relating to a shipment stage. */
  [LoadingTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The loading of goods in this shipment stage. */
  [ExaminationTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The examination of shipments in this shipment stage. */
  [AvailabilityTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The making available of shipments in this shipment stage. */
  [ExportationTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The export event associated with this shipment stage. */
  [DischargeTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The discharge event associated with this shipment stage. */
  [WarehousingTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The warehousing event associated with this shipment stage. */
  [TakeoverTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The receiver's takeover of the goods in this shipment stage. */
  [OptionalTakeoverTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The optional takeover of the goods in this shipment stage. */
  [DropoffTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The dropping off of goods in this shipment stage. */
  [ActualPickupTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The pickup of goods in this shipment stage. */
  [DeliveryTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The delivery of goods in this shipment stage. */
  [ReceiptTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The receipt of goods in this shipment stage. */
  [StorageTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The storage of goods in this shipment stage. */
  [AcceptanceTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The acceptance of goods in this shipment stage. */
  [TerminalOperatorParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A terminal operator associated with this shipment stage. */
  [CustomsAgentParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A customs agent associated with this shipment stage. */
  [EstimatedTransitPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The estimated transit period of this shipment stage. */
  [FreightAllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A freight allowance charge for this shipment stage. */
  [FreightChargeLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location associated with a freight charge related to this shipment stage. */
  [DetentionTransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** The detention of a transport means during loading and unloading operations. */
  [RequestedDepartureTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The departure requested by the party requesting a transportation service. */
  [RequestedArrivalTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The arrival requested by the party requesting a transportation service. */
  [RequestedWaypointTransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** A waypoint requested by the party requesting a transportation service. */
  [PlannedDepartureTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The departure planned by the party providing a transportation service. */
  [PlannedArrivalTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The arrival planned by the party providing a transportation service. */
  [PlannedWaypointTransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** A waypoint planned by the party providing a transportation service. */
  [ActualDepartureTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The actual departure from a specific location during a transportation service. */
  [ActualWaypointTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The location of an actual waypoint during a transportation service. */
  [ActualArrivalTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The actual arrival at a specific location during a transportation service. */
  [TransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** A significant occurrence in the course of this shipment of goods. */
  [EstimatedDepartureTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** Describes an estimated departure at a location during a transport service. */
  [EstimatedArrivalTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** Describes an estimated arrival at a location during a transport service. */
  [PassengerPerson] [numeric](18,0) NULL, /* 0..n ASBIE Person ** A person who travels in a conveyance without participating in its operation. */
  [DriverPerson] [numeric](18,0) NULL, /* 0..n ASBIE Person ** Describes a person responsible for driving the transport means. */
  [ReportingPerson] [numeric](18,0) NULL, /* 0..1 ASBIE Person ** Describes a person being responsible for providing the required administrative reporting relating to a transport. */
  [CrewMemberPerson] [numeric](18,0) NULL, /* 0..n ASBIE Person ** A person operating or serving aboard a transport means. */
  [SecurityOfficerPerson] [numeric](18,0) NULL, /* 0..1 ASBIE Person ** The person on board the vessel, accountable to the master, designated by the company as responsible for the security of the ship, including implementation and maintenance of the ship security plan and for the liaison with the company security officer and the port facility security officers. */
  [MasterPerson] [numeric](18,0) NULL, /* 0..1 ASBIE Person ** The person responsible for the ship's safe and efficient operation, including cargo operations, navigation, crew management and for ensuring that the vessel complies with local and international laws, as well as company and flag state policies. */
  [ShipsSurgeonPerson] [numeric](18,0) NULL, /* 0..1 ASBIE Person ** The person responsible for the health of the people aboard a ship at sea. */
 CONSTRAINT [PK_ShipmentStage] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_ID] ON [dbo].[ShipmentStage] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_TransportModeCode] ON [dbo].[ShipmentStage] 
(
	[TransportModeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_TransportMeansTypeCode] ON [dbo].[ShipmentStage] 
(
	[TransportMeansTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_TransitDirectionCode] ON [dbo].[ShipmentStage] 
(
	[TransitDirectionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_PreCarriageIndicator] ON [dbo].[ShipmentStage] 
(
	[PreCarriageIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_OnCarriageIndicator] ON [dbo].[ShipmentStage] 
(
	[OnCarriageIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_EstimatedDeliveryDate] ON [dbo].[ShipmentStage] 
(
	[EstimatedDeliveryDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_EstimatedDeliveryTime] ON [dbo].[ShipmentStage] 
(
	[EstimatedDeliveryTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_RequiredDeliveryDate] ON [dbo].[ShipmentStage] 
(
	[RequiredDeliveryDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_RequiredDeliveryTime] ON [dbo].[ShipmentStage] 
(
	[RequiredDeliveryTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_LoadingSequenceID] ON [dbo].[ShipmentStage] 
(
	[LoadingSequenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_SuccessiveSequenceID] ON [dbo].[ShipmentStage] 
(
	[SuccessiveSequenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_Instructions] ON [dbo].[ShipmentStage] 
(
	[Instructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_DemurrageInstructions] ON [dbo].[ShipmentStage] 
(
	[DemurrageInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_CrewQuantity] ON [dbo].[ShipmentStage] 
(
	[CrewQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_PassengerQuantity] ON [dbo].[ShipmentStage] 
(
	[PassengerQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_TransitPeriod] ON [dbo].[ShipmentStage] 
(
	[TransitPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_CarrierParty] ON [dbo].[ShipmentStage] 
(
	[CarrierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_TransportMeans] ON [dbo].[ShipmentStage] 
(
	[TransportMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_LoadingPortLocation] ON [dbo].[ShipmentStage] 
(
	[LoadingPortLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_UnloadingPortLocation] ON [dbo].[ShipmentStage] 
(
	[UnloadingPortLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_TransshipPortLocation] ON [dbo].[ShipmentStage] 
(
	[TransshipPortLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_LoadingTransportEvent] ON [dbo].[ShipmentStage] 
(
	[LoadingTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_ExaminationTransportEvent] ON [dbo].[ShipmentStage] 
(
	[ExaminationTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_AvailabilityTransportEvent] ON [dbo].[ShipmentStage] 
(
	[AvailabilityTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_ExportationTransportEvent] ON [dbo].[ShipmentStage] 
(
	[ExportationTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_DischargeTransportEvent] ON [dbo].[ShipmentStage] 
(
	[DischargeTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_WarehousingTransportEvent] ON [dbo].[ShipmentStage] 
(
	[WarehousingTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_TakeoverTransportEvent] ON [dbo].[ShipmentStage] 
(
	[TakeoverTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_OptionalTakeoverTransportEvent] ON [dbo].[ShipmentStage] 
(
	[OptionalTakeoverTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_DropoffTransportEvent] ON [dbo].[ShipmentStage] 
(
	[DropoffTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_ActualPickupTransportEvent] ON [dbo].[ShipmentStage] 
(
	[ActualPickupTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_DeliveryTransportEvent] ON [dbo].[ShipmentStage] 
(
	[DeliveryTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_ReceiptTransportEvent] ON [dbo].[ShipmentStage] 
(
	[ReceiptTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_StorageTransportEvent] ON [dbo].[ShipmentStage] 
(
	[StorageTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_AcceptanceTransportEvent] ON [dbo].[ShipmentStage] 
(
	[AcceptanceTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_TerminalOperatorParty] ON [dbo].[ShipmentStage] 
(
	[TerminalOperatorParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_CustomsAgentParty] ON [dbo].[ShipmentStage] 
(
	[CustomsAgentParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_EstimatedTransitPeriod] ON [dbo].[ShipmentStage] 
(
	[EstimatedTransitPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_FreightAllowanceCharge] ON [dbo].[ShipmentStage] 
(
	[FreightAllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_FreightChargeLocation] ON [dbo].[ShipmentStage] 
(
	[FreightChargeLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_DetentionTransportEvent] ON [dbo].[ShipmentStage] 
(
	[DetentionTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_RequestedDepartureTransportEvent] ON [dbo].[ShipmentStage] 
(
	[RequestedDepartureTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_RequestedArrivalTransportEvent] ON [dbo].[ShipmentStage] 
(
	[RequestedArrivalTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_RequestedWaypointTransportEvent] ON [dbo].[ShipmentStage] 
(
	[RequestedWaypointTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_PlannedDepartureTransportEvent] ON [dbo].[ShipmentStage] 
(
	[PlannedDepartureTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_PlannedArrivalTransportEvent] ON [dbo].[ShipmentStage] 
(
	[PlannedArrivalTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_PlannedWaypointTransportEvent] ON [dbo].[ShipmentStage] 
(
	[PlannedWaypointTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_ActualDepartureTransportEvent] ON [dbo].[ShipmentStage] 
(
	[ActualDepartureTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_ActualWaypointTransportEvent] ON [dbo].[ShipmentStage] 
(
	[ActualWaypointTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_ActualArrivalTransportEvent] ON [dbo].[ShipmentStage] 
(
	[ActualArrivalTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_TransportEvent] ON [dbo].[ShipmentStage] 
(
	[TransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_EstimatedDepartureTransportEvent] ON [dbo].[ShipmentStage] 
(
	[EstimatedDepartureTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_EstimatedArrivalTransportEvent] ON [dbo].[ShipmentStage] 
(
	[EstimatedArrivalTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_PassengerPerson] ON [dbo].[ShipmentStage] 
(
	[PassengerPerson] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_DriverPerson] ON [dbo].[ShipmentStage] 
(
	[DriverPerson] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_ReportingPerson] ON [dbo].[ShipmentStage] 
(
	[ReportingPerson] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_CrewMemberPerson] ON [dbo].[ShipmentStage] 
(
	[CrewMemberPerson] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_SecurityOfficerPerson] ON [dbo].[ShipmentStage] 
(
	[SecurityOfficerPerson] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_MasterPerson] ON [dbo].[ShipmentStage] 
(
	[MasterPerson] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ShipmentStage_ShipsSurgeonPerson] ON [dbo].[ShipmentStage] 
(
	[ShipsSurgeonPerson] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Signature] Script Date: 2013-10-13 00:21z
A class to define a signature.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Signature](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this signature. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures; in particular, information regarding the circumstances in which the signature is being used. */
  [ValidationDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date upon which this signature was verified. */
  [ValidationTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this signature was verified. */
  [ValidatorID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the organization, person, service, or server that verified this signature. */
  [CanonicalizationMethod] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The method used to perform XML canonicalization of this signature. */
  [SignatureMethod] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Text describing the method of signature. */
  [SignatoryParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The signing party. */
  [DigitalSignatureAttachment] [numeric](18,0) NULL, /* 0..1 ASBIE Attachment ** The actual encoded signature (e.g., in XMLDsig format). */
  [OriginalDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the document that the signature applies to. For evidentiary purposes, this may be the document image that the signatory party saw when applying their signature. */
 CONSTRAINT [PK_Signature] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Signature_ID] ON [dbo].[Signature] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Signature_Note] ON [dbo].[Signature] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Signature_ValidationDate] ON [dbo].[Signature] 
(
	[ValidationDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Signature_ValidationTime] ON [dbo].[Signature] 
(
	[ValidationTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Signature_ValidatorID] ON [dbo].[Signature] 
(
	[ValidatorID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Signature_CanonicalizationMethod] ON [dbo].[Signature] 
(
	[CanonicalizationMethod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Signature_SignatureMethod] ON [dbo].[Signature] 
(
	[SignatureMethod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Signature_SignatoryParty] ON [dbo].[Signature] 
(
	[SignatoryParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Signature_DigitalSignatureAttachment] ON [dbo].[Signature] 
(
	[DigitalSignatureAttachment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Signature_OriginalDocumentReference] ON [dbo].[Signature] 
(
	[OriginalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[StatementLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Statement of account.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[StatementLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this statement line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [UUID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A universally unique identifier for this statement line. */
  [BalanceBroughtForwardIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication that this statement line contains an outstanding balance from the previous bill(s) (true) or does not (false). */
  [DebitLineAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount debited on this statement line. */
  [CreditLineAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount credited on this statement line. */
  [BalanceAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The balance amount on this statement line. */
  [PaymentPurposeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the business purpose for this payment. */
  [PaymentMeans] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Means ** A means of payment associated with this statement line. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A specification of payment terms associated with this statement line. */
  [BuyerCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The buyer associated with this statement line. */
  [SellerSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The seller/supplier associated with this statement line. */
  [OriginatorCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The originating party. */
  [AccountingCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Customer Party ** The Accounting Customer Party related to the statement information reported on this Statement Line. */
  [AccountingSupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The Accounting Supplier Party related to the statement information reported on this Statement Line. */
  [PayeeParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The payee. */
  [InvoicePeriod] [numeric](18,0) NULL, /* 0..n ASBIE Period ** An invoice period to which this statement line applies. */
  [BillingReference] [numeric](18,0) NULL, /* 0..n ASBIE Billing Reference ** A reference to a billing document associated with this statement line. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this statement line. */
  [ExchangeRate] [numeric](18,0) NULL, /* 0..1 ASBIE Exchange Rate ** The rate of exchange between the currency of the Statement and the currency of the document described in the BillingReference. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A charge or discount price component associated with this statement line. */
  [CollectedPayment] [numeric](18,0) NULL, /* 0..n ASBIE Payment ** A collected payment. */
 CONSTRAINT [PK_StatementLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_ID] ON [dbo].[StatementLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_Note] ON [dbo].[StatementLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_UUID] ON [dbo].[StatementLine] 
(
	[UUID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_BalanceBroughtForwardIndicator] ON [dbo].[StatementLine] 
(
	[BalanceBroughtForwardIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_DebitLineAmount] ON [dbo].[StatementLine] 
(
	[DebitLineAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_CreditLineAmount] ON [dbo].[StatementLine] 
(
	[CreditLineAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_BalanceAmount] ON [dbo].[StatementLine] 
(
	[BalanceAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_PaymentPurposeCode] ON [dbo].[StatementLine] 
(
	[PaymentPurposeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_PaymentMeans] ON [dbo].[StatementLine] 
(
	[PaymentMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_PaymentTerms] ON [dbo].[StatementLine] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_BuyerCustomerParty] ON [dbo].[StatementLine] 
(
	[BuyerCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_SellerSupplierParty] ON [dbo].[StatementLine] 
(
	[SellerSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_OriginatorCustomerParty] ON [dbo].[StatementLine] 
(
	[OriginatorCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_AccountingCustomerParty] ON [dbo].[StatementLine] 
(
	[AccountingCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_AccountingSupplierParty] ON [dbo].[StatementLine] 
(
	[AccountingSupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_PayeeParty] ON [dbo].[StatementLine] 
(
	[PayeeParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_InvoicePeriod] ON [dbo].[StatementLine] 
(
	[InvoicePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_BillingReference] ON [dbo].[StatementLine] 
(
	[BillingReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_DocumentReference] ON [dbo].[StatementLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_ExchangeRate] ON [dbo].[StatementLine] 
(
	[ExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_AllowanceCharge] ON [dbo].[StatementLine] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StatementLine_CollectedPayment] ON [dbo].[StatementLine] 
(
	[CollectedPayment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Status] Script Date: 2013-10-13 00:21z
A class to describe the condition or position of an object.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Status](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ConditionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Specifies the status condition of the related object. */
  [ReferenceDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The reference date for this status. */
  [ReferenceTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The reference time for this status. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this status. */
  [StatusReasonCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The reason for this status condition or position, expressed as a code. */
  [StatusReason] [numeric](18,0) NULL, /* 0..n BBIE Text ** The reason for this status condition or position, expressed as text. */
  [SequenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** A sequence identifier for this status. */
  [Text] [numeric](18,0) NULL, /* 0..n BBIE Text ** Provides any textual information related to this status. */
  [IndicationIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Specifies an indicator relevant to a specific status. */
  [Percent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** A percentage meaningful in the context of this status. */
  [ReliabilityPercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The reliability of this status, expressed as a percentage. */
  [Condition] [numeric](18,0) NULL, /* 0..n ASBIE Condition ** Measurements that quantify the condition of the objects covered by the status. */
 CONSTRAINT [PK_Status] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_ConditionCode] ON [dbo].[Status] 
(
	[ConditionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_ReferenceDate] ON [dbo].[Status] 
(
	[ReferenceDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_ReferenceTime] ON [dbo].[Status] 
(
	[ReferenceTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_Description] ON [dbo].[Status] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_StatusReasonCode] ON [dbo].[Status] 
(
	[StatusReasonCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_StatusReason] ON [dbo].[Status] 
(
	[StatusReason] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_SequenceID] ON [dbo].[Status] 
(
	[SequenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_Text] ON [dbo].[Status] 
(
	[Text] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_IndicationIndicator] ON [dbo].[Status] 
(
	[IndicationIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_Percent] ON [dbo].[Status] 
(
	[Percent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_ReliabilityPercent] ON [dbo].[Status] 
(
	[ReliabilityPercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Status_Condition] ON [dbo].[Status] 
(
	[Condition] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[StockAvailabilityReportLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Stock Availability Report describing the availability of an item of sale.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[StockAvailabilityReportLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this stock availability line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [Quantity] [numeric](18,0) NOT NULL, /* 1 BBIE Quantity ** The quantity of the item currently in stock. */
  [ValueAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary value of the quantity of the item currently in stock. */
  [AvailabilityDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date from which the item will be available. A date identical to or earlier than the IssueDate of the Stock Availability Report means that the item is available now */
  [AvailabilityStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the level of availability of the item. */
  [Item] [numeric](18,0) NOT NULL, /* 1 ASBIE Item ** The item associated with this stock availability report line. */
 CONSTRAINT [PK_StockAvailabilityReportLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReportLine_ID] ON [dbo].[StockAvailabilityReportLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReportLine_Note] ON [dbo].[StockAvailabilityReportLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReportLine_Quantity] ON [dbo].[StockAvailabilityReportLine] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReportLine_ValueAmount] ON [dbo].[StockAvailabilityReportLine] 
(
	[ValueAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReportLine_AvailabilityDate] ON [dbo].[StockAvailabilityReportLine] 
(
	[AvailabilityDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReportLine_AvailabilityStatusCode] ON [dbo].[StockAvailabilityReportLine] 
(
	[AvailabilityStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_StockAvailabilityReportLine_Item] ON [dbo].[StockAvailabilityReportLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Stowage] Script Date: 2013-10-13 00:21z
A class to describe a location on board a means of transport where specified goods or transport equipment have been stowed or are to be stowed.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Stowage](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [LocationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the location. */
  [Location] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the location. */
  [MeasurementDimension] [numeric](18,0) NULL, /* 0..n ASBIE Dimension ** A measurable dimension (length, mass, weight, or volume) of this stowage. */
 CONSTRAINT [PK_Stowage] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Stowage_LocationID] ON [dbo].[Stowage] 
(
	[LocationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Stowage_Location] ON [dbo].[Stowage] 
(
	[Location] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Stowage_MeasurementDimension] ON [dbo].[Stowage] 
(
	[MeasurementDimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[SubcontractTerms] Script Date: 2013-10-13 00:21z
A class to describe subcontract terms for a tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[SubcontractTerms](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Rate] [numeric](18,0) NULL, /* 0..1 BBIE Rate ** MF: I agree with the query. Rate? */
  [UnknownPriceIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that the subcontract price is known (true) or not (false). */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the subcontract terms. */
  [Amount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary amount assigned to the subcontracted task. */
  [SubcontractingConditionsCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code specifying the conditions for subcontracting. */
  [MaximumPercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The maximum percentage allowed to be subcontracted. */
  [MinimumPercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The minimum percentage allowed to be subcontracted. */
 CONSTRAINT [PK_SubcontractTerms] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubcontractTerms_Rate] ON [dbo].[SubcontractTerms] 
(
	[Rate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubcontractTerms_UnknownPriceIndicator] ON [dbo].[SubcontractTerms] 
(
	[UnknownPriceIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubcontractTerms_Description] ON [dbo].[SubcontractTerms] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubcontractTerms_Amount] ON [dbo].[SubcontractTerms] 
(
	[Amount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubcontractTerms_SubcontractingConditionsCode] ON [dbo].[SubcontractTerms] 
(
	[SubcontractingConditionsCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubcontractTerms_MaximumPercent] ON [dbo].[SubcontractTerms] 
(
	[MaximumPercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubcontractTerms_MinimumPercent] ON [dbo].[SubcontractTerms] 
(
	[MinimumPercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[SubscriberConsumption] Script Date: 2013-10-13 00:21z
The consumption for a specific party for given consumption point provided by a numbers of suppliers. An enterprise can have one utility statement for several parties (e.g. a ministry of defence receiving a telephone bill). In this way each subscriber consumption represent a sub utility statement.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[SubscriberConsumption](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ConsumptionID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The identifier tor this specification. */
  [SpecificationTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The code which specifies the type of this specification, e.g. an on account specification or the yearly specification. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [TotalMeteredQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total quantity consumed, as calculated from meter readings. */
  [SubscriberParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party subscribing to the utility. */
  [UtilityConsumptionPoint] [numeric](18,0) NOT NULL, /* 1 ASBIE Consumption Point ** The point at which the utility is consumed. */
  [OnAccountPayment] [numeric](18,0) NULL, /* 0..n ASBIE On Account Payment ** The planned prepayments (on account) regarding this subscription. */
  [Consumption] [numeric](18,0) NULL, /* 0..1 ASBIE Consumption ** The consumption in case the consumption is from one and only one supplier. */
  [SupplierConsumption] [numeric](18,0) NULL, /* 0..n ASBIE Supplier Consumption ** The consumption in case the consumption is from more than one supplier. */
 CONSTRAINT [PK_SubscriberConsumption] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubscriberConsumption_ConsumptionID] ON [dbo].[SubscriberConsumption] 
(
	[ConsumptionID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubscriberConsumption_SpecificationTypeCode] ON [dbo].[SubscriberConsumption] 
(
	[SpecificationTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubscriberConsumption_Note] ON [dbo].[SubscriberConsumption] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubscriberConsumption_TotalMeteredQuantity] ON [dbo].[SubscriberConsumption] 
(
	[TotalMeteredQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubscriberConsumption_SubscriberParty] ON [dbo].[SubscriberConsumption] 
(
	[SubscriberParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubscriberConsumption_UtilityConsumptionPoint] ON [dbo].[SubscriberConsumption] 
(
	[UtilityConsumptionPoint] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubscriberConsumption_OnAccountPayment] ON [dbo].[SubscriberConsumption] 
(
	[OnAccountPayment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubscriberConsumption_Consumption] ON [dbo].[SubscriberConsumption] 
(
	[Consumption] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SubscriberConsumption_SupplierConsumption] ON [dbo].[SubscriberConsumption] 
(
	[SupplierConsumption] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[SupplierConsumption] Script Date: 2013-10-13 00:21z
The consumption in case the consumption is for one and only one supplier.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[SupplierConsumption](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [UtilitySupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party supplying the utility. */
  [UtilityCustomerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The utility customer. */
  [Consumption] [numeric](18,0) NOT NULL, /* 1 ASBIE Consumption ** The consumption regarding this supplier */
  [Contract] [numeric](18,0) NULL, /* 0..1 ASBIE Contract ** A contract setting forth conditions regulating the consumption. */
  [ConsumptionLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Consumption Line ** The consumption of a utility product. */
 CONSTRAINT [PK_SupplierConsumption] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierConsumption_Description] ON [dbo].[SupplierConsumption] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierConsumption_UtilitySupplierParty] ON [dbo].[SupplierConsumption] 
(
	[UtilitySupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierConsumption_UtilityCustomerParty] ON [dbo].[SupplierConsumption] 
(
	[UtilityCustomerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierConsumption_Consumption] ON [dbo].[SupplierConsumption] 
(
	[Consumption] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierConsumption_Contract] ON [dbo].[SupplierConsumption] 
(
	[Contract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierConsumption_ConsumptionLine] ON [dbo].[SupplierConsumption] 
(
	[ConsumptionLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[SupplierParty] Script Date: 2013-10-13 00:21z
A class to describe a supplier party.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[SupplierParty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [CustomerAssignedAccountID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this supplier party, assigned by the customer. */
  [AdditionalAccountID] [numeric](18,0) NULL, /* 0..n BBIE Identifier ** An additional identifier for this supplier party. */
  [DataSendingCapability] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Text describing the supplier's ability to send invoice data via a purchase card provider (e.g., VISA, MasterCard, American Express). */
  [Party] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The supplier party itself. */
  [DespatchContact] [numeric](18,0) NULL, /* 0..1 ASBIE Contact ** A contact at this supplier party for despatches (pickups). */
  [AccountingContact] [numeric](18,0) NULL, /* 0..1 ASBIE Contact ** A contact at this supplier party for accounting. */
  [SellerContact] [numeric](18,0) NULL, /* 0..1 ASBIE Contact ** The primary contact for this supplier party. */
 CONSTRAINT [PK_SupplierParty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierParty_CustomerAssignedAccountID] ON [dbo].[SupplierParty] 
(
	[CustomerAssignedAccountID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierParty_AdditionalAccountID] ON [dbo].[SupplierParty] 
(
	[AdditionalAccountID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierParty_DataSendingCapability] ON [dbo].[SupplierParty] 
(
	[DataSendingCapability] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierParty_Party] ON [dbo].[SupplierParty] 
(
	[Party] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierParty_DespatchContact] ON [dbo].[SupplierParty] 
(
	[DespatchContact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierParty_AccountingContact] ON [dbo].[SupplierParty] 
(
	[AccountingContact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_SupplierParty_SellerContact] ON [dbo].[SupplierParty] 
(
	[SellerContact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TaxCategory] Script Date: 2013-10-13 00:21z
A class to describe one of the tax categories within a taxation scheme (e.g., High Rate VAT, Low Rate VAT).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TaxCategory](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this tax category. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this tax category. */
  [Percent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The tax rate for this category, expressed as a percentage. */
  [BaseUnitMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** A Unit of Measures used as the basic for the tax calculation applied at a certain rate per unit. */
  [PerUnitAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** Where a tax is applied at a certain rate per unit, the rate per unit applied. */
  [TaxExemptionReasonCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The reason for tax being exempted, expressed as a code. */
  [TaxExemptionReason] [numeric](18,0) NULL, /* 0..n BBIE Text ** The reason for tax being exempted, expressed as text. */
  [TierRange] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Where a tax is tiered, the range of taxable amounts that determines the rate of tax applicable to this tax category. */
  [TierRatePercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** Where a tax is tiered, the tax rate that applies within the specified range of taxable amounts for this tax category. */
  [TaxScheme] [numeric](18,0) NOT NULL, /* 1 ASBIE Tax Scheme ** The taxation scheme within which this tax category is defined. */
 CONSTRAINT [PK_TaxCategory] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxCategory_ID] ON [dbo].[TaxCategory] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxCategory_Name] ON [dbo].[TaxCategory] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxCategory_Percent] ON [dbo].[TaxCategory] 
(
	[Percent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxCategory_BaseUnitMeasure] ON [dbo].[TaxCategory] 
(
	[BaseUnitMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxCategory_PerUnitAmount] ON [dbo].[TaxCategory] 
(
	[PerUnitAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxCategory_TaxExemptionReasonCode] ON [dbo].[TaxCategory] 
(
	[TaxExemptionReasonCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxCategory_TaxExemptionReason] ON [dbo].[TaxCategory] 
(
	[TaxExemptionReason] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxCategory_TierRange] ON [dbo].[TaxCategory] 
(
	[TierRange] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxCategory_TierRatePercent] ON [dbo].[TaxCategory] 
(
	[TierRatePercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxCategory_TaxScheme] ON [dbo].[TaxCategory] 
(
	[TaxScheme] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TaxScheme] Script Date: 2013-10-13 00:21z
A class to describe a taxation scheme (e.g., VAT, State tax, County tax).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TaxScheme](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this taxation scheme. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this taxation scheme. */
  [TaxTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of tax. */
  [CurrencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the currency in which the tax is collected and reported. */
  [JurisdictionRegionAddress] [numeric](18,0) NULL, /* 0..n ASBIE Address ** A geographic area in which this taxation scheme applies. */
 CONSTRAINT [PK_TaxScheme] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxScheme_ID] ON [dbo].[TaxScheme] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxScheme_Name] ON [dbo].[TaxScheme] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxScheme_TaxTypeCode] ON [dbo].[TaxScheme] 
(
	[TaxTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxScheme_CurrencyCode] ON [dbo].[TaxScheme] 
(
	[CurrencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxScheme_JurisdictionRegionAddress] ON [dbo].[TaxScheme] 
(
	[JurisdictionRegionAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TaxSubtotal] Script Date: 2013-10-13 00:21z
A class to define the subtotal for a particular tax category within a particular taxation scheme, such as standard rate within VAT.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TaxSubtotal](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [TaxableAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The net amount to which the tax percent (rate) is applied to calculate the tax amount. */
  [TaxAmount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The amount of this tax subtotal. */
  [CalculationSequenceNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of this tax subtotal in the sequence of subtotals corresponding to the order in which multiple taxes are applied. If all taxes are applied to the same taxable amount (i.e., their order of application is inconsequential), then CalculationSequenceNumeric is 1 for all tax subtotals applied to a given amount. */
  [TransactionCurrencyTaxAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount of this tax subtotal, expressed in the currency used for invoicing. */
  [Percent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The tax rate of the tax category applied to this tax subtotal, expressed as a percentage. */
  [BaseUnitMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The unit of measure on which the tax calculation is based */
  [PerUnitAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** Where a tax is applied at a certain rate per unit, the rate per unit applied. */
  [TierRange] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Where a tax is tiered, the range of taxable amounts that determines the rate of tax applicable to this tax subtotal. */
  [TierRatePercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** Where a tax is tiered, the tax rate that applies within a specified range of taxable amounts for this tax subtotal. */
  [TaxCategory] [numeric](18,0) NOT NULL, /* 1 ASBIE Tax Category ** The tax category applicable to this subtotal. */
 CONSTRAINT [PK_TaxSubtotal] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxSubtotal_TaxableAmount] ON [dbo].[TaxSubtotal] 
(
	[TaxableAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxSubtotal_TaxAmount] ON [dbo].[TaxSubtotal] 
(
	[TaxAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxSubtotal_CalculationSequenceNumeric] ON [dbo].[TaxSubtotal] 
(
	[CalculationSequenceNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxSubtotal_TransactionCurrencyTaxAmount] ON [dbo].[TaxSubtotal] 
(
	[TransactionCurrencyTaxAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxSubtotal_Percent] ON [dbo].[TaxSubtotal] 
(
	[Percent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxSubtotal_BaseUnitMeasure] ON [dbo].[TaxSubtotal] 
(
	[BaseUnitMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxSubtotal_PerUnitAmount] ON [dbo].[TaxSubtotal] 
(
	[PerUnitAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxSubtotal_TierRange] ON [dbo].[TaxSubtotal] 
(
	[TierRange] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxSubtotal_TierRatePercent] ON [dbo].[TaxSubtotal] 
(
	[TierRatePercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxSubtotal_TaxCategory] ON [dbo].[TaxSubtotal] 
(
	[TaxCategory] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TaxTotal] Script Date: 2013-10-13 00:21z
A class to describe the total tax for a particular taxation scheme.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TaxTotal](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [TaxAmount] [numeric](18,0) NOT NULL, /* 1 BBIE Amount ** The total tax amount for a particular taxation scheme, e.g., VAT; the sum of the tax subtotals for each tax category within the taxation scheme. */
  [RoundingAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The rounding amount (positive or negative) added to the calculated tax total to produce the rounded TaxAmount. */
  [TaxEvidenceIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this total is recognized as legal evidence for taxation purposes (true) or not (false). */
  [TaxIncludedIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that tax is included in the calculation (true) or not (false). */
  [TaxSubtotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Subtotal ** One of the subtotals the sum of which equals the total tax amount for a particular taxation scheme. */
 CONSTRAINT [PK_TaxTotal] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxTotal_TaxAmount] ON [dbo].[TaxTotal] 
(
	[TaxAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxTotal_RoundingAmount] ON [dbo].[TaxTotal] 
(
	[RoundingAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxTotal_TaxEvidenceIndicator] ON [dbo].[TaxTotal] 
(
	[TaxEvidenceIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxTotal_TaxIncludedIndicator] ON [dbo].[TaxTotal] 
(
	[TaxIncludedIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TaxTotal_TaxSubtotal] ON [dbo].[TaxTotal] 
(
	[TaxSubtotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TelecommunicationsService] Script Date: 2013-10-13 00:21z
A class to describe a telecommunications service (e.g., a telephone call or a video on demand service).
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TelecommunicationsService](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this telecommunications service. */
  [CallDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** In the case of a telephone call, the date of the call. */
  [CallTime] [numeric](18,0) NOT NULL, /* 1 BBIE Time ** In the case of a telephone call, the time of the call. */
  [ServiceNumberCalled] [numeric](18,0) NOT NULL, /* 1 BBIE Text ** In the case of a telephone call, the phone number called. */
  [TelecommunicationsServiceCategory] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The telecommunications category, expressed as text. */
  [TelecommunicationsServiceCategoryCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The telecommunications category, expressed as a code. */
  [MovieTitle] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The title of a movie delivered via this telecommunications service. */
  [RoamingPartnerName] [numeric](18,0) NULL, /* 0..1 BBIE Name ** Statement of the roaming partner name. */
  [PayPerView] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A pay-per-view delivered via this telecommunications service. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of calls. */
  [TelecommunicationsServiceCall] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The telecommunications call described as a text */
  [TelecommunicationsServiceCallCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The telecommunications call described as a code */
  [CallBaseAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount to be payed as the base for one call */
  [CallExtensionAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount to be payed for the call */
  [Price] [numeric](18,0) NULL, /* 0..1 ASBIE Price ** The price for using the telecommunication service */
  [Country] [numeric](18,0) NULL, /* 0..1 ASBIE Country ** The country to which the service is provided. In case of a telephone call it is the country where the receiver is located. */
  [ExchangeRate] [numeric](18,0) NULL, /* 0..n ASBIE Exchange Rate ** A exchanges rates used in the pricing e.g.. when phone calls has crossed border lines. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** An allowance or charge that applies to the UtilityStatement as a whole. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** A total amount of taxes of a particular kind applicable to this telecommunications service. */
  [CallDuty] [numeric](18,0) NULL, /* 0..n ASBIE Duty ** In the case of a telephone call, a duty on this call. */
  [TimeDuty] [numeric](18,0) NULL, /* 0..n ASBIE Duty ** A duty on a consumption of time. */
 CONSTRAINT [PK_TelecommunicationsService] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_ID] ON [dbo].[TelecommunicationsService] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_CallDate] ON [dbo].[TelecommunicationsService] 
(
	[CallDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_CallTime] ON [dbo].[TelecommunicationsService] 
(
	[CallTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_ServiceNumberCalled] ON [dbo].[TelecommunicationsService] 
(
	[ServiceNumberCalled] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_TelecommunicationsServiceCategory] ON [dbo].[TelecommunicationsService] 
(
	[TelecommunicationsServiceCategory] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_TelecommunicationsServiceCategoryCode] ON [dbo].[TelecommunicationsService] 
(
	[TelecommunicationsServiceCategoryCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_MovieTitle] ON [dbo].[TelecommunicationsService] 
(
	[MovieTitle] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_RoamingPartnerName] ON [dbo].[TelecommunicationsService] 
(
	[RoamingPartnerName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_PayPerView] ON [dbo].[TelecommunicationsService] 
(
	[PayPerView] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_Quantity] ON [dbo].[TelecommunicationsService] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_TelecommunicationsServiceCall] ON [dbo].[TelecommunicationsService] 
(
	[TelecommunicationsServiceCall] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_TelecommunicationsServiceCallCode] ON [dbo].[TelecommunicationsService] 
(
	[TelecommunicationsServiceCallCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_CallBaseAmount] ON [dbo].[TelecommunicationsService] 
(
	[CallBaseAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_CallExtensionAmount] ON [dbo].[TelecommunicationsService] 
(
	[CallExtensionAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_Price] ON [dbo].[TelecommunicationsService] 
(
	[Price] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_Country] ON [dbo].[TelecommunicationsService] 
(
	[Country] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_ExchangeRate] ON [dbo].[TelecommunicationsService] 
(
	[ExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_AllowanceCharge] ON [dbo].[TelecommunicationsService] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_TaxTotal] ON [dbo].[TelecommunicationsService] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_CallDuty] ON [dbo].[TelecommunicationsService] 
(
	[CallDuty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsService_TimeDuty] ON [dbo].[TelecommunicationsService] 
(
	[TimeDuty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TelecommunicationsSupply] Script Date: 2013-10-13 00:21z
A class describing the supply of a telecommunication service, e.g., providing telephone calls.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TelecommunicationsSupply](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [TelecommunicationsSupplyType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The type of telecommunications supply, expressed as text. */
  [TelecommunicationsSupplyTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of telecommunications supply, expressed as a code. */
  [PrivacyCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the level of confidentiality of this information for this telecommunication supply. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the telecommunications supply. */
  [TotalAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total amount associated with this telecommunications supply. */
  [TelecommunicationsSupplyLine] [numeric](18,0) NOT NULL, /* 1..n ASBIE Telecommunications Supply Line ** Outlines the provided telecommunication supply */
 CONSTRAINT [PK_TelecommunicationsSupply] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupply_TelecommunicationsSupplyType] ON [dbo].[TelecommunicationsSupply] 
(
	[TelecommunicationsSupplyType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupply_TelecommunicationsSupplyTypeCode] ON [dbo].[TelecommunicationsSupply] 
(
	[TelecommunicationsSupplyTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupply_PrivacyCode] ON [dbo].[TelecommunicationsSupply] 
(
	[PrivacyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupply_Description] ON [dbo].[TelecommunicationsSupply] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupply_TotalAmount] ON [dbo].[TelecommunicationsSupply] 
(
	[TotalAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupply_TelecommunicationsSupplyLine] ON [dbo].[TelecommunicationsSupply] 
(
	[TelecommunicationsSupplyLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TelecommunicationsSupplyLine] Script Date: 2013-10-13 00:21z
A class that outlines the telecommunication supply in details
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TelecommunicationsSupplyLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this telecommunications supply line. */
  [PhoneNumber] [numeric](18,0) NOT NULL, /* 1 BBIE Text ** The phone number used for this telecommunication supply line */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** The description of the telecommunication supply line */
  [LineExtensionAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** An amount specifying the cost of this telecommunication line */
  [ExchangeRate] [numeric](18,0) NULL, /* 0..n ASBIE Exchange Rate ** Exchanges rates used to calculate the amount for this line. */
  [AllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** An allowance or charge that applies to this telecommunication supply line. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** A total amount of taxes of a particular kind applicable to this telecommunications supply line */
  [TelecommunicationsService] [numeric](18,0) NOT NULL, /* 1..n ASBIE Telecommunications Service ** A telecommunications service (e.g., a telephone call). */
 CONSTRAINT [PK_TelecommunicationsSupplyLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupplyLine_ID] ON [dbo].[TelecommunicationsSupplyLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupplyLine_PhoneNumber] ON [dbo].[TelecommunicationsSupplyLine] 
(
	[PhoneNumber] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupplyLine_Description] ON [dbo].[TelecommunicationsSupplyLine] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupplyLine_LineExtensionAmount] ON [dbo].[TelecommunicationsSupplyLine] 
(
	[LineExtensionAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupplyLine_ExchangeRate] ON [dbo].[TelecommunicationsSupplyLine] 
(
	[ExchangeRate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupplyLine_AllowanceCharge] ON [dbo].[TelecommunicationsSupplyLine] 
(
	[AllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupplyLine_TaxTotal] ON [dbo].[TelecommunicationsSupplyLine] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TelecommunicationsSupplyLine_TelecommunicationsService] ON [dbo].[TelecommunicationsSupplyLine] 
(
	[TelecommunicationsService] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Temperature] Script Date: 2013-10-13 00:21z
A class to describe a measurement of temperature.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Temperature](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [AttributeID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this temperature measurement. */
  [Measure] [numeric](18,0) NOT NULL, /* 1 BBIE Measure ** The value of this temperature measurement. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this temperature measurement. */
 CONSTRAINT [PK_Temperature] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Temperature_AttributeID] ON [dbo].[Temperature] 
(
	[AttributeID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Temperature_Measure] ON [dbo].[Temperature] 
(
	[Measure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Temperature_Description] ON [dbo].[Temperature] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TenderLine] Script Date: 2013-10-13 00:21z
A class to define a line in a Tender.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TenderLine](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this tender line. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [Quantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The quantity of the item quoted in this tender line. */
  [LineExtensionAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total amount for this tender line, including allowance charges but net of taxes. */
  [TotalTaxAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The total tax amount for this tender line. */
  [OrderableUnit] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Text describing a unit in which the item described in this tender line can be ordered. */
  [ContentUnitQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The unit of measure and quantity of the orderable unit. */
  [OrderQuantityIncrementNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of items that can set the order quantity increments. */
  [MinimumOrderQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The minimum number of items described in this tender line that can be ordered. */
  [MaximumOrderQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The maximum number of items described in this tender line that can be ordered. */
  [WarrantyInformation] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text about a warranty (provided by WarrantyParty) for the good or service described in this tender line. */
  [PackLevelCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A mutually agreed code signifying the level of packaging associated with the item described in this tender line. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this tender line. */
  [Item] [numeric](18,0) NULL, /* 0..1 ASBIE Item ** The item associated with this tender line. */
  [OfferedItemLocationQuantity] [numeric](18,0) NULL, /* 0..n ASBIE Item Location Quantity ** A set of location-specific properties (e.g., price, quantity, lead time) associated with the item described in this tender line. */
  [ReplacementRelatedItem] [numeric](18,0) NULL, /* 0..n ASBIE Related Item ** A catalogue item that may be a replacement for the item described in this tender line. */
  [WarrantyParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party responsible for any warranty described in this tender line. */
  [WarrantyValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period for which a warranty associated with the item described in this tender line is valid. */
  [SubTenderLine] [numeric](18,0) NULL, /* 0..n ASBIE Tender Line ** An association to a Sub Tender Line */
  [CallForTendersLineReference] [numeric](18,0) NULL, /* 0..1 ASBIE Line Reference ** Reference to a Line on a Call For Tenders document. */
  [CallForTendersDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A class defining references to a Call For Tenders document. */
 CONSTRAINT [PK_TenderLine] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_ID] ON [dbo].[TenderLine] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_Note] ON [dbo].[TenderLine] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_Quantity] ON [dbo].[TenderLine] 
(
	[Quantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_LineExtensionAmount] ON [dbo].[TenderLine] 
(
	[LineExtensionAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_TotalTaxAmount] ON [dbo].[TenderLine] 
(
	[TotalTaxAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_OrderableUnit] ON [dbo].[TenderLine] 
(
	[OrderableUnit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_ContentUnitQuantity] ON [dbo].[TenderLine] 
(
	[ContentUnitQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_OrderQuantityIncrementNumeric] ON [dbo].[TenderLine] 
(
	[OrderQuantityIncrementNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_MinimumOrderQuantity] ON [dbo].[TenderLine] 
(
	[MinimumOrderQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_MaximumOrderQuantity] ON [dbo].[TenderLine] 
(
	[MaximumOrderQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_WarrantyInformation] ON [dbo].[TenderLine] 
(
	[WarrantyInformation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_PackLevelCode] ON [dbo].[TenderLine] 
(
	[PackLevelCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_DocumentReference] ON [dbo].[TenderLine] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_Item] ON [dbo].[TenderLine] 
(
	[Item] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_OfferedItemLocationQuantity] ON [dbo].[TenderLine] 
(
	[OfferedItemLocationQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_ReplacementRelatedItem] ON [dbo].[TenderLine] 
(
	[ReplacementRelatedItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_WarrantyParty] ON [dbo].[TenderLine] 
(
	[WarrantyParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_WarrantyValidityPeriod] ON [dbo].[TenderLine] 
(
	[WarrantyValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_SubTenderLine] ON [dbo].[TenderLine] 
(
	[SubTenderLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_CallForTendersLineReference] ON [dbo].[TenderLine] 
(
	[CallForTendersLineReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderLine_CallForTendersDocumentReference] ON [dbo].[TenderLine] 
(
	[CallForTendersDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TenderPreparation] Script Date: 2013-10-13 00:21z
A class to describe directions for preparing a tender.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TenderPreparation](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [TenderEnvelopeID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for the tender envelope to be used with the tender. */
  [TenderEnvelopeTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of tender envelope (economical or objective criteria versus technical or subjective criteria). */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the tender envelope. */
  [OpenTenderID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the open tender associated with this tender preparation. */
  [ProcurementProjectLot] [numeric](18,0) NULL, /* 0..n ASBIE Procurement Project Lot ** The procurement project lot associated with a particular tenderer. */
  [DocumentTenderRequirement] [numeric](18,0) NULL, /* 0..n ASBIE Tender Requirement ** A reference to the template for a required document in a tendering process. */
 CONSTRAINT [PK_TenderPreparation] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderPreparation_TenderEnvelopeID] ON [dbo].[TenderPreparation] 
(
	[TenderEnvelopeID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderPreparation_TenderEnvelopeTypeCode] ON [dbo].[TenderPreparation] 
(
	[TenderEnvelopeTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderPreparation_Description] ON [dbo].[TenderPreparation] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderPreparation_OpenTenderID] ON [dbo].[TenderPreparation] 
(
	[OpenTenderID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderPreparation_ProcurementProjectLot] ON [dbo].[TenderPreparation] 
(
	[ProcurementProjectLot] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderPreparation_DocumentTenderRequirement] ON [dbo].[TenderPreparation] 
(
	[DocumentTenderRequirement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TenderRequirement] Script Date: 2013-10-13 00:21z
A template for a required document in a tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TenderRequirement](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Name] [numeric](18,0) NOT NULL, /* 1 BBIE Name ** A name of this tender requirement. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this tender requirement. */
  [TemplateDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the template for a required document. */
 CONSTRAINT [PK_TenderRequirement] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderRequirement_Name] ON [dbo].[TenderRequirement] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderRequirement_Description] ON [dbo].[TenderRequirement] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderRequirement_TemplateDocumentReference] ON [dbo].[TenderRequirement] 
(
	[TemplateDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TenderResult] Script Date: 2013-10-13 00:21z
A class to describe the awarding of a tender in a tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TenderResult](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [TenderResultCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the result of the tendering process. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the result of the tendering process. */
  [AdvertisementAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The monetary value of the advertisement for this tendering process.  */
  [AwardDate] [numeric](18,0) NOT NULL, /* 1 BBIE Date ** The date on which this result was formalized. */
  [AwardTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time at which this result was formalized. */
  [ReceivedTenderQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total number of tenders received in this tendering process. */
  [LowerTenderAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The least expensive tender received in the tendering process. */
  [HigherTenderAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The most expensive tender received in this tendering process. */
  [StartDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which the awarded contract begins. */
  [ReceivedElectronicTenderQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of electronic tenders received. */
  [ReceivedForeignTenderQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The number of foreing tenders received. */
  [Contract] [numeric](18,0) NULL, /* 0..1 ASBIE Contract ** A contract governing this tender result. */
  [AwardedTenderedProject] [numeric](18,0) NULL, /* 0..1 ASBIE Tendered Project ** The awarded tendered project associated with this tender result. */
  [ContractFormalizationPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which a contract associated with the awarded project is to be formalized. */
  [SubcontractTerms] [numeric](18,0) NULL, /* 0..n ASBIE Subcontract Terms ** Subcontract terms for this tender result. */
  [WinningParty] [numeric](18,0) NULL, /* 0..n ASBIE Winning Party ** A party that is identified as the awarded by a tender result. */
 CONSTRAINT [PK_TenderResult] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_TenderResultCode] ON [dbo].[TenderResult] 
(
	[TenderResultCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_Description] ON [dbo].[TenderResult] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_AdvertisementAmount] ON [dbo].[TenderResult] 
(
	[AdvertisementAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_AwardDate] ON [dbo].[TenderResult] 
(
	[AwardDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_AwardTime] ON [dbo].[TenderResult] 
(
	[AwardTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_ReceivedTenderQuantity] ON [dbo].[TenderResult] 
(
	[ReceivedTenderQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_LowerTenderAmount] ON [dbo].[TenderResult] 
(
	[LowerTenderAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_HigherTenderAmount] ON [dbo].[TenderResult] 
(
	[HigherTenderAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_StartDate] ON [dbo].[TenderResult] 
(
	[StartDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_ReceivedElectronicTenderQuantity] ON [dbo].[TenderResult] 
(
	[ReceivedElectronicTenderQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_ReceivedForeignTenderQuantity] ON [dbo].[TenderResult] 
(
	[ReceivedForeignTenderQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_Contract] ON [dbo].[TenderResult] 
(
	[Contract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_AwardedTenderedProject] ON [dbo].[TenderResult] 
(
	[AwardedTenderedProject] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_ContractFormalizationPeriod] ON [dbo].[TenderResult] 
(
	[ContractFormalizationPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_SubcontractTerms] ON [dbo].[TenderResult] 
(
	[SubcontractTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderResult_WinningParty] ON [dbo].[TenderResult] 
(
	[WinningParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TenderedProject] Script Date: 2013-10-13 00:21z
A class to describe a tendered project or project lot.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TenderedProject](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [VariantID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this variant of a tendered project. */
  [FeeAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The fee amount for tendered projects. */
  [FeeDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the fee amount for tendered projects. */
  [TenderEnvelopeID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the tender envelope this tendered project belongs to. */
  [TenderEnvelopeTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of tender envelope this tendered project belongs to. */
  [ProcurementProjectLot] [numeric](18,0) NULL, /* 0..1 ASBIE Procurement Project Lot ** The procurement project lot to which this Tender Line refers to. If there are no lots, this should not be defined. */
  [EvidenceDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a non-structured evidentiary document supporting this tendered project. */
  [TaxTotal] [numeric](18,0) NULL, /* 0..n ASBIE Tax Total ** A total amount of taxes of a particular kind applicable to the monetary total for this tendered project. */
  [LegalMonetaryTotal] [numeric](18,0) NULL, /* 0..1 ASBIE Monetary Total ** The total amount for this tendered project. */
  [TenderLine] [numeric](18,0) NULL, /* 0..n ASBIE Tender Line ** A line in the tender for this tendered project. */
  [AwardingCriterionResponse] [numeric](18,0) NULL, /* 0..n ASBIE Awarding Criterion Response ** An association to an Awarding Criterion Response. */
 CONSTRAINT [PK_TenderedProject] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderedProject_VariantID] ON [dbo].[TenderedProject] 
(
	[VariantID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderedProject_FeeAmount] ON [dbo].[TenderedProject] 
(
	[FeeAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderedProject_FeeDescription] ON [dbo].[TenderedProject] 
(
	[FeeDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderedProject_TenderEnvelopeID] ON [dbo].[TenderedProject] 
(
	[TenderEnvelopeID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderedProject_TenderEnvelopeTypeCode] ON [dbo].[TenderedProject] 
(
	[TenderEnvelopeTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderedProject_ProcurementProjectLot] ON [dbo].[TenderedProject] 
(
	[ProcurementProjectLot] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderedProject_EvidenceDocumentReference] ON [dbo].[TenderedProject] 
(
	[EvidenceDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderedProject_TaxTotal] ON [dbo].[TenderedProject] 
(
	[TaxTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderedProject_LegalMonetaryTotal] ON [dbo].[TenderedProject] 
(
	[LegalMonetaryTotal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderedProject_TenderLine] ON [dbo].[TenderedProject] 
(
	[TenderLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderedProject_AwardingCriterionResponse] ON [dbo].[TenderedProject] 
(
	[AwardingCriterionResponse] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TendererPartyQualification] Script Date: 2013-10-13 00:21z
A class to describe the qualifications of a tenderer party.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TendererPartyQualification](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [InterestedProcurementProjectLot] [numeric](18,0) NULL, /* 0..n ASBIE Procurement Project Lot ** The procurement project lot the party is interested in. */
  [MainQualifyingParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Qualifying Party ** The qualifications of the main tenderer party. */
  [AdditionalQualifyingParty] [numeric](18,0) NULL, /* 0..n ASBIE Qualifying Party ** The qualifications of a tenderer party other than the main tenderer party when bidding as a consortium. */
 CONSTRAINT [PK_TendererPartyQualification] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererPartyQualification_InterestedProcurementProjectLot] ON [dbo].[TendererPartyQualification] 
(
	[InterestedProcurementProjectLot] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererPartyQualification_MainQualifyingParty] ON [dbo].[TendererPartyQualification] 
(
	[MainQualifyingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererPartyQualification_AdditionalQualifyingParty] ON [dbo].[TendererPartyQualification] 
(
	[AdditionalQualifyingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TendererQualificationRequest] Script Date: 2013-10-13 00:21z
The evaluation that the Contracting Authority party requests to fulfill to the tenderers.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TendererQualificationRequest](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [CompanyLegalFormCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The legal status requested for potential tenderers, expressed as a code. */
  [CompanyLegalForm] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The legal status requested for potential tenderers, expressed as text */
  [PersonalSituation] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the personal situation of the economic operators in this tendering process. */
  [OperatingYearsQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Textual description of the legal form required for potential tenderers. */
  [EmployeeQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Textual description of the legal form required for potential tenderers. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the evaluation requirements for this tenderer. */
  [RequiredBusinessClassificationScheme] [numeric](18,0) NULL, /* 0..n ASBIE Classification Scheme ** A classification scheme for the business profile. */
  [TechnicalEvaluationCriterion] [numeric](18,0) NULL, /* 0..n ASBIE Evaluation Criterion ** A technical evaluation criterion required for an economic operator in a tendering process. */
  [FinancialEvaluationCriterion] [numeric](18,0) NULL, /* 0..n ASBIE Evaluation Criterion ** A financial evaluation criterion required for an economic operator in a tendering process. */
  [SpecificTendererRequirement] [numeric](18,0) NULL, /* 0..n ASBIE Tenderer Requirement ** A requirement to be met by a tenderer. */
  [EconomicOperatorRole] [numeric](18,0) NULL, /* 0..n ASBIE Economic Operator Role ** A class to describe the tenderer contracting role. */
 CONSTRAINT [PK_TendererQualificationRequest] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationRequest_CompanyLegalFormCode] ON [dbo].[TendererQualificationRequest] 
(
	[CompanyLegalFormCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationRequest_CompanyLegalForm] ON [dbo].[TendererQualificationRequest] 
(
	[CompanyLegalForm] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationRequest_PersonalSituation] ON [dbo].[TendererQualificationRequest] 
(
	[PersonalSituation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationRequest_OperatingYearsQuantity] ON [dbo].[TendererQualificationRequest] 
(
	[OperatingYearsQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationRequest_EmployeeQuantity] ON [dbo].[TendererQualificationRequest] 
(
	[EmployeeQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationRequest_Description] ON [dbo].[TendererQualificationRequest] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationRequest_RequiredBusinessClassificationScheme] ON [dbo].[TendererQualificationRequest] 
(
	[RequiredBusinessClassificationScheme] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationRequest_TechnicalEvaluationCriterion] ON [dbo].[TendererQualificationRequest] 
(
	[TechnicalEvaluationCriterion] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationRequest_FinancialEvaluationCriterion] ON [dbo].[TendererQualificationRequest] 
(
	[FinancialEvaluationCriterion] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationRequest_SpecificTendererRequirement] ON [dbo].[TendererQualificationRequest] 
(
	[SpecificTendererRequirement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererQualificationRequest_EconomicOperatorRole] ON [dbo].[TendererQualificationRequest] 
(
	[EconomicOperatorRole] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TendererRequirement] Script Date: 2013-10-13 00:21z
A class to describe an action or statement required of an economic operator participating in a tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TendererRequirement](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Name] [numeric](18,0) NULL, /* 0..n BBIE Name ** A name of this tenderer requirement. */
  [TendererRequirementTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying this requirement. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this requirement. */
  [LegalReference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The legal reference of the exclusion criterion. */
  [SuggestedEvidence] [numeric](18,0) NULL, /* 0..n ASBIE Evidence ** An item of evidence that should be submitted to satisfy this requirement. */
 CONSTRAINT [PK_TendererRequirement] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererRequirement_Name] ON [dbo].[TendererRequirement] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererRequirement_TendererRequirementTypeCode] ON [dbo].[TendererRequirement] 
(
	[TendererRequirementTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererRequirement_Description] ON [dbo].[TendererRequirement] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererRequirement_LegalReference] ON [dbo].[TendererRequirement] 
(
	[LegalReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TendererRequirement_SuggestedEvidence] ON [dbo].[TendererRequirement] 
(
	[SuggestedEvidence] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TenderingProcess] Script Date: 2013-10-13 00:21z
A class to describe the process of a formal offer and response to execute work or supply goods at a stated price.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TenderingProcess](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this tendering process. */
  [OriginalContractingSystemID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** When reopening a tendering process, the identifier of the original framework agreement or dynamic purchasing system. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the tendering process. */
  [NegotiationDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the negotiation to be followed during the tendering process. */
  [ProcedureCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of this tendering procedure. */
  [UrgencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the urgency of this tendering process. */
  [ExpenseCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of expense for this tendering process. */
  [PartPresentationCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of presentation of tenders required (e.g., one lot, multiple lots, or all the lots). */
  [ContractingSystemCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of contracting system (e.g., framework agreement, dynamic purchasing system). If the procedure is individual (nonrepetitive), this code should be omitted. */
  [SubmissionMethodCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the method to be followed in submitting tenders. */
  [CandidateReductionConstraintIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that the number of candidates participating in this process has been reduced (true) or not (false). */
  [GovernmentAgreementConstraintIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that the project associated with this tendering process is constrained by a government procurement agreement (true) or not (false). */
  [DocumentAvailabilityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which documents relating to this tendering process must be completed. */
  [TenderSubmissionDeadlinePeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which tenders must be delivered. */
  [InvitationSubmissionPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which invitations to tender must be completed and delivered. */
  [ParticipationRequestReceptionPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which requests for participation must be completed and delivered. */
  [NoticeDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a notice pertaining to this tendering process. */
  [AdditionalDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to an additional document. */
  [ProcessJustification] [numeric](18,0) NULL, /* 0..n ASBIE Process Justification ** A justification for the selection of this tendering process. */
  [EconomicOperatorShortList] [numeric](18,0) NULL, /* 0..1 ASBIE Economic Operator Short List ** A set of criteria used to create a short list of candidates. */
  [OpenTenderEvent] [numeric](18,0) NULL, /* 0..n ASBIE Event ** Textual description of the legal form required for potential tenderers. */
  [AuctionTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Auction Terms ** The terms to be fulfilled by tenderers if an auction is to be executed before the awarding of a tender. */
  [FrameworkAgreement] [numeric](18,0) NULL, /* 0..1 ASBIE Framework Agreement ** A tendering framework agreement. */
 CONSTRAINT [PK_TenderingProcess] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_ID] ON [dbo].[TenderingProcess] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_OriginalContractingSystemID] ON [dbo].[TenderingProcess] 
(
	[OriginalContractingSystemID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_Description] ON [dbo].[TenderingProcess] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_NegotiationDescription] ON [dbo].[TenderingProcess] 
(
	[NegotiationDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_ProcedureCode] ON [dbo].[TenderingProcess] 
(
	[ProcedureCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_UrgencyCode] ON [dbo].[TenderingProcess] 
(
	[UrgencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_ExpenseCode] ON [dbo].[TenderingProcess] 
(
	[ExpenseCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_PartPresentationCode] ON [dbo].[TenderingProcess] 
(
	[PartPresentationCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_ContractingSystemCode] ON [dbo].[TenderingProcess] 
(
	[ContractingSystemCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_SubmissionMethodCode] ON [dbo].[TenderingProcess] 
(
	[SubmissionMethodCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_CandidateReductionConstraintIndicator] ON [dbo].[TenderingProcess] 
(
	[CandidateReductionConstraintIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_GovernmentAgreementConstraintIndicator] ON [dbo].[TenderingProcess] 
(
	[GovernmentAgreementConstraintIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_DocumentAvailabilityPeriod] ON [dbo].[TenderingProcess] 
(
	[DocumentAvailabilityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_TenderSubmissionDeadlinePeriod] ON [dbo].[TenderingProcess] 
(
	[TenderSubmissionDeadlinePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_InvitationSubmissionPeriod] ON [dbo].[TenderingProcess] 
(
	[InvitationSubmissionPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_ParticipationRequestReceptionPeriod] ON [dbo].[TenderingProcess] 
(
	[ParticipationRequestReceptionPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_NoticeDocumentReference] ON [dbo].[TenderingProcess] 
(
	[NoticeDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_AdditionalDocumentReference] ON [dbo].[TenderingProcess] 
(
	[AdditionalDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_ProcessJustification] ON [dbo].[TenderingProcess] 
(
	[ProcessJustification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_EconomicOperatorShortList] ON [dbo].[TenderingProcess] 
(
	[EconomicOperatorShortList] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_OpenTenderEvent] ON [dbo].[TenderingProcess] 
(
	[OpenTenderEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_AuctionTerms] ON [dbo].[TenderingProcess] 
(
	[AuctionTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingProcess_FrameworkAgreement] ON [dbo].[TenderingProcess] 
(
	[FrameworkAgreement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TenderingTerms] Script Date: 2013-10-13 00:21z
A class to describe tendering terms for a tendering process.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TenderingTerms](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [AwardingMethodTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the awarding method in a tendering process (e.g., a method favoring the tender with the lowest price or the tender that is most economically advantageous). */
  [PriceEvaluationCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Textual description of the legal form required for potential tenderers. */
  [MaximumVariantQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** Maximum number of variants the tenderer is allowed to present for this tendering project. */
  [VariantConstraintIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that variants are allowed and unconstrained in number (true) or not allowed (false). */
  [AcceptedVariantsDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text specifying the things for which variants are accepted. */
  [PriceRevisionFormulaDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the formula for price revision. */
  [FundingProgramCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The program that funds the tendering process (e.g., "National", "European"), expressed as a code. */
  [FundingProgram] [numeric](18,0) NULL, /* 0..n BBIE Text ** The program that funds the tendering process (e.g., EU 6th Framework Program) expressed as text. */
  [MaximumAdvertisementAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The maximum advertised monetary value of the tendering process. */
  [Note] [numeric](18,0) NULL, /* 0..n BBIE Text ** Free-form text conveying information that is not contained explicitly in other structures. */
  [PaymentFrequencyCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the frequency of payment in the contract associated with the tendering process. */
  [EconomicOperatorRegistryURI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The Uniform Resource Identifier (URI) of an electronic registry of economic operators. */
  [RequiredCurriculaIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that tenderers are required to provide a curriculum vitae for each participant in the project (true) or are not so required (false). */
  [OtherConditionsIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** Indicates whether other conditions exist (true) or not (false). If the indicator is true, the description may be provided. */
  [AdditionalConditions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Other existing conditions. */
  [LatestSecurityClearanceDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The end date until which the candidates can obtain the necessary level of security clearance. */
  [DocumentationFeeAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The amount to be paid to obtain the contract documents and additional documentation. */
  [PenaltyClause] [numeric](18,0) NULL, /* 0..n ASBIE Clause ** The penalty clauses */
  [RequiredFinancialGuarantee] [numeric](18,0) NULL, /* 0..n ASBIE Financial Guarantee ** A financial guarantee of a tenderer or bid submitter's actual entry into a contract in the event that it is the successful bidder. */
  [ProcurementLegislationDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a document providing references to procurement legislation applicable to the tendering process. */
  [FiscalLegislationDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a document providing references to fiscal legislation applicable to the tendering process. */
  [EnvironmentalLegislationDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a document providing references to environmental legislation applicable to the tendering process. */
  [EmploymentLegislationDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a document providing references to employment legislation applicable to the tendering process. */
  [ContractualDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document that will become part of the awarded contract. */
  [CallForTendersDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to the Call for Tender associated with these tendering terms. */
  [WarrantyValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which a warranty for work, service, or goods associated with these tendering terms is valid. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** A specification of payment terms associated with the tendering process. */
  [TendererQualificationRequest] [numeric](18,0) NULL, /* 0..n ASBIE Tenderer Qualification Request ** Required set of qualifications for a tenderer in this tendering process. */
  [AllowedSubcontractTerms] [numeric](18,0) NULL, /* 0..n ASBIE Subcontract Terms ** Subcontract terms for the tendering process. */
  [TenderPreparation] [numeric](18,0) NULL, /* 0..n ASBIE Tender Preparation ** Directions for preparing a tender for the+D2057 tendering process. */
  [ContractExecutionRequirement] [numeric](18,0) NULL, /* 0..n ASBIE Contract Execution Requirement ** A requirement relating to execution of the contract that will be awarded as a result of the tendering process. */
  [AwardingTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Awarding Terms ** The terms in the tendering process for awarding the contract for a project. */
  [AdditionalInformationParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** A party that has additional information about the tendering process. */
  [DocumentProviderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that has the contract documents for the tendering process. */
  [TenderRecipientParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party to which tenders should be presented. */
  [ContractResponsibleParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party responsible for the execution of the contract. */
  [TenderEvaluationParty] [numeric](18,0) NULL, /* 0..n ASBIE Party ** A party in the contracting authority responsible for evaluating tenders received. */
  [TenderValidityPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period during which tenders submitted for this tendering process must remain valid. */
  [ContractAcceptancePeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The period of time during which the contracting authority may accept a contract. */
  [AppealTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Appeal Terms ** Information about the terms to present for an appeal against a tender award. */
  [Language] [numeric](18,0) NULL, /* 0..n ASBIE Language ** One of the default languages specified for the tendering process. */
  [BudgetAccountLine] [numeric](18,0) NULL, /* 0..n ASBIE Budget Account Line ** A budget account line associated with the tendering process. */
  [ReplacedNoticeDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A class defining a reference to the notice that is being replaced. */
 CONSTRAINT [PK_TenderingTerms] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_AwardingMethodTypeCode] ON [dbo].[TenderingTerms] 
(
	[AwardingMethodTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_PriceEvaluationCode] ON [dbo].[TenderingTerms] 
(
	[PriceEvaluationCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_MaximumVariantQuantity] ON [dbo].[TenderingTerms] 
(
	[MaximumVariantQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_VariantConstraintIndicator] ON [dbo].[TenderingTerms] 
(
	[VariantConstraintIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_AcceptedVariantsDescription] ON [dbo].[TenderingTerms] 
(
	[AcceptedVariantsDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_PriceRevisionFormulaDescription] ON [dbo].[TenderingTerms] 
(
	[PriceRevisionFormulaDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_FundingProgramCode] ON [dbo].[TenderingTerms] 
(
	[FundingProgramCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_FundingProgram] ON [dbo].[TenderingTerms] 
(
	[FundingProgram] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_MaximumAdvertisementAmount] ON [dbo].[TenderingTerms] 
(
	[MaximumAdvertisementAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_Note] ON [dbo].[TenderingTerms] 
(
	[Note] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_PaymentFrequencyCode] ON [dbo].[TenderingTerms] 
(
	[PaymentFrequencyCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_EconomicOperatorRegistryURI] ON [dbo].[TenderingTerms] 
(
	[EconomicOperatorRegistryURI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_RequiredCurriculaIndicator] ON [dbo].[TenderingTerms] 
(
	[RequiredCurriculaIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_OtherConditionsIndicator] ON [dbo].[TenderingTerms] 
(
	[OtherConditionsIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_AdditionalConditions] ON [dbo].[TenderingTerms] 
(
	[AdditionalConditions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_LatestSecurityClearanceDate] ON [dbo].[TenderingTerms] 
(
	[LatestSecurityClearanceDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_DocumentationFeeAmount] ON [dbo].[TenderingTerms] 
(
	[DocumentationFeeAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_PenaltyClause] ON [dbo].[TenderingTerms] 
(
	[PenaltyClause] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_RequiredFinancialGuarantee] ON [dbo].[TenderingTerms] 
(
	[RequiredFinancialGuarantee] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_ProcurementLegislationDocumentReference] ON [dbo].[TenderingTerms] 
(
	[ProcurementLegislationDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_FiscalLegislationDocumentReference] ON [dbo].[TenderingTerms] 
(
	[FiscalLegislationDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_EnvironmentalLegislationDocumentReference] ON [dbo].[TenderingTerms] 
(
	[EnvironmentalLegislationDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_EmploymentLegislationDocumentReference] ON [dbo].[TenderingTerms] 
(
	[EmploymentLegislationDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_ContractualDocumentReference] ON [dbo].[TenderingTerms] 
(
	[ContractualDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_CallForTendersDocumentReference] ON [dbo].[TenderingTerms] 
(
	[CallForTendersDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_WarrantyValidityPeriod] ON [dbo].[TenderingTerms] 
(
	[WarrantyValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_PaymentTerms] ON [dbo].[TenderingTerms] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_TendererQualificationRequest] ON [dbo].[TenderingTerms] 
(
	[TendererQualificationRequest] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_AllowedSubcontractTerms] ON [dbo].[TenderingTerms] 
(
	[AllowedSubcontractTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_TenderPreparation] ON [dbo].[TenderingTerms] 
(
	[TenderPreparation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_ContractExecutionRequirement] ON [dbo].[TenderingTerms] 
(
	[ContractExecutionRequirement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_AwardingTerms] ON [dbo].[TenderingTerms] 
(
	[AwardingTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_AdditionalInformationParty] ON [dbo].[TenderingTerms] 
(
	[AdditionalInformationParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_DocumentProviderParty] ON [dbo].[TenderingTerms] 
(
	[DocumentProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_TenderRecipientParty] ON [dbo].[TenderingTerms] 
(
	[TenderRecipientParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_ContractResponsibleParty] ON [dbo].[TenderingTerms] 
(
	[ContractResponsibleParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_TenderEvaluationParty] ON [dbo].[TenderingTerms] 
(
	[TenderEvaluationParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_TenderValidityPeriod] ON [dbo].[TenderingTerms] 
(
	[TenderValidityPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_ContractAcceptancePeriod] ON [dbo].[TenderingTerms] 
(
	[ContractAcceptancePeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_AppealTerms] ON [dbo].[TenderingTerms] 
(
	[AppealTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_Language] ON [dbo].[TenderingTerms] 
(
	[Language] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_BudgetAccountLine] ON [dbo].[TenderingTerms] 
(
	[BudgetAccountLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TenderingTerms_ReplacedNoticeDocumentReference] ON [dbo].[TenderingTerms] 
(
	[ReplacedNoticeDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TradeFinancing] Script Date: 2013-10-13 00:21z
A class to describe a trade financing instrument.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TradeFinancing](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this trade financing instrument. */
  [FinancingInstrumentCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of this financing instrument. */
  [ContractDocumentReference] [numeric](18,0) NULL, /* 0..1 ASBIE Document Reference ** A reference to a contract document. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document associated with this trade financing instrument. */
  [FinancingParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The financing party (bank or other enabled party). */
  [FinancingFinancialAccount] [numeric](18,0) NULL, /* 0..1 ASBIE Financial Account ** An internal bank account used by the bank or its first agent to manage the line of credit granted to the financing requester. */
  [Clause] [numeric](18,0) NULL, /* 0..n ASBIE Clause ** A clause applicable to this trade financing instrument. */
 CONSTRAINT [PK_TradeFinancing] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeFinancing_ID] ON [dbo].[TradeFinancing] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeFinancing_FinancingInstrumentCode] ON [dbo].[TradeFinancing] 
(
	[FinancingInstrumentCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeFinancing_ContractDocumentReference] ON [dbo].[TradeFinancing] 
(
	[ContractDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeFinancing_DocumentReference] ON [dbo].[TradeFinancing] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeFinancing_FinancingParty] ON [dbo].[TradeFinancing] 
(
	[FinancingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeFinancing_FinancingFinancialAccount] ON [dbo].[TradeFinancing] 
(
	[FinancingFinancialAccount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradeFinancing_Clause] ON [dbo].[TradeFinancing] 
(
	[Clause] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TradingTerms] Script Date: 2013-10-13 00:21z
A class for describing the terms of a trade agreement.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TradingTerms](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Information] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the terms of a trade agreement. */
  [Reference] [numeric](18,0) NULL, /* 0..1 BBIE Text ** A reference quoting the basis of the terms */
  [ApplicableAddress] [numeric](18,0) NULL, /* 0..1 ASBIE Address ** The address at which these trading terms apply. */
 CONSTRAINT [PK_TradingTerms] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradingTerms_Information] ON [dbo].[TradingTerms] 
(
	[Information] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradingTerms_Reference] ON [dbo].[TradingTerms] 
(
	[Reference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TradingTerms_ApplicableAddress] ON [dbo].[TradingTerms] 
(
	[ApplicableAddress] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransactionConditions] Script Date: 2013-10-13 00:21z
A class to describe purchasing, sales, or payment conditions.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransactionConditions](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for conditions of the transaction, typically purchase/sales conditions. */
  [ActionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying a type of action relating to sales or payment conditions. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the transaction conditions. */
  [DocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A document associated with these transaction conditions. */
 CONSTRAINT [PK_TransactionConditions] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransactionConditions_ID] ON [dbo].[TransactionConditions] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransactionConditions_ActionCode] ON [dbo].[TransactionConditions] 
(
	[ActionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransactionConditions_Description] ON [dbo].[TransactionConditions] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransactionConditions_DocumentReference] ON [dbo].[TransactionConditions] 
(
	[DocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportEquipment] Script Date: 2013-10-13 00:21z
A class to describe a piece of equipment used to transport goods.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportEquipment](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this piece of transport equipment. */
  [ReferencedConsignmentID] [numeric](18,0) NULL, /* 0..n BBIE Identifier ** An identifier for the consignment contained by this piece of transport equipment. */
  [TransportEquipmentTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of this piece of transport equipment. */
  [ProviderTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of provider of this piece of transport equipment. */
  [OwnerTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of owner of this piece of transport equipment. */
  [SizeTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the size and type of this piece of piece of transport equipment. When the piece of transport equipment is a shipping container, it is recommended to use ContainerSizeTypeCode for validation. */
  [DispositionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the current disposition of this piece of transport equipment. */
  [FullnessIndicationCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying whether this piece of transport equipment is full, partially full, or empty. */
  [RefrigerationOnIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this piece of transport equipment's refrigeration is on (true) or off (false). */
  [Information] [numeric](18,0) NULL, /* 0..n BBIE Text ** Additional information about this piece of transport equipment. */
  [ReturnabilityIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this piece of transport equipment is returnable (true) or not (false). */
  [LegalStatusIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indication of the legal status of this piece of transport equipment with respect to the Container Convention Code. */
  [AirFlowPercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The percent of the airflow within this piece of transport equipment. */
  [HumidityPercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The percent humidity within this piece of transport equipment. */
  [AnimalFoodApprovedIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this piece of transport equipment is approved for animal food (true) or not (false). */
  [HumanFoodApprovedIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this piece of transport equipment is approved for human food (true) or not (false). */
  [DangerousGoodsApprovedIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this piece of transport equipment is approved for dangerous goods (true) or not (false). */
  [RefrigeratedIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this piece of transport equipment is refrigerated (true) or not (false). */
  [Characteristics] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Characteristics of this piece of transport equipment. */
  [DamageRemarks] [numeric](18,0) NULL, /* 0..n BBIE Text ** Damage associated with this piece of transport equipment. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this piece of transport equipment. */
  [SpecialTransportRequirements] [numeric](18,0) NULL, /* 0..n BBIE Text ** Special transport requirements expressed as text. */
  [GrossWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The gross weight of this piece of transport equipment. */
  [GrossVolumeMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The gross volume of this piece of transport equipment. */
  [TareWeightMeasure] [numeric](18,0) NULL, /* 0..1 BBIE Measure ** The weight of this piece of transport equipment when empty. */
  [TrackingDeviceCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the tracking device for this piece of transport equipment. */
  [PowerIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this piece of transport equipment can supply power (true) or not (false). */
  [TraceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for use in tracing this piece of transport equipment, such as the EPC number used in RFID. */
  [MeasurementDimension] [numeric](18,0) NULL, /* 0..n ASBIE Dimension ** A measurable dimension (length, mass, weight, or volume) of this piece of transport equipment. */
  [TransportEquipmentSeal] [numeric](18,0) NULL, /* 0..n ASBIE Transport Equipment Seal ** A seal securing the door of a piece of transport equipment. */
  [MinimumTemperature] [numeric](18,0) NULL, /* 0..1 ASBIE Temperature ** In the case of a refrigeration unit, the minimum allowable operating temperature for this container. */
  [MaximumTemperature] [numeric](18,0) NULL, /* 0..1 ASBIE Temperature ** In the case of a refrigeration unit, the maximum allowable operating temperature for this container. */
  [ProviderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party providing this piece of transport equipment. */
  [LoadingProofParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The authorized party responsible for certifying that the goods were loaded into this piece of transport equipment. */
  [SupplierParty] [numeric](18,0) NULL, /* 0..1 ASBIE Supplier Party ** The party that supplies this piece of transport equipment. */
  [OwnerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that owns this piece of transport equipment. */
  [OperatingParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that operates this piece of transport equipment. */
  [LoadingLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location where this piece of transport equipment is loaded. */
  [UnloadingLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location where this piece of transport equipment is unloaded. */
  [StorageLocation] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location where this piece of transport equipment is being stored. */
  [PositioningTransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** A positioning of this piece of transport equipment. */
  [QuarantineTransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** A quarantine of this piece of transport equipment. */
  [DeliveryTransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** A delivery of this piece of transport equipment. */
  [PickupTransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** A pickup of this piece of transport equipment. */
  [HandlingTransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** A handling of this piece of transport equipment. */
  [LoadingTransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** A loading of this piece of transport equipment. */
  [TransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** A transport event associated with this piece of transport equipment. */
  [ApplicableTransportMeans] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Means ** The applicable transport means associated with this piece of transport equipment. */
  [HaulageTradingTerms] [numeric](18,0) NULL, /* 0..n ASBIE Trading Terms ** A set of haulage trading terms associated with this piece of transport equipment. */
  [HazardousGoodsTransit] [numeric](18,0) NULL, /* 0..n ASBIE Hazardous Goods Transit ** Transit-related information regarding a type of hazardous goods contained in this piece of transport equipment. */
  [PackagedTransportHandlingUnit] [numeric](18,0) NULL, /* 0..n ASBIE Transport Handling Unit ** A packaged transport handling unit associated with this piece of transport equipment. */
  [ServiceAllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A service allowance charge associated with this piece of transport equipment. */
  [FreightAllowanceCharge] [numeric](18,0) NULL, /* 0..n ASBIE Allowance Charge ** A freight allowance charge associated with this piece of transport equipment. */
  [AttachedTransportEquipment] [numeric](18,0) NULL, /* 0..n ASBIE Transport Equipment ** A piece of transport equipment attached to this piece of transport equipment. */
  [Delivery] [numeric](18,0) NULL, /* 0..1 ASBIE Delivery ** The delivery of this piece of transport equipment. */
  [Pickup] [numeric](18,0) NULL, /* 0..1 ASBIE Pickup ** The pickup of this piece of transport equipment. */
  [Despatch] [numeric](18,0) NULL, /* 0..1 ASBIE Despatch ** The despatch of this piece of transport equipment. */
  [ShipmentDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a shipping document associated with this piece of transport equipment. */
  [ContainedInTransportEquipment] [numeric](18,0) NULL, /* 0..n ASBIE Transport Equipment ** A piece of transport equipment contained in this piece of transport equipment. */
  [Package] [numeric](18,0) NULL, /* 0..n ASBIE Package ** A package contained in this piece of transport equipment. */
  [GoodsItem] [numeric](18,0) NULL, /* 0..n ASBIE Goods Item ** A goods item contained in this piece of transport equipment. */
 CONSTRAINT [PK_TransportEquipment] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_ID] ON [dbo].[TransportEquipment] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_ReferencedConsignmentID] ON [dbo].[TransportEquipment] 
(
	[ReferencedConsignmentID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_TransportEquipmentTypeCode] ON [dbo].[TransportEquipment] 
(
	[TransportEquipmentTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_ProviderTypeCode] ON [dbo].[TransportEquipment] 
(
	[ProviderTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_OwnerTypeCode] ON [dbo].[TransportEquipment] 
(
	[OwnerTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_SizeTypeCode] ON [dbo].[TransportEquipment] 
(
	[SizeTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_DispositionCode] ON [dbo].[TransportEquipment] 
(
	[DispositionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_FullnessIndicationCode] ON [dbo].[TransportEquipment] 
(
	[FullnessIndicationCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_RefrigerationOnIndicator] ON [dbo].[TransportEquipment] 
(
	[RefrigerationOnIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_Information] ON [dbo].[TransportEquipment] 
(
	[Information] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_ReturnabilityIndicator] ON [dbo].[TransportEquipment] 
(
	[ReturnabilityIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_LegalStatusIndicator] ON [dbo].[TransportEquipment] 
(
	[LegalStatusIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_AirFlowPercent] ON [dbo].[TransportEquipment] 
(
	[AirFlowPercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_HumidityPercent] ON [dbo].[TransportEquipment] 
(
	[HumidityPercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_AnimalFoodApprovedIndicator] ON [dbo].[TransportEquipment] 
(
	[AnimalFoodApprovedIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_HumanFoodApprovedIndicator] ON [dbo].[TransportEquipment] 
(
	[HumanFoodApprovedIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_DangerousGoodsApprovedIndicator] ON [dbo].[TransportEquipment] 
(
	[DangerousGoodsApprovedIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_RefrigeratedIndicator] ON [dbo].[TransportEquipment] 
(
	[RefrigeratedIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_Characteristics] ON [dbo].[TransportEquipment] 
(
	[Characteristics] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_DamageRemarks] ON [dbo].[TransportEquipment] 
(
	[DamageRemarks] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_Description] ON [dbo].[TransportEquipment] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_SpecialTransportRequirements] ON [dbo].[TransportEquipment] 
(
	[SpecialTransportRequirements] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_GrossWeightMeasure] ON [dbo].[TransportEquipment] 
(
	[GrossWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_GrossVolumeMeasure] ON [dbo].[TransportEquipment] 
(
	[GrossVolumeMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_TareWeightMeasure] ON [dbo].[TransportEquipment] 
(
	[TareWeightMeasure] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_TrackingDeviceCode] ON [dbo].[TransportEquipment] 
(
	[TrackingDeviceCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_PowerIndicator] ON [dbo].[TransportEquipment] 
(
	[PowerIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_TraceID] ON [dbo].[TransportEquipment] 
(
	[TraceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_MeasurementDimension] ON [dbo].[TransportEquipment] 
(
	[MeasurementDimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_TransportEquipmentSeal] ON [dbo].[TransportEquipment] 
(
	[TransportEquipmentSeal] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_MinimumTemperature] ON [dbo].[TransportEquipment] 
(
	[MinimumTemperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_MaximumTemperature] ON [dbo].[TransportEquipment] 
(
	[MaximumTemperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_ProviderParty] ON [dbo].[TransportEquipment] 
(
	[ProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_LoadingProofParty] ON [dbo].[TransportEquipment] 
(
	[LoadingProofParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_SupplierParty] ON [dbo].[TransportEquipment] 
(
	[SupplierParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_OwnerParty] ON [dbo].[TransportEquipment] 
(
	[OwnerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_OperatingParty] ON [dbo].[TransportEquipment] 
(
	[OperatingParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_LoadingLocation] ON [dbo].[TransportEquipment] 
(
	[LoadingLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_UnloadingLocation] ON [dbo].[TransportEquipment] 
(
	[UnloadingLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_StorageLocation] ON [dbo].[TransportEquipment] 
(
	[StorageLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_PositioningTransportEvent] ON [dbo].[TransportEquipment] 
(
	[PositioningTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_QuarantineTransportEvent] ON [dbo].[TransportEquipment] 
(
	[QuarantineTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_DeliveryTransportEvent] ON [dbo].[TransportEquipment] 
(
	[DeliveryTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_PickupTransportEvent] ON [dbo].[TransportEquipment] 
(
	[PickupTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_HandlingTransportEvent] ON [dbo].[TransportEquipment] 
(
	[HandlingTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_LoadingTransportEvent] ON [dbo].[TransportEquipment] 
(
	[LoadingTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_TransportEvent] ON [dbo].[TransportEquipment] 
(
	[TransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_ApplicableTransportMeans] ON [dbo].[TransportEquipment] 
(
	[ApplicableTransportMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_HaulageTradingTerms] ON [dbo].[TransportEquipment] 
(
	[HaulageTradingTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_HazardousGoodsTransit] ON [dbo].[TransportEquipment] 
(
	[HazardousGoodsTransit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_PackagedTransportHandlingUnit] ON [dbo].[TransportEquipment] 
(
	[PackagedTransportHandlingUnit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_ServiceAllowanceCharge] ON [dbo].[TransportEquipment] 
(
	[ServiceAllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_FreightAllowanceCharge] ON [dbo].[TransportEquipment] 
(
	[FreightAllowanceCharge] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_AttachedTransportEquipment] ON [dbo].[TransportEquipment] 
(
	[AttachedTransportEquipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_Delivery] ON [dbo].[TransportEquipment] 
(
	[Delivery] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_Pickup] ON [dbo].[TransportEquipment] 
(
	[Pickup] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_Despatch] ON [dbo].[TransportEquipment] 
(
	[Despatch] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_ShipmentDocumentReference] ON [dbo].[TransportEquipment] 
(
	[ShipmentDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_ContainedInTransportEquipment] ON [dbo].[TransportEquipment] 
(
	[ContainedInTransportEquipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_Package] ON [dbo].[TransportEquipment] 
(
	[Package] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipment_GoodsItem] ON [dbo].[TransportEquipment] 
(
	[GoodsItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportEquipmentSeal] Script Date: 2013-10-13 00:21z
A class to describe a device (a transport equipment seal) for securing the doors of a shipping container.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportEquipmentSeal](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this transport equipment seal. */
  [SealIssuerTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of party that issues and is responsible for this transport equipment seal. */
  [Condition] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The condition of this transport equipment seal. */
  [SealStatusCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the condition of this transport equipment seal. */
  [SealingPartyType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The role of the sealing party. */
 CONSTRAINT [PK_TransportEquipmentSeal] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipmentSeal_ID] ON [dbo].[TransportEquipmentSeal] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipmentSeal_SealIssuerTypeCode] ON [dbo].[TransportEquipmentSeal] 
(
	[SealIssuerTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipmentSeal_Condition] ON [dbo].[TransportEquipmentSeal] 
(
	[Condition] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipmentSeal_SealStatusCode] ON [dbo].[TransportEquipmentSeal] 
(
	[SealStatusCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEquipmentSeal_SealingPartyType] ON [dbo].[TransportEquipmentSeal] 
(
	[SealingPartyType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportEvent] Script Date: 2013-10-13 00:21z
A class to describe a significant occurrence or happening related to the transportation of goods.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportEvent](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [IdentificationID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this transport event within an agreed event identification scheme. */
  [OccurrenceDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date of this transport event. */
  [OccurrenceTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The time of this transport event. */
  [TransportEventTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of this transport event. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this transport event. */
  [CompletionIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that this transport event has been completed (true) or not (false). */
  [ReportedShipment] [numeric](18,0) NULL, /* 0..1 ASBIE Shipment ** The shipment involved in this transport event. */
  [CurrentStatus] [numeric](18,0) NULL, /* 0..n ASBIE Status ** The current status of this transport event. */
  [Contact] [numeric](18,0) NULL, /* 0..n ASBIE Contact ** A contact associated with this transport event. */
  [Location] [numeric](18,0) NULL, /* 0..1 ASBIE Location ** The location associated with this transport event. */
  [Signature] [numeric](18,0) NULL, /* 0..1 ASBIE Signature ** A signature that can be used to sign for an entry or an exit at a transport location (e.g., port terminal). */
  [Period] [numeric](18,0) NULL, /* 0..n ASBIE Period ** A period of time associated with this transport event. */
 CONSTRAINT [PK_TransportEvent] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_IdentificationID] ON [dbo].[TransportEvent] 
(
	[IdentificationID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_OccurrenceDate] ON [dbo].[TransportEvent] 
(
	[OccurrenceDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_OccurrenceTime] ON [dbo].[TransportEvent] 
(
	[OccurrenceTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_TransportEventTypeCode] ON [dbo].[TransportEvent] 
(
	[TransportEventTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_Description] ON [dbo].[TransportEvent] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_CompletionIndicator] ON [dbo].[TransportEvent] 
(
	[CompletionIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_ReportedShipment] ON [dbo].[TransportEvent] 
(
	[ReportedShipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_CurrentStatus] ON [dbo].[TransportEvent] 
(
	[CurrentStatus] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_Contact] ON [dbo].[TransportEvent] 
(
	[Contact] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_Location] ON [dbo].[TransportEvent] 
(
	[Location] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_Signature] ON [dbo].[TransportEvent] 
(
	[Signature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportEvent_Period] ON [dbo].[TransportEvent] 
(
	[Period] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportExecutionTerms] Script Date: 2013-10-13 00:21z
A class to describe terms applying to a transport execution plan.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportExecutionTerms](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [TransportUserSpecialTerms] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing special terms specified by the transport user. */
  [TransportServiceProviderSpecialTerms] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing special terms specified by the transport service provider. */
  [ChangeConditions] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing conditions applying to a change of these transport execution terms. */
  [PaymentTerms] [numeric](18,0) NULL, /* 0..n ASBIE Payment Terms ** Payment terms associated with the transportation service. */
  [DeliveryTerms] [numeric](18,0) NULL, /* 0..n ASBIE Delivery Terms ** Delivery terms (e.g., Incoterms) associated with the transportation service. */
  [BonusPaymentTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Terms ** Terms relating to payment of applicable bonuses associated with the transport service. */
  [CommissionPaymentTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Terms ** Terms of payment applying to a commission specified in the transport execution plan. */
  [PenaltyPaymentTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Terms ** Terms of payment applying to a penalty specified in the transport execution plan. */
  [EnvironmentalEmission] [numeric](18,0) NULL, /* 0..n ASBIE Environmental Emission ** An environmental emission resulting from the transportation service. */
  [NotificationRequirement] [numeric](18,0) NULL, /* 0..n ASBIE Notification Requirement ** A notification requirement related to the transportation service; e.g., a requirement that the transport user should be notified when goods are ready for pickup. */
  [ServiceChargePaymentTerms] [numeric](18,0) NULL, /* 0..1 ASBIE Payment Terms ** Payment terms for the service charge associated with the transport service. */
 CONSTRAINT [PK_TransportExecutionTerms] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionTerms_TransportUserSpecialTerms] ON [dbo].[TransportExecutionTerms] 
(
	[TransportUserSpecialTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionTerms_TransportServiceProviderSpecialTerms] ON [dbo].[TransportExecutionTerms] 
(
	[TransportServiceProviderSpecialTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionTerms_ChangeConditions] ON [dbo].[TransportExecutionTerms] 
(
	[ChangeConditions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionTerms_PaymentTerms] ON [dbo].[TransportExecutionTerms] 
(
	[PaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionTerms_DeliveryTerms] ON [dbo].[TransportExecutionTerms] 
(
	[DeliveryTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionTerms_BonusPaymentTerms] ON [dbo].[TransportExecutionTerms] 
(
	[BonusPaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionTerms_CommissionPaymentTerms] ON [dbo].[TransportExecutionTerms] 
(
	[CommissionPaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionTerms_PenaltyPaymentTerms] ON [dbo].[TransportExecutionTerms] 
(
	[PenaltyPaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionTerms_EnvironmentalEmission] ON [dbo].[TransportExecutionTerms] 
(
	[EnvironmentalEmission] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionTerms_NotificationRequirement] ON [dbo].[TransportExecutionTerms] 
(
	[NotificationRequirement] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportExecutionTerms_ServiceChargePaymentTerms] ON [dbo].[TransportExecutionTerms] 
(
	[ServiceChargePaymentTerms] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportHandlingUnit] Script Date: 2013-10-13 00:21z
A class to describe a uniquely identifiable unit consisting of one or more packages, goods items, or pieces of transport equipment.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportHandlingUnit](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this transport handling unit. */
  [TransportHandlingUnitTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of this transport handling unit. */
  [HandlingCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The handling required for this transport handling unit, expressed as a code. */
  [HandlingInstructions] [numeric](18,0) NULL, /* 0..n BBIE Text ** The handling required for this transport handling unit, expressed as text. */
  [HazardousRiskIndicator] [numeric](18,0) NULL, /* 0..1 BBIE Indicator ** An indicator that the materials contained in this transport handling unit are subject to an international regulation concerning the carriage of dangerous goods (true) or not (false). */
  [TotalGoodsItemQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total number of goods items in this transport handling unit. */
  [TotalPackageQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The total number of packages in this transport handling unit. */
  [DamageRemarks] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing damage associated with this transport handling unit. */
  [ShippingMarks] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the marks and numbers on this transport handling unit. */
  [TraceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for use in tracing this transport handling unit, such as the EPC number used in RFID. */
  [HandlingUnitDespatchLine] [numeric](18,0) NULL, /* 0..n ASBIE Despatch Line ** A despatch line associated with this transport handling unit. */
  [ActualPackage] [numeric](18,0) NULL, /* 0..n ASBIE Package ** A package contained in this transport handling unit. */
  [ReceivedHandlingUnitReceiptLine] [numeric](18,0) NULL, /* 0..n ASBIE Receipt Line ** A receipt line associated with this transport handling unit. */
  [TransportEquipment] [numeric](18,0) NULL, /* 0..n ASBIE Transport Equipment ** A piece of transport equipment associated with this transport handling unit. */
  [TransportMeans] [numeric](18,0) NULL, /* 0..n ASBIE Transport Means ** A means of transport associated with this transport handling unit. */
  [HazardousGoodsTransit] [numeric](18,0) NULL, /* 0..n ASBIE Hazardous Goods Transit ** Transit-related information regarding a type of hazardous goods contained in this transport handling unit. */
  [MeasurementDimension] [numeric](18,0) NULL, /* 0..n ASBIE Dimension ** A measurable dimension (length, mass, weight, or volume) of this transport handling unit. */
  [MinimumTemperature] [numeric](18,0) NULL, /* 0..1 ASBIE Temperature ** The minimum required operating temperature of this transport handling unit. */
  [MaximumTemperature] [numeric](18,0) NULL, /* 0..1 ASBIE Temperature ** The maximum allowable operating temperature of this transport handling unit. */
  [GoodsItem] [numeric](18,0) NULL, /* 0..n ASBIE Goods Item ** A goods item contained in this transport handling unit. */
  [FloorSpaceMeasurementDimension] [numeric](18,0) NULL, /* 0..1 ASBIE Dimension ** The floor space measurement dimension associated with this transport handling unit. */
  [PalletSpaceMeasurementDimension] [numeric](18,0) NULL, /* 0..1 ASBIE Dimension ** The pallet space measurement dimension associated to this transport handling unit. */
  [ShipmentDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a shipping document associated with this transport handling unit. */
  [Status] [numeric](18,0) NULL, /* 0..n ASBIE Status ** The status of this transport handling unit. */
  [CustomsDeclaration] [numeric](18,0) NULL, /* 0..n ASBIE Customs Declaration ** Describes identifiers or references relating to customs procedures. */
  [ReferencedShipment] [numeric](18,0) NULL, /* 0..n ASBIE Shipment ** A shipment associated with this transport handling unit. */
  [Package] [numeric](18,0) NULL, /* 0..n ASBIE Package ** A package contained in this transport handling unit. */
 CONSTRAINT [PK_TransportHandlingUnit] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_ID] ON [dbo].[TransportHandlingUnit] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_TransportHandlingUnitTypeCode] ON [dbo].[TransportHandlingUnit] 
(
	[TransportHandlingUnitTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_HandlingCode] ON [dbo].[TransportHandlingUnit] 
(
	[HandlingCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_HandlingInstructions] ON [dbo].[TransportHandlingUnit] 
(
	[HandlingInstructions] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_HazardousRiskIndicator] ON [dbo].[TransportHandlingUnit] 
(
	[HazardousRiskIndicator] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_TotalGoodsItemQuantity] ON [dbo].[TransportHandlingUnit] 
(
	[TotalGoodsItemQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_TotalPackageQuantity] ON [dbo].[TransportHandlingUnit] 
(
	[TotalPackageQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_DamageRemarks] ON [dbo].[TransportHandlingUnit] 
(
	[DamageRemarks] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_ShippingMarks] ON [dbo].[TransportHandlingUnit] 
(
	[ShippingMarks] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_TraceID] ON [dbo].[TransportHandlingUnit] 
(
	[TraceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_HandlingUnitDespatchLine] ON [dbo].[TransportHandlingUnit] 
(
	[HandlingUnitDespatchLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_ActualPackage] ON [dbo].[TransportHandlingUnit] 
(
	[ActualPackage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_ReceivedHandlingUnitReceiptLine] ON [dbo].[TransportHandlingUnit] 
(
	[ReceivedHandlingUnitReceiptLine] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_TransportEquipment] ON [dbo].[TransportHandlingUnit] 
(
	[TransportEquipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_TransportMeans] ON [dbo].[TransportHandlingUnit] 
(
	[TransportMeans] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_HazardousGoodsTransit] ON [dbo].[TransportHandlingUnit] 
(
	[HazardousGoodsTransit] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_MeasurementDimension] ON [dbo].[TransportHandlingUnit] 
(
	[MeasurementDimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_MinimumTemperature] ON [dbo].[TransportHandlingUnit] 
(
	[MinimumTemperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_MaximumTemperature] ON [dbo].[TransportHandlingUnit] 
(
	[MaximumTemperature] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_GoodsItem] ON [dbo].[TransportHandlingUnit] 
(
	[GoodsItem] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_FloorSpaceMeasurementDimension] ON [dbo].[TransportHandlingUnit] 
(
	[FloorSpaceMeasurementDimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_PalletSpaceMeasurementDimension] ON [dbo].[TransportHandlingUnit] 
(
	[PalletSpaceMeasurementDimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_ShipmentDocumentReference] ON [dbo].[TransportHandlingUnit] 
(
	[ShipmentDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_Status] ON [dbo].[TransportHandlingUnit] 
(
	[Status] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_CustomsDeclaration] ON [dbo].[TransportHandlingUnit] 
(
	[CustomsDeclaration] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_ReferencedShipment] ON [dbo].[TransportHandlingUnit] 
(
	[ReferencedShipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportHandlingUnit_Package] ON [dbo].[TransportHandlingUnit] 
(
	[Package] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportMeans] Script Date: 2013-10-13 00:21z
A class to describe a particular vehicle or vessel used for the conveyance of goods or persons.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportMeans](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [JourneyID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the regular service schedule of this means of transport. */
  [RegistrationNationalityID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the country in which this means of transport is registered. */
  [RegistrationNationality] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the country in which this means of transport is registered. */
  [DirectionCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the direction of this means of transport. */
  [TransportMeansTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the type of this means of transport (truck, vessel, etc.). */
  [TradeServiceCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the service regularly provided by the carrier operating this means of transport. */
  [Stowage] [numeric](18,0) NULL, /* 0..1 ASBIE Stowage ** The location within the means of transport where goods are to be or have been stowed. */
  [AirTransport] [numeric](18,0) NULL, /* 0..1 ASBIE Air Transport ** An aircraft used for transport. */
  [RoadTransport] [numeric](18,0) NULL, /* 0..1 ASBIE Road Transport ** A vehicle used for road transport. */
  [RailTransport] [numeric](18,0) NULL, /* 0..1 ASBIE Rail Transport ** Equipment used for rail transport. */
  [MaritimeTransport] [numeric](18,0) NULL, /* 0..1 ASBIE Maritime Transport ** A vessel used for transport by water (not only by sea). */
  [OwnerParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The party that owns this means of transport. */
  [MeasurementDimension] [numeric](18,0) NULL, /* 0..n ASBIE Dimension ** A measurable dimension (length, mass, weight, or volume) of this means of transport. */
 CONSTRAINT [PK_TransportMeans] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_JourneyID] ON [dbo].[TransportMeans] 
(
	[JourneyID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_RegistrationNationalityID] ON [dbo].[TransportMeans] 
(
	[RegistrationNationalityID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_RegistrationNationality] ON [dbo].[TransportMeans] 
(
	[RegistrationNationality] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_DirectionCode] ON [dbo].[TransportMeans] 
(
	[DirectionCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_TransportMeansTypeCode] ON [dbo].[TransportMeans] 
(
	[TransportMeansTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_TradeServiceCode] ON [dbo].[TransportMeans] 
(
	[TradeServiceCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_Stowage] ON [dbo].[TransportMeans] 
(
	[Stowage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_AirTransport] ON [dbo].[TransportMeans] 
(
	[AirTransport] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_RoadTransport] ON [dbo].[TransportMeans] 
(
	[RoadTransport] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_RailTransport] ON [dbo].[TransportMeans] 
(
	[RailTransport] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_MaritimeTransport] ON [dbo].[TransportMeans] 
(
	[MaritimeTransport] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_OwnerParty] ON [dbo].[TransportMeans] 
(
	[OwnerParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportMeans_MeasurementDimension] ON [dbo].[TransportMeans] 
(
	[MeasurementDimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportSchedule] Script Date: 2013-10-13 00:21z
Describes the location and schedule relating to a transport means.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportSchedule](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [SequenceNumeric] [numeric](18,0) NOT NULL, /* 1 BBIE Numeric ** A number indicating the order of this status in the sequence in which statuses are to be presented. */
  [ReferenceDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The reference date for the transport schedule status. */
  [ReferenceTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** The reference time for the transport schedule status. */
  [ReliabilityPercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The reliability of the transport schedule status, expressed as a percentage. */
  [Remarks] [numeric](18,0) NULL, /* 0..n BBIE Text ** Remarks related to the transport schedule status. */
  [StatusLocation] [numeric](18,0) NOT NULL, /* 1 ASBIE Location ** The location for which status is reported. */
  [ActualArrivalTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The actual arrival at a location. */
  [ActualDepartureTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The actual departure from a location. */
  [EstimatedDepartureTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** An estimated departure from a specified location. */
  [EstimatedArrivalTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** An estimated arrival at a specified location. */
  [PlannedDepartureTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The planned departure from a specified location. */
  [PlannedArrivalTransportEvent] [numeric](18,0) NULL, /* 0..1 ASBIE Transport Event ** The planned arrival at a specified location. */
 CONSTRAINT [PK_TransportSchedule] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_SequenceNumeric] ON [dbo].[TransportSchedule] 
(
	[SequenceNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_ReferenceDate] ON [dbo].[TransportSchedule] 
(
	[ReferenceDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_ReferenceTime] ON [dbo].[TransportSchedule] 
(
	[ReferenceTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_ReliabilityPercent] ON [dbo].[TransportSchedule] 
(
	[ReliabilityPercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_Remarks] ON [dbo].[TransportSchedule] 
(
	[Remarks] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_StatusLocation] ON [dbo].[TransportSchedule] 
(
	[StatusLocation] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_ActualArrivalTransportEvent] ON [dbo].[TransportSchedule] 
(
	[ActualArrivalTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_ActualDepartureTransportEvent] ON [dbo].[TransportSchedule] 
(
	[ActualDepartureTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_EstimatedDepartureTransportEvent] ON [dbo].[TransportSchedule] 
(
	[EstimatedDepartureTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_EstimatedArrivalTransportEvent] ON [dbo].[TransportSchedule] 
(
	[EstimatedArrivalTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_PlannedDepartureTransportEvent] ON [dbo].[TransportSchedule] 
(
	[PlannedDepartureTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportSchedule_PlannedArrivalTransportEvent] ON [dbo].[TransportSchedule] 
(
	[PlannedArrivalTransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportationSegment] Script Date: 2013-10-13 00:21z
A class to describe one segment or leg in a transportation service.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportationSegment](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [SequenceNumeric] [numeric](18,0) NOT NULL, /* 1 BBIE Numeric ** A number indicating the order of this segment in the sequence of transportation segments making up a transportation service. */
  [TransportExecutionPlanReferenceID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the transport execution plan governing this transportation segment. */
  [TransportationService] [numeric](18,0) NOT NULL, /* 1 ASBIE Transportation Service ** The transportation service used in this transportation segment. */
  [TransportServiceProviderParty] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** The transport service provider responsible for carrying out transportation services in this transportation segment. */
  [ReferencedConsignment] [numeric](18,0) NULL, /* 0..1 ASBIE Consignment ** A consignment referenced in this transportation segment. Such a consignment may have different identifiers than the consignment identifiers being used in the transportation service agreed between the transport user and the transport service provider. */
  [ShipmentStage] [numeric](18,0) NULL, /* 0..n ASBIE Shipment Stage ** The shipment stage associated with this transportation segment. */
 CONSTRAINT [PK_TransportationSegment] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationSegment_SequenceNumeric] ON [dbo].[TransportationSegment] 
(
	[SequenceNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationSegment_TransportExecutionPlanReferenceID] ON [dbo].[TransportationSegment] 
(
	[TransportExecutionPlanReferenceID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationSegment_TransportationService] ON [dbo].[TransportationSegment] 
(
	[TransportationService] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationSegment_TransportServiceProviderParty] ON [dbo].[TransportationSegment] 
(
	[TransportServiceProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationSegment_ReferencedConsignment] ON [dbo].[TransportationSegment] 
(
	[ReferencedConsignment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationSegment_ShipmentStage] ON [dbo].[TransportationSegment] 
(
	[ShipmentStage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[TransportationService] Script Date: 2013-10-13 00:21z
A class to describe a transportation service.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[TransportationService](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [TransportServiceCode] [numeric](18,0) NOT NULL, /* 1 BBIE Code ** A code signifying the extent of this transportation service (e.g., door-to-door, port-to-port). */
  [TariffClassCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the tariff class applicable to this transportation service. */
  [Priority] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The priority of this transportation service. */
  [FreightRateClassCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying the rate class for freight in this transportation service. */
  [TransportationServiceDescription] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this transportation service. */
  [TransportationServiceDetailsURI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The Uniform Resource Identifier (URI) of a document providing additional details regarding this transportation service. */
  [NominationDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** In a transport contract, the deadline date by which this transportation service has to be booked. For example, if this service is scheduled for Wednesday 16 February 2011 at 10 a.m. CET, the nomination date might be Tuesday15 February 2011. */
  [NominationTime] [numeric](18,0) NULL, /* 0..1 BBIE Time ** In a transport contract, the deadline time by which this transportation service has to be booked. For example, if this service is scheduled for Wednesday 16 February 2011 at 10 a.m. CET, the nomination date might be Tuesday15 February 2011 and the nomination time 4 p.m. at the latest. */
  [Name] [numeric](18,0) NULL, /* 0..1 BBIE Name ** The name of this transportation service. */
  [SequenceNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** A number indicating the order of this transportation service in a sequence of transportation services. */
  [TransportEquipment] [numeric](18,0) NULL, /* 0..n ASBIE Transport Equipment ** A piece of transport equipment used in this transportation service. */
  [SupportedTransportEquipment] [numeric](18,0) NULL, /* 0..n ASBIE Transport Equipment ** A piece of transport equipment supported in this transportation service. */
  [UnsupportedTransportEquipment] [numeric](18,0) NULL, /* 0..n ASBIE Transport Equipment ** A piece of transport equipment that is not supported in this transportation service. */
  [CommodityClassification] [numeric](18,0) NULL, /* 0..n ASBIE Commodity Classification ** A classification of this transportation service. */
  [SupportedCommodityClassification] [numeric](18,0) NULL, /* 0..n ASBIE Commodity Classification ** A classification (e.g., general cargo) for commodities that can be handled in this transportation service. */
  [UnsupportedCommodityClassification] [numeric](18,0) NULL, /* 0..n ASBIE Commodity Classification ** A classification for commodities that cannot be handled in this transportation service. */
  [TotalCapacityDimension] [numeric](18,0) NULL, /* 0..1 ASBIE Dimension ** The total capacity or volume available in this transportation service. */
  [ShipmentStage] [numeric](18,0) NULL, /* 0..n ASBIE Shipment Stage ** One of the stages of shipment in this transportation service. */
  [TransportEvent] [numeric](18,0) NULL, /* 0..n ASBIE Transport Event ** One of the transport events taking place in this transportation service. */
  [ResponsibleTransportServiceProviderParty] [numeric](18,0) NULL, /* 0..1 ASBIE Party ** The transport service provider responsible for this transportation service. */
  [EnvironmentalEmission] [numeric](18,0) NULL, /* 0..n ASBIE Environmental Emission ** An environmental emission resulting from this transportation service. */
  [EstimatedDurationPeriod] [numeric](18,0) NULL, /* 0..1 ASBIE Period ** The estimated duration of this transportation service. */
  [ScheduledServiceFrequency] [numeric](18,0) NULL, /* 0..n ASBIE Service Frequency ** A class to specify which day of the week a transport service is operational. */
 CONSTRAINT [PK_TransportationService] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_TransportServiceCode] ON [dbo].[TransportationService] 
(
	[TransportServiceCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_TariffClassCode] ON [dbo].[TransportationService] 
(
	[TariffClassCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_Priority] ON [dbo].[TransportationService] 
(
	[Priority] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_FreightRateClassCode] ON [dbo].[TransportationService] 
(
	[FreightRateClassCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_TransportationServiceDescription] ON [dbo].[TransportationService] 
(
	[TransportationServiceDescription] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_TransportationServiceDetailsURI] ON [dbo].[TransportationService] 
(
	[TransportationServiceDetailsURI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_NominationDate] ON [dbo].[TransportationService] 
(
	[NominationDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_NominationTime] ON [dbo].[TransportationService] 
(
	[NominationTime] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_Name] ON [dbo].[TransportationService] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_SequenceNumeric] ON [dbo].[TransportationService] 
(
	[SequenceNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_TransportEquipment] ON [dbo].[TransportationService] 
(
	[TransportEquipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_SupportedTransportEquipment] ON [dbo].[TransportationService] 
(
	[SupportedTransportEquipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_UnsupportedTransportEquipment] ON [dbo].[TransportationService] 
(
	[UnsupportedTransportEquipment] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_CommodityClassification] ON [dbo].[TransportationService] 
(
	[CommodityClassification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_SupportedCommodityClassification] ON [dbo].[TransportationService] 
(
	[SupportedCommodityClassification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_UnsupportedCommodityClassification] ON [dbo].[TransportationService] 
(
	[UnsupportedCommodityClassification] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_TotalCapacityDimension] ON [dbo].[TransportationService] 
(
	[TotalCapacityDimension] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_ShipmentStage] ON [dbo].[TransportationService] 
(
	[ShipmentStage] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_TransportEvent] ON [dbo].[TransportationService] 
(
	[TransportEvent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_ResponsibleTransportServiceProviderParty] ON [dbo].[TransportationService] 
(
	[ResponsibleTransportServiceProviderParty] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_EnvironmentalEmission] ON [dbo].[TransportationService] 
(
	[EnvironmentalEmission] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_EstimatedDurationPeriod] ON [dbo].[TransportationService] 
(
	[EstimatedDurationPeriod] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TransportationService_ScheduledServiceFrequency] ON [dbo].[TransportationService] 
(
	[ScheduledServiceFrequency] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[UnstructuredPrice] Script Date: 2013-10-13 00:21z
A simplified version of the Price class intended for applications such as telephone billing.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[UnstructuredPrice](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [PriceAmount] [numeric](18,0) NULL, /* 0..1 BBIE Amount ** The price amount. */
  [TimeAmount] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The usage time upon which the price is based. */
 CONSTRAINT [PK_UnstructuredPrice] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnstructuredPrice_PriceAmount] ON [dbo].[UnstructuredPrice] 
(
	[PriceAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UnstructuredPrice_TimeAmount] ON [dbo].[UnstructuredPrice] 
(
	[TimeAmount] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[UtilityItem] Script Date: 2013-10-13 00:21z
A class to describe the consumption of a utility product.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[UtilityItem](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NOT NULL, /* 1 BBIE Identifier ** An identifier for this utility item. */
  [SubscriberID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for the subscriber to the utility. */
  [SubscriberType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Identification of the subscriber type, expressed as text.. */
  [SubscriberTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The code identifying for the service type. */
  [Description] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing the consumption product. */
  [PackQuantity] [numeric](18,0) NULL, /* 0..1 BBIE Quantity ** The unit packaging quantity. */
  [PackSizeNumeric] [numeric](18,0) NULL, /* 0..1 BBIE Numeric ** The number of items in a pack. */
  [ConsumptionType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** The type of product consumed, expressed as text. */
  [ConsumptionTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** The type of product consumed, expressed as a code. */
  [CurrentChargeType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Information of the actual payments type for the utility Item */
  [CurrentChargeTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Information of the actual payments type code expressed as a code */
  [OneTimeChargeType] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Information about the one-time payment type in case everything is paid One time */
  [OneTimeChargeTypeCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** Information about the one-time payment type code */
  [TaxCategory] [numeric](18,0) NULL, /* 0..1 ASBIE Tax Category ** The tax category applicable to this utility item. */
  [Contract] [numeric](18,0) NULL, /* 0..1 ASBIE Contract ** A contract setting forth conditions applicable to this utility item. */
 CONSTRAINT [PK_UtilityItem] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_ID] ON [dbo].[UtilityItem] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_SubscriberID] ON [dbo].[UtilityItem] 
(
	[SubscriberID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_SubscriberType] ON [dbo].[UtilityItem] 
(
	[SubscriberType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_SubscriberTypeCode] ON [dbo].[UtilityItem] 
(
	[SubscriberTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_Description] ON [dbo].[UtilityItem] 
(
	[Description] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_PackQuantity] ON [dbo].[UtilityItem] 
(
	[PackQuantity] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_PackSizeNumeric] ON [dbo].[UtilityItem] 
(
	[PackSizeNumeric] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_ConsumptionType] ON [dbo].[UtilityItem] 
(
	[ConsumptionType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_ConsumptionTypeCode] ON [dbo].[UtilityItem] 
(
	[ConsumptionTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_CurrentChargeType] ON [dbo].[UtilityItem] 
(
	[CurrentChargeType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_CurrentChargeTypeCode] ON [dbo].[UtilityItem] 
(
	[CurrentChargeTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_OneTimeChargeType] ON [dbo].[UtilityItem] 
(
	[OneTimeChargeType] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_OneTimeChargeTypeCode] ON [dbo].[UtilityItem] 
(
	[OneTimeChargeTypeCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_TaxCategory] ON [dbo].[UtilityItem] 
(
	[TaxCategory] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_UtilityItem_Contract] ON [dbo].[UtilityItem] 
(
	[Contract] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[WebSiteAccess] Script Date: 2013-10-13 00:21z
A class to describe access to a web site.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[WebSiteAccess](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [URI] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** The Uniform Resource Identifier (URI) for this web site; i.e., its Uniform Resource Locator (URL). */
  [Password] [numeric](18,0) NOT NULL, /* 1 BBIE Text ** A password to the web site. */
  [Login] [numeric](18,0) NOT NULL, /* 1 BBIE Text ** Text describing login details. */
 CONSTRAINT [PK_WebSiteAccess] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WebSiteAccess_URI] ON [dbo].[WebSiteAccess] 
(
	[URI] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WebSiteAccess_Password] ON [dbo].[WebSiteAccess] 
(
	[Password] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WebSiteAccess_Login] ON [dbo].[WebSiteAccess] 
(
	[Login] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[WinningParty] Script Date: 2013-10-13 00:21z
A party that is identified as the awarded by a tender result.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[WinningParty](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [Rank] [numeric](18,0) NULL, /* 0..1 BBIE Text ** Indicates the rank obtained in the award. */
  [Party] [numeric](18,0) NOT NULL, /* 1 ASBIE Party ** Information about an organization, sub-organization, or individual fulfilling a role in a business process. */
 CONSTRAINT [PK_WinningParty] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WinningParty_Rank] ON [dbo].[WinningParty] 
(
	[Rank] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WinningParty_Party] ON [dbo].[WinningParty] 
(
	[Party] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[WorkPhaseReference] Script Date: 2013-10-13 00:21z
A class that refers to a phase of work. Used for instance to specify what part of the contract the billing is referring to.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[WorkPhaseReference](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
  [ID] [numeric](18,0) NULL, /* 0..1 BBIE Identifier ** An identifier for this phase of work. */
  [WorkPhaseCode] [numeric](18,0) NULL, /* 0..1 BBIE Code ** A code signifying this phase of work. */
  [WorkPhase] [numeric](18,0) NULL, /* 0..n BBIE Text ** Text describing this phase of work. */
  [ProgressPercent] [numeric](18,0) NULL, /* 0..1 BBIE Percent ** The progress percentage of the work phase. */
  [StartDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this phase of work begins. */
  [EndDate] [numeric](18,0) NULL, /* 0..1 BBIE Date ** The date on which this phase of work ends. */
  [WorkOrderDocumentReference] [numeric](18,0) NULL, /* 0..n ASBIE Document Reference ** A reference to a document regarding the work order for the project in which this phase of work takes place. */
 CONSTRAINT [PK_WorkPhaseReference] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WorkPhaseReference_ID] ON [dbo].[WorkPhaseReference] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WorkPhaseReference_WorkPhaseCode] ON [dbo].[WorkPhaseReference] 
(
	[WorkPhaseCode] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WorkPhaseReference_WorkPhase] ON [dbo].[WorkPhaseReference] 
(
	[WorkPhase] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WorkPhaseReference_ProgressPercent] ON [dbo].[WorkPhaseReference] 
(
	[ProgressPercent] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WorkPhaseReference_StartDate] ON [dbo].[WorkPhaseReference] 
(
	[StartDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WorkPhaseReference_EndDate] ON [dbo].[WorkPhaseReference] 
(
	[EndDate] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_WorkPhaseReference_WorkOrderDocumentReference] ON [dbo].[WorkPhaseReference] 
(
	[WorkOrderDocumentReference] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

/*
===============================================================================
Unqualified Data Types
===============================================================================
*/

/****** Object:  Table [dbo].[Amount] Script Date: 2013-10-13 00:21z
A number of monetary units specified using a given unit of currency.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Amount](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [currencyID] [nvarchar](max) NOT NULL,/* 1 */
  [currencyCodeListVersionID] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Amount] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[BinaryObject] Script Date: 2013-10-13 00:21z
A set of finite-length sequences of binary octets.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[BinaryObject](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [mimeCode] [nvarchar](max) NOT NULL,/* 1 */
  [format] [nvarchar](max) NULL,/* 0..1 */
  [encodingCode] [nvarchar](max) NULL,/* 0..1 */
  [characterSetCode] [nvarchar](max) NULL,/* 0..1 */
  [uri] [nvarchar](max) NULL,/* 0..1 */
  [filename] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_BinaryObject] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Graphic] Script Date: 2013-10-13 00:21z
A diagram, graph, mathematical curve, or similar representation.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Graphic](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [mimeCode] [nvarchar](max) NOT NULL,/* 1 */
  [format] [nvarchar](max) NULL,/* 0..1 */
  [encodingCode] [nvarchar](max) NULL,/* 0..1 */
  [characterSetCode] [nvarchar](max) NULL,/* 0..1 */
  [uri] [nvarchar](max) NULL,/* 0..1 */
  [filename] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Graphic] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Picture] Script Date: 2013-10-13 00:21z
A diagram, graph, mathematical curve, or similar representation.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Picture](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [mimeCode] [nvarchar](max) NOT NULL,/* 1 */
  [format] [nvarchar](max) NULL,/* 0..1 */
  [encodingCode] [nvarchar](max) NULL,/* 0..1 */
  [characterSetCode] [nvarchar](max) NULL,/* 0..1 */
  [uri] [nvarchar](max) NULL,/* 0..1 */
  [filename] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Picture] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Sound] Script Date: 2013-10-13 00:21z
An audio representation.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Sound](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [mimeCode] [nvarchar](max) NOT NULL,/* 1 */
  [format] [nvarchar](max) NULL,/* 0..1 */
  [encodingCode] [nvarchar](max) NULL,/* 0..1 */
  [characterSetCode] [nvarchar](max) NULL,/* 0..1 */
  [uri] [nvarchar](max) NULL,/* 0..1 */
  [filename] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Sound] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Video] Script Date: 2013-10-13 00:21z
A video representation.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Video](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [mimeCode] [nvarchar](max) NOT NULL,/* 1 */
  [format] [nvarchar](max) NULL,/* 0..1 */
  [encodingCode] [nvarchar](max) NULL,/* 0..1 */
  [characterSetCode] [nvarchar](max) NULL,/* 0..1 */
  [uri] [nvarchar](max) NULL,/* 0..1 */
  [filename] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Video] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Code] Script Date: 2013-10-13 00:21z
A character string (letters, figures, or symbols) that for brevity and/or language independence may be used to represent or replace a definitive value or text of an attribute, together with relevant supplementary information.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Code](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [listID] [nvarchar](max) NULL,/* 0..1 */
  [listAgencyID] [nvarchar](max) NULL,/* 0..1 */
  [listAgencyName] [nvarchar](max) NULL,/* 0..1 */
  [listName] [nvarchar](max) NULL,/* 0..1 */
  [listVersionID] [nvarchar](max) NULL,/* 0..1 */
  [name] [nvarchar](max) NULL,/* 0..1 */
  [languageID] [nvarchar](max) NULL,/* 0..1 */
  [listURI] [nvarchar](max) NULL,/* 0..1 */
  [listSchemeURI] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Code] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[DateTime] Script Date: 2013-10-13 00:21z
A particular point in the progression of time, together with relevant supplementary information.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DateTime](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
 CONSTRAINT [PK_DateTime] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Date] Script Date: 2013-10-13 00:21z
One calendar day according the Gregorian calendar.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Date](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
 CONSTRAINT [PK_Date] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Time] Script Date: 2013-10-13 00:21z
An instance of time that occurs every day.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Time](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
 CONSTRAINT [PK_Time] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Identifier] Script Date: 2013-10-13 00:21z
A character string to identify and uniquely distinguish one instance of an object in an identification scheme from all other objects in the same scheme, together with relevant supplementary information.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Identifier](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [schemeID] [nvarchar](max) NULL,/* 0..1 */
  [schemeName] [nvarchar](max) NULL,/* 0..1 */
  [schemeAgencyID] [nvarchar](max) NULL,/* 0..1 */
  [schemeAgencyName] [nvarchar](max) NULL,/* 0..1 */
  [schemeVersionID] [nvarchar](max) NULL,/* 0..1 */
  [schemeDataURI] [nvarchar](max) NULL,/* 0..1 */
  [schemeURI] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Identifier] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Indicator] Script Date: 2013-10-13 00:21z
A list of two mutually exclusive Boolean values that express the only possible states of a property.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Indicator](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
 CONSTRAINT [PK_Indicator] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Measure] Script Date: 2013-10-13 00:21z
A numeric value determined by measuring an object using a specified unit of measure.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Measure](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [unitCode] [nvarchar](max) NOT NULL,/* 1 */
  [unitCodeListVersionID] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Measure] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Numeric] Script Date: 2013-10-13 00:21z
Numeric information that is assigned or is determined by calculation, counting, or sequencing. It does not require a unit of quantity or unit of measure.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Numeric](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [format] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Numeric] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Value] Script Date: 2013-10-13 00:21z
Numeric information that is assigned or is determined by calculation, counting, or sequencing. It does not require a unit of quantity or unit of measure.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Value](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [format] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Value] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Percent] Script Date: 2013-10-13 00:21z
Numeric information that is assigned or is determined by calculation, counting, or sequencing and is expressed as a percentage. It does not require a unit of quantity or unit of measure.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Percent](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [format] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Percent] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Rate] Script Date: 2013-10-13 00:21z
A numeric expression of a rate that is assigned or is determined by calculation, counting, or sequencing. It does not require a unit of quantity or unit of measure.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Rate](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [format] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Rate] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Quantity] Script Date: 2013-10-13 00:21z
A counted number of non-monetary units, possibly including a fractional part.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Quantity](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [unitCode] [nvarchar](max) NULL,/* 0..1 */
  [unitCodeListID] [nvarchar](max) NULL,/* 0..1 */
  [unitCodeListAgencyID] [nvarchar](max) NULL,/* 0..1 */
  [unitCodeListAgencyName] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Quantity] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Text] Script Date: 2013-10-13 00:21z
A character string (i.e. a finite set of characters), generally in the form of words of a language.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Text](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [languageID] [nvarchar](max) NULL,/* 0..1 */
  [languageLocaleID] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Text] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[Name] Script Date: 2013-10-13 00:21z
A character string that constitutes the distinctive designation of a person, place, thing or concept.
******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Name](
	[Ref] [numeric](18, 0) NOT NULL,
	[Seq] [numeric](18, 0) IDENTITY(1,1) NOT NULL,
	[Core] [nvarchar](max) NOT NULL,
  [languageID] [nvarchar](max) NULL,/* 0..1 */
  [languageLocaleID] [nvarchar](max) NULL,/* 0..1 */
 CONSTRAINT [PK_Name] PRIMARY KEY CLUSTERED 
(
	[Ref] ASC,
	[Seq] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO

/*
===============================================================================
Association Business Information Entities
===============================================================================
*/

ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_ApplicationResponse]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_ApplicationResponse]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_ApplicationResponse]
GO
ALTER TABLE [dbo].[DocumentResponse] WITH CHECK ADD CONSTRAINT [FK_DocumentResponse_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([DocumentResponse])
GO
ALTER TABLE [dbo].[DocumentResponse] CHECK CONSTRAINT [FK_DocumentResponse_ApplicationResponse]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_AttachedDocument]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_AttachedDocument]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_AttachedDocument]
GO
ALTER TABLE [dbo].[Attachment] WITH CHECK ADD CONSTRAINT [FK_Attachment_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([Attachment])
GO
ALTER TABLE [dbo].[Attachment] CHECK CONSTRAINT [FK_Attachment_AttachedDocument]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_ParentDocumentLineReference_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([ParentDocumentLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_ParentDocumentLineReference_AttachedDocument]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_AwardedNotification]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_AwardedNotification]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_MinutesDocumentReference_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([MinutesDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_MinutesDocumentReference_AwardedNotification]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_AwardedNotification]
GO
ALTER TABLE [dbo].[TenderResult] WITH CHECK ADD CONSTRAINT [FK_TenderResult_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([TenderResult])
GO
ALTER TABLE [dbo].[TenderResult] CHECK CONSTRAINT [FK_TenderResult_AwardedNotification]
GO
ALTER TABLE [dbo].[FinancialGuarantee] WITH CHECK ADD CONSTRAINT [FK_FinalFinancialGuarantee_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([FinalFinancialGuarantee])
GO
ALTER TABLE [dbo].[FinancialGuarantee] CHECK CONSTRAINT [FK_FinalFinancialGuarantee_AwardedNotification]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_AwardedNotification]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ConsignorParty_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([ConsignorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ConsignorParty_BillOfLading]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_CarrierParty_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([CarrierParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_CarrierParty_BillOfLading]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_FreightForwarderParty_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([FreightForwarderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_FreightForwarderParty_BillOfLading]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_BillOfLading]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_BillOfLading]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_ExchangeRate_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([ExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_ExchangeRate_BillOfLading]
GO
ALTER TABLE [dbo].[DocumentDistribution] WITH CHECK ADD CONSTRAINT [FK_DocumentDistribution_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([DocumentDistribution])
GO
ALTER TABLE [dbo].[DocumentDistribution] CHECK CONSTRAINT [FK_DocumentDistribution_BillOfLading]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_BillOfLading]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_LegalDocumentReference_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([LegalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_LegalDocumentReference_CallForTenders]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TechnicalDocumentReference_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([TechnicalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TechnicalDocumentReference_CallForTenders]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_CallForTenders]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_CallForTenders]
GO
ALTER TABLE [dbo].[ContractingParty] WITH CHECK ADD CONSTRAINT [FK_ContractingParty_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([ContractingParty])
GO
ALTER TABLE [dbo].[ContractingParty] CHECK CONSTRAINT [FK_ContractingParty_CallForTenders]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_CallForTenders]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_CallForTenders]
GO
ALTER TABLE [dbo].[TenderingTerms] WITH CHECK ADD CONSTRAINT [FK_TenderingTerms_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([TenderingTerms])
GO
ALTER TABLE [dbo].[TenderingTerms] CHECK CONSTRAINT [FK_TenderingTerms_CallForTenders]
GO
ALTER TABLE [dbo].[TenderingProcess] WITH CHECK ADD CONSTRAINT [FK_TenderingProcess_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([TenderingProcess])
GO
ALTER TABLE [dbo].[TenderingProcess] CHECK CONSTRAINT [FK_TenderingProcess_CallForTenders]
GO
ALTER TABLE [dbo].[ProcurementProject] WITH CHECK ADD CONSTRAINT [FK_ProcurementProject_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([ProcurementProject])
GO
ALTER TABLE [dbo].[ProcurementProject] CHECK CONSTRAINT [FK_ProcurementProject_CallForTenders]
GO
ALTER TABLE [dbo].[ProcurementProjectLot] WITH CHECK ADD CONSTRAINT [FK_ProcurementProjectLot_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([ProcurementProjectLot])
GO
ALTER TABLE [dbo].[ProcurementProjectLot] CHECK CONSTRAINT [FK_ProcurementProjectLot_CallForTenders]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_Catalogue]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_ReferencedContract_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([ReferencedContract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_ReferencedContract_Catalogue]
GO
ALTER TABLE [dbo].[CatalogueReference] WITH CHECK ADD CONSTRAINT [FK_SourceCatalogueReference_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([SourceCatalogueReference])
GO
ALTER TABLE [dbo].[CatalogueReference] CHECK CONSTRAINT [FK_SourceCatalogueReference_Catalogue]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_Catalogue]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_Catalogue]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ProviderParty_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([ProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ProviderParty_Catalogue]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_Catalogue]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_Catalogue]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_ContractorCustomerParty_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([ContractorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_ContractorCustomerParty_Catalogue]
GO
ALTER TABLE [dbo].[TradingTerms] WITH CHECK ADD CONSTRAINT [FK_TradingTerms_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([TradingTerms])
GO
ALTER TABLE [dbo].[TradingTerms] CHECK CONSTRAINT [FK_TradingTerms_Catalogue]
GO
ALTER TABLE [dbo].[CatalogueLine] WITH CHECK ADD CONSTRAINT [FK_CatalogueLine_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([CatalogueLine])
GO
ALTER TABLE [dbo].[CatalogueLine] CHECK CONSTRAINT [FK_CatalogueLine_Catalogue]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_CatalogueDeletion]
GO
ALTER TABLE [dbo].[CatalogueReference] WITH CHECK ADD CONSTRAINT [FK_DeletedCatalogueReference_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([DeletedCatalogueReference])
GO
ALTER TABLE [dbo].[CatalogueReference] CHECK CONSTRAINT [FK_DeletedCatalogueReference_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_ReferencedContract_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([ReferencedContract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_ReferencedContract_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ProviderParty_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([ProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ProviderParty_CatalogueDeletion]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_CatalogueDeletion]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_ContractorCustomerParty_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([ContractorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_ContractorCustomerParty_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[CatalogueReference] WITH CHECK ADD CONSTRAINT [FK_RelatedCatalogueReference_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([RelatedCatalogueReference])
GO
ALTER TABLE [dbo].[CatalogueReference] CHECK CONSTRAINT [FK_RelatedCatalogueReference_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_ReferencedContract_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([ReferencedContract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_ReferencedContract_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ProviderParty_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([ProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ProviderParty_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_ContractorCustomerParty_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([ContractorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_ContractorCustomerParty_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[TradingTerms] WITH CHECK ADD CONSTRAINT [FK_TradingTerms_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([TradingTerms])
GO
ALTER TABLE [dbo].[TradingTerms] CHECK CONSTRAINT [FK_TradingTerms_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Language] WITH CHECK ADD CONSTRAINT [FK_DefaultLanguage_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([DefaultLanguage])
GO
ALTER TABLE [dbo].[Language] CHECK CONSTRAINT [FK_DefaultLanguage_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[CatalogueItemSpecificationUpdateLine] WITH CHECK ADD CONSTRAINT [FK_CatalogueItemSpecificationUpdateLine_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([CatalogueItemSpecificationUpdateLine])
GO
ALTER TABLE [dbo].[CatalogueItemSpecificationUpdateLine] CHECK CONSTRAINT [FK_CatalogueItemSpecificationUpdateLine_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[CatalogueReference] WITH CHECK ADD CONSTRAINT [FK_RelatedCatalogueReference_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([RelatedCatalogueReference])
GO
ALTER TABLE [dbo].[CatalogueReference] CHECK CONSTRAINT [FK_RelatedCatalogueReference_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_ReferencedContract_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([ReferencedContract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_ReferencedContract_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ProviderParty_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([ProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ProviderParty_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_ContractorCustomerParty_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([ContractorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_ContractorCustomerParty_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[TradingTerms] WITH CHECK ADD CONSTRAINT [FK_TradingTerms_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([TradingTerms])
GO
ALTER TABLE [dbo].[TradingTerms] CHECK CONSTRAINT [FK_TradingTerms_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Language] WITH CHECK ADD CONSTRAINT [FK_DefaultLanguage_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([DefaultLanguage])
GO
ALTER TABLE [dbo].[Language] CHECK CONSTRAINT [FK_DefaultLanguage_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[CataloguePricingUpdateLine] WITH CHECK ADD CONSTRAINT [FK_CataloguePricingUpdateLine_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([CataloguePricingUpdateLine])
GO
ALTER TABLE [dbo].[CataloguePricingUpdateLine] CHECK CONSTRAINT [FK_CataloguePricingUpdateLine_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_CatalogueRequest]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_CatalogueRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_CatalogueRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ProviderParty_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([ProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ProviderParty_CatalogueRequest]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_CatalogueRequest]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_ContractorCustomerParty_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([ContractorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_ContractorCustomerParty_CatalogueRequest]
GO
ALTER TABLE [dbo].[CatalogueReference] WITH CHECK ADD CONSTRAINT [FK_RequestedCatalogueReference_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([RequestedCatalogueReference])
GO
ALTER TABLE [dbo].[CatalogueReference] CHECK CONSTRAINT [FK_RequestedCatalogueReference_CatalogueRequest]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_ReferencedContract_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([ReferencedContract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_ReferencedContract_CatalogueRequest]
GO
ALTER TABLE [dbo].[TradingTerms] WITH CHECK ADD CONSTRAINT [FK_TradingTerms_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([TradingTerms])
GO
ALTER TABLE [dbo].[TradingTerms] CHECK CONSTRAINT [FK_TradingTerms_CatalogueRequest]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_CatalogueRequest]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_ApplicableTerritoryAddress_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([ApplicableTerritoryAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_ApplicableTerritoryAddress_CatalogueRequest]
GO
ALTER TABLE [dbo].[Language] WITH CHECK ADD CONSTRAINT [FK_RequestedLanguage_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([RequestedLanguage])
GO
ALTER TABLE [dbo].[Language] CHECK CONSTRAINT [FK_RequestedLanguage_CatalogueRequest]
GO
ALTER TABLE [dbo].[ClassificationScheme] WITH CHECK ADD CONSTRAINT [FK_RequestedClassificationScheme_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([RequestedClassificationScheme])
GO
ALTER TABLE [dbo].[ClassificationScheme] CHECK CONSTRAINT [FK_RequestedClassificationScheme_CatalogueRequest]
GO
ALTER TABLE [dbo].[CatalogueRequestLine] WITH CHECK ADD CONSTRAINT [FK_CatalogueRequestLine_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([CatalogueRequestLine])
GO
ALTER TABLE [dbo].[CatalogueRequestLine] CHECK CONSTRAINT [FK_CatalogueRequestLine_CatalogueRequest]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ExporterParty_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([ExporterParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ExporterParty_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ImporterParty_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([ImporterParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ImporterParty_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[EndorserParty] WITH CHECK ADD CONSTRAINT [FK_EndorserParty_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([EndorserParty])
GO
ALTER TABLE [dbo].[EndorserParty] CHECK CONSTRAINT [FK_EndorserParty_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[CertificateOfOriginApplication] WITH CHECK ADD CONSTRAINT [FK_CertificateOfOriginApplication_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([CertificateOfOriginApplication])
GO
ALTER TABLE [dbo].[CertificateOfOriginApplication] CHECK CONSTRAINT [FK_CertificateOfOriginApplication_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Endorsement] WITH CHECK ADD CONSTRAINT [FK_IssuerEndorsement_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([IssuerEndorsement])
GO
ALTER TABLE [dbo].[Endorsement] CHECK CONSTRAINT [FK_IssuerEndorsement_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Endorsement] WITH CHECK ADD CONSTRAINT [FK_EmbassyEndorsement_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([EmbassyEndorsement])
GO
ALTER TABLE [dbo].[Endorsement] CHECK CONSTRAINT [FK_EmbassyEndorsement_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Endorsement] WITH CHECK ADD CONSTRAINT [FK_InsuranceEndorsement_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([InsuranceEndorsement])
GO
ALTER TABLE [dbo].[Endorsement] CHECK CONSTRAINT [FK_InsuranceEndorsement_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_PreviousDocumentReference_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([PreviousDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_PreviousDocumentReference_ContractAwardNotice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_MinutesDocumentReference_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([MinutesDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_MinutesDocumentReference_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_ContractAwardNotice]
GO
ALTER TABLE [dbo].[ContractingParty] WITH CHECK ADD CONSTRAINT [FK_ContractingParty_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([ContractingParty])
GO
ALTER TABLE [dbo].[ContractingParty] CHECK CONSTRAINT [FK_ContractingParty_ContractAwardNotice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_ContractAwardNotice]
GO
ALTER TABLE [dbo].[TenderingTerms] WITH CHECK ADD CONSTRAINT [FK_TenderingTerms_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([TenderingTerms])
GO
ALTER TABLE [dbo].[TenderingTerms] CHECK CONSTRAINT [FK_TenderingTerms_ContractAwardNotice]
GO
ALTER TABLE [dbo].[TenderingProcess] WITH CHECK ADD CONSTRAINT [FK_TenderingProcess_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([TenderingProcess])
GO
ALTER TABLE [dbo].[TenderingProcess] CHECK CONSTRAINT [FK_TenderingProcess_ContractAwardNotice]
GO
ALTER TABLE [dbo].[ProcurementProject] WITH CHECK ADD CONSTRAINT [FK_ProcurementProject_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([ProcurementProject])
GO
ALTER TABLE [dbo].[ProcurementProject] CHECK CONSTRAINT [FK_ProcurementProject_ContractAwardNotice]
GO
ALTER TABLE [dbo].[ProcurementProjectLot] WITH CHECK ADD CONSTRAINT [FK_ProcurementProjectLot_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([ProcurementProjectLot])
GO
ALTER TABLE [dbo].[ProcurementProjectLot] CHECK CONSTRAINT [FK_ProcurementProjectLot_ContractAwardNotice]
GO
ALTER TABLE [dbo].[TenderResult] WITH CHECK ADD CONSTRAINT [FK_TenderResult_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([TenderResult])
GO
ALTER TABLE [dbo].[TenderResult] CHECK CONSTRAINT [FK_TenderResult_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_FrequencyPeriod_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([FrequencyPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_FrequencyPeriod_ContractNotice]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_ContractNotice]
GO
ALTER TABLE [dbo].[ContractingParty] WITH CHECK ADD CONSTRAINT [FK_ContractingParty_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([ContractingParty])
GO
ALTER TABLE [dbo].[ContractingParty] CHECK CONSTRAINT [FK_ContractingParty_ContractNotice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_ContractNotice]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_ContractNotice]
GO
ALTER TABLE [dbo].[TenderingTerms] WITH CHECK ADD CONSTRAINT [FK_TenderingTerms_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([TenderingTerms])
GO
ALTER TABLE [dbo].[TenderingTerms] CHECK CONSTRAINT [FK_TenderingTerms_ContractNotice]
GO
ALTER TABLE [dbo].[TenderingProcess] WITH CHECK ADD CONSTRAINT [FK_TenderingProcess_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([TenderingProcess])
GO
ALTER TABLE [dbo].[TenderingProcess] CHECK CONSTRAINT [FK_TenderingProcess_ContractNotice]
GO
ALTER TABLE [dbo].[ProcurementProject] WITH CHECK ADD CONSTRAINT [FK_ProcurementProject_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([ProcurementProject])
GO
ALTER TABLE [dbo].[ProcurementProject] CHECK CONSTRAINT [FK_ProcurementProject_ContractNotice]
GO
ALTER TABLE [dbo].[ProcurementProjectLot] WITH CHECK ADD CONSTRAINT [FK_ProcurementProjectLot_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([ProcurementProjectLot])
GO
ALTER TABLE [dbo].[ProcurementProjectLot] CHECK CONSTRAINT [FK_ProcurementProjectLot_ContractNotice]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvoicePeriod_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([InvoicePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvoicePeriod_CreditNote]
GO
ALTER TABLE [dbo].[Response] WITH CHECK ADD CONSTRAINT [FK_DiscrepancyResponse_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([DiscrepancyResponse])
GO
ALTER TABLE [dbo].[Response] CHECK CONSTRAINT [FK_DiscrepancyResponse_CreditNote]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_CreditNote]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_CreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DespatchDocumentReference_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([DespatchDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DespatchDocumentReference_CreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ReceiptDocumentReference_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([ReceiptDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ReceiptDocumentReference_CreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ContractDocumentReference_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([ContractDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ContractDocumentReference_CreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_CreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_StatementDocumentReference_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([StatementDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_StatementDocumentReference_CreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginatorDocumentReference_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([OriginatorDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginatorDocumentReference_CreditNote]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_CreditNote]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_CreditNote]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_CreditNote]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_CreditNote]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_CreditNote]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_CreditNote]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TaxRepresentativeParty_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([TaxRepresentativeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TaxRepresentativeParty_CreditNote]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_CreditNote]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_CreditNote]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_CreditNote]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_CreditNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_TaxExchangeRate_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([TaxExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_TaxExchangeRate_CreditNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PricingExchangeRate_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([PricingExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PricingExchangeRate_CreditNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentExchangeRate_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([PaymentExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentExchangeRate_CreditNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeExchangeRate_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([PaymentAlternativeExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentAlternativeExchangeRate_CreditNote]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_CreditNote]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_CreditNote]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_LegalMonetaryTotal_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([LegalMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_LegalMonetaryTotal_CreditNote]
GO
ALTER TABLE [dbo].[CreditNoteLine] WITH CHECK ADD CONSTRAINT [FK_CreditNoteLine_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([CreditNoteLine])
GO
ALTER TABLE [dbo].[CreditNoteLine] CHECK CONSTRAINT [FK_CreditNoteLine_CreditNote]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvoicePeriod_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([InvoicePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvoicePeriod_DebitNote]
GO
ALTER TABLE [dbo].[Response] WITH CHECK ADD CONSTRAINT [FK_DiscrepancyResponse_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([DiscrepancyResponse])
GO
ALTER TABLE [dbo].[Response] CHECK CONSTRAINT [FK_DiscrepancyResponse_DebitNote]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_DebitNote]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_DebitNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DespatchDocumentReference_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([DespatchDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DespatchDocumentReference_DebitNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ReceiptDocumentReference_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([ReceiptDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ReceiptDocumentReference_DebitNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_StatementDocumentReference_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([StatementDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_StatementDocumentReference_DebitNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ContractDocumentReference_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([ContractDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ContractDocumentReference_DebitNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_DebitNote]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_DebitNote]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_DebitNote]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_DebitNote]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_DebitNote]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_DebitNote]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_DebitNote]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TaxRepresentativeParty_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([TaxRepresentativeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TaxRepresentativeParty_DebitNote]
GO
ALTER TABLE [dbo].[Payment] WITH CHECK ADD CONSTRAINT [FK_PrepaidPayment_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([PrepaidPayment])
GO
ALTER TABLE [dbo].[Payment] CHECK CONSTRAINT [FK_PrepaidPayment_DebitNote]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_DebitNote]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_DebitNote]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_DebitNote]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_DebitNote]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_DebitNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_TaxExchangeRate_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([TaxExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_TaxExchangeRate_DebitNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PricingExchangeRate_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([PricingExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PricingExchangeRate_DebitNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentExchangeRate_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([PaymentExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentExchangeRate_DebitNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeExchangeRate_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([PaymentAlternativeExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentAlternativeExchangeRate_DebitNote]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_DebitNote]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_RequestedMonetaryTotal_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([RequestedMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_RequestedMonetaryTotal_DebitNote]
GO
ALTER TABLE [dbo].[DebitNoteLine] WITH CHECK ADD CONSTRAINT [FK_DebitNoteLine_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([DebitNoteLine])
GO
ALTER TABLE [dbo].[DebitNoteLine] CHECK CONSTRAINT [FK_DebitNoteLine_DebitNote]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_DespatchAdvice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_DespatchAdvice]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_DespatchAdvice]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_DespatchSupplierParty_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([DespatchSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_DespatchSupplierParty_DespatchAdvice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_DeliveryCustomerParty_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([DeliveryCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_DeliveryCustomerParty_DespatchAdvice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_DespatchAdvice]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_DespatchAdvice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_DespatchAdvice]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_DespatchAdvice]
GO
ALTER TABLE [dbo].[DespatchLine] WITH CHECK ADD CONSTRAINT [FK_DespatchLine_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([DespatchLine])
GO
ALTER TABLE [dbo].[DespatchLine] CHECK CONSTRAINT [FK_DespatchLine_DespatchAdvice]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_DocumentStatus]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_DocumentStatus]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_DocumentStatus]
GO
ALTER TABLE [dbo].[DocumentResponse] WITH CHECK ADD CONSTRAINT [FK_DocumentResponse_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([DocumentResponse])
GO
ALTER TABLE [dbo].[DocumentResponse] CHECK CONSTRAINT [FK_DocumentResponse_DocumentStatus]
GO
ALTER TABLE [dbo].[DocumentResponse] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentResponse_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([AdditionalDocumentResponse])
GO
ALTER TABLE [dbo].[DocumentResponse] CHECK CONSTRAINT [FK_AdditionalDocumentResponse_DocumentStatus]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_RequestedDocumentReference_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([RequestedDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_RequestedDocumentReference_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_ExceptionCriteria]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_ExceptionCriteria]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_ExceptionCriteria]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_ExceptionCriteria]
GO
ALTER TABLE [dbo].[ExceptionCriteriaLine] WITH CHECK ADD CONSTRAINT [FK_ExceptionCriteriaLine_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([ExceptionCriteriaLine])
GO
ALTER TABLE [dbo].[ExceptionCriteriaLine] CHECK CONSTRAINT [FK_ExceptionCriteriaLine_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ExceptionObservationPeriod_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([ExceptionObservationPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ExceptionObservationPeriod_ExceptionNotification]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_ExceptionNotification]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_ExceptionNotification]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_ExceptionNotification]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_ExceptionNotification]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_ExceptionNotification]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_ExceptionNotification]
GO
ALTER TABLE [dbo].[ExceptionNotificationLine] WITH CHECK ADD CONSTRAINT [FK_ExceptionNotificationLine_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([ExceptionNotificationLine])
GO
ALTER TABLE [dbo].[ExceptionNotificationLine] CHECK CONSTRAINT [FK_ExceptionNotificationLine_ExceptionNotification]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ForecastPeriod_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([ForecastPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ForecastPeriod_Forecast]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_Forecast]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_Forecast]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_Forecast]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_Forecast]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_Forecast]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_Forecast]
GO
ALTER TABLE [dbo].[ForecastLine] WITH CHECK ADD CONSTRAINT [FK_ForecastLine_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([ForecastLine])
GO
ALTER TABLE [dbo].[ForecastLine] CHECK CONSTRAINT [FK_ForecastLine_Forecast]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ForecastPeriod_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([ForecastPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ForecastPeriod_ForecastRevision]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginalDocumentReference_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([OriginalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginalDocumentReference_ForecastRevision]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_ForecastRevision]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_ForecastRevision]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_ForecastRevision]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_ForecastRevision]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_ForecastRevision]
GO
ALTER TABLE [dbo].[ForecastRevisionLine] WITH CHECK ADD CONSTRAINT [FK_ForecastRevisionLine_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([ForecastRevisionLine])
GO
ALTER TABLE [dbo].[ForecastRevisionLine] CHECK CONSTRAINT [FK_ForecastRevisionLine_ForecastRevision]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ConsignorParty_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([ConsignorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ConsignorParty_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_CarrierParty_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([CarrierParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_CarrierParty_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_FreightForwarderParty_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([FreightForwarderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_FreightForwarderParty_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_ForwardingInstructions]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_ForwardingInstructions]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_ExchangeRate_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([ExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_ExchangeRate_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvoicePeriod_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([InvoicePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvoicePeriod_FreightInvoice]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_FreightInvoice]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_FreightInvoice]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_FreightInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DespatchDocumentReference_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([DespatchDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DespatchDocumentReference_FreightInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ReceiptDocumentReference_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([ReceiptDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ReceiptDocumentReference_FreightInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginatorDocumentReference_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([OriginatorDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginatorDocumentReference_FreightInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ContractDocumentReference_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([ContractDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ContractDocumentReference_FreightInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_FreightInvoice]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_FreightInvoice]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_FreightInvoice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_FreightInvoice]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_FreightInvoice]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TaxRepresentativeParty_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([TaxRepresentativeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TaxRepresentativeParty_FreightInvoice]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_FreightInvoice]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_FreightInvoice]
GO
ALTER TABLE [dbo].[Payment] WITH CHECK ADD CONSTRAINT [FK_PrepaidPayment_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([PrepaidPayment])
GO
ALTER TABLE [dbo].[Payment] CHECK CONSTRAINT [FK_PrepaidPayment_FreightInvoice]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_FreightInvoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_TaxExchangeRate_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([TaxExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_TaxExchangeRate_FreightInvoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PricingExchangeRate_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([PricingExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PricingExchangeRate_FreightInvoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentExchangeRate_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([PaymentExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentExchangeRate_FreightInvoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeExchangeRate_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([PaymentAlternativeExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentAlternativeExchangeRate_FreightInvoice]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_FreightInvoice]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_LegalMonetaryTotal_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([LegalMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_LegalMonetaryTotal_FreightInvoice]
GO
ALTER TABLE [dbo].[InvoiceLine] WITH CHECK ADD CONSTRAINT [FK_InvoiceLine_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([InvoiceLine])
GO
ALTER TABLE [dbo].[InvoiceLine] CHECK CONSTRAINT [FK_InvoiceLine_FreightInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DespatchDocumentReference_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([DespatchDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DespatchDocumentReference_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ReceiptDocumentReference_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([ReceiptDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ReceiptDocumentReference_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_Contract_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([Contract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_Contract_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_DeliveryCustomerParty_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([DeliveryCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_DeliveryCustomerParty_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_DespatchSupplierParty_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([DespatchSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_DespatchSupplierParty_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Consignment] WITH CHECK ADD CONSTRAINT [FK_ReferencedConsignment_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([ReferencedConsignment])
GO
ALTER TABLE [dbo].[Consignment] CHECK CONSTRAINT [FK_ReferencedConsignment_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[TransportEquipment] WITH CHECK ADD CONSTRAINT [FK_ReferencedTransportEquipment_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([ReferencedTransportEquipment])
GO
ALTER TABLE [dbo].[TransportEquipment] CHECK CONSTRAINT [FK_ReferencedTransportEquipment_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Package] WITH CHECK ADD CONSTRAINT [FK_ReferencedPackage_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([ReferencedPackage])
GO
ALTER TABLE [dbo].[Package] CHECK CONSTRAINT [FK_ReferencedPackage_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[GoodsItem] WITH CHECK ADD CONSTRAINT [FK_ReferencedGoodsItem_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([ReferencedGoodsItem])
GO
ALTER TABLE [dbo].[GoodsItem] CHECK CONSTRAINT [FK_ReferencedGoodsItem_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[TransportationSegment] WITH CHECK ADD CONSTRAINT [FK_TransportationSegment_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([TransportationSegment])
GO
ALTER TABLE [dbo].[TransportationSegment] CHECK CONSTRAINT [FK_TransportationSegment_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ApplicablePeriod_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([ApplicablePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ApplicablePeriod_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Regulation] WITH CHECK ADD CONSTRAINT [FK_ApplicableRegulation_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([ApplicableRegulation])
GO
ALTER TABLE [dbo].[Regulation] CHECK CONSTRAINT [FK_ApplicableRegulation_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_GuaranteeDocumentReference_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([GuaranteeDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_GuaranteeDocumentReference_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[ImmobilizedSecurity] WITH CHECK ADD CONSTRAINT [FK_ImmobilizedSecurity_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([ImmobilizedSecurity])
GO
ALTER TABLE [dbo].[ImmobilizedSecurity] CHECK CONSTRAINT [FK_ImmobilizedSecurity_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_GuarantorParty_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([GuarantorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_GuarantorParty_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_InterestedParty_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([InterestedParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_InterestedParty_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_BeneficiaryParty_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([BeneficiaryParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_BeneficiaryParty_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_InstructionForReturns]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_InstructionForReturns]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_InstructionForReturns]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_RetailerCustomerParty_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([RetailerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_RetailerCustomerParty_InstructionForReturns]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ManufacturerParty_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([ManufacturerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ManufacturerParty_InstructionForReturns]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_InstructionForReturns]
GO
ALTER TABLE [dbo].[InstructionForReturnsLine] WITH CHECK ADD CONSTRAINT [FK_InstructionForReturnsLine_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([InstructionForReturnsLine])
GO
ALTER TABLE [dbo].[InstructionForReturnsLine] CHECK CONSTRAINT [FK_InstructionForReturnsLine_InstructionForReturns]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InventoryPeriod_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([InventoryPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InventoryPeriod_InventoryReport]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_InventoryReport]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_InventoryReport]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_RetailerCustomerParty_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([RetailerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_RetailerCustomerParty_InventoryReport]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_InventoryReportingParty_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([InventoryReportingParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_InventoryReportingParty_InventoryReport]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_InventoryReport]
GO
ALTER TABLE [dbo].[InventoryReportLine] WITH CHECK ADD CONSTRAINT [FK_InventoryReportLine_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([InventoryReportLine])
GO
ALTER TABLE [dbo].[InventoryReportLine] CHECK CONSTRAINT [FK_InventoryReportLine_InventoryReport]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvoicePeriod_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([InvoicePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvoicePeriod_Invoice]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_Invoice]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_Invoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DespatchDocumentReference_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([DespatchDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DespatchDocumentReference_Invoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ReceiptDocumentReference_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([ReceiptDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ReceiptDocumentReference_Invoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_StatementDocumentReference_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([StatementDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_StatementDocumentReference_Invoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginatorDocumentReference_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([OriginatorDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginatorDocumentReference_Invoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ContractDocumentReference_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([ContractDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ContractDocumentReference_Invoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_Invoice]
GO
ALTER TABLE [dbo].[ProjectReference] WITH CHECK ADD CONSTRAINT [FK_ProjectReference_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([ProjectReference])
GO
ALTER TABLE [dbo].[ProjectReference] CHECK CONSTRAINT [FK_ProjectReference_Invoice]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_Invoice]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_Invoice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_Invoice]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_Invoice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_Invoice]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_Invoice]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TaxRepresentativeParty_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([TaxRepresentativeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TaxRepresentativeParty_Invoice]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_Invoice]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_Invoice]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_Invoice]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_Invoice]
GO
ALTER TABLE [dbo].[Payment] WITH CHECK ADD CONSTRAINT [FK_PrepaidPayment_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([PrepaidPayment])
GO
ALTER TABLE [dbo].[Payment] CHECK CONSTRAINT [FK_PrepaidPayment_Invoice]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_Invoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_TaxExchangeRate_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([TaxExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_TaxExchangeRate_Invoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PricingExchangeRate_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([PricingExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PricingExchangeRate_Invoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentExchangeRate_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([PaymentExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentExchangeRate_Invoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeExchangeRate_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([PaymentAlternativeExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentAlternativeExchangeRate_Invoice]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_Invoice]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_WithholdingTaxTotal_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([WithholdingTaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_WithholdingTaxTotal_Invoice]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_LegalMonetaryTotal_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([LegalMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_LegalMonetaryTotal_Invoice]
GO
ALTER TABLE [dbo].[InvoiceLine] WITH CHECK ADD CONSTRAINT [FK_InvoiceLine_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([InvoiceLine])
GO
ALTER TABLE [dbo].[InvoiceLine] CHECK CONSTRAINT [FK_InvoiceLine_Invoice]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_ItemInformationRequest]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_ItemInformationRequest]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_ItemInformationRequest]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_ItemInformationRequest]
GO
ALTER TABLE [dbo].[ItemInformationRequestLine] WITH CHECK ADD CONSTRAINT [FK_ItemInformationRequestLine_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([ItemInformationRequestLine])
GO
ALTER TABLE [dbo].[ItemInformationRequestLine] CHECK CONSTRAINT [FK_ItemInformationRequestLine_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_Order]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_QuotationDocumentReference_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([QuotationDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_QuotationDocumentReference_Order]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OrderDocumentReference_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([OrderDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OrderDocumentReference_Order]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginatorDocumentReference_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([OriginatorDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginatorDocumentReference_Order]
GO
ALTER TABLE [dbo].[CatalogueReference] WITH CHECK ADD CONSTRAINT [FK_CatalogueReference_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([CatalogueReference])
GO
ALTER TABLE [dbo].[CatalogueReference] CHECK CONSTRAINT [FK_CatalogueReference_Order]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_Order]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_Contract_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([Contract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_Contract_Order]
GO
ALTER TABLE [dbo].[ProjectReference] WITH CHECK ADD CONSTRAINT [FK_ProjectReference_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([ProjectReference])
GO
ALTER TABLE [dbo].[ProjectReference] CHECK CONSTRAINT [FK_ProjectReference_Order]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_Order]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_Order]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_Order]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_Order]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_FreightForwarderParty_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([FreightForwarderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_FreightForwarderParty_Order]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_Order]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_Order]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_Order]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_Order]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_Order]
GO
ALTER TABLE [dbo].[TransactionConditions] WITH CHECK ADD CONSTRAINT [FK_TransactionConditions_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([TransactionConditions])
GO
ALTER TABLE [dbo].[TransactionConditions] CHECK CONSTRAINT [FK_TransactionConditions_Order]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_Order]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_TaxExchangeRate_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([TaxExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_TaxExchangeRate_Order]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PricingExchangeRate_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([PricingExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PricingExchangeRate_Order]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentExchangeRate_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([PaymentExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentExchangeRate_Order]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_DestinationCountry_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([DestinationCountry])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_DestinationCountry_Order]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_Order]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_AnticipatedMonetaryTotal_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([AnticipatedMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_AnticipatedMonetaryTotal_Order]
GO
ALTER TABLE [dbo].[OrderLine] WITH CHECK ADD CONSTRAINT [FK_OrderLine_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([OrderLine])
GO
ALTER TABLE [dbo].[OrderLine] CHECK CONSTRAINT [FK_OrderLine_Order]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_OrderCancellation]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginatorDocumentReference_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([OriginatorDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginatorDocumentReference_OrderCancellation]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_OrderCancellation]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_Contract_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([Contract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_Contract_OrderCancellation]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_OrderCancellation]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_OrderCancellation]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_OrderCancellation]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_OrderCancellation]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_OrderChange]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_OrderChange]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_QuotationDocumentReference_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([QuotationDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_QuotationDocumentReference_OrderChange]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginatorDocumentReference_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([OriginatorDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginatorDocumentReference_OrderChange]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_OrderChange]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_Contract_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([Contract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_Contract_OrderChange]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_OrderChange]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_OrderChange]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_OrderChange]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_OrderChange]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_FreightForwarderParty_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([FreightForwarderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_FreightForwarderParty_OrderChange]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_OrderChange]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_OrderChange]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_OrderChange]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_OrderChange]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_OrderChange]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_OrderChange]
GO
ALTER TABLE [dbo].[TransactionConditions] WITH CHECK ADD CONSTRAINT [FK_TransactionConditions_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([TransactionConditions])
GO
ALTER TABLE [dbo].[TransactionConditions] CHECK CONSTRAINT [FK_TransactionConditions_OrderChange]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_OrderChange]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_TaxExchangeRate_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([TaxExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_TaxExchangeRate_OrderChange]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PricingExchangeRate_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([PricingExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PricingExchangeRate_OrderChange]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentExchangeRate_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([PaymentExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentExchangeRate_OrderChange]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_DestinationCountry_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([DestinationCountry])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_DestinationCountry_OrderChange]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_OrderChange]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_AnticipatedMonetaryTotal_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([AnticipatedMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_AnticipatedMonetaryTotal_OrderChange]
GO
ALTER TABLE [dbo].[OrderLine] WITH CHECK ADD CONSTRAINT [FK_OrderLine_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([OrderLine])
GO
ALTER TABLE [dbo].[OrderLine] CHECK CONSTRAINT [FK_OrderLine_OrderChange]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_OrderResponse]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_OrderResponse]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OrderDocumentReference_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([OrderDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OrderDocumentReference_OrderResponse]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginatorDocumentReference_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([OriginatorDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginatorDocumentReference_OrderResponse]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_OrderResponse]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_Contract_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([Contract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_Contract_OrderResponse]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_OrderResponse]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_OrderResponse]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_OrderResponse]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_OrderResponse]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_FreightForwarderParty_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([FreightForwarderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_FreightForwarderParty_OrderResponse]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_OrderResponse]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_OrderResponse]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_OrderResponse]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_OrderResponse]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_OrderResponse]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_OrderResponse]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_OrderResponse]
GO
ALTER TABLE [dbo].[TransactionConditions] WITH CHECK ADD CONSTRAINT [FK_TransactionConditions_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([TransactionConditions])
GO
ALTER TABLE [dbo].[TransactionConditions] CHECK CONSTRAINT [FK_TransactionConditions_OrderResponse]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_TaxExchangeRate_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([TaxExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_TaxExchangeRate_OrderResponse]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PricingExchangeRate_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([PricingExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PricingExchangeRate_OrderResponse]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentExchangeRate_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([PaymentExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentExchangeRate_OrderResponse]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_DestinationCountry_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([DestinationCountry])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_DestinationCountry_OrderResponse]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_OrderResponse]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_LegalMonetaryTotal_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([LegalMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_LegalMonetaryTotal_OrderResponse]
GO
ALTER TABLE [dbo].[OrderLine] WITH CHECK ADD CONSTRAINT [FK_OrderLine_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([OrderLine])
GO
ALTER TABLE [dbo].[OrderLine] CHECK CONSTRAINT [FK_OrderLine_OrderResponse]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_OrderResponseSimple]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_OrderResponseSimple]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_OrderResponseSimple]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_OrderResponseSimple]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_OrderResponseSimple]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_OrderResponseSimple]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ConsignorParty_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([ConsignorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ConsignorParty_PackingList]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_CarrierParty_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([CarrierParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_CarrierParty_PackingList]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_FreightForwarderParty_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([FreightForwarderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_FreightForwarderParty_PackingList]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_PackingList]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_PackingList]
GO
ALTER TABLE [dbo].[DocumentDistribution] WITH CHECK ADD CONSTRAINT [FK_DocumentDistribution_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([DocumentDistribution])
GO
ALTER TABLE [dbo].[DocumentDistribution] CHECK CONSTRAINT [FK_DocumentDistribution_PackingList]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_PackingList]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_PriorInformationNotice]
GO
ALTER TABLE [dbo].[ContractingParty] WITH CHECK ADD CONSTRAINT [FK_ContractingParty_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([ContractingParty])
GO
ALTER TABLE [dbo].[ContractingParty] CHECK CONSTRAINT [FK_ContractingParty_PriorInformationNotice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_PriorInformationNotice]
GO
ALTER TABLE [dbo].[TenderingTerms] WITH CHECK ADD CONSTRAINT [FK_TenderingTerms_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([TenderingTerms])
GO
ALTER TABLE [dbo].[TenderingTerms] CHECK CONSTRAINT [FK_TenderingTerms_PriorInformationNotice]
GO
ALTER TABLE [dbo].[TenderingProcess] WITH CHECK ADD CONSTRAINT [FK_TenderingProcess_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([TenderingProcess])
GO
ALTER TABLE [dbo].[TenderingProcess] CHECK CONSTRAINT [FK_TenderingProcess_PriorInformationNotice]
GO
ALTER TABLE [dbo].[ProcurementProject] WITH CHECK ADD CONSTRAINT [FK_ProcurementProject_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([ProcurementProject])
GO
ALTER TABLE [dbo].[ProcurementProject] CHECK CONSTRAINT [FK_ProcurementProject_PriorInformationNotice]
GO
ALTER TABLE [dbo].[ProcurementProjectLot] WITH CHECK ADD CONSTRAINT [FK_ProcurementProjectLot_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([ProcurementProjectLot])
GO
ALTER TABLE [dbo].[ProcurementProjectLot] CHECK CONSTRAINT [FK_ProcurementProjectLot_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ActivityPeriod_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([ActivityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ActivityPeriod_ProductActivity]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_ProductActivity]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_ProductActivity]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_ProductActivity]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_ProductActivity]
GO
ALTER TABLE [dbo].[ActivityDataLine] WITH CHECK ADD CONSTRAINT [FK_SupplyChainActivityDataLine_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([SupplyChainActivityDataLine])
GO
ALTER TABLE [dbo].[ActivityDataLine] CHECK CONSTRAINT [FK_SupplyChainActivityDataLine_ProductActivity]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_Quotation]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_RequestForQuotationDocumentReference_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([RequestForQuotationDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_RequestForQuotationDocumentReference_Quotation]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_Quotation]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_Contract_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([Contract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_Contract_Quotation]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_Quotation]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_Quotation]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_Quotation]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_Quotation]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_Quotation]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_Quotation]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_Quotation]
GO
ALTER TABLE [dbo].[TransactionConditions] WITH CHECK ADD CONSTRAINT [FK_TransactionConditions_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([TransactionConditions])
GO
ALTER TABLE [dbo].[TransactionConditions] CHECK CONSTRAINT [FK_TransactionConditions_Quotation]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_Quotation]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_DestinationCountry_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([DestinationCountry])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_DestinationCountry_Quotation]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_Quotation]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_QuotedMonetaryTotal_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([QuotedMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_QuotedMonetaryTotal_Quotation]
GO
ALTER TABLE [dbo].[QuotationLine] WITH CHECK ADD CONSTRAINT [FK_QuotationLine_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([QuotationLine])
GO
ALTER TABLE [dbo].[QuotationLine] CHECK CONSTRAINT [FK_QuotationLine_Quotation]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_ReceiptAdvice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DespatchDocumentReference_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([DespatchDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DespatchDocumentReference_ReceiptAdvice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_ReceiptAdvice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_DeliveryCustomerParty_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([DeliveryCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_DeliveryCustomerParty_ReceiptAdvice]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_DespatchSupplierParty_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([DespatchSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_DespatchSupplierParty_ReceiptAdvice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_ReceiptAdvice]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_ReceiptAdvice]
GO
ALTER TABLE [dbo].[ReceiptLine] WITH CHECK ADD CONSTRAINT [FK_ReceiptLine_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([ReceiptLine])
GO
ALTER TABLE [dbo].[ReceiptLine] CHECK CONSTRAINT [FK_ReceiptLine_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ReminderPeriod_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([ReminderPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ReminderPeriod_Reminder]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_Reminder]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_Reminder]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_Reminder]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_Reminder]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_Reminder]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TaxRepresentativeParty_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([TaxRepresentativeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TaxRepresentativeParty_Reminder]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_Reminder]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_Reminder]
GO
ALTER TABLE [dbo].[Payment] WITH CHECK ADD CONSTRAINT [FK_PrepaidPayment_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([PrepaidPayment])
GO
ALTER TABLE [dbo].[Payment] CHECK CONSTRAINT [FK_PrepaidPayment_Reminder]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_Reminder]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_TaxExchangeRate_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([TaxExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_TaxExchangeRate_Reminder]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PricingExchangeRate_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([PricingExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PricingExchangeRate_Reminder]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentExchangeRate_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([PaymentExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentExchangeRate_Reminder]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeExchangeRate_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([PaymentAlternativeExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentAlternativeExchangeRate_Reminder]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_Reminder]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_LegalMonetaryTotal_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([LegalMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_LegalMonetaryTotal_Reminder]
GO
ALTER TABLE [dbo].[ReminderLine] WITH CHECK ADD CONSTRAINT [FK_ReminderLine_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([ReminderLine])
GO
ALTER TABLE [dbo].[ReminderLine] CHECK CONSTRAINT [FK_ReminderLine_Reminder]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvoicePeriod_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([InvoicePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvoicePeriod_RemittanceAdvice]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_RemittanceAdvice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_RemittanceAdvice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_RemittanceAdvice]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_RemittanceAdvice]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_RemittanceAdvice]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_RemittanceAdvice]
GO
ALTER TABLE [dbo].[RemittanceAdviceLine] WITH CHECK ADD CONSTRAINT [FK_RemittanceAdviceLine_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([RemittanceAdviceLine])
GO
ALTER TABLE [dbo].[RemittanceAdviceLine] CHECK CONSTRAINT [FK_RemittanceAdviceLine_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_RequestedValidityPeriod_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([RequestedValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_RequestedValidityPeriod_RequestForQuotation]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_CatalogueDocumentReference_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([CatalogueDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_CatalogueDocumentReference_RequestForQuotation]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_RequestForQuotation]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_RequestForQuotation]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_RequestForQuotation]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_RequestForQuotation]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_RequestForQuotation]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_RequestForQuotation]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_RequestForQuotation]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_DestinationCountry_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([DestinationCountry])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_DestinationCountry_RequestForQuotation]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_Contract_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([Contract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_Contract_RequestForQuotation]
GO
ALTER TABLE [dbo].[RequestForQuotationLine] WITH CHECK ADD CONSTRAINT [FK_RequestForQuotationLine_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([RequestForQuotationLine])
GO
ALTER TABLE [dbo].[RequestForQuotationLine] CHECK CONSTRAINT [FK_RequestForQuotationLine_RequestForQuotation]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_RetailEvent]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginalDocumentReference_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([OriginalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginalDocumentReference_RetailEvent]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_RetailEvent]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_RetailEvent]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_RetailEvent]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_RetailEvent]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_RetailEvent]
GO
ALTER TABLE [dbo].[EventComment] WITH CHECK ADD CONSTRAINT [FK_EventComment_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([EventComment])
GO
ALTER TABLE [dbo].[EventComment] CHECK CONSTRAINT [FK_EventComment_RetailEvent]
GO
ALTER TABLE [dbo].[PromotionalEvent] WITH CHECK ADD CONSTRAINT [FK_PromotionalEvent_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([PromotionalEvent])
GO
ALTER TABLE [dbo].[PromotionalEvent] CHECK CONSTRAINT [FK_PromotionalEvent_RetailEvent]
GO
ALTER TABLE [dbo].[MiscellaneousEvent] WITH CHECK ADD CONSTRAINT [FK_MiscellaneousEvent_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([MiscellaneousEvent])
GO
ALTER TABLE [dbo].[MiscellaneousEvent] CHECK CONSTRAINT [FK_MiscellaneousEvent_RetailEvent]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvoicePeriod_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([InvoicePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvoicePeriod_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Response] WITH CHECK ADD CONSTRAINT [FK_DiscrepancyResponse_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([DiscrepancyResponse])
GO
ALTER TABLE [dbo].[Response] CHECK CONSTRAINT [FK_DiscrepancyResponse_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DespatchDocumentReference_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([DespatchDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DespatchDocumentReference_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ReceiptDocumentReference_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([ReceiptDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ReceiptDocumentReference_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ContractDocumentReference_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([ContractDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ContractDocumentReference_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_StatementDocumentReference_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([StatementDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_StatementDocumentReference_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginatorDocumentReference_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([OriginatorDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginatorDocumentReference_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TaxRepresentativeParty_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([TaxRepresentativeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TaxRepresentativeParty_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_TaxExchangeRate_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([TaxExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_TaxExchangeRate_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PricingExchangeRate_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([PricingExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PricingExchangeRate_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentExchangeRate_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([PaymentExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentExchangeRate_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeExchangeRate_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([PaymentAlternativeExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentAlternativeExchangeRate_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_LegalMonetaryTotal_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([LegalMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_LegalMonetaryTotal_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[CreditNoteLine] WITH CHECK ADD CONSTRAINT [FK_CreditNoteLine_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([CreditNoteLine])
GO
ALTER TABLE [dbo].[CreditNoteLine] CHECK CONSTRAINT [FK_CreditNoteLine_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvoicePeriod_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([InvoicePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvoicePeriod_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ContractDocumentReference_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([ContractDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ContractDocumentReference_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DespatchDocumentReference_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([DespatchDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DespatchDocumentReference_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ReceiptDocumentReference_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([ReceiptDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ReceiptDocumentReference_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_StatementDocumentReference_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([StatementDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_StatementDocumentReference_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginatorDocumentReference_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([OriginatorDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginatorDocumentReference_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TaxRepresentativeParty_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([TaxRepresentativeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TaxRepresentativeParty_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Payment] WITH CHECK ADD CONSTRAINT [FK_PrepaidPayment_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([PrepaidPayment])
GO
ALTER TABLE [dbo].[Payment] CHECK CONSTRAINT [FK_PrepaidPayment_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_TaxExchangeRate_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([TaxExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_TaxExchangeRate_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PricingExchangeRate_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([PricingExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PricingExchangeRate_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentExchangeRate_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([PaymentExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentExchangeRate_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeExchangeRate_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([PaymentAlternativeExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PaymentAlternativeExchangeRate_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_LegalMonetaryTotal_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([LegalMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_LegalMonetaryTotal_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[InvoiceLine] WITH CHECK ADD CONSTRAINT [FK_InvoiceLine_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([InvoiceLine])
GO
ALTER TABLE [dbo].[InvoiceLine] CHECK CONSTRAINT [FK_InvoiceLine_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_StatementPeriod_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([StatementPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_StatementPeriod_Statement]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_Statement]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_Statement]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_Statement]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_Statement]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_Statement]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_Statement]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_Statement]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_Statement]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_Statement]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_Statement]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_Statement]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_Statement]
GO
ALTER TABLE [dbo].[StatementLine] WITH CHECK ADD CONSTRAINT [FK_StatementLine_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([StatementLine])
GO
ALTER TABLE [dbo].[StatementLine] CHECK CONSTRAINT [FK_StatementLine_Statement]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InventoryPeriod_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([InventoryPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InventoryPeriod_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_RetailerCustomerParty_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([RetailerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_RetailerCustomerParty_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_InventoryReportingParty_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([InventoryReportingParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_InventoryReportingParty_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[StockAvailabilityReportLine] WITH CHECK ADD CONSTRAINT [FK_StockAvailabilityReportLine_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([StockAvailabilityReportLine])
GO
ALTER TABLE [dbo].[StockAvailabilityReportLine] CHECK CONSTRAINT [FK_StockAvailabilityReportLine_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_Tender]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_Tender]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_Tender]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TendererParty_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([TendererParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TendererParty_Tender]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TendererQualificationDocumentReference_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([TendererQualificationDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TendererQualificationDocumentReference_Tender]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SubcontractorParty_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([SubcontractorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SubcontractorParty_Tender]
GO
ALTER TABLE [dbo].[ContractingParty] WITH CHECK ADD CONSTRAINT [FK_ContractingParty_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([ContractingParty])
GO
ALTER TABLE [dbo].[ContractingParty] CHECK CONSTRAINT [FK_ContractingParty_Tender]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_Tender]
GO
ALTER TABLE [dbo].[TenderedProject] WITH CHECK ADD CONSTRAINT [FK_TenderedProject_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([TenderedProject])
GO
ALTER TABLE [dbo].[TenderedProject] CHECK CONSTRAINT [FK_TenderedProject_Tender]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TendererQualification]
GO
ALTER TABLE [dbo].[TendererPartyQualification] WITH CHECK ADD CONSTRAINT [FK_TendererPartyQualification_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([TendererPartyQualification])
GO
ALTER TABLE [dbo].[TendererPartyQualification] CHECK CONSTRAINT [FK_TendererPartyQualification_TendererQualification]
GO
ALTER TABLE [dbo].[ContractingParty] WITH CHECK ADD CONSTRAINT [FK_ContractingParty_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([ContractingParty])
GO
ALTER TABLE [dbo].[ContractingParty] CHECK CONSTRAINT [FK_ContractingParty_TendererQualification]
GO
ALTER TABLE [dbo].[Evidence] WITH CHECK ADD CONSTRAINT [FK_Evidence_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([Evidence])
GO
ALTER TABLE [dbo].[Evidence] CHECK CONSTRAINT [FK_Evidence_TendererQualification]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_TendererQualification]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ResolutionDocumentReference_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([ResolutionDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ResolutionDocumentReference_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[QualificationResolution] WITH CHECK ADD CONSTRAINT [FK_QualificationResolution_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([QualificationResolution])
GO
ALTER TABLE [dbo].[QualificationResolution] CHECK CONSTRAINT [FK_QualificationResolution_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[AppealTerms] WITH CHECK ADD CONSTRAINT [FK_AppealTerms_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([AppealTerms])
GO
ALTER TABLE [dbo].[AppealTerms] CHECK CONSTRAINT [FK_AppealTerms_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TenderDocumentReference_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([TenderDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TenderDocumentReference_TenderReceipt]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TenderReceipt]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_TenderReceipt]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_TenderReceipt]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[ItemManagementProfile] WITH CHECK ADD CONSTRAINT [FK_ItemManagementProfile_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([ItemManagementProfile])
GO
ALTER TABLE [dbo].[ItemManagementProfile] CHECK CONSTRAINT [FK_ItemManagementProfile_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Consignment] WITH CHECK ADD CONSTRAINT [FK_Consignment_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([Consignment])
GO
ALTER TABLE [dbo].[Consignment] CHECK CONSTRAINT [FK_Consignment_TransportationStatus]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_TransportEvent_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([TransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_TransportEvent_TransportationStatus]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_TransportationStatus]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TransportationStatus]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_TransportationStatus]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_TransportationStatus]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TransportationStatusRequestDocumentReference_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([TransportationStatusRequestDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TransportationStatusRequestDocumentReference_TransportationStatus]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TransportExecutionPlanDocumentReference_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([TransportExecutionPlanDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TransportExecutionPlanDocumentReference_TransportationStatus]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_UpdatedPickupTransportEvent_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([UpdatedPickupTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_UpdatedPickupTransportEvent_TransportationStatus]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_UpdatedDeliveryTransportEvent_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([UpdatedDeliveryTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_UpdatedDeliveryTransportEvent_TransportationStatus]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_StatusLocation_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([StatusLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_StatusLocation_TransportationStatus]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_StatusPeriod_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([StatusPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_StatusPeriod_TransportationStatus]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TransportExecutionPlanDocumentReference_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([TransportExecutionPlanDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TransportExecutionPlanDocumentReference_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Consignment] WITH CHECK ADD CONSTRAINT [FK_Consignment_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([Consignment])
GO
ALTER TABLE [dbo].[Consignment] CHECK CONSTRAINT [FK_Consignment_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_RequestedStatusLocation_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([RequestedStatusLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_RequestedStatusLocation_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_RequestedStatusPeriod_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([RequestedStatusPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_RequestedStatusPeriod_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TransportUserParty_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([TransportUserParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TransportUserParty_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TransportServiceProviderParty_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([TransportServiceProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TransportServiceProviderParty_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_BillToParty_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([BillToParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_BillToParty_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TransportExecutionPlanRequestDocumentReference_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([TransportExecutionPlanRequestDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TransportExecutionPlanRequestDocumentReference_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TransportExecutionPlanDocumentReference_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([TransportExecutionPlanDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TransportExecutionPlanDocumentReference_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TransportServiceDescriptionDocumentReference_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([TransportServiceDescriptionDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TransportServiceDescriptionDocumentReference_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_TransportContract_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([TransportContract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_TransportContract_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_TransportServiceProviderResponseRequiredPeriod_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([TransportServiceProviderResponseRequiredPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_TransportServiceProviderResponseRequiredPeriod_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_TransportUserResponseRequiredPeriod_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([TransportUserResponseRequiredPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_TransportUserResponseRequiredPeriod_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[TransportationService] WITH CHECK ADD CONSTRAINT [FK_MainTransportationService_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([MainTransportationService])
GO
ALTER TABLE [dbo].[TransportationService] CHECK CONSTRAINT [FK_MainTransportationService_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[TransportationService] WITH CHECK ADD CONSTRAINT [FK_AdditionalTransportationService_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([AdditionalTransportationService])
GO
ALTER TABLE [dbo].[TransportationService] CHECK CONSTRAINT [FK_AdditionalTransportationService_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ServiceStartTimePeriod_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([ServiceStartTimePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ServiceStartTimePeriod_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ServiceEndTimePeriod_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([ServiceEndTimePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ServiceEndTimePeriod_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_FromLocation_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([FromLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_FromLocation_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_ToLocation_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([ToLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_ToLocation_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_AtLocation_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([AtLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_AtLocation_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[TransportExecutionTerms] WITH CHECK ADD CONSTRAINT [FK_TransportExecutionTerms_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([TransportExecutionTerms])
GO
ALTER TABLE [dbo].[TransportExecutionTerms] CHECK CONSTRAINT [FK_TransportExecutionTerms_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Consignment] WITH CHECK ADD CONSTRAINT [FK_Consignment_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([Consignment])
GO
ALTER TABLE [dbo].[Consignment] CHECK CONSTRAINT [FK_Consignment_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TransportUserParty_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([TransportUserParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TransportUserParty_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TransportServiceProviderParty_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([TransportServiceProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TransportServiceProviderParty_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TransportExecutionPlanDocumentReference_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([TransportExecutionPlanDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TransportExecutionPlanDocumentReference_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TransportServiceDescriptionDocumentReference_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([TransportServiceDescriptionDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TransportServiceDescriptionDocumentReference_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_TransportContract_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([TransportContract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_TransportContract_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_TransportServiceProviderResponseDeadlinePeriod_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([TransportServiceProviderResponseDeadlinePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_TransportServiceProviderResponseDeadlinePeriod_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[TransportationService] WITH CHECK ADD CONSTRAINT [FK_MainTransportationService_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([MainTransportationService])
GO
ALTER TABLE [dbo].[TransportationService] CHECK CONSTRAINT [FK_MainTransportationService_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[TransportationService] WITH CHECK ADD CONSTRAINT [FK_AdditionalTransportationService_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([AdditionalTransportationService])
GO
ALTER TABLE [dbo].[TransportationService] CHECK CONSTRAINT [FK_AdditionalTransportationService_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ServiceStartTimePeriod_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([ServiceStartTimePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ServiceStartTimePeriod_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ServiceEndTimePeriod_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([ServiceEndTimePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ServiceEndTimePeriod_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_FromLocation_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([FromLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_FromLocation_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_ToLocation_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([ToLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_ToLocation_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_AtLocation_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([AtLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_AtLocation_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[TransportExecutionTerms] WITH CHECK ADD CONSTRAINT [FK_TransportExecutionTerms_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([TransportExecutionTerms])
GO
ALTER TABLE [dbo].[TransportExecutionTerms] CHECK CONSTRAINT [FK_TransportExecutionTerms_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Consignment] WITH CHECK ADD CONSTRAINT [FK_Consignment_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([Consignment])
GO
ALTER TABLE [dbo].[Consignment] CHECK CONSTRAINT [FK_Consignment_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SourceIssuerParty_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([SourceIssuerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SourceIssuerParty_TransportProgressStatus]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TransportProgressStatusRequestDocumentReference_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([TransportProgressStatusRequestDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TransportProgressStatusRequestDocumentReference_TransportProgressStatus]
GO
ALTER TABLE [dbo].[TransportMeans] WITH CHECK ADD CONSTRAINT [FK_TransportMeans_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([TransportMeans])
GO
ALTER TABLE [dbo].[TransportMeans] CHECK CONSTRAINT [FK_TransportMeans_TransportProgressStatus]
GO
ALTER TABLE [dbo].[TransportSchedule] WITH CHECK ADD CONSTRAINT [FK_TransportSchedule_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([TransportSchedule])
GO
ALTER TABLE [dbo].[TransportSchedule] CHECK CONSTRAINT [FK_TransportSchedule_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[TransportMeans] WITH CHECK ADD CONSTRAINT [FK_TransportMeans_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([TransportMeans])
GO
ALTER TABLE [dbo].[TransportMeans] CHECK CONSTRAINT [FK_TransportMeans_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_StatusLocation_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([StatusLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_StatusLocation_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_TransportServiceDescription]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TransportServiceDescriptionRequestDocumentReference_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([TransportServiceDescriptionRequestDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TransportServiceDescriptionRequestDocumentReference_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TransportServiceProviderParty_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([TransportServiceProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TransportServiceProviderParty_TransportServiceDescription]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_ServiceChargePaymentTerms_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([ServiceChargePaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_ServiceChargePaymentTerms_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_TransportServiceDescription]
GO
ALTER TABLE [dbo].[TransportationService] WITH CHECK ADD CONSTRAINT [FK_TransportationService_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([TransportationService])
GO
ALTER TABLE [dbo].[TransportationService] CHECK CONSTRAINT [FK_TransportationService_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TransportServiceProviderParty_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([TransportServiceProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TransportServiceProviderParty_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[TransportationService] WITH CHECK ADD CONSTRAINT [FK_TransportationService_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([TransportationService])
GO
ALTER TABLE [dbo].[TransportationService] CHECK CONSTRAINT [FK_TransportationService_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_UnawardedNotification]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_UnawardedNotification]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_UnawardedNotification]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_MinutesDocumentReference_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([MinutesDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_MinutesDocumentReference_UnawardedNotification]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_UnawardedNotification]
GO
ALTER TABLE [dbo].[TenderResult] WITH CHECK ADD CONSTRAINT [FK_TenderResult_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([TenderResult])
GO
ALTER TABLE [dbo].[TenderResult] CHECK CONSTRAINT [FK_TenderResult_UnawardedNotification]
GO
ALTER TABLE [dbo].[AppealTerms] WITH CHECK ADD CONSTRAINT [FK_AppealTerms_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([AppealTerms])
GO
ALTER TABLE [dbo].[AppealTerms] CHECK CONSTRAINT [FK_AppealTerms_UnawardedNotification]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ParentDocumentReference_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([ParentDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ParentDocumentReference_UtilityStatement]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_UtilityStatement]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_UtilityStatement]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SenderParty_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([SenderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SenderParty_UtilityStatement]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ReceiverParty_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([ReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ReceiverParty_UtilityStatement]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_CustomerParty_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([CustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_CustomerParty_UtilityStatement]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SubscriberParty_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([SubscriberParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SubscriberParty_UtilityStatement]
GO
ALTER TABLE [dbo].[OnAccountPayment] WITH CHECK ADD CONSTRAINT [FK_MainOnAccountPayment_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([MainOnAccountPayment])
GO
ALTER TABLE [dbo].[OnAccountPayment] CHECK CONSTRAINT [FK_MainOnAccountPayment_UtilityStatement]
GO
ALTER TABLE [dbo].[SubscriberConsumption] WITH CHECK ADD CONSTRAINT [FK_SubscriberConsumption_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([SubscriberConsumption])
GO
ALTER TABLE [dbo].[SubscriberConsumption] CHECK CONSTRAINT [FK_SubscriberConsumption_UtilityStatement]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ConsignorParty_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([ConsignorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ConsignorParty_Waybill]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_CarrierParty_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([CarrierParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_CarrierParty_Waybill]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_FreightForwarderParty_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([FreightForwarderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_FreightForwarderParty_Waybill]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_Waybill]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_Waybill]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_ExchangeRate_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([ExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_ExchangeRate_Waybill]
GO
ALTER TABLE [dbo].[DocumentDistribution] WITH CHECK ADD CONSTRAINT [FK_DocumentDistribution_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([DocumentDistribution])
GO
ALTER TABLE [dbo].[DocumentDistribution] CHECK CONSTRAINT [FK_DocumentDistribution_Waybill]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_Waybill]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_ActivityDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ActivityDataLine] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_ActivityDataLine]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_ActivityDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ActivityDataLine] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_ActivityDataLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ActivityPeriod_ActivityDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ActivityDataLine] ([ActivityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ActivityPeriod_ActivityDataLine]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_ActivityOriginLocation_ActivityDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ActivityDataLine] ([ActivityOriginLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_ActivityOriginLocation_ActivityDataLine]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_ActivityFinalLocation_ActivityDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ActivityDataLine] ([ActivityFinalLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_ActivityFinalLocation_ActivityDataLine]
GO
ALTER TABLE [dbo].[SalesItem] WITH CHECK ADD CONSTRAINT [FK_SalesItem_ActivityDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ActivityDataLine] ([SalesItem])
GO
ALTER TABLE [dbo].[SalesItem] CHECK CONSTRAINT [FK_SalesItem_ActivityDataLine]
GO
ALTER TABLE [dbo].[AddressLine] WITH CHECK ADD CONSTRAINT [FK_AddressLine_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([AddressLine])
GO
ALTER TABLE [dbo].[AddressLine] CHECK CONSTRAINT [FK_AddressLine_Address]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_Country_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([Country])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_Country_Address]
GO
ALTER TABLE [dbo].[LocationCoordinate] WITH CHECK ADD CONSTRAINT [FK_LocationCoordinate_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([LocationCoordinate])
GO
ALTER TABLE [dbo].[LocationCoordinate] CHECK CONSTRAINT [FK_LocationCoordinate_Address]
GO
ALTER TABLE [dbo].[TaxCategory] WITH CHECK ADD CONSTRAINT [FK_TaxCategory_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([TaxCategory])
GO
ALTER TABLE [dbo].[TaxCategory] CHECK CONSTRAINT [FK_TaxCategory_AllowanceCharge]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_AllowanceCharge]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_AllowanceCharge]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_PresentationPeriod_AppealTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AppealTerms] ([PresentationPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_PresentationPeriod_AppealTerms]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_AppealInformationParty_AppealTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AppealTerms] ([AppealInformationParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_AppealInformationParty_AppealTerms]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_AppealReceiverParty_AppealTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AppealTerms] ([AppealReceiverParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_AppealReceiverParty_AppealTerms]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_MediationParty_AppealTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AppealTerms] ([MediationParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_MediationParty_AppealTerms]
GO
ALTER TABLE [dbo].[ExternalReference] WITH CHECK ADD CONSTRAINT [FK_ExternalReference_Attachment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Attachment] ([ExternalReference])
GO
ALTER TABLE [dbo].[ExternalReference] CHECK CONSTRAINT [FK_ExternalReference_Attachment]
GO
ALTER TABLE [dbo].[AwardingCriterion] WITH CHECK ADD CONSTRAINT [FK_SubordinateAwardingCriterion_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([SubordinateAwardingCriterion])
GO
ALTER TABLE [dbo].[AwardingCriterion] CHECK CONSTRAINT [FK_SubordinateAwardingCriterion_AwardingCriterion]
GO
ALTER TABLE [dbo].[AwardingCriterionResponse] WITH CHECK ADD CONSTRAINT [FK_SubordinateAwardingCriterionResponse_AwardingCriterionResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterionResponse] ([SubordinateAwardingCriterionResponse])
GO
ALTER TABLE [dbo].[AwardingCriterionResponse] CHECK CONSTRAINT [FK_SubordinateAwardingCriterionResponse_AwardingCriterionResponse]
GO
ALTER TABLE [dbo].[AwardingCriterion] WITH CHECK ADD CONSTRAINT [FK_AwardingCriterion_AwardingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingTerms] ([AwardingCriterion])
GO
ALTER TABLE [dbo].[AwardingCriterion] CHECK CONSTRAINT [FK_AwardingCriterion_AwardingTerms]
GO
ALTER TABLE [dbo].[Person] WITH CHECK ADD CONSTRAINT [FK_TechnicalCommitteePerson_AwardingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingTerms] ([TechnicalCommitteePerson])
GO
ALTER TABLE [dbo].[Person] CHECK CONSTRAINT [FK_TechnicalCommitteePerson_AwardingTerms]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_InvoiceDocumentReference_BillingReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillingReference] ([InvoiceDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_InvoiceDocumentReference_BillingReference]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_SelfBilledInvoiceDocumentReference_BillingReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillingReference] ([SelfBilledInvoiceDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_SelfBilledInvoiceDocumentReference_BillingReference]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_CreditNoteDocumentReference_BillingReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillingReference] ([CreditNoteDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_CreditNoteDocumentReference_BillingReference]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_SelfBilledCreditNoteDocumentReference_BillingReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillingReference] ([SelfBilledCreditNoteDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_SelfBilledCreditNoteDocumentReference_BillingReference]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DebitNoteDocumentReference_BillingReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillingReference] ([DebitNoteDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DebitNoteDocumentReference_BillingReference]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ReminderDocumentReference_BillingReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillingReference] ([ReminderDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ReminderDocumentReference_BillingReference]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_BillingReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillingReference] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_BillingReference]
GO
ALTER TABLE [dbo].[BillingReferenceLine] WITH CHECK ADD CONSTRAINT [FK_BillingReferenceLine_BillingReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillingReference] ([BillingReferenceLine])
GO
ALTER TABLE [dbo].[BillingReferenceLine] CHECK CONSTRAINT [FK_BillingReferenceLine_BillingReference]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_BillingReferenceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillingReferenceLine] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_BillingReferenceLine]
GO
ALTER TABLE [dbo].[FinancialInstitution] WITH CHECK ADD CONSTRAINT [FK_FinancialInstitution_Branch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Branch] ([FinancialInstitution])
GO
ALTER TABLE [dbo].[FinancialInstitution] CHECK CONSTRAINT [FK_FinancialInstitution_Branch]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_Address_Branch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Branch] ([Address])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_Address_Branch]
GO
ALTER TABLE [dbo].[ClassificationScheme] WITH CHECK ADD CONSTRAINT [FK_RequiredClassificationScheme_BudgetAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[BudgetAccount] ([RequiredClassificationScheme])
GO
ALTER TABLE [dbo].[ClassificationScheme] CHECK CONSTRAINT [FK_RequiredClassificationScheme_BudgetAccount]
GO
ALTER TABLE [dbo].[BudgetAccount] WITH CHECK ADD CONSTRAINT [FK_BudgetAccount_BudgetAccountLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[BudgetAccountLine] ([BudgetAccount])
GO
ALTER TABLE [dbo].[BudgetAccount] CHECK CONSTRAINT [FK_BudgetAccount_BudgetAccountLine]
GO
ALTER TABLE [dbo].[EvidenceSupplied] WITH CHECK ADD CONSTRAINT [FK_EvidenceSupplied_Capability] FOREIGN KEY([Ref])
REFERENCES [dbo].[Capability] ([EvidenceSupplied])
GO
ALTER TABLE [dbo].[EvidenceSupplied] CHECK CONSTRAINT [FK_EvidenceSupplied_Capability]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_Capability] FOREIGN KEY([Ref])
REFERENCES [dbo].[Capability] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_Capability]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_ContractorCustomerParty_CatalogueItemSpecificationUpdateLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdateLine] ([ContractorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_ContractorCustomerParty_CatalogueItemSpecificationUpdateLine]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_CatalogueItemSpecificationUpdateLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdateLine] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_CatalogueItemSpecificationUpdateLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_CatalogueItemSpecificationUpdateLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdateLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_CatalogueItemSpecificationUpdateLine]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_ContractorCustomerParty_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([ContractorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_ContractorCustomerParty_CatalogueLine]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_CatalogueLine]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_WarrantyParty_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([WarrantyParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_WarrantyParty_CatalogueLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_WarrantyValidityPeriod_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([WarrantyValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_WarrantyValidityPeriod_CatalogueLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_LineValidityPeriod_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([LineValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_LineValidityPeriod_CatalogueLine]
GO
ALTER TABLE [dbo].[ItemComparison] WITH CHECK ADD CONSTRAINT [FK_ItemComparison_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([ItemComparison])
GO
ALTER TABLE [dbo].[ItemComparison] CHECK CONSTRAINT [FK_ItemComparison_CatalogueLine]
GO
ALTER TABLE [dbo].[RelatedItem] WITH CHECK ADD CONSTRAINT [FK_ComponentRelatedItem_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([ComponentRelatedItem])
GO
ALTER TABLE [dbo].[RelatedItem] CHECK CONSTRAINT [FK_ComponentRelatedItem_CatalogueLine]
GO
ALTER TABLE [dbo].[RelatedItem] WITH CHECK ADD CONSTRAINT [FK_AccessoryRelatedItem_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([AccessoryRelatedItem])
GO
ALTER TABLE [dbo].[RelatedItem] CHECK CONSTRAINT [FK_AccessoryRelatedItem_CatalogueLine]
GO
ALTER TABLE [dbo].[RelatedItem] WITH CHECK ADD CONSTRAINT [FK_RequiredRelatedItem_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([RequiredRelatedItem])
GO
ALTER TABLE [dbo].[RelatedItem] CHECK CONSTRAINT [FK_RequiredRelatedItem_CatalogueLine]
GO
ALTER TABLE [dbo].[RelatedItem] WITH CHECK ADD CONSTRAINT [FK_ReplacementRelatedItem_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([ReplacementRelatedItem])
GO
ALTER TABLE [dbo].[RelatedItem] CHECK CONSTRAINT [FK_ReplacementRelatedItem_CatalogueLine]
GO
ALTER TABLE [dbo].[RelatedItem] WITH CHECK ADD CONSTRAINT [FK_ComplementaryRelatedItem_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([ComplementaryRelatedItem])
GO
ALTER TABLE [dbo].[RelatedItem] CHECK CONSTRAINT [FK_ComplementaryRelatedItem_CatalogueLine]
GO
ALTER TABLE [dbo].[RelatedItem] WITH CHECK ADD CONSTRAINT [FK_ReplacedRelatedItem_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([ReplacedRelatedItem])
GO
ALTER TABLE [dbo].[RelatedItem] CHECK CONSTRAINT [FK_ReplacedRelatedItem_CatalogueLine]
GO
ALTER TABLE [dbo].[ItemLocationQuantity] WITH CHECK ADD CONSTRAINT [FK_RequiredItemLocationQuantity_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([RequiredItemLocationQuantity])
GO
ALTER TABLE [dbo].[ItemLocationQuantity] CHECK CONSTRAINT [FK_RequiredItemLocationQuantity_CatalogueLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_CatalogueLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_CatalogueLine]
GO
ALTER TABLE [dbo].[ItemProperty] WITH CHECK ADD CONSTRAINT [FK_KeywordItemProperty_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([KeywordItemProperty])
GO
ALTER TABLE [dbo].[ItemProperty] CHECK CONSTRAINT [FK_KeywordItemProperty_CatalogueLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_CallForTendersLineReference_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([CallForTendersLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_CallForTendersLineReference_CatalogueLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_CallForTendersDocumentReference_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([CallForTendersDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_CallForTendersDocumentReference_CatalogueLine]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_ContractorCustomerParty_CataloguePricingUpdateLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdateLine] ([ContractorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_ContractorCustomerParty_CataloguePricingUpdateLine]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_CataloguePricingUpdateLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdateLine] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_CataloguePricingUpdateLine]
GO
ALTER TABLE [dbo].[ItemLocationQuantity] WITH CHECK ADD CONSTRAINT [FK_RequiredItemLocationQuantity_CataloguePricingUpdateLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdateLine] ([RequiredItemLocationQuantity])
GO
ALTER TABLE [dbo].[ItemLocationQuantity] CHECK CONSTRAINT [FK_RequiredItemLocationQuantity_CataloguePricingUpdateLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_LineValidityPeriod_CatalogueRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequestLine] ([LineValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_LineValidityPeriod_CatalogueRequestLine]
GO
ALTER TABLE [dbo].[ItemLocationQuantity] WITH CHECK ADD CONSTRAINT [FK_RequiredItemLocationQuantity_CatalogueRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequestLine] ([RequiredItemLocationQuantity])
GO
ALTER TABLE [dbo].[ItemLocationQuantity] CHECK CONSTRAINT [FK_RequiredItemLocationQuantity_CatalogueRequestLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_CatalogueRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequestLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_CatalogueRequestLine]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_IssuerParty_Certificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[Certificate] ([IssuerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_IssuerParty_Certificate]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_Certificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[Certificate] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_Certificate]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_Certificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[Certificate] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_Certificate]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[EndorserParty] WITH CHECK ADD CONSTRAINT [FK_EndorserParty_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([EndorserParty])
GO
ALTER TABLE [dbo].[EndorserParty] CHECK CONSTRAINT [FK_EndorserParty_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PreparationParty_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([PreparationParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PreparationParty_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_IssuerParty_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([IssuerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_IssuerParty_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ExporterParty_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([ExporterParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ExporterParty_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ImporterParty_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([ImporterParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ImporterParty_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_IssuingCountry_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([IssuingCountry])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_IssuingCountry_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[DocumentDistribution] WITH CHECK ADD CONSTRAINT [FK_DocumentDistribution_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([DocumentDistribution])
GO
ALTER TABLE [dbo].[DocumentDistribution] CHECK CONSTRAINT [FK_DocumentDistribution_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_SupportingDocumentReference_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([SupportingDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_SupportingDocumentReference_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[ClassificationCategory] WITH CHECK ADD CONSTRAINT [FK_CategorizesClassificationCategory_ClassificationCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationCategory] ([CategorizesClassificationCategory])
GO
ALTER TABLE [dbo].[ClassificationCategory] CHECK CONSTRAINT [FK_CategorizesClassificationCategory_ClassificationCategory]
GO
ALTER TABLE [dbo].[ClassificationCategory] WITH CHECK ADD CONSTRAINT [FK_ClassificationCategory_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([ClassificationCategory])
GO
ALTER TABLE [dbo].[ClassificationCategory] CHECK CONSTRAINT [FK_ClassificationCategory_ClassificationScheme]
GO
ALTER TABLE [dbo].[EvidenceSupplied] WITH CHECK ADD CONSTRAINT [FK_EvidenceSupplied_CompletedTask] FOREIGN KEY([Ref])
REFERENCES [dbo].[CompletedTask] ([EvidenceSupplied])
GO
ALTER TABLE [dbo].[EvidenceSupplied] CHECK CONSTRAINT [FK_EvidenceSupplied_CompletedTask]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_CompletedTask] FOREIGN KEY([Ref])
REFERENCES [dbo].[CompletedTask] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_CompletedTask]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_RecipientCustomerParty_CompletedTask] FOREIGN KEY([Ref])
REFERENCES [dbo].[CompletedTask] ([RecipientCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_RecipientCustomerParty_CompletedTask]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_ConsolidatedShipment_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ConsolidatedShipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_ConsolidatedShipment_Consignment]
GO
ALTER TABLE [dbo].[CustomsDeclaration] WITH CHECK ADD CONSTRAINT [FK_CustomsDeclaration_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([CustomsDeclaration])
GO
ALTER TABLE [dbo].[CustomsDeclaration] CHECK CONSTRAINT [FK_CustomsDeclaration_Consignment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_RequestedPickupTransportEvent_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([RequestedPickupTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_RequestedPickupTransportEvent_Consignment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_RequestedDeliveryTransportEvent_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([RequestedDeliveryTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_RequestedDeliveryTransportEvent_Consignment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_PlannedPickupTransportEvent_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([PlannedPickupTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_PlannedPickupTransportEvent_Consignment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_PlannedDeliveryTransportEvent_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([PlannedDeliveryTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_PlannedDeliveryTransportEvent_Consignment]
GO
ALTER TABLE [dbo].[Status] WITH CHECK ADD CONSTRAINT [FK_Status_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([Status])
GO
ALTER TABLE [dbo].[Status] CHECK CONSTRAINT [FK_Status_Consignment]
GO
ALTER TABLE [dbo].[Consignment] WITH CHECK ADD CONSTRAINT [FK_ChildConsignment_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ChildConsignment])
GO
ALTER TABLE [dbo].[Consignment] CHECK CONSTRAINT [FK_ChildConsignment_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ConsigneeParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ConsigneeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ConsigneeParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ExporterParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ExporterParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ExporterParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ConsignorParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ConsignorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ConsignorParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ImporterParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ImporterParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ImporterParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_CarrierParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([CarrierParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_CarrierParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_FreightForwarderParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([FreightForwarderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_FreightForwarderParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_NotifyParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([NotifyParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_NotifyParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_OriginalDespatchParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([OriginalDespatchParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_OriginalDespatchParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_FinalDeliveryParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([FinalDeliveryParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_FinalDeliveryParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PerformingCarrierParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([PerformingCarrierParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PerformingCarrierParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SubstituteCarrierParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([SubstituteCarrierParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SubstituteCarrierParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_LogisticsOperatorParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([LogisticsOperatorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_LogisticsOperatorParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TransportAdvisorParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([TransportAdvisorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TransportAdvisorParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_HazardousItemNotificationParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([HazardousItemNotificationParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_HazardousItemNotificationParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_InsuranceParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([InsuranceParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_InsuranceParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_MortgageHolderParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([MortgageHolderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_MortgageHolderParty_Consignment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_BillOfLadingHolderParty_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([BillOfLadingHolderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_BillOfLadingHolderParty_Consignment]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_OriginalDepartureCountry_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([OriginalDepartureCountry])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_OriginalDepartureCountry_Consignment]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_FinalDestinationCountry_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([FinalDestinationCountry])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_FinalDestinationCountry_Consignment]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_TransitCountry_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([TransitCountry])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_TransitCountry_Consignment]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_TransportContract_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([TransportContract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_TransportContract_Consignment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_TransportEvent_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([TransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_TransportEvent_Consignment]
GO
ALTER TABLE [dbo].[TransportationService] WITH CHECK ADD CONSTRAINT [FK_OriginalDespatchTransportationService_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([OriginalDespatchTransportationService])
GO
ALTER TABLE [dbo].[TransportationService] CHECK CONSTRAINT [FK_OriginalDespatchTransportationService_Consignment]
GO
ALTER TABLE [dbo].[TransportationService] WITH CHECK ADD CONSTRAINT [FK_FinalDeliveryTransportationService_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([FinalDeliveryTransportationService])
GO
ALTER TABLE [dbo].[TransportationService] CHECK CONSTRAINT [FK_FinalDeliveryTransportationService_Consignment]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_Consignment]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_Consignment]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_CollectPaymentTerms_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([CollectPaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_CollectPaymentTerms_Consignment]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_DisbursementPaymentTerms_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([DisbursementPaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_DisbursementPaymentTerms_Consignment]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PrepaidPaymentTerms_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([PrepaidPaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PrepaidPaymentTerms_Consignment]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_FreightAllowanceCharge_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([FreightAllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_FreightAllowanceCharge_Consignment]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_ExtraAllowanceCharge_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ExtraAllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_ExtraAllowanceCharge_Consignment]
GO
ALTER TABLE [dbo].[ShipmentStage] WITH CHECK ADD CONSTRAINT [FK_MainCarriageShipmentStage_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([MainCarriageShipmentStage])
GO
ALTER TABLE [dbo].[ShipmentStage] CHECK CONSTRAINT [FK_MainCarriageShipmentStage_Consignment]
GO
ALTER TABLE [dbo].[ShipmentStage] WITH CHECK ADD CONSTRAINT [FK_PreCarriageShipmentStage_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([PreCarriageShipmentStage])
GO
ALTER TABLE [dbo].[ShipmentStage] CHECK CONSTRAINT [FK_PreCarriageShipmentStage_Consignment]
GO
ALTER TABLE [dbo].[ShipmentStage] WITH CHECK ADD CONSTRAINT [FK_OnCarriageShipmentStage_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([OnCarriageShipmentStage])
GO
ALTER TABLE [dbo].[ShipmentStage] CHECK CONSTRAINT [FK_OnCarriageShipmentStage_Consignment]
GO
ALTER TABLE [dbo].[TransportHandlingUnit] WITH CHECK ADD CONSTRAINT [FK_TransportHandlingUnit_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([TransportHandlingUnit])
GO
ALTER TABLE [dbo].[TransportHandlingUnit] CHECK CONSTRAINT [FK_TransportHandlingUnit_Consignment]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_FirstArrivalPortLocation_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([FirstArrivalPortLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_FirstArrivalPortLocation_Consignment]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_LastExitPortLocation_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([LastExitPortLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_LastExitPortLocation_Consignment]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_MainPeriod_Consumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consumption] ([MainPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_MainPeriod_Consumption]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_Consumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consumption] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_Consumption]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_Consumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consumption] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_Consumption]
GO
ALTER TABLE [dbo].[EnergyWaterSupply] WITH CHECK ADD CONSTRAINT [FK_EnergyWaterSupply_Consumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consumption] ([EnergyWaterSupply])
GO
ALTER TABLE [dbo].[EnergyWaterSupply] CHECK CONSTRAINT [FK_EnergyWaterSupply_Consumption]
GO
ALTER TABLE [dbo].[TelecommunicationsSupply] WITH CHECK ADD CONSTRAINT [FK_TelecommunicationsSupply_Consumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consumption] ([TelecommunicationsSupply])
GO
ALTER TABLE [dbo].[TelecommunicationsSupply] CHECK CONSTRAINT [FK_TelecommunicationsSupply_Consumption]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_LegalMonetaryTotal_Consumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consumption] ([LegalMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_LegalMonetaryTotal_Consumption]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_ConsumptionHistory] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionHistory] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_ConsumptionHistory]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_ConsumptionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionLine] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_ConsumptionLine]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_ConsumptionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionLine] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_ConsumptionLine]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_ConsumptionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionLine] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_ConsumptionLine]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_ConsumptionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionLine] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_ConsumptionLine]
GO
ALTER TABLE [dbo].[UtilityItem] WITH CHECK ADD CONSTRAINT [FK_UtilityItem_ConsumptionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionLine] ([UtilityItem])
GO
ALTER TABLE [dbo].[UtilityItem] CHECK CONSTRAINT [FK_UtilityItem_ConsumptionLine]
GO
ALTER TABLE [dbo].[Price] WITH CHECK ADD CONSTRAINT [FK_Price_ConsumptionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionLine] ([Price])
GO
ALTER TABLE [dbo].[Price] CHECK CONSTRAINT [FK_Price_ConsumptionLine]
GO
ALTER TABLE [dbo].[UnstructuredPrice] WITH CHECK ADD CONSTRAINT [FK_UnstructuredPrice_ConsumptionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionLine] ([UnstructuredPrice])
GO
ALTER TABLE [dbo].[UnstructuredPrice] CHECK CONSTRAINT [FK_UnstructuredPrice_ConsumptionLine]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_Address_ConsumptionPoint] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionPoint] ([Address])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_Address_ConsumptionPoint]
GO
ALTER TABLE [dbo].[WebSiteAccess] WITH CHECK ADD CONSTRAINT [FK_WebSiteAccess_ConsumptionPoint] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionPoint] ([WebSiteAccess])
GO
ALTER TABLE [dbo].[WebSiteAccess] CHECK CONSTRAINT [FK_WebSiteAccess_ConsumptionPoint]
GO
ALTER TABLE [dbo].[Meter] WITH CHECK ADD CONSTRAINT [FK_UtilityMeter_ConsumptionPoint] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionPoint] ([UtilityMeter])
GO
ALTER TABLE [dbo].[Meter] CHECK CONSTRAINT [FK_UtilityMeter_ConsumptionPoint]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_ConsumptionReport]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_GuidanceDocumentReference_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([GuidanceDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_GuidanceDocumentReference_ConsumptionReport]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_ConsumptionReport]
GO
ALTER TABLE [dbo].[ConsumptionReportReference] WITH CHECK ADD CONSTRAINT [FK_ConsumptionReportReference_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([ConsumptionReportReference])
GO
ALTER TABLE [dbo].[ConsumptionReportReference] CHECK CONSTRAINT [FK_ConsumptionReportReference_ConsumptionReport]
GO
ALTER TABLE [dbo].[ConsumptionHistory] WITH CHECK ADD CONSTRAINT [FK_ConsumptionHistory_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([ConsumptionHistory])
GO
ALTER TABLE [dbo].[ConsumptionHistory] CHECK CONSTRAINT [FK_ConsumptionHistory_ConsumptionReport]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_ConsumptionReportReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReportReference] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_ConsumptionReportReference]
GO
ALTER TABLE [dbo].[Communication] WITH CHECK ADD CONSTRAINT [FK_OtherCommunication_Contact] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contact] ([OtherCommunication])
GO
ALTER TABLE [dbo].[Communication] CHECK CONSTRAINT [FK_OtherCommunication_Contact]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_Contract]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ContractDocumentReference_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([ContractDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ContractDocumentReference_Contract]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_NominationPeriod_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([NominationPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_NominationPeriod_Contract]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_ContractualDelivery_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([ContractualDelivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_ContractualDelivery_Contract]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_OptionValidityPeriod_ContractExtension] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractExtension] ([OptionValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_OptionValidityPeriod_ContractExtension]
GO
ALTER TABLE [dbo].[Renewal] WITH CHECK ADD CONSTRAINT [FK_Renewal_ContractExtension] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractExtension] ([Renewal])
GO
ALTER TABLE [dbo].[Renewal] CHECK CONSTRAINT [FK_Renewal_ContractExtension]
GO
ALTER TABLE [dbo].[ContractingPartyType] WITH CHECK ADD CONSTRAINT [FK_ContractingPartyType_ContractingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractingParty] ([ContractingPartyType])
GO
ALTER TABLE [dbo].[ContractingPartyType] CHECK CONSTRAINT [FK_ContractingPartyType_ContractingParty]
GO
ALTER TABLE [dbo].[ContractingActivity] WITH CHECK ADD CONSTRAINT [FK_ContractingActivity_ContractingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractingParty] ([ContractingActivity])
GO
ALTER TABLE [dbo].[ContractingActivity] CHECK CONSTRAINT [FK_ContractingActivity_ContractingParty]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_Party_ContractingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractingParty] ([Party])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_Party_ContractingParty]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_JurisdictionRegionAddress_CorporateRegistrationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[CorporateRegistrationScheme] ([JurisdictionRegionAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_JurisdictionRegionAddress_CorporateRegistrationScheme]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvoicePeriod_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([InvoicePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvoicePeriod_CreditNoteLine]
GO
ALTER TABLE [dbo].[OrderLineReference] WITH CHECK ADD CONSTRAINT [FK_OrderLineReference_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([OrderLineReference])
GO
ALTER TABLE [dbo].[OrderLineReference] CHECK CONSTRAINT [FK_OrderLineReference_CreditNoteLine]
GO
ALTER TABLE [dbo].[Response] WITH CHECK ADD CONSTRAINT [FK_DiscrepancyResponse_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([DiscrepancyResponse])
GO
ALTER TABLE [dbo].[Response] CHECK CONSTRAINT [FK_DiscrepancyResponse_CreditNoteLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_DespatchLineReference_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([DespatchLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_DespatchLineReference_CreditNoteLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_ReceiptLineReference_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([ReceiptLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_ReceiptLineReference_CreditNoteLine]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_CreditNoteLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_CreditNoteLine]
GO
ALTER TABLE [dbo].[PricingReference] WITH CHECK ADD CONSTRAINT [FK_PricingReference_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([PricingReference])
GO
ALTER TABLE [dbo].[PricingReference] CHECK CONSTRAINT [FK_PricingReference_CreditNoteLine]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_OriginatorParty_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([OriginatorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_OriginatorParty_CreditNoteLine]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_CreditNoteLine]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_CreditNoteLine]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_CreditNoteLine]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_CreditNoteLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_CreditNoteLine]
GO
ALTER TABLE [dbo].[Price] WITH CHECK ADD CONSTRAINT [FK_Price_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([Price])
GO
ALTER TABLE [dbo].[Price] CHECK CONSTRAINT [FK_Price_CreditNoteLine]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_CreditNoteLine]
GO
ALTER TABLE [dbo].[CreditNoteLine] WITH CHECK ADD CONSTRAINT [FK_SubCreditNoteLine_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([SubCreditNoteLine])
GO
ALTER TABLE [dbo].[CreditNoteLine] CHECK CONSTRAINT [FK_SubCreditNoteLine_CreditNoteLine]
GO
ALTER TABLE [dbo].[PriceExtension] WITH CHECK ADD CONSTRAINT [FK_ItemPriceExtension_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([ItemPriceExtension])
GO
ALTER TABLE [dbo].[PriceExtension] CHECK CONSTRAINT [FK_ItemPriceExtension_CreditNoteLine]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_Party_CustomerParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[CustomerParty] ([Party])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_Party_CustomerParty]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_DeliveryContact_CustomerParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[CustomerParty] ([DeliveryContact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_DeliveryContact_CustomerParty]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_AccountingContact_CustomerParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[CustomerParty] ([AccountingContact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_AccountingContact_CustomerParty]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_BuyerContact_CustomerParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[CustomerParty] ([BuyerContact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_BuyerContact_CustomerParty]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_IssuerParty_CustomsDeclaration] FOREIGN KEY([Ref])
REFERENCES [dbo].[CustomsDeclaration] ([IssuerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_IssuerParty_CustomsDeclaration]
GO
ALTER TABLE [dbo].[Response] WITH CHECK ADD CONSTRAINT [FK_DiscrepancyResponse_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([DiscrepancyResponse])
GO
ALTER TABLE [dbo].[Response] CHECK CONSTRAINT [FK_DiscrepancyResponse_DebitNoteLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_DespatchLineReference_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([DespatchLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_DespatchLineReference_DebitNoteLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_ReceiptLineReference_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([ReceiptLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_ReceiptLineReference_DebitNoteLine]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_DebitNoteLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_DebitNoteLine]
GO
ALTER TABLE [dbo].[PricingReference] WITH CHECK ADD CONSTRAINT [FK_PricingReference_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([PricingReference])
GO
ALTER TABLE [dbo].[PricingReference] CHECK CONSTRAINT [FK_PricingReference_DebitNoteLine]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_DebitNoteLine]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_DebitNoteLine]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_DebitNoteLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_DebitNoteLine]
GO
ALTER TABLE [dbo].[Price] WITH CHECK ADD CONSTRAINT [FK_Price_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([Price])
GO
ALTER TABLE [dbo].[Price] CHECK CONSTRAINT [FK_Price_DebitNoteLine]
GO
ALTER TABLE [dbo].[DebitNoteLine] WITH CHECK ADD CONSTRAINT [FK_SubDebitNoteLine_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([SubDebitNoteLine])
GO
ALTER TABLE [dbo].[DebitNoteLine] CHECK CONSTRAINT [FK_SubDebitNoteLine_DebitNoteLine]
GO
ALTER TABLE [dbo].[EvidenceSupplied] WITH CHECK ADD CONSTRAINT [FK_EvidenceSupplied_Declaration] FOREIGN KEY([Ref])
REFERENCES [dbo].[Declaration] ([EvidenceSupplied])
GO
ALTER TABLE [dbo].[EvidenceSupplied] CHECK CONSTRAINT [FK_EvidenceSupplied_Declaration]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_DeliveryAddress_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([DeliveryAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_DeliveryAddress_Delivery]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_DeliveryLocation_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([DeliveryLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_DeliveryLocation_Delivery]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_AlternativeDeliveryLocation_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([AlternativeDeliveryLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_AlternativeDeliveryLocation_Delivery]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_RequestedDeliveryPeriod_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([RequestedDeliveryPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_RequestedDeliveryPeriod_Delivery]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_PromisedDeliveryPeriod_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([PromisedDeliveryPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_PromisedDeliveryPeriod_Delivery]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_EstimatedDeliveryPeriod_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([EstimatedDeliveryPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_EstimatedDeliveryPeriod_Delivery]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_CarrierParty_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([CarrierParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_CarrierParty_Delivery]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_DeliveryParty_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([DeliveryParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_DeliveryParty_Delivery]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_NotifyParty_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([NotifyParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_NotifyParty_Delivery]
GO
ALTER TABLE [dbo].[Despatch] WITH CHECK ADD CONSTRAINT [FK_Despatch_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([Despatch])
GO
ALTER TABLE [dbo].[Despatch] CHECK CONSTRAINT [FK_Despatch_Delivery]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_Delivery]
GO
ALTER TABLE [dbo].[DeliveryUnit] WITH CHECK ADD CONSTRAINT [FK_MinimumDeliveryUnit_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([MinimumDeliveryUnit])
GO
ALTER TABLE [dbo].[DeliveryUnit] CHECK CONSTRAINT [FK_MinimumDeliveryUnit_Delivery]
GO
ALTER TABLE [dbo].[DeliveryUnit] WITH CHECK ADD CONSTRAINT [FK_MaximumDeliveryUnit_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([MaximumDeliveryUnit])
GO
ALTER TABLE [dbo].[DeliveryUnit] CHECK CONSTRAINT [FK_MaximumDeliveryUnit_Delivery]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_Delivery]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_DeliveryLocation_DeliveryTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[DeliveryTerms] ([DeliveryLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_DeliveryLocation_DeliveryTerms]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_DeliveryTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[DeliveryTerms] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_DeliveryTerms]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_LocationAddress_DependentPriceReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DependentPriceReference] ([LocationAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_LocationAddress_DependentPriceReference]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_DependentLineReference_DependentPriceReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DependentPriceReference] ([DependentLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_DependentLineReference_DependentPriceReference]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_DespatchAddress_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([DespatchAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_DespatchAddress_Despatch]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_DespatchLocation_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([DespatchLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_DespatchLocation_Despatch]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_DespatchParty_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([DespatchParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_DespatchParty_Despatch]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_CarrierParty_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([CarrierParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_CarrierParty_Despatch]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_NotifyParty_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([NotifyParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_NotifyParty_Despatch]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_Contact_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([Contact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_Contact_Despatch]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_EstimatedDespatchPeriod_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([EstimatedDespatchPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_EstimatedDespatchPeriod_Despatch]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_RequestedDespatchPeriod_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([RequestedDespatchPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_RequestedDespatchPeriod_Despatch]
GO
ALTER TABLE [dbo].[OrderLineReference] WITH CHECK ADD CONSTRAINT [FK_OrderLineReference_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([OrderLineReference])
GO
ALTER TABLE [dbo].[OrderLineReference] CHECK CONSTRAINT [FK_OrderLineReference_DespatchLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_DespatchLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_DespatchLine]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_DespatchLine]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_Party_DocumentDistribution] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentDistribution] ([Party])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_Party_DocumentDistribution]
GO
ALTER TABLE [dbo].[Attachment] WITH CHECK ADD CONSTRAINT [FK_Attachment_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([Attachment])
GO
ALTER TABLE [dbo].[Attachment] CHECK CONSTRAINT [FK_Attachment_DocumentReference]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_DocumentReference]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_IssuerParty_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([IssuerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_IssuerParty_DocumentReference]
GO
ALTER TABLE [dbo].[ResultOfVerification] WITH CHECK ADD CONSTRAINT [FK_ResultOfVerification_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([ResultOfVerification])
GO
ALTER TABLE [dbo].[ResultOfVerification] CHECK CONSTRAINT [FK_ResultOfVerification_DocumentReference]
GO
ALTER TABLE [dbo].[Response] WITH CHECK ADD CONSTRAINT [FK_Response_DocumentResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentResponse] ([Response])
GO
ALTER TABLE [dbo].[Response] CHECK CONSTRAINT [FK_Response_DocumentResponse]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_DocumentResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentResponse] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_DocumentResponse]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_IssuerParty_DocumentResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentResponse] ([IssuerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_IssuerParty_DocumentResponse]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_RecipientParty_DocumentResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentResponse] ([RecipientParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_RecipientParty_DocumentResponse]
GO
ALTER TABLE [dbo].[LineResponse] WITH CHECK ADD CONSTRAINT [FK_LineResponse_DocumentResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentResponse] ([LineResponse])
GO
ALTER TABLE [dbo].[LineResponse] CHECK CONSTRAINT [FK_LineResponse_DocumentResponse]
GO
ALTER TABLE [dbo].[TaxCategory] WITH CHECK ADD CONSTRAINT [FK_TaxCategory_Duty] FOREIGN KEY([Ref])
REFERENCES [dbo].[Duty] ([TaxCategory])
GO
ALTER TABLE [dbo].[TaxCategory] CHECK CONSTRAINT [FK_TaxCategory_Duty]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PreSelectedParty_EconomicOperatorShortList] FOREIGN KEY([Ref])
REFERENCES [dbo].[EconomicOperatorShortList] ([PreSelectedParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PreSelectedParty_EconomicOperatorShortList]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_MeasurementFromLocation_EmissionCalculationMethod] FOREIGN KEY([Ref])
REFERENCES [dbo].[EmissionCalculationMethod] ([MeasurementFromLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_MeasurementFromLocation_EmissionCalculationMethod]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_MeasurementToLocation_EmissionCalculationMethod] FOREIGN KEY([Ref])
REFERENCES [dbo].[EmissionCalculationMethod] ([MeasurementToLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_MeasurementToLocation_EmissionCalculationMethod]
GO
ALTER TABLE [dbo].[EndorserParty] WITH CHECK ADD CONSTRAINT [FK_EndorserParty_Endorsement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Endorsement] ([EndorserParty])
GO
ALTER TABLE [dbo].[EndorserParty] CHECK CONSTRAINT [FK_EndorserParty_Endorsement]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_Endorsement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Endorsement] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_Endorsement]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_Party_EndorserParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[EndorserParty] ([Party])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_Party_EndorserParty]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_SignatoryContact_EndorserParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[EndorserParty] ([SignatoryContact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_SignatoryContact_EndorserParty]
GO
ALTER TABLE [dbo].[TaxScheme] WITH CHECK ADD CONSTRAINT [FK_TaxScheme_EnergyTaxReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnergyTaxReport] ([TaxScheme])
GO
ALTER TABLE [dbo].[TaxScheme] CHECK CONSTRAINT [FK_TaxScheme_EnergyTaxReport]
GO
ALTER TABLE [dbo].[ConsumptionReport] WITH CHECK ADD CONSTRAINT [FK_ConsumptionReport_EnergyWaterSupply] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnergyWaterSupply] ([ConsumptionReport])
GO
ALTER TABLE [dbo].[ConsumptionReport] CHECK CONSTRAINT [FK_ConsumptionReport_EnergyWaterSupply]
GO
ALTER TABLE [dbo].[EnergyTaxReport] WITH CHECK ADD CONSTRAINT [FK_EnergyTaxReport_EnergyWaterSupply] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnergyWaterSupply] ([EnergyTaxReport])
GO
ALTER TABLE [dbo].[EnergyTaxReport] CHECK CONSTRAINT [FK_EnergyTaxReport_EnergyWaterSupply]
GO
ALTER TABLE [dbo].[ConsumptionAverage] WITH CHECK ADD CONSTRAINT [FK_ConsumptionAverage_EnergyWaterSupply] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnergyWaterSupply] ([ConsumptionAverage])
GO
ALTER TABLE [dbo].[ConsumptionAverage] CHECK CONSTRAINT [FK_ConsumptionAverage_EnergyWaterSupply]
GO
ALTER TABLE [dbo].[ConsumptionCorrection] WITH CHECK ADD CONSTRAINT [FK_EnergyWaterConsumptionCorrection_EnergyWaterSupply] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnergyWaterSupply] ([EnergyWaterConsumptionCorrection])
GO
ALTER TABLE [dbo].[ConsumptionCorrection] CHECK CONSTRAINT [FK_EnergyWaterConsumptionCorrection_EnergyWaterSupply]
GO
ALTER TABLE [dbo].[EmissionCalculationMethod] WITH CHECK ADD CONSTRAINT [FK_EmissionCalculationMethod_EnvironmentalEmission] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnvironmentalEmission] ([EmissionCalculationMethod])
GO
ALTER TABLE [dbo].[EmissionCalculationMethod] CHECK CONSTRAINT [FK_EmissionCalculationMethod_EnvironmentalEmission]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_DurationPeriod_EvaluationCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[EvaluationCriterion] ([DurationPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_DurationPeriod_EvaluationCriterion]
GO
ALTER TABLE [dbo].[Evidence] WITH CHECK ADD CONSTRAINT [FK_SuggestedEvidence_EvaluationCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[EvaluationCriterion] ([SuggestedEvidence])
GO
ALTER TABLE [dbo].[Evidence] CHECK CONSTRAINT [FK_SuggestedEvidence_EvaluationCriterion]
GO
ALTER TABLE [dbo].[Status] WITH CHECK ADD CONSTRAINT [FK_CurrentStatus_Event] FOREIGN KEY([Ref])
REFERENCES [dbo].[Event] ([CurrentStatus])
GO
ALTER TABLE [dbo].[Status] CHECK CONSTRAINT [FK_CurrentStatus_Event]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_Contact_Event] FOREIGN KEY([Ref])
REFERENCES [dbo].[Event] ([Contact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_Contact_Event]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_OccurenceLocation_Event] FOREIGN KEY([Ref])
REFERENCES [dbo].[Event] ([OccurenceLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_OccurenceLocation_Event]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_ParticipatingLocationsLocation_EventLineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventLineItem] ([ParticipatingLocationsLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_ParticipatingLocationsLocation_EventLineItem]
GO
ALTER TABLE [dbo].[RetailPlannedImpact] WITH CHECK ADD CONSTRAINT [FK_RetailPlannedImpact_EventLineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventLineItem] ([RetailPlannedImpact])
GO
ALTER TABLE [dbo].[RetailPlannedImpact] CHECK CONSTRAINT [FK_RetailPlannedImpact_EventLineItem]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_SupplyItem_EventLineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventLineItem] ([SupplyItem])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_SupplyItem_EventLineItem]
GO
ALTER TABLE [dbo].[EventTacticEnumeration] WITH CHECK ADD CONSTRAINT [FK_EventTacticEnumeration_EventTactic] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventTactic] ([EventTacticEnumeration])
GO
ALTER TABLE [dbo].[EventTacticEnumeration] CHECK CONSTRAINT [FK_EventTacticEnumeration_EventTactic]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_EventTactic] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventTactic] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_EventTactic]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_EvidenceIssuingParty_Evidence] FOREIGN KEY([Ref])
REFERENCES [dbo].[Evidence] ([EvidenceIssuingParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_EvidenceIssuingParty_Evidence]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_Evidence] FOREIGN KEY([Ref])
REFERENCES [dbo].[Evidence] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_Evidence]
GO
ALTER TABLE [dbo].[Language] WITH CHECK ADD CONSTRAINT [FK_Language_Evidence] FOREIGN KEY([Ref])
REFERENCES [dbo].[Evidence] ([Language])
GO
ALTER TABLE [dbo].[Language] CHECK CONSTRAINT [FK_Language_Evidence]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_EffectivePeriod_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([EffectivePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_EffectivePeriod_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_SupplyItem_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([SupplyItem])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_SupplyItem_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[ForecastExceptionCriterionLine] WITH CHECK ADD CONSTRAINT [FK_ForecastExceptionCriterionLine_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([ForecastExceptionCriterionLine])
GO
ALTER TABLE [dbo].[ForecastExceptionCriterionLine] CHECK CONSTRAINT [FK_ForecastExceptionCriterionLine_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ExceptionObservationPeriod_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([ExceptionObservationPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ExceptionObservationPeriod_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[ForecastException] WITH CHECK ADD CONSTRAINT [FK_ForecastException_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([ForecastException])
GO
ALTER TABLE [dbo].[ForecastException] CHECK CONSTRAINT [FK_ForecastException_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_SupplyItem_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([SupplyItem])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_SupplyItem_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_ForeignExchangeContract_ExchangeRate] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExchangeRate] ([ForeignExchangeContract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_ForeignExchangeContract_ExchangeRate]
GO
ALTER TABLE [dbo].[Branch] WITH CHECK ADD CONSTRAINT [FK_FinancialInstitutionBranch_FinancialAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialAccount] ([FinancialInstitutionBranch])
GO
ALTER TABLE [dbo].[Branch] CHECK CONSTRAINT [FK_FinancialInstitutionBranch_FinancialAccount]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_Country_FinancialAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialAccount] ([Country])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_Country_FinancialAccount]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ConstitutionPeriod_FinancialGuarantee] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialGuarantee] ([ConstitutionPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ConstitutionPeriod_FinancialGuarantee]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_Address_FinancialInstitution] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialInstitution] ([Address])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_Address_FinancialInstitution]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ForecastPeriod_ForecastLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastLine] ([ForecastPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ForecastPeriod_ForecastLine]
GO
ALTER TABLE [dbo].[SalesItem] WITH CHECK ADD CONSTRAINT [FK_SalesItem_ForecastLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastLine] ([SalesItem])
GO
ALTER TABLE [dbo].[SalesItem] CHECK CONSTRAINT [FK_SalesItem_ForecastLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ForecastPeriod_ForecastRevisionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevisionLine] ([ForecastPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ForecastPeriod_ForecastRevisionLine]
GO
ALTER TABLE [dbo].[SalesItem] WITH CHECK ADD CONSTRAINT [FK_SalesItem_ForecastRevisionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevisionLine] ([SalesItem])
GO
ALTER TABLE [dbo].[SalesItem] CHECK CONSTRAINT [FK_SalesItem_ForecastRevisionLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_DurationPeriod_FrameworkAgreement] FOREIGN KEY([Ref])
REFERENCES [dbo].[FrameworkAgreement] ([DurationPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_DurationPeriod_FrameworkAgreement]
GO
ALTER TABLE [dbo].[TenderRequirement] WITH CHECK ADD CONSTRAINT [FK_SubsequentProcessTenderRequirement_FrameworkAgreement] FOREIGN KEY([Ref])
REFERENCES [dbo].[FrameworkAgreement] ([SubsequentProcessTenderRequirement])
GO
ALTER TABLE [dbo].[TenderRequirement] CHECK CONSTRAINT [FK_SubsequentProcessTenderRequirement_FrameworkAgreement]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_GoodsItem]
GO
ALTER TABLE [dbo].[GoodsItemContainer] WITH CHECK ADD CONSTRAINT [FK_GoodsItemContainer_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([GoodsItemContainer])
GO
ALTER TABLE [dbo].[GoodsItemContainer] CHECK CONSTRAINT [FK_GoodsItemContainer_GoodsItem]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_FreightAllowanceCharge_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([FreightAllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_FreightAllowanceCharge_GoodsItem]
GO
ALTER TABLE [dbo].[InvoiceLine] WITH CHECK ADD CONSTRAINT [FK_InvoiceLine_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([InvoiceLine])
GO
ALTER TABLE [dbo].[InvoiceLine] CHECK CONSTRAINT [FK_InvoiceLine_GoodsItem]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_Temperature_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([Temperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_Temperature_GoodsItem]
GO
ALTER TABLE [dbo].[GoodsItem] WITH CHECK ADD CONSTRAINT [FK_ContainedGoodsItem_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([ContainedGoodsItem])
GO
ALTER TABLE [dbo].[GoodsItem] CHECK CONSTRAINT [FK_ContainedGoodsItem_GoodsItem]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_OriginAddress_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([OriginAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_OriginAddress_GoodsItem]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_GoodsItem]
GO
ALTER TABLE [dbo].[Pickup] WITH CHECK ADD CONSTRAINT [FK_Pickup_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([Pickup])
GO
ALTER TABLE [dbo].[Pickup] CHECK CONSTRAINT [FK_Pickup_GoodsItem]
GO
ALTER TABLE [dbo].[Despatch] WITH CHECK ADD CONSTRAINT [FK_Despatch_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([Despatch])
GO
ALTER TABLE [dbo].[Despatch] CHECK CONSTRAINT [FK_Despatch_GoodsItem]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_MeasurementDimension_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([MeasurementDimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_MeasurementDimension_GoodsItem]
GO
ALTER TABLE [dbo].[Package] WITH CHECK ADD CONSTRAINT [FK_ContainingPackage_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([ContainingPackage])
GO
ALTER TABLE [dbo].[Package] CHECK CONSTRAINT [FK_ContainingPackage_GoodsItem]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ShipmentDocumentReference_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([ShipmentDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ShipmentDocumentReference_GoodsItem]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_MinimumTemperature_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([MinimumTemperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_MinimumTemperature_GoodsItem]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_MaximumTemperature_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([MaximumTemperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_MaximumTemperature_GoodsItem]
GO
ALTER TABLE [dbo].[TransportEquipment] WITH CHECK ADD CONSTRAINT [FK_TransportEquipment_GoodsItemContainer] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemContainer] ([TransportEquipment])
GO
ALTER TABLE [dbo].[TransportEquipment] CHECK CONSTRAINT [FK_TransportEquipment_GoodsItemContainer]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_MaximumTemperature_HazardousGoodsTransit] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousGoodsTransit] ([MaximumTemperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_MaximumTemperature_HazardousGoodsTransit]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_MinimumTemperature_HazardousGoodsTransit] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousGoodsTransit] ([MinimumTemperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_MinimumTemperature_HazardousGoodsTransit]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ContactParty_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([ContactParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ContactParty_HazardousItem]
GO
ALTER TABLE [dbo].[SecondaryHazard] WITH CHECK ADD CONSTRAINT [FK_SecondaryHazard_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([SecondaryHazard])
GO
ALTER TABLE [dbo].[SecondaryHazard] CHECK CONSTRAINT [FK_SecondaryHazard_HazardousItem]
GO
ALTER TABLE [dbo].[HazardousGoodsTransit] WITH CHECK ADD CONSTRAINT [FK_HazardousGoodsTransit_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([HazardousGoodsTransit])
GO
ALTER TABLE [dbo].[HazardousGoodsTransit] CHECK CONSTRAINT [FK_HazardousGoodsTransit_HazardousItem]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_EmergencyTemperature_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([EmergencyTemperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_EmergencyTemperature_HazardousItem]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_FlashpointTemperature_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([FlashpointTemperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_FlashpointTemperature_HazardousItem]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_AdditionalTemperature_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([AdditionalTemperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_AdditionalTemperature_HazardousItem]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_IssuerParty_ImmobilizedSecurity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ImmobilizedSecurity] ([IssuerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_IssuerParty_ImmobilizedSecurity]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ManufacturerParty_InstructionForReturnsLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturnsLine] ([ManufacturerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ManufacturerParty_InstructionForReturnsLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_InstructionForReturnsLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturnsLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_InstructionForReturnsLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_InventoryReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReportLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_InventoryReportLine]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_InventoryLocation_InventoryReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReportLine] ([InventoryLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_InventoryLocation_InventoryReportLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvoicePeriod_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([InvoicePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvoicePeriod_InvoiceLine]
GO
ALTER TABLE [dbo].[OrderLineReference] WITH CHECK ADD CONSTRAINT [FK_OrderLineReference_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([OrderLineReference])
GO
ALTER TABLE [dbo].[OrderLineReference] CHECK CONSTRAINT [FK_OrderLineReference_InvoiceLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_DespatchLineReference_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([DespatchLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_DespatchLineReference_InvoiceLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_ReceiptLineReference_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([ReceiptLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_ReceiptLineReference_InvoiceLine]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_InvoiceLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_InvoiceLine]
GO
ALTER TABLE [dbo].[PricingReference] WITH CHECK ADD CONSTRAINT [FK_PricingReference_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([PricingReference])
GO
ALTER TABLE [dbo].[PricingReference] CHECK CONSTRAINT [FK_PricingReference_InvoiceLine]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_OriginatorParty_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([OriginatorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_OriginatorParty_InvoiceLine]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_InvoiceLine]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_InvoiceLine]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_InvoiceLine]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_InvoiceLine]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_WithholdingTaxTotal_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([WithholdingTaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_WithholdingTaxTotal_InvoiceLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_InvoiceLine]
GO
ALTER TABLE [dbo].[Price] WITH CHECK ADD CONSTRAINT [FK_Price_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([Price])
GO
ALTER TABLE [dbo].[Price] CHECK CONSTRAINT [FK_Price_InvoiceLine]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_InvoiceLine]
GO
ALTER TABLE [dbo].[InvoiceLine] WITH CHECK ADD CONSTRAINT [FK_SubInvoiceLine_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([SubInvoiceLine])
GO
ALTER TABLE [dbo].[InvoiceLine] CHECK CONSTRAINT [FK_SubInvoiceLine_InvoiceLine]
GO
ALTER TABLE [dbo].[PriceExtension] WITH CHECK ADD CONSTRAINT [FK_ItemPriceExtension_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([ItemPriceExtension])
GO
ALTER TABLE [dbo].[PriceExtension] CHECK CONSTRAINT [FK_ItemPriceExtension_InvoiceLine]
GO
ALTER TABLE [dbo].[ItemIdentification] WITH CHECK ADD CONSTRAINT [FK_BuyersItemIdentification_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([BuyersItemIdentification])
GO
ALTER TABLE [dbo].[ItemIdentification] CHECK CONSTRAINT [FK_BuyersItemIdentification_Item]
GO
ALTER TABLE [dbo].[ItemIdentification] WITH CHECK ADD CONSTRAINT [FK_SellersItemIdentification_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([SellersItemIdentification])
GO
ALTER TABLE [dbo].[ItemIdentification] CHECK CONSTRAINT [FK_SellersItemIdentification_Item]
GO
ALTER TABLE [dbo].[ItemIdentification] WITH CHECK ADD CONSTRAINT [FK_ManufacturersItemIdentification_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([ManufacturersItemIdentification])
GO
ALTER TABLE [dbo].[ItemIdentification] CHECK CONSTRAINT [FK_ManufacturersItemIdentification_Item]
GO
ALTER TABLE [dbo].[ItemIdentification] WITH CHECK ADD CONSTRAINT [FK_StandardItemIdentification_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([StandardItemIdentification])
GO
ALTER TABLE [dbo].[ItemIdentification] CHECK CONSTRAINT [FK_StandardItemIdentification_Item]
GO
ALTER TABLE [dbo].[ItemIdentification] WITH CHECK ADD CONSTRAINT [FK_CatalogueItemIdentification_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([CatalogueItemIdentification])
GO
ALTER TABLE [dbo].[ItemIdentification] CHECK CONSTRAINT [FK_CatalogueItemIdentification_Item]
GO
ALTER TABLE [dbo].[ItemIdentification] WITH CHECK ADD CONSTRAINT [FK_AdditionalItemIdentification_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([AdditionalItemIdentification])
GO
ALTER TABLE [dbo].[ItemIdentification] CHECK CONSTRAINT [FK_AdditionalItemIdentification_Item]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_CatalogueDocumentReference_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([CatalogueDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_CatalogueDocumentReference_Item]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ItemSpecificationDocumentReference_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([ItemSpecificationDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ItemSpecificationDocumentReference_Item]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_OriginCountry_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([OriginCountry])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_OriginCountry_Item]
GO
ALTER TABLE [dbo].[CommodityClassification] WITH CHECK ADD CONSTRAINT [FK_CommodityClassification_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([CommodityClassification])
GO
ALTER TABLE [dbo].[CommodityClassification] CHECK CONSTRAINT [FK_CommodityClassification_Item]
GO
ALTER TABLE [dbo].[TransactionConditions] WITH CHECK ADD CONSTRAINT [FK_TransactionConditions_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([TransactionConditions])
GO
ALTER TABLE [dbo].[TransactionConditions] CHECK CONSTRAINT [FK_TransactionConditions_Item]
GO
ALTER TABLE [dbo].[HazardousItem] WITH CHECK ADD CONSTRAINT [FK_HazardousItem_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([HazardousItem])
GO
ALTER TABLE [dbo].[HazardousItem] CHECK CONSTRAINT [FK_HazardousItem_Item]
GO
ALTER TABLE [dbo].[TaxCategory] WITH CHECK ADD CONSTRAINT [FK_ClassifiedTaxCategory_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([ClassifiedTaxCategory])
GO
ALTER TABLE [dbo].[TaxCategory] CHECK CONSTRAINT [FK_ClassifiedTaxCategory_Item]
GO
ALTER TABLE [dbo].[ItemProperty] WITH CHECK ADD CONSTRAINT [FK_AdditionalItemProperty_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([AdditionalItemProperty])
GO
ALTER TABLE [dbo].[ItemProperty] CHECK CONSTRAINT [FK_AdditionalItemProperty_Item]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ManufacturerParty_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([ManufacturerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ManufacturerParty_Item]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_InformationContentProviderParty_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([InformationContentProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_InformationContentProviderParty_Item]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_OriginAddress_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([OriginAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_OriginAddress_Item]
GO
ALTER TABLE [dbo].[ItemInstance] WITH CHECK ADD CONSTRAINT [FK_ItemInstance_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([ItemInstance])
GO
ALTER TABLE [dbo].[ItemInstance] CHECK CONSTRAINT [FK_ItemInstance_Item]
GO
ALTER TABLE [dbo].[Certificate] WITH CHECK ADD CONSTRAINT [FK_Certificate_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([Certificate])
GO
ALTER TABLE [dbo].[Certificate] CHECK CONSTRAINT [FK_Certificate_Item]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_Dimension_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([Dimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_Dimension_Item]
GO
ALTER TABLE [dbo].[PhysicalAttribute] WITH CHECK ADD CONSTRAINT [FK_PhysicalAttribute_ItemIdentification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemIdentification] ([PhysicalAttribute])
GO
ALTER TABLE [dbo].[PhysicalAttribute] CHECK CONSTRAINT [FK_PhysicalAttribute_ItemIdentification]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_MeasurementDimension_ItemIdentification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemIdentification] ([MeasurementDimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_MeasurementDimension_ItemIdentification]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_IssuerParty_ItemIdentification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemIdentification] ([IssuerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_IssuerParty_ItemIdentification]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_ItemInformationRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequestLine] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_ItemInformationRequestLine]
GO
ALTER TABLE [dbo].[SalesItem] WITH CHECK ADD CONSTRAINT [FK_SalesItem_ItemInformationRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequestLine] ([SalesItem])
GO
ALTER TABLE [dbo].[SalesItem] CHECK CONSTRAINT [FK_SalesItem_ItemInformationRequestLine]
GO
ALTER TABLE [dbo].[ItemProperty] WITH CHECK ADD CONSTRAINT [FK_AdditionalItemProperty_ItemInstance] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInstance] ([AdditionalItemProperty])
GO
ALTER TABLE [dbo].[ItemProperty] CHECK CONSTRAINT [FK_AdditionalItemProperty_ItemInstance]
GO
ALTER TABLE [dbo].[LotIdentification] WITH CHECK ADD CONSTRAINT [FK_LotIdentification_ItemInstance] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInstance] ([LotIdentification])
GO
ALTER TABLE [dbo].[LotIdentification] CHECK CONSTRAINT [FK_LotIdentification_ItemInstance]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_ApplicableTerritoryAddress_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([ApplicableTerritoryAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_ApplicableTerritoryAddress_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[Price] WITH CHECK ADD CONSTRAINT [FK_Price_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([Price])
GO
ALTER TABLE [dbo].[Price] CHECK CONSTRAINT [FK_Price_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[DeliveryUnit] WITH CHECK ADD CONSTRAINT [FK_DeliveryUnit_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([DeliveryUnit])
GO
ALTER TABLE [dbo].[DeliveryUnit] CHECK CONSTRAINT [FK_DeliveryUnit_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[TaxCategory] WITH CHECK ADD CONSTRAINT [FK_ApplicableTaxCategory_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([ApplicableTaxCategory])
GO
ALTER TABLE [dbo].[TaxCategory] CHECK CONSTRAINT [FK_ApplicableTaxCategory_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[Package] WITH CHECK ADD CONSTRAINT [FK_Package_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([Package])
GO
ALTER TABLE [dbo].[Package] CHECK CONSTRAINT [FK_Package_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[DependentPriceReference] WITH CHECK ADD CONSTRAINT [FK_DependentPriceReference_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([DependentPriceReference])
GO
ALTER TABLE [dbo].[DependentPriceReference] CHECK CONSTRAINT [FK_DependentPriceReference_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_EffectivePeriod_ItemManagementProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemManagementProfile] ([EffectivePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_EffectivePeriod_ItemManagementProfile]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_ItemManagementProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemManagementProfile] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_ItemManagementProfile]
GO
ALTER TABLE [dbo].[ItemLocationQuantity] WITH CHECK ADD CONSTRAINT [FK_ItemLocationQuantity_ItemManagementProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemManagementProfile] ([ItemLocationQuantity])
GO
ALTER TABLE [dbo].[ItemLocationQuantity] CHECK CONSTRAINT [FK_ItemLocationQuantity_ItemManagementProfile]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_UsabilityPeriod_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([UsabilityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_UsabilityPeriod_ItemProperty]
GO
ALTER TABLE [dbo].[ItemPropertyGroup] WITH CHECK ADD CONSTRAINT [FK_ItemPropertyGroup_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([ItemPropertyGroup])
GO
ALTER TABLE [dbo].[ItemPropertyGroup] CHECK CONSTRAINT [FK_ItemPropertyGroup_ItemProperty]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_RangeDimension_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([RangeDimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_RangeDimension_ItemProperty]
GO
ALTER TABLE [dbo].[ItemPropertyRange] WITH CHECK ADD CONSTRAINT [FK_ItemPropertyRange_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([ItemPropertyRange])
GO
ALTER TABLE [dbo].[ItemPropertyRange] CHECK CONSTRAINT [FK_ItemPropertyRange_ItemProperty]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_LineItem]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_LineItem]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_OriginatorParty_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([OriginatorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_OriginatorParty_LineItem]
GO
ALTER TABLE [dbo].[OrderedShipment] WITH CHECK ADD CONSTRAINT [FK_OrderedShipment_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([OrderedShipment])
GO
ALTER TABLE [dbo].[OrderedShipment] CHECK CONSTRAINT [FK_OrderedShipment_LineItem]
GO
ALTER TABLE [dbo].[PricingReference] WITH CHECK ADD CONSTRAINT [FK_PricingReference_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([PricingReference])
GO
ALTER TABLE [dbo].[PricingReference] CHECK CONSTRAINT [FK_PricingReference_LineItem]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_LineItem]
GO
ALTER TABLE [dbo].[Price] WITH CHECK ADD CONSTRAINT [FK_Price_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([Price])
GO
ALTER TABLE [dbo].[Price] CHECK CONSTRAINT [FK_Price_LineItem]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_LineItem]
GO
ALTER TABLE [dbo].[LineItem] WITH CHECK ADD CONSTRAINT [FK_SubLineItem_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([SubLineItem])
GO
ALTER TABLE [dbo].[LineItem] CHECK CONSTRAINT [FK_SubLineItem_LineItem]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_WarrantyValidityPeriod_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([WarrantyValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_WarrantyValidityPeriod_LineItem]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_WarrantyParty_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([WarrantyParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_WarrantyParty_LineItem]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_LineItem]
GO
ALTER TABLE [dbo].[PriceExtension] WITH CHECK ADD CONSTRAINT [FK_ItemPriceExtension_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([ItemPriceExtension])
GO
ALTER TABLE [dbo].[PriceExtension] CHECK CONSTRAINT [FK_ItemPriceExtension_LineItem]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_LineReference_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([LineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_LineReference_LineItem]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_LineReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineReference] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_LineReference]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_LineReference_LineResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineResponse] ([LineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_LineReference_LineResponse]
GO
ALTER TABLE [dbo].[Response] WITH CHECK ADD CONSTRAINT [FK_Response_LineResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineResponse] ([Response])
GO
ALTER TABLE [dbo].[Response] CHECK CONSTRAINT [FK_Response_LineResponse]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_Location]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_Address_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([Address])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_Address_Location]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_SubsidiaryLocation_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([SubsidiaryLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_SubsidiaryLocation_Location]
GO
ALTER TABLE [dbo].[LocationCoordinate] WITH CHECK ADD CONSTRAINT [FK_LocationCoordinate_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([LocationCoordinate])
GO
ALTER TABLE [dbo].[LocationCoordinate] CHECK CONSTRAINT [FK_LocationCoordinate_Location]
GO
ALTER TABLE [dbo].[ItemProperty] WITH CHECK ADD CONSTRAINT [FK_AdditionalItemProperty_LotIdentification] FOREIGN KEY([Ref])
REFERENCES [dbo].[LotIdentification] ([AdditionalItemProperty])
GO
ALTER TABLE [dbo].[ItemProperty] CHECK CONSTRAINT [FK_AdditionalItemProperty_LotIdentification]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_RegistryCertificateDocumentReference_MaritimeTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[MaritimeTransport] ([RegistryCertificateDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_RegistryCertificateDocumentReference_MaritimeTransport]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_RegistryPortLocation_MaritimeTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[MaritimeTransport] ([RegistryPortLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_RegistryPortLocation_MaritimeTransport]
GO
ALTER TABLE [dbo].[MeterReading] WITH CHECK ADD CONSTRAINT [FK_MeterReading_Meter] FOREIGN KEY([Ref])
REFERENCES [dbo].[Meter] ([MeterReading])
GO
ALTER TABLE [dbo].[MeterReading] CHECK CONSTRAINT [FK_MeterReading_Meter]
GO
ALTER TABLE [dbo].[MeterProperty] WITH CHECK ADD CONSTRAINT [FK_MeterProperty_Meter] FOREIGN KEY([Ref])
REFERENCES [dbo].[Meter] ([MeterProperty])
GO
ALTER TABLE [dbo].[MeterProperty] CHECK CONSTRAINT [FK_MeterProperty_Meter]
GO
ALTER TABLE [dbo].[EventLineItem] WITH CHECK ADD CONSTRAINT [FK_EventLineItem_MiscellaneousEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[MiscellaneousEvent] ([EventLineItem])
GO
ALTER TABLE [dbo].[EventLineItem] CHECK CONSTRAINT [FK_EventLineItem_MiscellaneousEvent]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_NotifyParty_NotificationRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[NotificationRequirement] ([NotifyParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_NotifyParty_NotificationRequirement]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_NotificationPeriod_NotificationRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[NotificationRequirement] ([NotificationPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_NotificationPeriod_NotificationRequirement]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_NotificationLocation_NotificationRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[NotificationRequirement] ([NotificationLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_NotificationLocation_NotificationRequirement]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_OnAccountPayment] FOREIGN KEY([Ref])
REFERENCES [dbo].[OnAccountPayment] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_OnAccountPayment]
GO
ALTER TABLE [dbo].[LineItem] WITH CHECK ADD CONSTRAINT [FK_LineItem_OrderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLine] ([LineItem])
GO
ALTER TABLE [dbo].[LineItem] CHECK CONSTRAINT [FK_LineItem_OrderLine]
GO
ALTER TABLE [dbo].[LineItem] WITH CHECK ADD CONSTRAINT [FK_SellerProposedSubstituteLineItem_OrderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLine] ([SellerProposedSubstituteLineItem])
GO
ALTER TABLE [dbo].[LineItem] CHECK CONSTRAINT [FK_SellerProposedSubstituteLineItem_OrderLine]
GO
ALTER TABLE [dbo].[LineItem] WITH CHECK ADD CONSTRAINT [FK_SellerSubstitutedLineItem_OrderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLine] ([SellerSubstitutedLineItem])
GO
ALTER TABLE [dbo].[LineItem] CHECK CONSTRAINT [FK_SellerSubstitutedLineItem_OrderLine]
GO
ALTER TABLE [dbo].[LineItem] WITH CHECK ADD CONSTRAINT [FK_BuyerProposedSubstituteLineItem_OrderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLine] ([BuyerProposedSubstituteLineItem])
GO
ALTER TABLE [dbo].[LineItem] CHECK CONSTRAINT [FK_BuyerProposedSubstituteLineItem_OrderLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_CatalogueLineReference_OrderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLine] ([CatalogueLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_CatalogueLineReference_OrderLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_QuotationLineReference_OrderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLine] ([QuotationLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_QuotationLineReference_OrderLine]
GO
ALTER TABLE [dbo].[OrderLineReference] WITH CHECK ADD CONSTRAINT [FK_OrderLineReference_OrderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLine] ([OrderLineReference])
GO
ALTER TABLE [dbo].[OrderLineReference] CHECK CONSTRAINT [FK_OrderLineReference_OrderLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_OrderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_OrderLine]
GO
ALTER TABLE [dbo].[OrderReference] WITH CHECK ADD CONSTRAINT [FK_OrderReference_OrderLineReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLineReference] ([OrderReference])
GO
ALTER TABLE [dbo].[OrderReference] CHECK CONSTRAINT [FK_OrderReference_OrderLineReference]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_OrderReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderReference] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_OrderReference]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_OrderedShipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderedShipment] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_OrderedShipment]
GO
ALTER TABLE [dbo].[Package] WITH CHECK ADD CONSTRAINT [FK_Package_OrderedShipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderedShipment] ([Package])
GO
ALTER TABLE [dbo].[Package] CHECK CONSTRAINT [FK_Package_OrderedShipment]
GO
ALTER TABLE [dbo].[Package] WITH CHECK ADD CONSTRAINT [FK_ContainedPackage_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([ContainedPackage])
GO
ALTER TABLE [dbo].[Package] CHECK CONSTRAINT [FK_ContainedPackage_Package]
GO
ALTER TABLE [dbo].[TransportEquipment] WITH CHECK ADD CONSTRAINT [FK_ContainingTransportEquipment_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([ContainingTransportEquipment])
GO
ALTER TABLE [dbo].[TransportEquipment] CHECK CONSTRAINT [FK_ContainingTransportEquipment_Package]
GO
ALTER TABLE [dbo].[GoodsItem] WITH CHECK ADD CONSTRAINT [FK_GoodsItem_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([GoodsItem])
GO
ALTER TABLE [dbo].[GoodsItem] CHECK CONSTRAINT [FK_GoodsItem_Package]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_MeasurementDimension_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([MeasurementDimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_MeasurementDimension_Package]
GO
ALTER TABLE [dbo].[DeliveryUnit] WITH CHECK ADD CONSTRAINT [FK_DeliveryUnit_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([DeliveryUnit])
GO
ALTER TABLE [dbo].[DeliveryUnit] CHECK CONSTRAINT [FK_DeliveryUnit_Package]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_Package]
GO
ALTER TABLE [dbo].[Pickup] WITH CHECK ADD CONSTRAINT [FK_Pickup_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([Pickup])
GO
ALTER TABLE [dbo].[Pickup] CHECK CONSTRAINT [FK_Pickup_Package]
GO
ALTER TABLE [dbo].[Despatch] WITH CHECK ADD CONSTRAINT [FK_Despatch_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([Despatch])
GO
ALTER TABLE [dbo].[Despatch] CHECK CONSTRAINT [FK_Despatch_Package]
GO
ALTER TABLE [dbo].[PartyIdentification] WITH CHECK ADD CONSTRAINT [FK_PartyIdentification_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([PartyIdentification])
GO
ALTER TABLE [dbo].[PartyIdentification] CHECK CONSTRAINT [FK_PartyIdentification_Party]
GO
ALTER TABLE [dbo].[PartyName] WITH CHECK ADD CONSTRAINT [FK_PartyName_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([PartyName])
GO
ALTER TABLE [dbo].[PartyName] CHECK CONSTRAINT [FK_PartyName_Party]
GO
ALTER TABLE [dbo].[Language] WITH CHECK ADD CONSTRAINT [FK_Language_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([Language])
GO
ALTER TABLE [dbo].[Language] CHECK CONSTRAINT [FK_Language_Party]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_PostalAddress_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([PostalAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_PostalAddress_Party]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_PhysicalLocation_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([PhysicalLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_PhysicalLocation_Party]
GO
ALTER TABLE [dbo].[PartyTaxScheme] WITH CHECK ADD CONSTRAINT [FK_PartyTaxScheme_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([PartyTaxScheme])
GO
ALTER TABLE [dbo].[PartyTaxScheme] CHECK CONSTRAINT [FK_PartyTaxScheme_Party]
GO
ALTER TABLE [dbo].[PartyLegalEntity] WITH CHECK ADD CONSTRAINT [FK_PartyLegalEntity_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([PartyLegalEntity])
GO
ALTER TABLE [dbo].[PartyLegalEntity] CHECK CONSTRAINT [FK_PartyLegalEntity_Party]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_Contact_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([Contact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_Contact_Party]
GO
ALTER TABLE [dbo].[Person] WITH CHECK ADD CONSTRAINT [FK_Person_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([Person])
GO
ALTER TABLE [dbo].[Person] CHECK CONSTRAINT [FK_Person_Party]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_AgentParty_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([AgentParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_AgentParty_Party]
GO
ALTER TABLE [dbo].[ServiceProviderParty] WITH CHECK ADD CONSTRAINT [FK_ServiceProviderParty_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([ServiceProviderParty])
GO
ALTER TABLE [dbo].[ServiceProviderParty] CHECK CONSTRAINT [FK_ServiceProviderParty_Party]
GO
ALTER TABLE [dbo].[PowerOfAttorney] WITH CHECK ADD CONSTRAINT [FK_PowerOfAttorney_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([PowerOfAttorney])
GO
ALTER TABLE [dbo].[PowerOfAttorney] CHECK CONSTRAINT [FK_PowerOfAttorney_Party]
GO
ALTER TABLE [dbo].[FinancialAccount] WITH CHECK ADD CONSTRAINT [FK_FinancialAccount_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([FinancialAccount])
GO
ALTER TABLE [dbo].[FinancialAccount] CHECK CONSTRAINT [FK_FinancialAccount_Party]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_RegistrationAddress_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([RegistrationAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_RegistrationAddress_PartyLegalEntity]
GO
ALTER TABLE [dbo].[CorporateRegistrationScheme] WITH CHECK ADD CONSTRAINT [FK_CorporateRegistrationScheme_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([CorporateRegistrationScheme])
GO
ALTER TABLE [dbo].[CorporateRegistrationScheme] CHECK CONSTRAINT [FK_CorporateRegistrationScheme_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_HeadOfficeParty_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([HeadOfficeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_HeadOfficeParty_PartyLegalEntity]
GO
ALTER TABLE [dbo].[ShareholderParty] WITH CHECK ADD CONSTRAINT [FK_ShareholderParty_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([ShareholderParty])
GO
ALTER TABLE [dbo].[ShareholderParty] CHECK CONSTRAINT [FK_ShareholderParty_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_RegistrationAddress_PartyTaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyTaxScheme] ([RegistrationAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_RegistrationAddress_PartyTaxScheme]
GO
ALTER TABLE [dbo].[TaxScheme] WITH CHECK ADD CONSTRAINT [FK_TaxScheme_PartyTaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyTaxScheme] ([TaxScheme])
GO
ALTER TABLE [dbo].[TaxScheme] CHECK CONSTRAINT [FK_TaxScheme_PartyTaxScheme]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayerParty_PaymentMandate] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMandate] ([PayerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayerParty_PaymentMandate]
GO
ALTER TABLE [dbo].[FinancialAccount] WITH CHECK ADD CONSTRAINT [FK_PayerFinancialAccount_PaymentMandate] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMandate] ([PayerFinancialAccount])
GO
ALTER TABLE [dbo].[FinancialAccount] CHECK CONSTRAINT [FK_PayerFinancialAccount_PaymentMandate]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_PaymentMandate] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMandate] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_PaymentMandate]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_PaymentReversalPeriod_PaymentMandate] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMandate] ([PaymentReversalPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_PaymentReversalPeriod_PaymentMandate]
GO
ALTER TABLE [dbo].[Clause] WITH CHECK ADD CONSTRAINT [FK_Clause_PaymentMandate] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMandate] ([Clause])
GO
ALTER TABLE [dbo].[Clause] CHECK CONSTRAINT [FK_Clause_PaymentMandate]
GO
ALTER TABLE [dbo].[CardAccount] WITH CHECK ADD CONSTRAINT [FK_CardAccount_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([CardAccount])
GO
ALTER TABLE [dbo].[CardAccount] CHECK CONSTRAINT [FK_CardAccount_PaymentMeans]
GO
ALTER TABLE [dbo].[FinancialAccount] WITH CHECK ADD CONSTRAINT [FK_PayerFinancialAccount_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([PayerFinancialAccount])
GO
ALTER TABLE [dbo].[FinancialAccount] CHECK CONSTRAINT [FK_PayerFinancialAccount_PaymentMeans]
GO
ALTER TABLE [dbo].[FinancialAccount] WITH CHECK ADD CONSTRAINT [FK_PayeeFinancialAccount_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([PayeeFinancialAccount])
GO
ALTER TABLE [dbo].[FinancialAccount] CHECK CONSTRAINT [FK_PayeeFinancialAccount_PaymentMeans]
GO
ALTER TABLE [dbo].[CreditAccount] WITH CHECK ADD CONSTRAINT [FK_CreditAccount_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([CreditAccount])
GO
ALTER TABLE [dbo].[CreditAccount] CHECK CONSTRAINT [FK_CreditAccount_PaymentMeans]
GO
ALTER TABLE [dbo].[PaymentMandate] WITH CHECK ADD CONSTRAINT [FK_PaymentMandate_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([PaymentMandate])
GO
ALTER TABLE [dbo].[PaymentMandate] CHECK CONSTRAINT [FK_PaymentMandate_PaymentMeans]
GO
ALTER TABLE [dbo].[TradeFinancing] WITH CHECK ADD CONSTRAINT [FK_TradeFinancing_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([TradeFinancing])
GO
ALTER TABLE [dbo].[TradeFinancing] CHECK CONSTRAINT [FK_TradeFinancing_PaymentMeans]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_SettlementPeriod_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([SettlementPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_SettlementPeriod_PaymentTerms]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_PenaltyPeriod_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([PenaltyPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_PenaltyPeriod_PaymentTerms]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_ExchangeRate_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([ExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_ExchangeRate_PaymentTerms]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_PaymentTerms]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_PerformanceDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[PerformanceDataLine] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_PerformanceDataLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_PerformanceDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[PerformanceDataLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_PerformanceDataLine]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_Contact_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([Contact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_Contact_Person]
GO
ALTER TABLE [dbo].[FinancialAccount] WITH CHECK ADD CONSTRAINT [FK_FinancialAccount_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([FinancialAccount])
GO
ALTER TABLE [dbo].[FinancialAccount] CHECK CONSTRAINT [FK_FinancialAccount_Person]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_IdentityDocumentReference_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([IdentityDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_IdentityDocumentReference_Person]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_ResidenceAddress_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([ResidenceAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_ResidenceAddress_Person]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_PickupLocation_Pickup] FOREIGN KEY([Ref])
REFERENCES [dbo].[Pickup] ([PickupLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_PickupLocation_Pickup]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PickupParty_Pickup] FOREIGN KEY([Ref])
REFERENCES [dbo].[Pickup] ([PickupParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PickupParty_Pickup]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_NotaryParty_PowerOfAttorney] FOREIGN KEY([Ref])
REFERENCES [dbo].[PowerOfAttorney] ([NotaryParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_NotaryParty_PowerOfAttorney]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_AgentParty_PowerOfAttorney] FOREIGN KEY([Ref])
REFERENCES [dbo].[PowerOfAttorney] ([AgentParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_AgentParty_PowerOfAttorney]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_WitnessParty_PowerOfAttorney] FOREIGN KEY([Ref])
REFERENCES [dbo].[PowerOfAttorney] ([WitnessParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_WitnessParty_PowerOfAttorney]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_MandateDocumentReference_PowerOfAttorney] FOREIGN KEY([Ref])
REFERENCES [dbo].[PowerOfAttorney] ([MandateDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_MandateDocumentReference_PowerOfAttorney]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_Price] FOREIGN KEY([Ref])
REFERENCES [dbo].[Price] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_Price]
GO
ALTER TABLE [dbo].[PriceList] WITH CHECK ADD CONSTRAINT [FK_PriceList_Price] FOREIGN KEY([Ref])
REFERENCES [dbo].[Price] ([PriceList])
GO
ALTER TABLE [dbo].[PriceList] CHECK CONSTRAINT [FK_PriceList_Price]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_Price] FOREIGN KEY([Ref])
REFERENCES [dbo].[Price] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_Price]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_PricingExchangeRate_Price] FOREIGN KEY([Ref])
REFERENCES [dbo].[Price] ([PricingExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_PricingExchangeRate_Price]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_PriceExtension] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriceExtension] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_PriceExtension]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ValidityPeriod_PriceList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriceList] ([ValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ValidityPeriod_PriceList]
GO
ALTER TABLE [dbo].[PriceList] WITH CHECK ADD CONSTRAINT [FK_PreviousPriceList_PriceList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriceList] ([PreviousPriceList])
GO
ALTER TABLE [dbo].[PriceList] CHECK CONSTRAINT [FK_PreviousPriceList_PriceList]
GO
ALTER TABLE [dbo].[ItemLocationQuantity] WITH CHECK ADD CONSTRAINT [FK_OriginalItemLocationQuantity_PricingReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[PricingReference] ([OriginalItemLocationQuantity])
GO
ALTER TABLE [dbo].[ItemLocationQuantity] CHECK CONSTRAINT [FK_OriginalItemLocationQuantity_PricingReference]
GO
ALTER TABLE [dbo].[Price] WITH CHECK ADD CONSTRAINT [FK_AlternativeConditionPrice_PricingReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[PricingReference] ([AlternativeConditionPrice])
GO
ALTER TABLE [dbo].[Price] CHECK CONSTRAINT [FK_AlternativeConditionPrice_PricingReference]
GO
ALTER TABLE [dbo].[RequestedTenderTotal] WITH CHECK ADD CONSTRAINT [FK_RequestedTenderTotal_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([RequestedTenderTotal])
GO
ALTER TABLE [dbo].[RequestedTenderTotal] CHECK CONSTRAINT [FK_RequestedTenderTotal_ProcurementProject]
GO
ALTER TABLE [dbo].[CommodityClassification] WITH CHECK ADD CONSTRAINT [FK_MainCommodityClassification_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([MainCommodityClassification])
GO
ALTER TABLE [dbo].[CommodityClassification] CHECK CONSTRAINT [FK_MainCommodityClassification_ProcurementProject]
GO
ALTER TABLE [dbo].[CommodityClassification] WITH CHECK ADD CONSTRAINT [FK_AdditionalCommodityClassification_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([AdditionalCommodityClassification])
GO
ALTER TABLE [dbo].[CommodityClassification] CHECK CONSTRAINT [FK_AdditionalCommodityClassification_ProcurementProject]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_RealizedLocation_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([RealizedLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_RealizedLocation_ProcurementProject]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_PlannedPeriod_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([PlannedPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_PlannedPeriod_ProcurementProject]
GO
ALTER TABLE [dbo].[ContractExtension] WITH CHECK ADD CONSTRAINT [FK_ContractExtension_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([ContractExtension])
GO
ALTER TABLE [dbo].[ContractExtension] CHECK CONSTRAINT [FK_ContractExtension_ProcurementProject]
GO
ALTER TABLE [dbo].[RequestForTenderLine] WITH CHECK ADD CONSTRAINT [FK_RequestForTenderLine_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([RequestForTenderLine])
GO
ALTER TABLE [dbo].[RequestForTenderLine] CHECK CONSTRAINT [FK_RequestForTenderLine_ProcurementProject]
GO
ALTER TABLE [dbo].[TenderingTerms] WITH CHECK ADD CONSTRAINT [FK_TenderingTerms_ProcurementProjectLot] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProjectLot] ([TenderingTerms])
GO
ALTER TABLE [dbo].[TenderingTerms] CHECK CONSTRAINT [FK_TenderingTerms_ProcurementProjectLot]
GO
ALTER TABLE [dbo].[ProcurementProject] WITH CHECK ADD CONSTRAINT [FK_ProcurementProject_ProcurementProjectLot] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProjectLot] ([ProcurementProject])
GO
ALTER TABLE [dbo].[ProcurementProject] CHECK CONSTRAINT [FK_ProcurementProject_ProcurementProjectLot]
GO
ALTER TABLE [dbo].[WorkPhaseReference] WITH CHECK ADD CONSTRAINT [FK_WorkPhaseReference_ProjectReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProjectReference] ([WorkPhaseReference])
GO
ALTER TABLE [dbo].[WorkPhaseReference] CHECK CONSTRAINT [FK_WorkPhaseReference_ProjectReference]
GO
ALTER TABLE [dbo].[PromotionalSpecification] WITH CHECK ADD CONSTRAINT [FK_PromotionalSpecification_PromotionalEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[PromotionalEvent] ([PromotionalSpecification])
GO
ALTER TABLE [dbo].[PromotionalSpecification] CHECK CONSTRAINT [FK_PromotionalSpecification_PromotionalEvent]
GO
ALTER TABLE [dbo].[EventLineItem] WITH CHECK ADD CONSTRAINT [FK_EventLineItem_PromotionalEventLineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[PromotionalEventLineItem] ([EventLineItem])
GO
ALTER TABLE [dbo].[EventLineItem] CHECK CONSTRAINT [FK_EventLineItem_PromotionalEventLineItem]
GO
ALTER TABLE [dbo].[PromotionalEventLineItem] WITH CHECK ADD CONSTRAINT [FK_PromotionalEventLineItem_PromotionalSpecification] FOREIGN KEY([Ref])
REFERENCES [dbo].[PromotionalSpecification] ([PromotionalEventLineItem])
GO
ALTER TABLE [dbo].[PromotionalEventLineItem] CHECK CONSTRAINT [FK_PromotionalEventLineItem_PromotionalSpecification]
GO
ALTER TABLE [dbo].[EventTactic] WITH CHECK ADD CONSTRAINT [FK_EventTactic_PromotionalSpecification] FOREIGN KEY([Ref])
REFERENCES [dbo].[PromotionalSpecification] ([EventTactic])
GO
ALTER TABLE [dbo].[EventTactic] CHECK CONSTRAINT [FK_EventTactic_PromotionalSpecification]
GO
ALTER TABLE [dbo].[ProcurementProjectLot] WITH CHECK ADD CONSTRAINT [FK_ProcurementProjectLot_QualificationResolution] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualificationResolution] ([ProcurementProjectLot])
GO
ALTER TABLE [dbo].[ProcurementProjectLot] CHECK CONSTRAINT [FK_ProcurementProjectLot_QualificationResolution]
GO
ALTER TABLE [dbo].[ClassificationScheme] WITH CHECK ADD CONSTRAINT [FK_BusinessClassificationScheme_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([BusinessClassificationScheme])
GO
ALTER TABLE [dbo].[ClassificationScheme] CHECK CONSTRAINT [FK_BusinessClassificationScheme_QualifyingParty]
GO
ALTER TABLE [dbo].[Capability] WITH CHECK ADD CONSTRAINT [FK_TechnicalCapability_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([TechnicalCapability])
GO
ALTER TABLE [dbo].[Capability] CHECK CONSTRAINT [FK_TechnicalCapability_QualifyingParty]
GO
ALTER TABLE [dbo].[Capability] WITH CHECK ADD CONSTRAINT [FK_FinancialCapability_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([FinancialCapability])
GO
ALTER TABLE [dbo].[Capability] CHECK CONSTRAINT [FK_FinancialCapability_QualifyingParty]
GO
ALTER TABLE [dbo].[CompletedTask] WITH CHECK ADD CONSTRAINT [FK_CompletedTask_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([CompletedTask])
GO
ALTER TABLE [dbo].[CompletedTask] CHECK CONSTRAINT [FK_CompletedTask_QualifyingParty]
GO
ALTER TABLE [dbo].[Declaration] WITH CHECK ADD CONSTRAINT [FK_Declaration_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([Declaration])
GO
ALTER TABLE [dbo].[Declaration] CHECK CONSTRAINT [FK_Declaration_QualifyingParty]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_Party_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([Party])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_Party_QualifyingParty]
GO
ALTER TABLE [dbo].[EconomicOperatorRole] WITH CHECK ADD CONSTRAINT [FK_EconomicOperatorRole_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([EconomicOperatorRole])
GO
ALTER TABLE [dbo].[EconomicOperatorRole] CHECK CONSTRAINT [FK_EconomicOperatorRole_QualifyingParty]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_QuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[QuotationLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_QuotationLine]
GO
ALTER TABLE [dbo].[LineItem] WITH CHECK ADD CONSTRAINT [FK_LineItem_QuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[QuotationLine] ([LineItem])
GO
ALTER TABLE [dbo].[LineItem] CHECK CONSTRAINT [FK_LineItem_QuotationLine]
GO
ALTER TABLE [dbo].[LineItem] WITH CHECK ADD CONSTRAINT [FK_SellerProposedSubstituteLineItem_QuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[QuotationLine] ([SellerProposedSubstituteLineItem])
GO
ALTER TABLE [dbo].[LineItem] CHECK CONSTRAINT [FK_SellerProposedSubstituteLineItem_QuotationLine]
GO
ALTER TABLE [dbo].[LineItem] WITH CHECK ADD CONSTRAINT [FK_AlternativeLineItem_QuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[QuotationLine] ([AlternativeLineItem])
GO
ALTER TABLE [dbo].[LineItem] CHECK CONSTRAINT [FK_AlternativeLineItem_QuotationLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_RequestLineReference_QuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[QuotationLine] ([RequestLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_RequestLineReference_QuotationLine]
GO
ALTER TABLE [dbo].[OrderLineReference] WITH CHECK ADD CONSTRAINT [FK_OrderLineReference_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([OrderLineReference])
GO
ALTER TABLE [dbo].[OrderLineReference] CHECK CONSTRAINT [FK_OrderLineReference_ReceiptLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_DespatchLineReference_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([DespatchLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_DespatchLineReference_ReceiptLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_ReceiptLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_ReceiptLine]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_Shipment_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([Shipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_Shipment_ReceiptLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ReminderPeriod_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([ReminderPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ReminderPeriod_ReminderLine]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_ReminderLine]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_ExchangeRate_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([ExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_ExchangeRate_ReminderLine]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvoicePeriod_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([InvoicePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvoicePeriod_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_ExchangeRate_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([ExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_ExchangeRate_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_Renewal] FOREIGN KEY([Ref])
REFERENCES [dbo].[Renewal] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_Renewal]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_RequestForQuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotationLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_RequestForQuotationLine]
GO
ALTER TABLE [dbo].[LineItem] WITH CHECK ADD CONSTRAINT [FK_LineItem_RequestForQuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotationLine] ([LineItem])
GO
ALTER TABLE [dbo].[LineItem] CHECK CONSTRAINT [FK_LineItem_RequestForQuotationLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_DeliveryPeriod_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([DeliveryPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_DeliveryPeriod_RequestForTenderLine]
GO
ALTER TABLE [dbo].[ItemLocationQuantity] WITH CHECK ADD CONSTRAINT [FK_RequiredItemLocationQuantity_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([RequiredItemLocationQuantity])
GO
ALTER TABLE [dbo].[ItemLocationQuantity] CHECK CONSTRAINT [FK_RequiredItemLocationQuantity_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_WarrantyValidityPeriod_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([WarrantyValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_WarrantyValidityPeriod_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_RequestForTenderLine]
GO
ALTER TABLE [dbo].[RequestForTenderLine] WITH CHECK ADD CONSTRAINT [FK_SubRequestForTenderLine_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([SubRequestForTenderLine])
GO
ALTER TABLE [dbo].[RequestForTenderLine] CHECK CONSTRAINT [FK_SubRequestForTenderLine_RequestForTenderLine]
GO
ALTER TABLE [dbo].[TaxCategory] WITH CHECK ADD CONSTRAINT [FK_ApplicableTaxCategory_RequestedTenderTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestedTenderTotal] ([ApplicableTaxCategory])
GO
ALTER TABLE [dbo].[TaxCategory] CHECK CONSTRAINT [FK_ApplicableTaxCategory_RequestedTenderTotal]
GO
ALTER TABLE [dbo].[Status] WITH CHECK ADD CONSTRAINT [FK_Status_Response] FOREIGN KEY([Ref])
REFERENCES [dbo].[Response] ([Status])
GO
ALTER TABLE [dbo].[Status] CHECK CONSTRAINT [FK_Status_Response]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SignatoryParty_ResultOfVerification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ResultOfVerification] ([SignatoryParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SignatoryParty_ResultOfVerification]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_RetailPlannedImpact] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailPlannedImpact] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_RetailPlannedImpact]
GO
ALTER TABLE [dbo].[ActivityProperty] WITH CHECK ADD CONSTRAINT [FK_ActivityProperty_SalesItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[SalesItem] ([ActivityProperty])
GO
ALTER TABLE [dbo].[ActivityProperty] CHECK CONSTRAINT [FK_ActivityProperty_SalesItem]
GO
ALTER TABLE [dbo].[Price] WITH CHECK ADD CONSTRAINT [FK_TaxExclusivePrice_SalesItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[SalesItem] ([TaxExclusivePrice])
GO
ALTER TABLE [dbo].[Price] CHECK CONSTRAINT [FK_TaxExclusivePrice_SalesItem]
GO
ALTER TABLE [dbo].[Price] WITH CHECK ADD CONSTRAINT [FK_TaxInclusivePrice_SalesItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[SalesItem] ([TaxInclusivePrice])
GO
ALTER TABLE [dbo].[Price] CHECK CONSTRAINT [FK_TaxInclusivePrice_SalesItem]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_SalesItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[SalesItem] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_SalesItem]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_Party_ServiceProviderParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ServiceProviderParty] ([Party])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_Party_ServiceProviderParty]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_SellerContact_ServiceProviderParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ServiceProviderParty] ([SellerContact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_SellerContact_ServiceProviderParty]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_Party_ShareholderParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShareholderParty] ([Party])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_Party_ShareholderParty]
GO
ALTER TABLE [dbo].[Consignment] WITH CHECK ADD CONSTRAINT [FK_Consignment_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([Consignment])
GO
ALTER TABLE [dbo].[Consignment] CHECK CONSTRAINT [FK_Consignment_Shipment]
GO
ALTER TABLE [dbo].[GoodsItem] WITH CHECK ADD CONSTRAINT [FK_GoodsItem_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([GoodsItem])
GO
ALTER TABLE [dbo].[GoodsItem] CHECK CONSTRAINT [FK_GoodsItem_Shipment]
GO
ALTER TABLE [dbo].[ShipmentStage] WITH CHECK ADD CONSTRAINT [FK_ShipmentStage_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([ShipmentStage])
GO
ALTER TABLE [dbo].[ShipmentStage] CHECK CONSTRAINT [FK_ShipmentStage_Shipment]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_Shipment]
GO
ALTER TABLE [dbo].[TransportHandlingUnit] WITH CHECK ADD CONSTRAINT [FK_TransportHandlingUnit_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([TransportHandlingUnit])
GO
ALTER TABLE [dbo].[TransportHandlingUnit] CHECK CONSTRAINT [FK_TransportHandlingUnit_Shipment]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_ReturnAddress_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([ReturnAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_ReturnAddress_Shipment]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_OriginAddress_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([OriginAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_OriginAddress_Shipment]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_FirstArrivalPortLocation_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([FirstArrivalPortLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_FirstArrivalPortLocation_Shipment]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_LastExitPortLocation_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([LastExitPortLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_LastExitPortLocation_Shipment]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_ExportCountry_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([ExportCountry])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_ExportCountry_Shipment]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_FreightAllowanceCharge_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([FreightAllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_FreightAllowanceCharge_Shipment]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_TransitPeriod_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([TransitPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_TransitPeriod_ShipmentStage]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_CarrierParty_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([CarrierParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_CarrierParty_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportMeans] WITH CHECK ADD CONSTRAINT [FK_TransportMeans_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([TransportMeans])
GO
ALTER TABLE [dbo].[TransportMeans] CHECK CONSTRAINT [FK_TransportMeans_ShipmentStage]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_LoadingPortLocation_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([LoadingPortLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_LoadingPortLocation_ShipmentStage]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_UnloadingPortLocation_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([UnloadingPortLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_UnloadingPortLocation_ShipmentStage]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_TransshipPortLocation_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([TransshipPortLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_TransshipPortLocation_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_LoadingTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([LoadingTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_LoadingTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_ExaminationTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([ExaminationTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_ExaminationTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_AvailabilityTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([AvailabilityTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_AvailabilityTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_ExportationTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([ExportationTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_ExportationTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_DischargeTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([DischargeTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_DischargeTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_WarehousingTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([WarehousingTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_WarehousingTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_TakeoverTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([TakeoverTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_TakeoverTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_OptionalTakeoverTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([OptionalTakeoverTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_OptionalTakeoverTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_DropoffTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([DropoffTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_DropoffTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_ActualPickupTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([ActualPickupTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_ActualPickupTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_DeliveryTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([DeliveryTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_DeliveryTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_ReceiptTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([ReceiptTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_ReceiptTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_StorageTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([StorageTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_StorageTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_AcceptanceTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([AcceptanceTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_AcceptanceTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TerminalOperatorParty_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([TerminalOperatorParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TerminalOperatorParty_ShipmentStage]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_CustomsAgentParty_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([CustomsAgentParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_CustomsAgentParty_ShipmentStage]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_EstimatedTransitPeriod_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([EstimatedTransitPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_EstimatedTransitPeriod_ShipmentStage]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_FreightAllowanceCharge_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([FreightAllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_FreightAllowanceCharge_ShipmentStage]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_FreightChargeLocation_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([FreightChargeLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_FreightChargeLocation_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_DetentionTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([DetentionTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_DetentionTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_RequestedDepartureTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([RequestedDepartureTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_RequestedDepartureTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_RequestedArrivalTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([RequestedArrivalTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_RequestedArrivalTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_RequestedWaypointTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([RequestedWaypointTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_RequestedWaypointTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_PlannedDepartureTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([PlannedDepartureTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_PlannedDepartureTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_PlannedArrivalTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([PlannedArrivalTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_PlannedArrivalTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_PlannedWaypointTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([PlannedWaypointTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_PlannedWaypointTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_ActualDepartureTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([ActualDepartureTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_ActualDepartureTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_ActualWaypointTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([ActualWaypointTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_ActualWaypointTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_ActualArrivalTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([ActualArrivalTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_ActualArrivalTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_TransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([TransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_TransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_EstimatedDepartureTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([EstimatedDepartureTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_EstimatedDepartureTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_EstimatedArrivalTransportEvent_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([EstimatedArrivalTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_EstimatedArrivalTransportEvent_ShipmentStage]
GO
ALTER TABLE [dbo].[Person] WITH CHECK ADD CONSTRAINT [FK_PassengerPerson_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([PassengerPerson])
GO
ALTER TABLE [dbo].[Person] CHECK CONSTRAINT [FK_PassengerPerson_ShipmentStage]
GO
ALTER TABLE [dbo].[Person] WITH CHECK ADD CONSTRAINT [FK_DriverPerson_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([DriverPerson])
GO
ALTER TABLE [dbo].[Person] CHECK CONSTRAINT [FK_DriverPerson_ShipmentStage]
GO
ALTER TABLE [dbo].[Person] WITH CHECK ADD CONSTRAINT [FK_ReportingPerson_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([ReportingPerson])
GO
ALTER TABLE [dbo].[Person] CHECK CONSTRAINT [FK_ReportingPerson_ShipmentStage]
GO
ALTER TABLE [dbo].[Person] WITH CHECK ADD CONSTRAINT [FK_CrewMemberPerson_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([CrewMemberPerson])
GO
ALTER TABLE [dbo].[Person] CHECK CONSTRAINT [FK_CrewMemberPerson_ShipmentStage]
GO
ALTER TABLE [dbo].[Person] WITH CHECK ADD CONSTRAINT [FK_SecurityOfficerPerson_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([SecurityOfficerPerson])
GO
ALTER TABLE [dbo].[Person] CHECK CONSTRAINT [FK_SecurityOfficerPerson_ShipmentStage]
GO
ALTER TABLE [dbo].[Person] WITH CHECK ADD CONSTRAINT [FK_MasterPerson_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([MasterPerson])
GO
ALTER TABLE [dbo].[Person] CHECK CONSTRAINT [FK_MasterPerson_ShipmentStage]
GO
ALTER TABLE [dbo].[Person] WITH CHECK ADD CONSTRAINT [FK_ShipsSurgeonPerson_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([ShipsSurgeonPerson])
GO
ALTER TABLE [dbo].[Person] CHECK CONSTRAINT [FK_ShipsSurgeonPerson_ShipmentStage]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SignatoryParty_Signature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Signature] ([SignatoryParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SignatoryParty_Signature]
GO
ALTER TABLE [dbo].[Attachment] WITH CHECK ADD CONSTRAINT [FK_DigitalSignatureAttachment_Signature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Signature] ([DigitalSignatureAttachment])
GO
ALTER TABLE [dbo].[Attachment] CHECK CONSTRAINT [FK_DigitalSignatureAttachment_Signature]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_OriginalDocumentReference_Signature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Signature] ([OriginalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_OriginalDocumentReference_Signature]
GO
ALTER TABLE [dbo].[PaymentMeans] WITH CHECK ADD CONSTRAINT [FK_PaymentMeans_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([PaymentMeans])
GO
ALTER TABLE [dbo].[PaymentMeans] CHECK CONSTRAINT [FK_PaymentMeans_StatementLine]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_StatementLine]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_BuyerCustomerParty_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([BuyerCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_BuyerCustomerParty_StatementLine]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SellerSupplierParty_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([SellerSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SellerSupplierParty_StatementLine]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_OriginatorCustomerParty_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([OriginatorCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_OriginatorCustomerParty_StatementLine]
GO
ALTER TABLE [dbo].[CustomerParty] WITH CHECK ADD CONSTRAINT [FK_AccountingCustomerParty_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([AccountingCustomerParty])
GO
ALTER TABLE [dbo].[CustomerParty] CHECK CONSTRAINT [FK_AccountingCustomerParty_StatementLine]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_AccountingSupplierParty_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([AccountingSupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_AccountingSupplierParty_StatementLine]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_PayeeParty_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([PayeeParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_PayeeParty_StatementLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvoicePeriod_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([InvoicePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvoicePeriod_StatementLine]
GO
ALTER TABLE [dbo].[BillingReference] WITH CHECK ADD CONSTRAINT [FK_BillingReference_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([BillingReference])
GO
ALTER TABLE [dbo].[BillingReference] CHECK CONSTRAINT [FK_BillingReference_StatementLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_StatementLine]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_ExchangeRate_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([ExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_ExchangeRate_StatementLine]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_StatementLine]
GO
ALTER TABLE [dbo].[Payment] WITH CHECK ADD CONSTRAINT [FK_CollectedPayment_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([CollectedPayment])
GO
ALTER TABLE [dbo].[Payment] CHECK CONSTRAINT [FK_CollectedPayment_StatementLine]
GO
ALTER TABLE [dbo].[Condition] WITH CHECK ADD CONSTRAINT [FK_Condition_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([Condition])
GO
ALTER TABLE [dbo].[Condition] CHECK CONSTRAINT [FK_Condition_Status]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_StockAvailabilityReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReportLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_StockAvailabilityReportLine]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_MeasurementDimension_Stowage] FOREIGN KEY([Ref])
REFERENCES [dbo].[Stowage] ([MeasurementDimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_MeasurementDimension_Stowage]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_SubscriberParty_SubscriberConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubscriberConsumption] ([SubscriberParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_SubscriberParty_SubscriberConsumption]
GO
ALTER TABLE [dbo].[ConsumptionPoint] WITH CHECK ADD CONSTRAINT [FK_UtilityConsumptionPoint_SubscriberConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubscriberConsumption] ([UtilityConsumptionPoint])
GO
ALTER TABLE [dbo].[ConsumptionPoint] CHECK CONSTRAINT [FK_UtilityConsumptionPoint_SubscriberConsumption]
GO
ALTER TABLE [dbo].[OnAccountPayment] WITH CHECK ADD CONSTRAINT [FK_OnAccountPayment_SubscriberConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubscriberConsumption] ([OnAccountPayment])
GO
ALTER TABLE [dbo].[OnAccountPayment] CHECK CONSTRAINT [FK_OnAccountPayment_SubscriberConsumption]
GO
ALTER TABLE [dbo].[Consumption] WITH CHECK ADD CONSTRAINT [FK_Consumption_SubscriberConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubscriberConsumption] ([Consumption])
GO
ALTER TABLE [dbo].[Consumption] CHECK CONSTRAINT [FK_Consumption_SubscriberConsumption]
GO
ALTER TABLE [dbo].[SupplierConsumption] WITH CHECK ADD CONSTRAINT [FK_SupplierConsumption_SubscriberConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubscriberConsumption] ([SupplierConsumption])
GO
ALTER TABLE [dbo].[SupplierConsumption] CHECK CONSTRAINT [FK_SupplierConsumption_SubscriberConsumption]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_UtilitySupplierParty_SupplierConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierConsumption] ([UtilitySupplierParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_UtilitySupplierParty_SupplierConsumption]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_UtilityCustomerParty_SupplierConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierConsumption] ([UtilityCustomerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_UtilityCustomerParty_SupplierConsumption]
GO
ALTER TABLE [dbo].[Consumption] WITH CHECK ADD CONSTRAINT [FK_Consumption_SupplierConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierConsumption] ([Consumption])
GO
ALTER TABLE [dbo].[Consumption] CHECK CONSTRAINT [FK_Consumption_SupplierConsumption]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_Contract_SupplierConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierConsumption] ([Contract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_Contract_SupplierConsumption]
GO
ALTER TABLE [dbo].[ConsumptionLine] WITH CHECK ADD CONSTRAINT [FK_ConsumptionLine_SupplierConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierConsumption] ([ConsumptionLine])
GO
ALTER TABLE [dbo].[ConsumptionLine] CHECK CONSTRAINT [FK_ConsumptionLine_SupplierConsumption]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_Party_SupplierParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierParty] ([Party])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_Party_SupplierParty]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_DespatchContact_SupplierParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierParty] ([DespatchContact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_DespatchContact_SupplierParty]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_AccountingContact_SupplierParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierParty] ([AccountingContact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_AccountingContact_SupplierParty]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_SellerContact_SupplierParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierParty] ([SellerContact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_SellerContact_SupplierParty]
GO
ALTER TABLE [dbo].[TaxScheme] WITH CHECK ADD CONSTRAINT [FK_TaxScheme_TaxCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxCategory] ([TaxScheme])
GO
ALTER TABLE [dbo].[TaxScheme] CHECK CONSTRAINT [FK_TaxScheme_TaxCategory]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_JurisdictionRegionAddress_TaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxScheme] ([JurisdictionRegionAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_JurisdictionRegionAddress_TaxScheme]
GO
ALTER TABLE [dbo].[TaxCategory] WITH CHECK ADD CONSTRAINT [FK_TaxCategory_TaxSubtotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxSubtotal] ([TaxCategory])
GO
ALTER TABLE [dbo].[TaxCategory] CHECK CONSTRAINT [FK_TaxCategory_TaxSubtotal]
GO
ALTER TABLE [dbo].[TaxSubtotal] WITH CHECK ADD CONSTRAINT [FK_TaxSubtotal_TaxTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxTotal] ([TaxSubtotal])
GO
ALTER TABLE [dbo].[TaxSubtotal] CHECK CONSTRAINT [FK_TaxSubtotal_TaxTotal]
GO
ALTER TABLE [dbo].[Price] WITH CHECK ADD CONSTRAINT [FK_Price_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([Price])
GO
ALTER TABLE [dbo].[Price] CHECK CONSTRAINT [FK_Price_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Country] WITH CHECK ADD CONSTRAINT [FK_Country_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([Country])
GO
ALTER TABLE [dbo].[Country] CHECK CONSTRAINT [FK_Country_TelecommunicationsService]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_ExchangeRate_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([ExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_ExchangeRate_TelecommunicationsService]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_TelecommunicationsService]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Duty] WITH CHECK ADD CONSTRAINT [FK_CallDuty_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([CallDuty])
GO
ALTER TABLE [dbo].[Duty] CHECK CONSTRAINT [FK_CallDuty_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Duty] WITH CHECK ADD CONSTRAINT [FK_TimeDuty_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([TimeDuty])
GO
ALTER TABLE [dbo].[Duty] CHECK CONSTRAINT [FK_TimeDuty_TelecommunicationsService]
GO
ALTER TABLE [dbo].[TelecommunicationsSupplyLine] WITH CHECK ADD CONSTRAINT [FK_TelecommunicationsSupplyLine_TelecommunicationsSupply] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupply] ([TelecommunicationsSupplyLine])
GO
ALTER TABLE [dbo].[TelecommunicationsSupplyLine] CHECK CONSTRAINT [FK_TelecommunicationsSupplyLine_TelecommunicationsSupply]
GO
ALTER TABLE [dbo].[ExchangeRate] WITH CHECK ADD CONSTRAINT [FK_ExchangeRate_TelecommunicationsSupplyLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupplyLine] ([ExchangeRate])
GO
ALTER TABLE [dbo].[ExchangeRate] CHECK CONSTRAINT [FK_ExchangeRate_TelecommunicationsSupplyLine]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_AllowanceCharge_TelecommunicationsSupplyLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupplyLine] ([AllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_AllowanceCharge_TelecommunicationsSupplyLine]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_TelecommunicationsSupplyLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupplyLine] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_TelecommunicationsSupplyLine]
GO
ALTER TABLE [dbo].[TelecommunicationsService] WITH CHECK ADD CONSTRAINT [FK_TelecommunicationsService_TelecommunicationsSupplyLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupplyLine] ([TelecommunicationsService])
GO
ALTER TABLE [dbo].[TelecommunicationsService] CHECK CONSTRAINT [FK_TelecommunicationsService_TelecommunicationsSupplyLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_TenderLine]
GO
ALTER TABLE [dbo].[Item] WITH CHECK ADD CONSTRAINT [FK_Item_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([Item])
GO
ALTER TABLE [dbo].[Item] CHECK CONSTRAINT [FK_Item_TenderLine]
GO
ALTER TABLE [dbo].[ItemLocationQuantity] WITH CHECK ADD CONSTRAINT [FK_OfferedItemLocationQuantity_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([OfferedItemLocationQuantity])
GO
ALTER TABLE [dbo].[ItemLocationQuantity] CHECK CONSTRAINT [FK_OfferedItemLocationQuantity_TenderLine]
GO
ALTER TABLE [dbo].[RelatedItem] WITH CHECK ADD CONSTRAINT [FK_ReplacementRelatedItem_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([ReplacementRelatedItem])
GO
ALTER TABLE [dbo].[RelatedItem] CHECK CONSTRAINT [FK_ReplacementRelatedItem_TenderLine]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_WarrantyParty_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([WarrantyParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_WarrantyParty_TenderLine]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_WarrantyValidityPeriod_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([WarrantyValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_WarrantyValidityPeriod_TenderLine]
GO
ALTER TABLE [dbo].[TenderLine] WITH CHECK ADD CONSTRAINT [FK_SubTenderLine_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([SubTenderLine])
GO
ALTER TABLE [dbo].[TenderLine] CHECK CONSTRAINT [FK_SubTenderLine_TenderLine]
GO
ALTER TABLE [dbo].[LineReference] WITH CHECK ADD CONSTRAINT [FK_CallForTendersLineReference_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([CallForTendersLineReference])
GO
ALTER TABLE [dbo].[LineReference] CHECK CONSTRAINT [FK_CallForTendersLineReference_TenderLine]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_CallForTendersDocumentReference_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([CallForTendersDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_CallForTendersDocumentReference_TenderLine]
GO
ALTER TABLE [dbo].[ProcurementProjectLot] WITH CHECK ADD CONSTRAINT [FK_ProcurementProjectLot_TenderPreparation] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderPreparation] ([ProcurementProjectLot])
GO
ALTER TABLE [dbo].[ProcurementProjectLot] CHECK CONSTRAINT [FK_ProcurementProjectLot_TenderPreparation]
GO
ALTER TABLE [dbo].[TenderRequirement] WITH CHECK ADD CONSTRAINT [FK_DocumentTenderRequirement_TenderPreparation] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderPreparation] ([DocumentTenderRequirement])
GO
ALTER TABLE [dbo].[TenderRequirement] CHECK CONSTRAINT [FK_DocumentTenderRequirement_TenderPreparation]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_TemplateDocumentReference_TenderRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderRequirement] ([TemplateDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_TemplateDocumentReference_TenderRequirement]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_Contract_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([Contract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_Contract_TenderResult]
GO
ALTER TABLE [dbo].[TenderedProject] WITH CHECK ADD CONSTRAINT [FK_AwardedTenderedProject_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([AwardedTenderedProject])
GO
ALTER TABLE [dbo].[TenderedProject] CHECK CONSTRAINT [FK_AwardedTenderedProject_TenderResult]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ContractFormalizationPeriod_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([ContractFormalizationPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ContractFormalizationPeriod_TenderResult]
GO
ALTER TABLE [dbo].[SubcontractTerms] WITH CHECK ADD CONSTRAINT [FK_SubcontractTerms_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([SubcontractTerms])
GO
ALTER TABLE [dbo].[SubcontractTerms] CHECK CONSTRAINT [FK_SubcontractTerms_TenderResult]
GO
ALTER TABLE [dbo].[WinningParty] WITH CHECK ADD CONSTRAINT [FK_WinningParty_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([WinningParty])
GO
ALTER TABLE [dbo].[WinningParty] CHECK CONSTRAINT [FK_WinningParty_TenderResult]
GO
ALTER TABLE [dbo].[ProcurementProjectLot] WITH CHECK ADD CONSTRAINT [FK_ProcurementProjectLot_TenderedProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderedProject] ([ProcurementProjectLot])
GO
ALTER TABLE [dbo].[ProcurementProjectLot] CHECK CONSTRAINT [FK_ProcurementProjectLot_TenderedProject]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_EvidenceDocumentReference_TenderedProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderedProject] ([EvidenceDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_EvidenceDocumentReference_TenderedProject]
GO
ALTER TABLE [dbo].[TaxTotal] WITH CHECK ADD CONSTRAINT [FK_TaxTotal_TenderedProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderedProject] ([TaxTotal])
GO
ALTER TABLE [dbo].[TaxTotal] CHECK CONSTRAINT [FK_TaxTotal_TenderedProject]
GO
ALTER TABLE [dbo].[MonetaryTotal] WITH CHECK ADD CONSTRAINT [FK_LegalMonetaryTotal_TenderedProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderedProject] ([LegalMonetaryTotal])
GO
ALTER TABLE [dbo].[MonetaryTotal] CHECK CONSTRAINT [FK_LegalMonetaryTotal_TenderedProject]
GO
ALTER TABLE [dbo].[TenderLine] WITH CHECK ADD CONSTRAINT [FK_TenderLine_TenderedProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderedProject] ([TenderLine])
GO
ALTER TABLE [dbo].[TenderLine] CHECK CONSTRAINT [FK_TenderLine_TenderedProject]
GO
ALTER TABLE [dbo].[AwardingCriterionResponse] WITH CHECK ADD CONSTRAINT [FK_AwardingCriterionResponse_TenderedProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderedProject] ([AwardingCriterionResponse])
GO
ALTER TABLE [dbo].[AwardingCriterionResponse] CHECK CONSTRAINT [FK_AwardingCriterionResponse_TenderedProject]
GO
ALTER TABLE [dbo].[ProcurementProjectLot] WITH CHECK ADD CONSTRAINT [FK_InterestedProcurementProjectLot_TendererPartyQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererPartyQualification] ([InterestedProcurementProjectLot])
GO
ALTER TABLE [dbo].[ProcurementProjectLot] CHECK CONSTRAINT [FK_InterestedProcurementProjectLot_TendererPartyQualification]
GO
ALTER TABLE [dbo].[QualifyingParty] WITH CHECK ADD CONSTRAINT [FK_MainQualifyingParty_TendererPartyQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererPartyQualification] ([MainQualifyingParty])
GO
ALTER TABLE [dbo].[QualifyingParty] CHECK CONSTRAINT [FK_MainQualifyingParty_TendererPartyQualification]
GO
ALTER TABLE [dbo].[QualifyingParty] WITH CHECK ADD CONSTRAINT [FK_AdditionalQualifyingParty_TendererPartyQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererPartyQualification] ([AdditionalQualifyingParty])
GO
ALTER TABLE [dbo].[QualifyingParty] CHECK CONSTRAINT [FK_AdditionalQualifyingParty_TendererPartyQualification]
GO
ALTER TABLE [dbo].[ClassificationScheme] WITH CHECK ADD CONSTRAINT [FK_RequiredBusinessClassificationScheme_TendererQualificationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationRequest] ([RequiredBusinessClassificationScheme])
GO
ALTER TABLE [dbo].[ClassificationScheme] CHECK CONSTRAINT [FK_RequiredBusinessClassificationScheme_TendererQualificationRequest]
GO
ALTER TABLE [dbo].[EvaluationCriterion] WITH CHECK ADD CONSTRAINT [FK_TechnicalEvaluationCriterion_TendererQualificationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationRequest] ([TechnicalEvaluationCriterion])
GO
ALTER TABLE [dbo].[EvaluationCriterion] CHECK CONSTRAINT [FK_TechnicalEvaluationCriterion_TendererQualificationRequest]
GO
ALTER TABLE [dbo].[EvaluationCriterion] WITH CHECK ADD CONSTRAINT [FK_FinancialEvaluationCriterion_TendererQualificationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationRequest] ([FinancialEvaluationCriterion])
GO
ALTER TABLE [dbo].[EvaluationCriterion] CHECK CONSTRAINT [FK_FinancialEvaluationCriterion_TendererQualificationRequest]
GO
ALTER TABLE [dbo].[TendererRequirement] WITH CHECK ADD CONSTRAINT [FK_SpecificTendererRequirement_TendererQualificationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationRequest] ([SpecificTendererRequirement])
GO
ALTER TABLE [dbo].[TendererRequirement] CHECK CONSTRAINT [FK_SpecificTendererRequirement_TendererQualificationRequest]
GO
ALTER TABLE [dbo].[EconomicOperatorRole] WITH CHECK ADD CONSTRAINT [FK_EconomicOperatorRole_TendererQualificationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationRequest] ([EconomicOperatorRole])
GO
ALTER TABLE [dbo].[EconomicOperatorRole] CHECK CONSTRAINT [FK_EconomicOperatorRole_TendererQualificationRequest]
GO
ALTER TABLE [dbo].[Evidence] WITH CHECK ADD CONSTRAINT [FK_SuggestedEvidence_TendererRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererRequirement] ([SuggestedEvidence])
GO
ALTER TABLE [dbo].[Evidence] CHECK CONSTRAINT [FK_SuggestedEvidence_TendererRequirement]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_DocumentAvailabilityPeriod_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([DocumentAvailabilityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_DocumentAvailabilityPeriod_TenderingProcess]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_TenderSubmissionDeadlinePeriod_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([TenderSubmissionDeadlinePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_TenderSubmissionDeadlinePeriod_TenderingProcess]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_InvitationSubmissionPeriod_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([InvitationSubmissionPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_InvitationSubmissionPeriod_TenderingProcess]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ParticipationRequestReceptionPeriod_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([ParticipationRequestReceptionPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ParticipationRequestReceptionPeriod_TenderingProcess]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_NoticeDocumentReference_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([NoticeDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_NoticeDocumentReference_TenderingProcess]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_AdditionalDocumentReference_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([AdditionalDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_AdditionalDocumentReference_TenderingProcess]
GO
ALTER TABLE [dbo].[ProcessJustification] WITH CHECK ADD CONSTRAINT [FK_ProcessJustification_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([ProcessJustification])
GO
ALTER TABLE [dbo].[ProcessJustification] CHECK CONSTRAINT [FK_ProcessJustification_TenderingProcess]
GO
ALTER TABLE [dbo].[EconomicOperatorShortList] WITH CHECK ADD CONSTRAINT [FK_EconomicOperatorShortList_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([EconomicOperatorShortList])
GO
ALTER TABLE [dbo].[EconomicOperatorShortList] CHECK CONSTRAINT [FK_EconomicOperatorShortList_TenderingProcess]
GO
ALTER TABLE [dbo].[Event] WITH CHECK ADD CONSTRAINT [FK_OpenTenderEvent_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([OpenTenderEvent])
GO
ALTER TABLE [dbo].[Event] CHECK CONSTRAINT [FK_OpenTenderEvent_TenderingProcess]
GO
ALTER TABLE [dbo].[AuctionTerms] WITH CHECK ADD CONSTRAINT [FK_AuctionTerms_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([AuctionTerms])
GO
ALTER TABLE [dbo].[AuctionTerms] CHECK CONSTRAINT [FK_AuctionTerms_TenderingProcess]
GO
ALTER TABLE [dbo].[FrameworkAgreement] WITH CHECK ADD CONSTRAINT [FK_FrameworkAgreement_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([FrameworkAgreement])
GO
ALTER TABLE [dbo].[FrameworkAgreement] CHECK CONSTRAINT [FK_FrameworkAgreement_TenderingProcess]
GO
ALTER TABLE [dbo].[Clause] WITH CHECK ADD CONSTRAINT [FK_PenaltyClause_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([PenaltyClause])
GO
ALTER TABLE [dbo].[Clause] CHECK CONSTRAINT [FK_PenaltyClause_TenderingTerms]
GO
ALTER TABLE [dbo].[FinancialGuarantee] WITH CHECK ADD CONSTRAINT [FK_RequiredFinancialGuarantee_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([RequiredFinancialGuarantee])
GO
ALTER TABLE [dbo].[FinancialGuarantee] CHECK CONSTRAINT [FK_RequiredFinancialGuarantee_TenderingTerms]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ProcurementLegislationDocumentReference_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([ProcurementLegislationDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ProcurementLegislationDocumentReference_TenderingTerms]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_FiscalLegislationDocumentReference_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([FiscalLegislationDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_FiscalLegislationDocumentReference_TenderingTerms]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_EnvironmentalLegislationDocumentReference_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([EnvironmentalLegislationDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_EnvironmentalLegislationDocumentReference_TenderingTerms]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_EmploymentLegislationDocumentReference_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([EmploymentLegislationDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_EmploymentLegislationDocumentReference_TenderingTerms]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ContractualDocumentReference_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([ContractualDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ContractualDocumentReference_TenderingTerms]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_CallForTendersDocumentReference_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([CallForTendersDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_CallForTendersDocumentReference_TenderingTerms]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_WarrantyValidityPeriod_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([WarrantyValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_WarrantyValidityPeriod_TenderingTerms]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_TenderingTerms]
GO
ALTER TABLE [dbo].[TendererQualificationRequest] WITH CHECK ADD CONSTRAINT [FK_TendererQualificationRequest_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([TendererQualificationRequest])
GO
ALTER TABLE [dbo].[TendererQualificationRequest] CHECK CONSTRAINT [FK_TendererQualificationRequest_TenderingTerms]
GO
ALTER TABLE [dbo].[SubcontractTerms] WITH CHECK ADD CONSTRAINT [FK_AllowedSubcontractTerms_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([AllowedSubcontractTerms])
GO
ALTER TABLE [dbo].[SubcontractTerms] CHECK CONSTRAINT [FK_AllowedSubcontractTerms_TenderingTerms]
GO
ALTER TABLE [dbo].[TenderPreparation] WITH CHECK ADD CONSTRAINT [FK_TenderPreparation_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([TenderPreparation])
GO
ALTER TABLE [dbo].[TenderPreparation] CHECK CONSTRAINT [FK_TenderPreparation_TenderingTerms]
GO
ALTER TABLE [dbo].[ContractExecutionRequirement] WITH CHECK ADD CONSTRAINT [FK_ContractExecutionRequirement_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([ContractExecutionRequirement])
GO
ALTER TABLE [dbo].[ContractExecutionRequirement] CHECK CONSTRAINT [FK_ContractExecutionRequirement_TenderingTerms]
GO
ALTER TABLE [dbo].[AwardingTerms] WITH CHECK ADD CONSTRAINT [FK_AwardingTerms_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([AwardingTerms])
GO
ALTER TABLE [dbo].[AwardingTerms] CHECK CONSTRAINT [FK_AwardingTerms_TenderingTerms]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_AdditionalInformationParty_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([AdditionalInformationParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_AdditionalInformationParty_TenderingTerms]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_DocumentProviderParty_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([DocumentProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_DocumentProviderParty_TenderingTerms]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TenderRecipientParty_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([TenderRecipientParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TenderRecipientParty_TenderingTerms]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ContractResponsibleParty_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([ContractResponsibleParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ContractResponsibleParty_TenderingTerms]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TenderEvaluationParty_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([TenderEvaluationParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TenderEvaluationParty_TenderingTerms]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_TenderValidityPeriod_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([TenderValidityPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_TenderValidityPeriod_TenderingTerms]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_ContractAcceptancePeriod_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([ContractAcceptancePeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_ContractAcceptancePeriod_TenderingTerms]
GO
ALTER TABLE [dbo].[AppealTerms] WITH CHECK ADD CONSTRAINT [FK_AppealTerms_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([AppealTerms])
GO
ALTER TABLE [dbo].[AppealTerms] CHECK CONSTRAINT [FK_AppealTerms_TenderingTerms]
GO
ALTER TABLE [dbo].[Language] WITH CHECK ADD CONSTRAINT [FK_Language_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([Language])
GO
ALTER TABLE [dbo].[Language] CHECK CONSTRAINT [FK_Language_TenderingTerms]
GO
ALTER TABLE [dbo].[BudgetAccountLine] WITH CHECK ADD CONSTRAINT [FK_BudgetAccountLine_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([BudgetAccountLine])
GO
ALTER TABLE [dbo].[BudgetAccountLine] CHECK CONSTRAINT [FK_BudgetAccountLine_TenderingTerms]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ReplacedNoticeDocumentReference_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([ReplacedNoticeDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ReplacedNoticeDocumentReference_TenderingTerms]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ContractDocumentReference_TradeFinancing] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeFinancing] ([ContractDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ContractDocumentReference_TradeFinancing]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_TradeFinancing] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeFinancing] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_TradeFinancing]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_FinancingParty_TradeFinancing] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeFinancing] ([FinancingParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_FinancingParty_TradeFinancing]
GO
ALTER TABLE [dbo].[FinancialAccount] WITH CHECK ADD CONSTRAINT [FK_FinancingFinancialAccount_TradeFinancing] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeFinancing] ([FinancingFinancialAccount])
GO
ALTER TABLE [dbo].[FinancialAccount] CHECK CONSTRAINT [FK_FinancingFinancialAccount_TradeFinancing]
GO
ALTER TABLE [dbo].[Clause] WITH CHECK ADD CONSTRAINT [FK_Clause_TradeFinancing] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeFinancing] ([Clause])
GO
ALTER TABLE [dbo].[Clause] CHECK CONSTRAINT [FK_Clause_TradeFinancing]
GO
ALTER TABLE [dbo].[Address] WITH CHECK ADD CONSTRAINT [FK_ApplicableAddress_TradingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradingTerms] ([ApplicableAddress])
GO
ALTER TABLE [dbo].[Address] CHECK CONSTRAINT [FK_ApplicableAddress_TradingTerms]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_DocumentReference_TransactionConditions] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransactionConditions] ([DocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_DocumentReference_TransactionConditions]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_MeasurementDimension_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([MeasurementDimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_MeasurementDimension_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportEquipmentSeal] WITH CHECK ADD CONSTRAINT [FK_TransportEquipmentSeal_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([TransportEquipmentSeal])
GO
ALTER TABLE [dbo].[TransportEquipmentSeal] CHECK CONSTRAINT [FK_TransportEquipmentSeal_TransportEquipment]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_MinimumTemperature_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([MinimumTemperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_MinimumTemperature_TransportEquipment]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_MaximumTemperature_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([MaximumTemperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_MaximumTemperature_TransportEquipment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ProviderParty_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([ProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ProviderParty_TransportEquipment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_LoadingProofParty_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([LoadingProofParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_LoadingProofParty_TransportEquipment]
GO
ALTER TABLE [dbo].[SupplierParty] WITH CHECK ADD CONSTRAINT [FK_SupplierParty_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([SupplierParty])
GO
ALTER TABLE [dbo].[SupplierParty] CHECK CONSTRAINT [FK_SupplierParty_TransportEquipment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_OwnerParty_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([OwnerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_OwnerParty_TransportEquipment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_OperatingParty_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([OperatingParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_OperatingParty_TransportEquipment]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_LoadingLocation_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([LoadingLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_LoadingLocation_TransportEquipment]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_UnloadingLocation_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([UnloadingLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_UnloadingLocation_TransportEquipment]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_StorageLocation_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([StorageLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_StorageLocation_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_PositioningTransportEvent_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([PositioningTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_PositioningTransportEvent_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_QuarantineTransportEvent_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([QuarantineTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_QuarantineTransportEvent_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_DeliveryTransportEvent_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([DeliveryTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_DeliveryTransportEvent_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_PickupTransportEvent_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([PickupTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_PickupTransportEvent_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_HandlingTransportEvent_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([HandlingTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_HandlingTransportEvent_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_LoadingTransportEvent_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([LoadingTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_LoadingTransportEvent_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_TransportEvent_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([TransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_TransportEvent_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportMeans] WITH CHECK ADD CONSTRAINT [FK_ApplicableTransportMeans_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([ApplicableTransportMeans])
GO
ALTER TABLE [dbo].[TransportMeans] CHECK CONSTRAINT [FK_ApplicableTransportMeans_TransportEquipment]
GO
ALTER TABLE [dbo].[TradingTerms] WITH CHECK ADD CONSTRAINT [FK_HaulageTradingTerms_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([HaulageTradingTerms])
GO
ALTER TABLE [dbo].[TradingTerms] CHECK CONSTRAINT [FK_HaulageTradingTerms_TransportEquipment]
GO
ALTER TABLE [dbo].[HazardousGoodsTransit] WITH CHECK ADD CONSTRAINT [FK_HazardousGoodsTransit_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([HazardousGoodsTransit])
GO
ALTER TABLE [dbo].[HazardousGoodsTransit] CHECK CONSTRAINT [FK_HazardousGoodsTransit_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportHandlingUnit] WITH CHECK ADD CONSTRAINT [FK_PackagedTransportHandlingUnit_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([PackagedTransportHandlingUnit])
GO
ALTER TABLE [dbo].[TransportHandlingUnit] CHECK CONSTRAINT [FK_PackagedTransportHandlingUnit_TransportEquipment]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_ServiceAllowanceCharge_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([ServiceAllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_ServiceAllowanceCharge_TransportEquipment]
GO
ALTER TABLE [dbo].[AllowanceCharge] WITH CHECK ADD CONSTRAINT [FK_FreightAllowanceCharge_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([FreightAllowanceCharge])
GO
ALTER TABLE [dbo].[AllowanceCharge] CHECK CONSTRAINT [FK_FreightAllowanceCharge_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportEquipment] WITH CHECK ADD CONSTRAINT [FK_AttachedTransportEquipment_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([AttachedTransportEquipment])
GO
ALTER TABLE [dbo].[TransportEquipment] CHECK CONSTRAINT [FK_AttachedTransportEquipment_TransportEquipment]
GO
ALTER TABLE [dbo].[Delivery] WITH CHECK ADD CONSTRAINT [FK_Delivery_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([Delivery])
GO
ALTER TABLE [dbo].[Delivery] CHECK CONSTRAINT [FK_Delivery_TransportEquipment]
GO
ALTER TABLE [dbo].[Pickup] WITH CHECK ADD CONSTRAINT [FK_Pickup_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([Pickup])
GO
ALTER TABLE [dbo].[Pickup] CHECK CONSTRAINT [FK_Pickup_TransportEquipment]
GO
ALTER TABLE [dbo].[Despatch] WITH CHECK ADD CONSTRAINT [FK_Despatch_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([Despatch])
GO
ALTER TABLE [dbo].[Despatch] CHECK CONSTRAINT [FK_Despatch_TransportEquipment]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ShipmentDocumentReference_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([ShipmentDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ShipmentDocumentReference_TransportEquipment]
GO
ALTER TABLE [dbo].[TransportEquipment] WITH CHECK ADD CONSTRAINT [FK_ContainedInTransportEquipment_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([ContainedInTransportEquipment])
GO
ALTER TABLE [dbo].[TransportEquipment] CHECK CONSTRAINT [FK_ContainedInTransportEquipment_TransportEquipment]
GO
ALTER TABLE [dbo].[Package] WITH CHECK ADD CONSTRAINT [FK_Package_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([Package])
GO
ALTER TABLE [dbo].[Package] CHECK CONSTRAINT [FK_Package_TransportEquipment]
GO
ALTER TABLE [dbo].[GoodsItem] WITH CHECK ADD CONSTRAINT [FK_GoodsItem_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([GoodsItem])
GO
ALTER TABLE [dbo].[GoodsItem] CHECK CONSTRAINT [FK_GoodsItem_TransportEquipment]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_ReportedShipment_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([ReportedShipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_ReportedShipment_TransportEvent]
GO
ALTER TABLE [dbo].[Status] WITH CHECK ADD CONSTRAINT [FK_CurrentStatus_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([CurrentStatus])
GO
ALTER TABLE [dbo].[Status] CHECK CONSTRAINT [FK_CurrentStatus_TransportEvent]
GO
ALTER TABLE [dbo].[Contact] WITH CHECK ADD CONSTRAINT [FK_Contact_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([Contact])
GO
ALTER TABLE [dbo].[Contact] CHECK CONSTRAINT [FK_Contact_TransportEvent]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_Location_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([Location])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_Location_TransportEvent]
GO
ALTER TABLE [dbo].[Signature] WITH CHECK ADD CONSTRAINT [FK_Signature_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([Signature])
GO
ALTER TABLE [dbo].[Signature] CHECK CONSTRAINT [FK_Signature_TransportEvent]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_Period_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([Period])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_Period_TransportEvent]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PaymentTerms_TransportExecutionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionTerms] ([PaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PaymentTerms_TransportExecutionTerms]
GO
ALTER TABLE [dbo].[DeliveryTerms] WITH CHECK ADD CONSTRAINT [FK_DeliveryTerms_TransportExecutionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionTerms] ([DeliveryTerms])
GO
ALTER TABLE [dbo].[DeliveryTerms] CHECK CONSTRAINT [FK_DeliveryTerms_TransportExecutionTerms]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_BonusPaymentTerms_TransportExecutionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionTerms] ([BonusPaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_BonusPaymentTerms_TransportExecutionTerms]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_CommissionPaymentTerms_TransportExecutionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionTerms] ([CommissionPaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_CommissionPaymentTerms_TransportExecutionTerms]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_PenaltyPaymentTerms_TransportExecutionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionTerms] ([PenaltyPaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_PenaltyPaymentTerms_TransportExecutionTerms]
GO
ALTER TABLE [dbo].[EnvironmentalEmission] WITH CHECK ADD CONSTRAINT [FK_EnvironmentalEmission_TransportExecutionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionTerms] ([EnvironmentalEmission])
GO
ALTER TABLE [dbo].[EnvironmentalEmission] CHECK CONSTRAINT [FK_EnvironmentalEmission_TransportExecutionTerms]
GO
ALTER TABLE [dbo].[NotificationRequirement] WITH CHECK ADD CONSTRAINT [FK_NotificationRequirement_TransportExecutionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionTerms] ([NotificationRequirement])
GO
ALTER TABLE [dbo].[NotificationRequirement] CHECK CONSTRAINT [FK_NotificationRequirement_TransportExecutionTerms]
GO
ALTER TABLE [dbo].[PaymentTerms] WITH CHECK ADD CONSTRAINT [FK_ServiceChargePaymentTerms_TransportExecutionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionTerms] ([ServiceChargePaymentTerms])
GO
ALTER TABLE [dbo].[PaymentTerms] CHECK CONSTRAINT [FK_ServiceChargePaymentTerms_TransportExecutionTerms]
GO
ALTER TABLE [dbo].[DespatchLine] WITH CHECK ADD CONSTRAINT [FK_HandlingUnitDespatchLine_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([HandlingUnitDespatchLine])
GO
ALTER TABLE [dbo].[DespatchLine] CHECK CONSTRAINT [FK_HandlingUnitDespatchLine_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Package] WITH CHECK ADD CONSTRAINT [FK_ActualPackage_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([ActualPackage])
GO
ALTER TABLE [dbo].[Package] CHECK CONSTRAINT [FK_ActualPackage_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[ReceiptLine] WITH CHECK ADD CONSTRAINT [FK_ReceivedHandlingUnitReceiptLine_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([ReceivedHandlingUnitReceiptLine])
GO
ALTER TABLE [dbo].[ReceiptLine] CHECK CONSTRAINT [FK_ReceivedHandlingUnitReceiptLine_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[TransportEquipment] WITH CHECK ADD CONSTRAINT [FK_TransportEquipment_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([TransportEquipment])
GO
ALTER TABLE [dbo].[TransportEquipment] CHECK CONSTRAINT [FK_TransportEquipment_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[TransportMeans] WITH CHECK ADD CONSTRAINT [FK_TransportMeans_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([TransportMeans])
GO
ALTER TABLE [dbo].[TransportMeans] CHECK CONSTRAINT [FK_TransportMeans_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[HazardousGoodsTransit] WITH CHECK ADD CONSTRAINT [FK_HazardousGoodsTransit_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([HazardousGoodsTransit])
GO
ALTER TABLE [dbo].[HazardousGoodsTransit] CHECK CONSTRAINT [FK_HazardousGoodsTransit_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_MeasurementDimension_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([MeasurementDimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_MeasurementDimension_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_MinimumTemperature_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([MinimumTemperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_MinimumTemperature_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Temperature] WITH CHECK ADD CONSTRAINT [FK_MaximumTemperature_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([MaximumTemperature])
GO
ALTER TABLE [dbo].[Temperature] CHECK CONSTRAINT [FK_MaximumTemperature_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[GoodsItem] WITH CHECK ADD CONSTRAINT [FK_GoodsItem_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([GoodsItem])
GO
ALTER TABLE [dbo].[GoodsItem] CHECK CONSTRAINT [FK_GoodsItem_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_FloorSpaceMeasurementDimension_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([FloorSpaceMeasurementDimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_FloorSpaceMeasurementDimension_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_PalletSpaceMeasurementDimension_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([PalletSpaceMeasurementDimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_PalletSpaceMeasurementDimension_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_ShipmentDocumentReference_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([ShipmentDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_ShipmentDocumentReference_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Status] WITH CHECK ADD CONSTRAINT [FK_Status_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([Status])
GO
ALTER TABLE [dbo].[Status] CHECK CONSTRAINT [FK_Status_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[CustomsDeclaration] WITH CHECK ADD CONSTRAINT [FK_CustomsDeclaration_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([CustomsDeclaration])
GO
ALTER TABLE [dbo].[CustomsDeclaration] CHECK CONSTRAINT [FK_CustomsDeclaration_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Shipment] WITH CHECK ADD CONSTRAINT [FK_ReferencedShipment_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([ReferencedShipment])
GO
ALTER TABLE [dbo].[Shipment] CHECK CONSTRAINT [FK_ReferencedShipment_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Package] WITH CHECK ADD CONSTRAINT [FK_Package_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([Package])
GO
ALTER TABLE [dbo].[Package] CHECK CONSTRAINT [FK_Package_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Stowage] WITH CHECK ADD CONSTRAINT [FK_Stowage_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([Stowage])
GO
ALTER TABLE [dbo].[Stowage] CHECK CONSTRAINT [FK_Stowage_TransportMeans]
GO
ALTER TABLE [dbo].[AirTransport] WITH CHECK ADD CONSTRAINT [FK_AirTransport_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([AirTransport])
GO
ALTER TABLE [dbo].[AirTransport] CHECK CONSTRAINT [FK_AirTransport_TransportMeans]
GO
ALTER TABLE [dbo].[RoadTransport] WITH CHECK ADD CONSTRAINT [FK_RoadTransport_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([RoadTransport])
GO
ALTER TABLE [dbo].[RoadTransport] CHECK CONSTRAINT [FK_RoadTransport_TransportMeans]
GO
ALTER TABLE [dbo].[RailTransport] WITH CHECK ADD CONSTRAINT [FK_RailTransport_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([RailTransport])
GO
ALTER TABLE [dbo].[RailTransport] CHECK CONSTRAINT [FK_RailTransport_TransportMeans]
GO
ALTER TABLE [dbo].[MaritimeTransport] WITH CHECK ADD CONSTRAINT [FK_MaritimeTransport_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([MaritimeTransport])
GO
ALTER TABLE [dbo].[MaritimeTransport] CHECK CONSTRAINT [FK_MaritimeTransport_TransportMeans]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_OwnerParty_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([OwnerParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_OwnerParty_TransportMeans]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_MeasurementDimension_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([MeasurementDimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_MeasurementDimension_TransportMeans]
GO
ALTER TABLE [dbo].[Location] WITH CHECK ADD CONSTRAINT [FK_StatusLocation_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([StatusLocation])
GO
ALTER TABLE [dbo].[Location] CHECK CONSTRAINT [FK_StatusLocation_TransportSchedule]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_ActualArrivalTransportEvent_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([ActualArrivalTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_ActualArrivalTransportEvent_TransportSchedule]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_ActualDepartureTransportEvent_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([ActualDepartureTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_ActualDepartureTransportEvent_TransportSchedule]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_EstimatedDepartureTransportEvent_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([EstimatedDepartureTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_EstimatedDepartureTransportEvent_TransportSchedule]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_EstimatedArrivalTransportEvent_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([EstimatedArrivalTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_EstimatedArrivalTransportEvent_TransportSchedule]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_PlannedDepartureTransportEvent_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([PlannedDepartureTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_PlannedDepartureTransportEvent_TransportSchedule]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_PlannedArrivalTransportEvent_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([PlannedArrivalTransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_PlannedArrivalTransportEvent_TransportSchedule]
GO
ALTER TABLE [dbo].[TransportationService] WITH CHECK ADD CONSTRAINT [FK_TransportationService_TransportationSegment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationSegment] ([TransportationService])
GO
ALTER TABLE [dbo].[TransportationService] CHECK CONSTRAINT [FK_TransportationService_TransportationSegment]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_TransportServiceProviderParty_TransportationSegment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationSegment] ([TransportServiceProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_TransportServiceProviderParty_TransportationSegment]
GO
ALTER TABLE [dbo].[Consignment] WITH CHECK ADD CONSTRAINT [FK_ReferencedConsignment_TransportationSegment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationSegment] ([ReferencedConsignment])
GO
ALTER TABLE [dbo].[Consignment] CHECK CONSTRAINT [FK_ReferencedConsignment_TransportationSegment]
GO
ALTER TABLE [dbo].[ShipmentStage] WITH CHECK ADD CONSTRAINT [FK_ShipmentStage_TransportationSegment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationSegment] ([ShipmentStage])
GO
ALTER TABLE [dbo].[ShipmentStage] CHECK CONSTRAINT [FK_ShipmentStage_TransportationSegment]
GO
ALTER TABLE [dbo].[TransportEquipment] WITH CHECK ADD CONSTRAINT [FK_TransportEquipment_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([TransportEquipment])
GO
ALTER TABLE [dbo].[TransportEquipment] CHECK CONSTRAINT [FK_TransportEquipment_TransportationService]
GO
ALTER TABLE [dbo].[TransportEquipment] WITH CHECK ADD CONSTRAINT [FK_SupportedTransportEquipment_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([SupportedTransportEquipment])
GO
ALTER TABLE [dbo].[TransportEquipment] CHECK CONSTRAINT [FK_SupportedTransportEquipment_TransportationService]
GO
ALTER TABLE [dbo].[TransportEquipment] WITH CHECK ADD CONSTRAINT [FK_UnsupportedTransportEquipment_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([UnsupportedTransportEquipment])
GO
ALTER TABLE [dbo].[TransportEquipment] CHECK CONSTRAINT [FK_UnsupportedTransportEquipment_TransportationService]
GO
ALTER TABLE [dbo].[CommodityClassification] WITH CHECK ADD CONSTRAINT [FK_CommodityClassification_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([CommodityClassification])
GO
ALTER TABLE [dbo].[CommodityClassification] CHECK CONSTRAINT [FK_CommodityClassification_TransportationService]
GO
ALTER TABLE [dbo].[CommodityClassification] WITH CHECK ADD CONSTRAINT [FK_SupportedCommodityClassification_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([SupportedCommodityClassification])
GO
ALTER TABLE [dbo].[CommodityClassification] CHECK CONSTRAINT [FK_SupportedCommodityClassification_TransportationService]
GO
ALTER TABLE [dbo].[CommodityClassification] WITH CHECK ADD CONSTRAINT [FK_UnsupportedCommodityClassification_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([UnsupportedCommodityClassification])
GO
ALTER TABLE [dbo].[CommodityClassification] CHECK CONSTRAINT [FK_UnsupportedCommodityClassification_TransportationService]
GO
ALTER TABLE [dbo].[Dimension] WITH CHECK ADD CONSTRAINT [FK_TotalCapacityDimension_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([TotalCapacityDimension])
GO
ALTER TABLE [dbo].[Dimension] CHECK CONSTRAINT [FK_TotalCapacityDimension_TransportationService]
GO
ALTER TABLE [dbo].[ShipmentStage] WITH CHECK ADD CONSTRAINT [FK_ShipmentStage_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([ShipmentStage])
GO
ALTER TABLE [dbo].[ShipmentStage] CHECK CONSTRAINT [FK_ShipmentStage_TransportationService]
GO
ALTER TABLE [dbo].[TransportEvent] WITH CHECK ADD CONSTRAINT [FK_TransportEvent_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([TransportEvent])
GO
ALTER TABLE [dbo].[TransportEvent] CHECK CONSTRAINT [FK_TransportEvent_TransportationService]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_ResponsibleTransportServiceProviderParty_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([ResponsibleTransportServiceProviderParty])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_ResponsibleTransportServiceProviderParty_TransportationService]
GO
ALTER TABLE [dbo].[EnvironmentalEmission] WITH CHECK ADD CONSTRAINT [FK_EnvironmentalEmission_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([EnvironmentalEmission])
GO
ALTER TABLE [dbo].[EnvironmentalEmission] CHECK CONSTRAINT [FK_EnvironmentalEmission_TransportationService]
GO
ALTER TABLE [dbo].[Period] WITH CHECK ADD CONSTRAINT [FK_EstimatedDurationPeriod_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([EstimatedDurationPeriod])
GO
ALTER TABLE [dbo].[Period] CHECK CONSTRAINT [FK_EstimatedDurationPeriod_TransportationService]
GO
ALTER TABLE [dbo].[ServiceFrequency] WITH CHECK ADD CONSTRAINT [FK_ScheduledServiceFrequency_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([ScheduledServiceFrequency])
GO
ALTER TABLE [dbo].[ServiceFrequency] CHECK CONSTRAINT [FK_ScheduledServiceFrequency_TransportationService]
GO
ALTER TABLE [dbo].[TaxCategory] WITH CHECK ADD CONSTRAINT [FK_TaxCategory_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([TaxCategory])
GO
ALTER TABLE [dbo].[TaxCategory] CHECK CONSTRAINT [FK_TaxCategory_UtilityItem]
GO
ALTER TABLE [dbo].[Contract] WITH CHECK ADD CONSTRAINT [FK_Contract_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([Contract])
GO
ALTER TABLE [dbo].[Contract] CHECK CONSTRAINT [FK_Contract_UtilityItem]
GO
ALTER TABLE [dbo].[Party] WITH CHECK ADD CONSTRAINT [FK_Party_WinningParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[WinningParty] ([Party])
GO
ALTER TABLE [dbo].[Party] CHECK CONSTRAINT [FK_Party_WinningParty]
GO
ALTER TABLE [dbo].[DocumentReference] WITH CHECK ADD CONSTRAINT [FK_WorkOrderDocumentReference_WorkPhaseReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[WorkPhaseReference] ([WorkOrderDocumentReference])
GO
ALTER TABLE [dbo].[DocumentReference] CHECK CONSTRAINT [FK_WorkOrderDocumentReference_WorkPhaseReference]
GO

/*
===============================================================================
Basic Business Information Entities
===============================================================================
*/

ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_ApplicationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_ApplicationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_ApplicationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_ApplicationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ApplicationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ApplicationResponse]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ApplicationResponse]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_ApplicationResponse]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ResponseDate_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([ResponseDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ResponseDate_ApplicationResponse]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ResponseTime_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([ResponseTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ResponseTime_ApplicationResponse]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ApplicationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_ApplicationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[ApplicationResponse] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_ApplicationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_AttachedDocument]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_AttachedDocument]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_AttachedDocument]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_AttachedDocument]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_AttachedDocument]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_AttachedDocument]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_AttachedDocument]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_AttachedDocument]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_AttachedDocument]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentTypeCode_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([DocumentTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentTypeCode_AttachedDocument]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DocumentType_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([DocumentType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DocumentType_AttachedDocument]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ParentDocumentID_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([ParentDocumentID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ParentDocumentID_AttachedDocument]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ParentDocumentTypeCode_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([ParentDocumentTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ParentDocumentTypeCode_AttachedDocument]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ParentDocumentVersionID_AttachedDocument] FOREIGN KEY([Ref])
REFERENCES [dbo].[AttachedDocument] ([ParentDocumentVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ParentDocumentVersionID_AttachedDocument]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_AwardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_AwardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_AwardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_AwardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_AwardedNotification]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_AwardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_AwardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractFolderID_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([ContractFolderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractFolderID_AwardedNotification]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_AwardedNotification]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_AwardedNotification]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ContractName_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([ContractName])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ContractName_AwardedNotification]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_AwardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardedNotification] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_AwardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_BillOfLading]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_BillOfLading]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_BillOfLading]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_BillOfLading]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_BillOfLading]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CarrierAssignedID_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([CarrierAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CarrierAssignedID_BillOfLading]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_BillOfLading]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_BillOfLading]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_BillOfLading]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_BillOfLading]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_BillOfLading]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_BillOfLading]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentStatusCode_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([DocumentStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentStatusCode_BillOfLading]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ShippingOrderID_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([ShippingOrderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ShippingOrderID_BillOfLading]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_ToOrderIndicator_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([ToOrderIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_ToOrderIndicator_BillOfLading]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_AdValoremIndicator_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([AdValoremIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_AdValoremIndicator_BillOfLading]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredCarriageValueAmount_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([DeclaredCarriageValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredCarriageValueAmount_BillOfLading]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OtherInstruction_BillOfLading] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillOfLading] ([OtherInstruction])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OtherInstruction_BillOfLading]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_CallForTenders]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_CallForTenders]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_CallForTenders]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_CallForTenders]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CallForTenders]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_CallForTenders]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_CallForTenders]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractFolderID_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([ContractFolderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractFolderID_CallForTenders]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ApprovalDate_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([ApprovalDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ApprovalDate_CallForTenders]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_CallForTenders]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_CallForTenders]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_CallForTenders]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_CallForTenders]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_PreviousVersionID_CallForTenders] FOREIGN KEY([Ref])
REFERENCES [dbo].[CallForTenders] ([PreviousVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_PreviousVersionID_CallForTenders]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_Catalogue]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_Catalogue]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_Catalogue]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_Catalogue]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Catalogue]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_Catalogue]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ActionCode_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([ActionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ActionCode_Catalogue]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_Catalogue]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_Catalogue]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_Catalogue]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_RevisionDate_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([RevisionDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_RevisionDate_Catalogue]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_RevisionTime_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([RevisionTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_RevisionTime_Catalogue]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Catalogue]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Catalogue]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_Catalogue]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_PreviousVersionID_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([PreviousVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_PreviousVersionID_Catalogue]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_Catalogue] FOREIGN KEY([Ref])
REFERENCES [dbo].[Catalogue] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_Catalogue]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_EffectiveDate_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([EffectiveDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_EffectiveDate_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_EffectiveTime_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([EffectiveTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_EffectiveTime_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_CatalogueDeletion] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueDeletion] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_CatalogueDeletion]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_RevisionDate_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([RevisionDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_RevisionDate_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_RevisionTime_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([RevisionTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_RevisionTime_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_CatalogueItemSpecificationUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdate] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_CatalogueItemSpecificationUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_RevisionDate_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([RevisionDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_RevisionDate_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_RevisionTime_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([RevisionTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_RevisionTime_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_CataloguePricingUpdate] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdate] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_CataloguePricingUpdate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_CatalogueRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_CatalogueRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_CatalogueRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_CatalogueRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CatalogueRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_CatalogueRequest]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_CatalogueRequest]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_CatalogueRequest]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_CatalogueRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_CatalogueRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_CatalogueRequest]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_PricingUpdateRequestIndicator_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([PricingUpdateRequestIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_PricingUpdateRequestIndicator_CatalogueRequest]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_ItemUpdateRequestIndicator_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([ItemUpdateRequestIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_ItemUpdateRequestIndicator_CatalogueRequest]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_CatalogueRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequest] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_CatalogueRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_CertificateOfOrigin] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOrigin] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_CertificateOfOrigin]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractFolderID_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([ContractFolderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractFolderID_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_RegulatoryDomain_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([RegulatoryDomain])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_RegulatoryDomain_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_PublishAwardIndicator_ContractAwardNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractAwardNotice] ([PublishAwardIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_PublishAwardIndicator_ContractAwardNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_ContractNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_ContractNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_ContractNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_ContractNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ContractNotice]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_ContractNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ContractNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractFolderID_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([ContractFolderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractFolderID_ContractNotice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ContractNotice]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_ContractNotice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ContractNotice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_RequestedPublicationDate_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([RequestedPublicationDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_RequestedPublicationDate_ContractNotice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_RegulatoryDomain_ContractNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractNotice] ([RegulatoryDomain])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_RegulatoryDomain_ContractNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_CreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_CreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_CreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_CreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CreditNote]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_CreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_CreditNote]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_CreditNote]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_CreditNote]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_TaxPointDate_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([TaxPointDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_TaxPointDate_CreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CreditNoteTypeCode_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([CreditNoteTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CreditNoteTypeCode_CreditNote]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_CreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_CreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxCurrencyCode_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([TaxCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxCurrencyCode_CreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_CreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentCurrencyCode_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([PaymentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentCurrencyCode_CreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeCurrencyCode_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([PaymentAlternativeCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentAlternativeCurrencyCode_CreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_CreditNote]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_CreditNote]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_CreditNote]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_BuyerReference_CreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNote] ([BuyerReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_BuyerReference_CreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_DebitNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_DebitNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_DebitNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_DebitNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_DebitNote]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_DebitNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_DebitNote]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_DebitNote]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_DebitNote]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_DebitNote]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_TaxPointDate_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([TaxPointDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_TaxPointDate_DebitNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_DebitNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxCurrencyCode_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([TaxCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxCurrencyCode_DebitNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_DebitNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentCurrencyCode_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([PaymentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentCurrencyCode_DebitNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeCurrencyCode_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([PaymentAlternativeCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentAlternativeCurrencyCode_DebitNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_DebitNote]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_DebitNote]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_DebitNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNote] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_DebitNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_DespatchAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_DespatchAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_DespatchAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_DespatchAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_DespatchAdvice]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_DespatchAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_DespatchAdvice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_DespatchAdvice]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_DespatchAdvice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentStatusCode_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([DocumentStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentStatusCode_DespatchAdvice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DespatchAdviceTypeCode_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([DespatchAdviceTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DespatchAdviceTypeCode_DespatchAdvice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_DespatchAdvice]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_DespatchAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchAdvice] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_DespatchAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_DocumentStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_DocumentStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_DocumentStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_DocumentStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_DocumentStatus]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_DocumentStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_DocumentStatus]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_DocumentStatus]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_DocumentStatus]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_DocumentStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatus] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_DocumentStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TrackingID_DocumentStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentStatusRequest] ([TrackingID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TrackingID_DocumentStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_ExceptionCriteria] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteria] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_ExceptionCriteria]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_ExceptionNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_ExceptionNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_ExceptionNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_ExceptionNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ExceptionNotification]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_ExceptionNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ExceptionNotification]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ExceptionNotification]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_ExceptionNotification]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ExceptionNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotification] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ExceptionNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_Forecast]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_Forecast]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_Forecast]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_Forecast]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Forecast]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_Forecast]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_Forecast]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_Forecast]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_Forecast]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Forecast]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_Forecast]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_BasedOnConsensusIndicator_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([BasedOnConsensusIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_BasedOnConsensusIndicator_Forecast]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ForecastPurposeCode_Forecast] FOREIGN KEY([Ref])
REFERENCES [dbo].[Forecast] ([ForecastPurposeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ForecastPurposeCode_Forecast]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_ForecastRevision]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_ForecastRevision]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_ForecastRevision]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_ForecastRevision]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ForecastRevision]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_ForecastRevision]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ForecastRevision]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ForecastRevision]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_ForecastRevision]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ForecastRevision]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SequenceNumberID_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([SequenceNumberID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SequenceNumberID_ForecastRevision]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_RevisionStatusCode_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([RevisionStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_RevisionStatusCode_ForecastRevision]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PurposeCode_ForecastRevision] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevision] ([PurposeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PurposeCode_ForecastRevision]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CarrierAssignedID_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([CarrierAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CarrierAssignedID_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentStatusCode_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([DocumentStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentStatusCode_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ShippingOrderID_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([ShippingOrderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ShippingOrderID_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_ToOrderIndicator_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([ToOrderIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_ToOrderIndicator_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_AdValoremIndicator_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([AdValoremIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_AdValoremIndicator_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredCarriageValueAmount_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([DeclaredCarriageValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredCarriageValueAmount_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OtherInstruction_ForwardingInstructions] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForwardingInstructions] ([OtherInstruction])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OtherInstruction_ForwardingInstructions]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_FreightInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_FreightInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_FreightInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_FreightInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_FreightInvoice]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_FreightInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_FreightInvoice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_FreightInvoice]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_FreightInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_InvoiceTypeCode_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([InvoiceTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_InvoiceTypeCode_FreightInvoice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_FreightInvoice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_TaxPointDate_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([TaxPointDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_TaxPointDate_FreightInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_FreightInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxCurrencyCode_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([TaxCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxCurrencyCode_FreightInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_FreightInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentCurrencyCode_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([PaymentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentCurrencyCode_FreightInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeCurrencyCode_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([PaymentAlternativeCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentAlternativeCurrencyCode_FreightInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_FreightInvoice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_FreightInvoice]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_FreightInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[FreightInvoice] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_FreightInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CancellationNote_FulfilmentCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[FulfilmentCancellation] ([CancellationNote])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CancellationNote_FulfilmentCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TransportExecutionPlanReferenceID_GoodsItemItinerary] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemItinerary] ([TransportExecutionPlanReferenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TransportExecutionPlanReferenceID_GoodsItemItinerary]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractFolderID_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([ContractFolderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractFolderID_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_GuaranteeTypeCode_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([GuaranteeTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_GuaranteeTypeCode_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Purpose_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([Purpose])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Purpose_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LiabilityAmount_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([LiabilityAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LiabilityAmount_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ConstitutionCode_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([ConstitutionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ConstitutionCode_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_GuaranteeCertificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[GuaranteeCertificate] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_GuaranteeCertificate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_InstructionForReturns]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_InstructionForReturns]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_InstructionForReturns]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_InstructionForReturns]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_InstructionForReturns]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_InstructionForReturns]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_InstructionForReturns]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_InstructionForReturns]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_InstructionForReturns]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_InstructionForReturns] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturns] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_InstructionForReturns]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_InventoryReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_InventoryReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_InventoryReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_InventoryReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_InventoryReport]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_InventoryReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_InventoryReport]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_InventoryReport]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_InventoryReport]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_InventoryReport]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_InventoryReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReport] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_InventoryReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_Invoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_Invoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_Invoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_Invoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Invoice]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_Invoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_Invoice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_Invoice]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_Invoice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_DueDate_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([DueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_DueDate_Invoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_InvoiceTypeCode_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([InvoiceTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_InvoiceTypeCode_Invoice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Invoice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_TaxPointDate_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([TaxPointDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_TaxPointDate_Invoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_Invoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxCurrencyCode_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([TaxCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxCurrencyCode_Invoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_Invoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentCurrencyCode_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([PaymentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentCurrencyCode_Invoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeCurrencyCode_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([PaymentAlternativeCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentAlternativeCurrencyCode_Invoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_Invoice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_Invoice]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_Invoice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_BuyerReference_Invoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[Invoice] ([BuyerReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_BuyerReference_Invoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ItemInformationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequest] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ItemInformationRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_Order]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_Order]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_Order]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_Order]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Order]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SalesOrderID_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([SalesOrderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SalesOrderID_Order]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_Order]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_Order]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_Order]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_Order]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_OrderTypeCode_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([OrderTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_OrderTypeCode_Order]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Order]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_RequestedInvoiceCurrencyCode_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([RequestedInvoiceCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_RequestedInvoiceCurrencyCode_Order]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_Order]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_Order]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxCurrencyCode_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([TaxCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxCurrencyCode_Order]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CustomerReference_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([CustomerReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CustomerReference_Order]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_Order]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_Order]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_Order] FOREIGN KEY([Ref])
REFERENCES [dbo].[Order] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_Order]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_OrderCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_OrderCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_OrderCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_OrderCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_OrderCancellation]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_OrderCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_OrderCancellation]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_OrderCancellation]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_OrderCancellation]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_OrderCancellation]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CancellationNote_OrderCancellation] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderCancellation] ([CancellationNote])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CancellationNote_OrderCancellation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_OrderChange]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_OrderChange]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_OrderChange]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_OrderChange]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_OrderChange]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SalesOrderID_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([SalesOrderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SalesOrderID_OrderChange]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_OrderChange]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_OrderChange]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_OrderChange]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_OrderChange]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SequenceNumberID_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([SequenceNumberID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SequenceNumberID_OrderChange]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_OrderChange]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_RequestedInvoiceCurrencyCode_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([RequestedInvoiceCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_RequestedInvoiceCurrencyCode_OrderChange]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_OrderChange]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_OrderChange]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxCurrencyCode_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([TaxCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxCurrencyCode_OrderChange]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CustomerReference_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([CustomerReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CustomerReference_OrderChange]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_OrderChange]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_OrderChange]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_OrderChange] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderChange] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_OrderChange]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_OrderResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_OrderResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_OrderResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_OrderResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_OrderResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SalesOrderID_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([SalesOrderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SalesOrderID_OrderResponse]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_OrderResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_OrderResponse]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_OrderResponse]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_OrderResponse]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_OrderResponseCode_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([OrderResponseCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_OrderResponseCode_OrderResponse]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_OrderResponse]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_OrderResponse]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_OrderResponse]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxCurrencyCode_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([TaxCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxCurrencyCode_OrderResponse]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalPackagesQuantity_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([TotalPackagesQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalPackagesQuantity_OrderResponse]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_GrossWeightMeasure_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([GrossWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_GrossWeightMeasure_OrderResponse]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetWeightMeasure_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([NetWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetWeightMeasure_OrderResponse]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetNetWeightMeasure_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([NetNetWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetNetWeightMeasure_OrderResponse]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_GrossVolumeMeasure_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([GrossVolumeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_GrossVolumeMeasure_OrderResponse]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetVolumeMeasure_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([NetVolumeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetVolumeMeasure_OrderResponse]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CustomerReference_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([CustomerReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CustomerReference_OrderResponse]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_OrderResponse]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_OrderResponse]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_OrderResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponse] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_OrderResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_AcceptedIndicator_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([AcceptedIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_AcceptedIndicator_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_RejectionNote_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([RejectionNote])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_RejectionNote_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CustomerReference_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([CustomerReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CustomerReference_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_OrderResponseSimple] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderResponseSimple] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_OrderResponseSimple]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_PackingList]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_PackingList]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_PackingList]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_PackingList]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_PackingList]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_PackingList]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_PackingList]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_PackingList]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_PackingList]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_PackingList]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_PackingList]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_PackingList]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OtherInstruction_PackingList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PackingList] ([OtherInstruction])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OtherInstruction_PackingList]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractFolderID_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([ContractFolderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractFolderID_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_PlannedDate_PriorInformationNotice] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriorInformationNotice] ([PlannedDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_PlannedDate_PriorInformationNotice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_ProductActivity]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_ProductActivity]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_ProductActivity]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_ProductActivity]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ProductActivity]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_ProductActivity]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ProductActivity]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ProductActivity]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_ProductActivity]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ProductActivity]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_ProductActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProductActivity] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_ProductActivity]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_Quotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_Quotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_Quotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_Quotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Quotation]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_Quotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_Quotation]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_Quotation]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_Quotation]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Quotation]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_Quotation]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_Quotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Quotation] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_Quotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentStatusCode_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([DocumentStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentStatusCode_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ReceiptAdviceTypeCode_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([ReceiptAdviceTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ReceiptAdviceTypeCode_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_ReceiptAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptAdvice] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_ReceiptAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_Reminder]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_Reminder]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_Reminder]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_Reminder]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Reminder]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_Reminder]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_Reminder]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_Reminder]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_Reminder]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ReminderTypeCode_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([ReminderTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ReminderTypeCode_Reminder]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_ReminderSequenceNumeric_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([ReminderSequenceNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_ReminderSequenceNumeric_Reminder]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Reminder]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_TaxPointDate_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([TaxPointDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_TaxPointDate_Reminder]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_Reminder]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxCurrencyCode_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([TaxCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxCurrencyCode_Reminder]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_Reminder]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentCurrencyCode_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([PaymentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentCurrencyCode_Reminder]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeCurrencyCode_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([PaymentAlternativeCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentAlternativeCurrencyCode_Reminder]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_Reminder]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_Reminder]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_Reminder] FOREIGN KEY([Ref])
REFERENCES [dbo].[Reminder] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_Reminder]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalDebitAmount_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([TotalDebitAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalDebitAmount_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalCreditAmount_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([TotalCreditAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalCreditAmount_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalPaymentAmount_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([TotalPaymentAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalPaymentAmount_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PaymentOrderReference_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([PaymentOrderReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PaymentOrderReference_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PayerReference_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([PayerReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PayerReference_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_InvoicingPartyReference_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([InvoicingPartyReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_InvoicingPartyReference_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_RemittanceAdvice] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdvice] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_RemittanceAdvice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_RequestForQuotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_RequestForQuotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_RequestForQuotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_RequestForQuotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_RequestForQuotation]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_RequestForQuotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_RequestForQuotation]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_RequestForQuotation]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_RequestForQuotation]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_SubmissionDueDate_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([SubmissionDueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_SubmissionDueDate_RequestForQuotation]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_RequestForQuotation]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_RequestForQuotation]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_RequestForQuotation] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotation] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_RequestForQuotation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_RetailEvent]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_RetailEvent]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_RetailEvent]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_RetailEvent]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_RetailEvent]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_RetailEvent]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_RetailEvent]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_RetailEvent]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_RetailEvent]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_RetailEvent]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_RetailEventName_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([RetailEventName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_RetailEventName_RetailEvent]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_RetailEventStatusCode_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([RetailEventStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_RetailEventStatusCode_RetailEvent]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SellerEventID_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([SellerEventID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SellerEventID_RetailEvent]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_BuyerEventID_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([BuyerEventID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_BuyerEventID_RetailEvent]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_RetailEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailEvent] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_RetailEvent]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_TaxPointDate_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([TaxPointDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_TaxPointDate_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxCurrencyCode_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([TaxCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxCurrencyCode_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentCurrencyCode_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([PaymentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentCurrencyCode_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeCurrencyCode_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([PaymentAlternativeCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentAlternativeCurrencyCode_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_SelfBilledCreditNote] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledCreditNote] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_SelfBilledCreditNote]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_TaxPointDate_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([TaxPointDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_TaxPointDate_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_InvoiceTypeCode_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([InvoiceTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_InvoiceTypeCode_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxCurrencyCode_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([TaxCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxCurrencyCode_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PricingCurrencyCode_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([PricingCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PricingCurrencyCode_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentCurrencyCode_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([PaymentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentCurrencyCode_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentAlternativeCurrencyCode_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([PaymentAlternativeCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentAlternativeCurrencyCode_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_SelfBilledInvoice] FOREIGN KEY([Ref])
REFERENCES [dbo].[SelfBilledInvoice] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_SelfBilledInvoice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_Statement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_Statement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_Statement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_Statement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Statement]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_Statement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_Statement]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_Statement]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_Statement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Statement]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_Statement]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalDebitAmount_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([TotalDebitAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalDebitAmount_Statement]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalCreditAmount_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([TotalCreditAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalCreditAmount_Statement]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalBalanceAmount_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([TotalBalanceAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalBalanceAmount_Statement]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineCountNumeric_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([LineCountNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineCountNumeric_Statement]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_StatementTypeCode_Statement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Statement] ([StatementTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_StatementTypeCode_Statement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_StockAvailabilityReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReport] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_StockAvailabilityReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_Tender]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_Tender]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_Tender]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_Tender]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Tender]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_Tender]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_Tender]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TenderTypeCode_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([TenderTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TenderTypeCode_Tender]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractFolderID_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([ContractFolderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractFolderID_Tender]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_Tender]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_Tender]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ContractName_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([ContractName])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ContractName_Tender]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Tender] FOREIGN KEY([Ref])
REFERENCES [dbo].[Tender] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Tender]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TendererQualification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TendererQualification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TendererQualification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TendererQualification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TendererQualification]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_TendererQualification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TendererQualification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractFolderID_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([ContractFolderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractFolderID_TendererQualification]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TendererQualification]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TendererQualification]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TendererQualification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_TendererQualification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_PreviousVersionID_TendererQualification] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualification] ([PreviousVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_PreviousVersionID_TendererQualification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractFolderID_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([ContractFolderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractFolderID_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ContractName_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([ContractName])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ContractName_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TendererQualificationResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationResponse] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TendererQualificationResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TenderReceipt]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TenderReceipt]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TenderReceipt]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TenderReceipt]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TenderReceipt]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_TenderReceipt]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TenderReceipt]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractFolderID_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([ContractFolderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractFolderID_TenderReceipt]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TenderReceipt]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TenderReceipt]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ContractName_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([ContractName])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ContractName_TenderReceipt]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TenderReceipt]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_RegisteredDate_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([RegisteredDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_RegisteredDate_TenderReceipt]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_RegisteredTime_TenderReceipt] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderReceipt] ([RegisteredTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_RegisteredTime_TenderReceipt]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ProfileStatusCode_TradeItemLocationProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeItemLocationProfile] ([ProfileStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ProfileStatusCode_TradeItemLocationProfile]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TransportationStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TransportationStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TransportationStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TransportationStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransportationStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CarrierAssignedID_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([CarrierAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CarrierAssignedID_TransportationStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TransportationStatus]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TransportationStatus]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TransportationStatus]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_TransportationStatus]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TransportationStatus]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TransportationStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ShippingOrderID_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([ShippingOrderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ShippingOrderID_TransportationStatus]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OtherInstruction_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([OtherInstruction])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OtherInstruction_TransportationStatus]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportationStatusTypeCode_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([TransportationStatusTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportationStatusTypeCode_TransportationStatus]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportExecutionStatusCode_TransportationStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatus] ([TransportExecutionStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportExecutionStatusCode_TransportationStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CarrierAssignedID_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([CarrierAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CarrierAssignedID_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ShippingOrderID_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([ShippingOrderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ShippingOrderID_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OtherInstruction_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([OtherInstruction])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OtherInstruction_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportationStatusTypeCode_TransportationStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationStatusRequest] ([TransportationStatusTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportationStatusTypeCode_TransportationStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentStatusCode_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([DocumentStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentStatusCode_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentStatusReasonCode_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([DocumentStatusReasonCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentStatusReasonCode_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DocumentStatusReasonDescription_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([DocumentStatusReasonDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DocumentStatusReasonDescription_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TransportUserRemarks_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([TransportUserRemarks])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TransportUserRemarks_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TransportServiceProviderRemarks_TransportExecutionPlan] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlan] ([TransportServiceProviderRemarks])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TransportServiceProviderRemarks_TransportExecutionPlan]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentStatusCode_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([DocumentStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentStatusCode_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentStatusReasonCode_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([DocumentStatusReasonCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentStatusReasonCode_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DocumentStatusReasonDescription_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([DocumentStatusReasonDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DocumentStatusReasonDescription_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TransportUserRemarks_TransportExecutionPlanRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionPlanRequest] ([TransportUserRemarks])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TransportUserRemarks_TransportExecutionPlanRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_StatusAvailableIndicator_TransportProgressStatus] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatus] ([StatusAvailableIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_StatusAvailableIndicator_TransportProgressStatus]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TransportProgressStatusRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportProgressStatusRequest] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TransportProgressStatusRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_ServiceName_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([ServiceName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_ServiceName_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ResponseCode_TransportServiceDescription] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescription] ([ResponseCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ResponseCode_TransportServiceDescription]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ServiceInformationPreferenceCode_TransportServiceDescriptionRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportServiceDescriptionRequest] ([ServiceInformationPreferenceCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ServiceInformationPreferenceCode_TransportServiceDescriptionRequest]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_UnawardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_UnawardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_UnawardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_UnawardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_UnawardedNotification]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_UnawardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_UnawardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractFolderID_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([ContractFolderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractFolderID_UnawardedNotification]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_UnawardedNotification]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_UnawardedNotification]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ContractName_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([ContractName])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ContractName_UnawardedNotification]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_UnawardedNotification] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnawardedNotification] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_UnawardedNotification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_UtilityStatement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_UtilityStatement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_UtilityStatement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_UtilityStatement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_UtilityStatement]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_UtilityStatement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_UtilityStatement]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_UtilityStatement]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_UtilityStatement]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_UtilityStatementTypeCode_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([UtilityStatementTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_UtilityStatementTypeCode_UtilityStatement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_UtilityStatement]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentCurrencyCode_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([DocumentCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentCurrencyCode_UtilityStatement]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_UtilityStatement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_UtilityStatement] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityStatement] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_UtilityStatement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UBLVersionID_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([UBLVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UBLVersionID_Waybill]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomizationID_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([CustomizationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomizationID_Waybill]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileID_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([ProfileID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileID_Waybill]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProfileExecutionID_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([ProfileExecutionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProfileExecutionID_Waybill]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Waybill]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CarrierAssignedID_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([CarrierAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CarrierAssignedID_Waybill]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_Waybill]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_Waybill]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_Waybill]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_Waybill]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Waybill]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Waybill]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ShippingOrderID_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([ShippingOrderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ShippingOrderID_Waybill]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_AdValoremIndicator_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([AdValoremIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_AdValoremIndicator_Waybill]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredCarriageValueAmount_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([DeclaredCarriageValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredCarriageValueAmount_Waybill]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OtherInstruction_Waybill] FOREIGN KEY([Ref])
REFERENCES [dbo].[Waybill] ([OtherInstruction])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OtherInstruction_Waybill]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ActivityDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ActivityDataLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ActivityDataLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SupplyChainActivityTypeCode_ActivityDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ActivityDataLine] ([SupplyChainActivityTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SupplyChainActivityTypeCode_ActivityDataLine]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_ActivityProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ActivityProperty] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_ActivityProperty]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Value_ActivityProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ActivityProperty] ([Value])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Value_ActivityProperty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Address]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AddressTypeCode_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([AddressTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AddressTypeCode_Address]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AddressFormatCode_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([AddressFormatCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AddressFormatCode_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Postbox_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([Postbox])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Postbox_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Floor_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([Floor])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Floor_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Room_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([Room])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Room_Address]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_StreetName_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([StreetName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_StreetName_Address]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_AdditionalStreetName_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([AdditionalStreetName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_AdditionalStreetName_Address]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_BlockName_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([BlockName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_BlockName_Address]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_BuildingName_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([BuildingName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_BuildingName_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_BuildingNumber_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([BuildingNumber])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_BuildingNumber_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_InhouseMail_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([InhouseMail])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_InhouseMail_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Department_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([Department])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Department_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MarkAttention_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([MarkAttention])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MarkAttention_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MarkCare_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([MarkCare])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MarkCare_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PlotIdentification_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([PlotIdentification])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PlotIdentification_Address]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_CitySubdivisionName_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([CitySubdivisionName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_CitySubdivisionName_Address]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_CityName_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([CityName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_CityName_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PostalZone_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([PostalZone])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PostalZone_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CountrySubentity_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([CountrySubentity])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CountrySubentity_Address]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CountrySubentityCode_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([CountrySubentityCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CountrySubentityCode_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Region_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([Region])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Region_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_District_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([District])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_District_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TimezoneOffset_Address] FOREIGN KEY([Ref])
REFERENCES [dbo].[Address] ([TimezoneOffset])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TimezoneOffset_Address]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Line_AddressLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[AddressLine] ([Line])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Line_AddressLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_AircraftID_AirTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[AirTransport] ([AircraftID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_AircraftID_AirTransport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_AllowanceCharge]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_ChargeIndicator_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([ChargeIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_ChargeIndicator_AllowanceCharge]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AllowanceChargeReasonCode_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([AllowanceChargeReasonCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AllowanceChargeReasonCode_AllowanceCharge]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AllowanceChargeReason_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([AllowanceChargeReason])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AllowanceChargeReason_AllowanceCharge]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_MultiplierFactorNumeric_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([MultiplierFactorNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_MultiplierFactorNumeric_AllowanceCharge]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_PrepaidIndicator_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([PrepaidIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_PrepaidIndicator_AllowanceCharge]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_SequenceNumeric_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([SequenceNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_SequenceNumeric_AllowanceCharge]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_AllowanceCharge]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_BaseAmount_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([BaseAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_BaseAmount_AllowanceCharge]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_AllowanceCharge]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_AllowanceCharge]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PerUnitAmount_AllowanceCharge] FOREIGN KEY([Ref])
REFERENCES [dbo].[AllowanceCharge] ([PerUnitAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PerUnitAmount_AllowanceCharge]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_AppealTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AppealTerms] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_AppealTerms]
GO
ALTER TABLE [dbo].[BinaryObject] WITH CHECK ADD CONSTRAINT [FK_EmbeddedDocumentBinaryObject_Attachment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Attachment] ([EmbeddedDocumentBinaryObject])
GO
ALTER TABLE [dbo].[BinaryObject] CHECK CONSTRAINT [FK_EmbeddedDocumentBinaryObject_Attachment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_AuctionConstraintIndicator_AuctionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AuctionTerms] ([AuctionConstraintIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_AuctionConstraintIndicator_AuctionTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_JustificationDescription_AuctionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AuctionTerms] ([JustificationDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_JustificationDescription_AuctionTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_AuctionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AuctionTerms] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_AuctionTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ProcessDescription_AuctionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AuctionTerms] ([ProcessDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ProcessDescription_AuctionTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ConditionsDescription_AuctionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AuctionTerms] ([ConditionsDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ConditionsDescription_AuctionTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ElectronicDeviceDescription_AuctionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AuctionTerms] ([ElectronicDeviceDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ElectronicDeviceDescription_AuctionTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_AuctionURI_AuctionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AuctionTerms] ([AuctionURI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_AuctionURI_AuctionTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_AwardingCriterion]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AwardingCriterionTypeCode_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([AwardingCriterionTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AwardingCriterionTypeCode_AwardingCriterion]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_AwardingCriterion]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_WeightNumeric_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([WeightNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_WeightNumeric_AwardingCriterion]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Weight_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([Weight])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Weight_AwardingCriterion]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CalculationExpression_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([CalculationExpression])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CalculationExpression_AwardingCriterion]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CalculationExpressionCode_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([CalculationExpressionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CalculationExpressionCode_AwardingCriterion]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MinimumQuantity_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([MinimumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MinimumQuantity_AwardingCriterion]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MaximumQuantity_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([MaximumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MaximumQuantity_AwardingCriterion]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_MinimumAmount_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([MinimumAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_MinimumAmount_AwardingCriterion]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_MaximumAmount_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([MaximumAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_MaximumAmount_AwardingCriterion]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MinimumImprovementBid_AwardingCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterion] ([MinimumImprovementBid])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MinimumImprovementBid_AwardingCriterion]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_AwardingCriterionResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterionResponse] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_AwardingCriterionResponse]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_AwardingCriterionID_AwardingCriterionResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterionResponse] ([AwardingCriterionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_AwardingCriterionID_AwardingCriterionResponse]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AwardingCriterionDescription_AwardingCriterionResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterionResponse] ([AwardingCriterionDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AwardingCriterionDescription_AwardingCriterionResponse]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_AwardingCriterionResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterionResponse] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_AwardingCriterionResponse]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_AwardingCriterionResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterionResponse] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_AwardingCriterionResponse]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_AwardingCriterionResponse] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingCriterionResponse] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_AwardingCriterionResponse]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_WeightingAlgorithmCode_AwardingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingTerms] ([WeightingAlgorithmCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_WeightingAlgorithmCode_AwardingTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_AwardingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingTerms] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_AwardingTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TechnicalCommitteeDescription_AwardingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingTerms] ([TechnicalCommitteeDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TechnicalCommitteeDescription_AwardingTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_LowTendersDescription_AwardingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingTerms] ([LowTendersDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_LowTendersDescription_AwardingTerms]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_PrizeIndicator_AwardingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingTerms] ([PrizeIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_PrizeIndicator_AwardingTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PrizeDescription_AwardingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingTerms] ([PrizeDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PrizeDescription_AwardingTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PaymentDescription_AwardingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingTerms] ([PaymentDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PaymentDescription_AwardingTerms]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_FollowupContractIndicator_AwardingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingTerms] ([FollowupContractIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_FollowupContractIndicator_AwardingTerms]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_BindingOnBuyerIndicator_AwardingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[AwardingTerms] ([BindingOnBuyerIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_BindingOnBuyerIndicator_AwardingTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_BillingReferenceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillingReferenceLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_BillingReferenceLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_BillingReferenceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[BillingReferenceLine] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_BillingReferenceLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Branch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Branch] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Branch]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_Branch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Branch] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_Branch]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_BudgetAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[BudgetAccount] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_BudgetAccount]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_BudgetYearNumeric_BudgetAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[BudgetAccount] ([BudgetYearNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_BudgetYearNumeric_BudgetAccount]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_BudgetAccountLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[BudgetAccountLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_BudgetAccountLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalAmount_BudgetAccountLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[BudgetAccountLine] ([TotalAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalAmount_BudgetAccountLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CapabilityTypeCode_Capability] FOREIGN KEY([Ref])
REFERENCES [dbo].[Capability] ([CapabilityTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CapabilityTypeCode_Capability]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Capability] FOREIGN KEY([Ref])
REFERENCES [dbo].[Capability] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Capability]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_ValueAmount_Capability] FOREIGN KEY([Ref])
REFERENCES [dbo].[Capability] ([ValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_ValueAmount_Capability]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ValueQuantity_Capability] FOREIGN KEY([Ref])
REFERENCES [dbo].[Capability] ([ValueQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ValueQuantity_Capability]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_PrimaryAccountNumberID_CardAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CardAccount] ([PrimaryAccountNumberID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_PrimaryAccountNumberID_CardAccount]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_NetworkID_CardAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CardAccount] ([NetworkID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_NetworkID_CardAccount]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CardTypeCode_CardAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CardAccount] ([CardTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CardTypeCode_CardAccount]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ValidityStartDate_CardAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CardAccount] ([ValidityStartDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ValidityStartDate_CardAccount]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ExpiryDate_CardAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CardAccount] ([ExpiryDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ExpiryDate_CardAccount]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_IssuerID_CardAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CardAccount] ([IssuerID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_IssuerID_CardAccount]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_IssueNumberID_CardAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CardAccount] ([IssueNumberID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_IssueNumberID_CardAccount]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CV2ID_CardAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CardAccount] ([CV2ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CV2ID_CardAccount]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CardChipCode_CardAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CardAccount] ([CardChipCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CardChipCode_CardAccount]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ChipApplicationID_CardAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CardAccount] ([ChipApplicationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ChipApplicationID_CardAccount]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_HolderName_CardAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CardAccount] ([HolderName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_HolderName_CardAccount]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CatalogueItemSpecificationUpdateLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueItemSpecificationUpdateLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CatalogueItemSpecificationUpdateLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CatalogueLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ActionCode_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([ActionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ActionCode_CatalogueLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LifeCycleStatusCode_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([LifeCycleStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LifeCycleStatusCode_CatalogueLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ContractSubdivision_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([ContractSubdivision])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ContractSubdivision_CatalogueLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_CatalogueLine]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_OrderableIndicator_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([OrderableIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_OrderableIndicator_CatalogueLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OrderableUnit_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([OrderableUnit])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OrderableUnit_CatalogueLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ContentUnitQuantity_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([ContentUnitQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ContentUnitQuantity_CatalogueLine]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_OrderQuantityIncrementNumeric_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([OrderQuantityIncrementNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_OrderQuantityIncrementNumeric_CatalogueLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MinimumOrderQuantity_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([MinimumOrderQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MinimumOrderQuantity_CatalogueLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MaximumOrderQuantity_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([MaximumOrderQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MaximumOrderQuantity_CatalogueLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_WarrantyInformation_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([WarrantyInformation])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_WarrantyInformation_CatalogueLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PackLevelCode_CatalogueLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueLine] ([PackLevelCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PackLevelCode_CatalogueLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CataloguePricingUpdateLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CataloguePricingUpdateLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CataloguePricingUpdateLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CatalogueReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueReference] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CatalogueReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_CatalogueReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueReference] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_CatalogueReference]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_CatalogueReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueReference] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_CatalogueReference]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_CatalogueReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueReference] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_CatalogueReference]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_RevisionDate_CatalogueReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueReference] ([RevisionDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_RevisionDate_CatalogueReference]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_RevisionTime_CatalogueReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueReference] ([RevisionTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_RevisionTime_CatalogueReference]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_CatalogueReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueReference] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_CatalogueReference]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_CatalogueReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueReference] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_CatalogueReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_CatalogueReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueReference] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_CatalogueReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_PreviousVersionID_CatalogueReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueReference] ([PreviousVersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_PreviousVersionID_CatalogueReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CatalogueRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequestLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CatalogueRequestLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ContractSubdivision_CatalogueRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequestLine] ([ContractSubdivision])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ContractSubdivision_CatalogueRequestLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_CatalogueRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CatalogueRequestLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_CatalogueRequestLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Certificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[Certificate] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Certificate]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CertificateTypeCode_Certificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[Certificate] ([CertificateTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CertificateTypeCode_Certificate]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CertificateType_Certificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[Certificate] ([CertificateType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CertificateType_Certificate]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Remarks_Certificate] FOREIGN KEY([Ref])
REFERENCES [dbo].[Certificate] ([Remarks])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Remarks_Certificate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ReferenceID_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([ReferenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ReferenceID_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CertificateType_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([CertificateType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CertificateType_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ApplicationStatusCode_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([ApplicationStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ApplicationStatusCode_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_OriginalJobID_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([OriginalJobID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_OriginalJobID_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_PreviousJobID_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([PreviousJobID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_PreviousJobID_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Remarks_CertificateOfOriginApplication] FOREIGN KEY([Ref])
REFERENCES [dbo].[CertificateOfOriginApplication] ([Remarks])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Remarks_CertificateOfOriginApplication]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_ClassificationCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationCategory] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_ClassificationCategory]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CodeValue_ClassificationCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationCategory] ([CodeValue])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CodeValue_ClassificationCategory]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ClassificationCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationCategory] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ClassificationCategory]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ClassificationScheme]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ClassificationScheme]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_LastRevisionDate_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([LastRevisionDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_LastRevisionDate_ClassificationScheme]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_LastRevisionTime_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([LastRevisionTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_LastRevisionTime_ClassificationScheme]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ClassificationScheme]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_ClassificationScheme]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ClassificationScheme]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_AgencyID_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([AgencyID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_AgencyID_ClassificationScheme]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AgencyName_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([AgencyName])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AgencyName_ClassificationScheme]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_ClassificationScheme]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_URI_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([URI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_URI_ClassificationScheme]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SchemeURI_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([SchemeURI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SchemeURI_ClassificationScheme]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_LanguageID_ClassificationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[ClassificationScheme] ([LanguageID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_LanguageID_ClassificationScheme]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Clause] FOREIGN KEY([Ref])
REFERENCES [dbo].[Clause] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Clause]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Content_Clause] FOREIGN KEY([Ref])
REFERENCES [dbo].[Clause] ([Content])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Content_Clause]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_NatureCode_CommodityClassification] FOREIGN KEY([Ref])
REFERENCES [dbo].[CommodityClassification] ([NatureCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_NatureCode_CommodityClassification]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CargoTypeCode_CommodityClassification] FOREIGN KEY([Ref])
REFERENCES [dbo].[CommodityClassification] ([CargoTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CargoTypeCode_CommodityClassification]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CommodityCode_CommodityClassification] FOREIGN KEY([Ref])
REFERENCES [dbo].[CommodityClassification] ([CommodityCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CommodityCode_CommodityClassification]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ItemClassificationCode_CommodityClassification] FOREIGN KEY([Ref])
REFERENCES [dbo].[CommodityClassification] ([ItemClassificationCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ItemClassificationCode_CommodityClassification]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ChannelCode_Communication] FOREIGN KEY([Ref])
REFERENCES [dbo].[Communication] ([ChannelCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ChannelCode_Communication]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Channel_Communication] FOREIGN KEY([Ref])
REFERENCES [dbo].[Communication] ([Channel])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Channel_Communication]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Value_Communication] FOREIGN KEY([Ref])
REFERENCES [dbo].[Communication] ([Value])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Value_Communication]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_AnnualAverageAmount_CompletedTask] FOREIGN KEY([Ref])
REFERENCES [dbo].[CompletedTask] ([AnnualAverageAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_AnnualAverageAmount_CompletedTask]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalTaskAmount_CompletedTask] FOREIGN KEY([Ref])
REFERENCES [dbo].[CompletedTask] ([TotalTaskAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalTaskAmount_CompletedTask]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PartyCapacityAmount_CompletedTask] FOREIGN KEY([Ref])
REFERENCES [dbo].[CompletedTask] ([PartyCapacityAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PartyCapacityAmount_CompletedTask]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_CompletedTask] FOREIGN KEY([Ref])
REFERENCES [dbo].[CompletedTask] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_CompletedTask]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_AttributeID_Condition] FOREIGN KEY([Ref])
REFERENCES [dbo].[Condition] ([AttributeID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_AttributeID_Condition]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_Measure_Condition] FOREIGN KEY([Ref])
REFERENCES [dbo].[Condition] ([Measure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_Measure_Condition]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Condition] FOREIGN KEY([Ref])
REFERENCES [dbo].[Condition] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Condition]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_MinimumMeasure_Condition] FOREIGN KEY([Ref])
REFERENCES [dbo].[Condition] ([MinimumMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_MinimumMeasure_Condition]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_MaximumMeasure_Condition] FOREIGN KEY([Ref])
REFERENCES [dbo].[Condition] ([MaximumMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_MaximumMeasure_Condition]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Consignment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CarrierAssignedID_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([CarrierAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CarrierAssignedID_Consignment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ConsigneeAssignedID_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ConsigneeAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ConsigneeAssignedID_Consignment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ConsignorAssignedID_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ConsignorAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ConsignorAssignedID_Consignment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_FreightForwarderAssignedID_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([FreightForwarderAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_FreightForwarderAssignedID_Consignment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_BrokerAssignedID_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([BrokerAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_BrokerAssignedID_Consignment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ContractedCarrierAssignedID_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ContractedCarrierAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ContractedCarrierAssignedID_Consignment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_PerformingCarrierAssignedID_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([PerformingCarrierAssignedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_PerformingCarrierAssignedID_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_SummaryDescription_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([SummaryDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_SummaryDescription_Consignment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalInvoiceAmount_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([TotalInvoiceAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalInvoiceAmount_Consignment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredCustomsValueAmount_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([DeclaredCustomsValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredCustomsValueAmount_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TariffDescription_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([TariffDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TariffDescription_Consignment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TariffCode_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([TariffCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TariffCode_Consignment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_InsurancePremiumAmount_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([InsurancePremiumAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_InsurancePremiumAmount_Consignment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_GrossWeightMeasure_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([GrossWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_GrossWeightMeasure_Consignment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetWeightMeasure_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([NetWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetWeightMeasure_Consignment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetNetWeightMeasure_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([NetNetWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetNetWeightMeasure_Consignment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_ChargeableWeightMeasure_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ChargeableWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_ChargeableWeightMeasure_Consignment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_GrossVolumeMeasure_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([GrossVolumeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_GrossVolumeMeasure_Consignment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetVolumeMeasure_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([NetVolumeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetVolumeMeasure_Consignment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_LoadingLengthMeasure_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([LoadingLengthMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_LoadingLengthMeasure_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Remarks_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([Remarks])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Remarks_Consignment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_HazardousRiskIndicator_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([HazardousRiskIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_HazardousRiskIndicator_Consignment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_AnimalFoodIndicator_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([AnimalFoodIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_AnimalFoodIndicator_Consignment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_HumanFoodIndicator_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([HumanFoodIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_HumanFoodIndicator_Consignment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_LivestockIndicator_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([LivestockIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_LivestockIndicator_Consignment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_BulkCargoIndicator_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([BulkCargoIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_BulkCargoIndicator_Consignment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_ContainerizedIndicator_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ContainerizedIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_ContainerizedIndicator_Consignment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_GeneralCargoIndicator_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([GeneralCargoIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_GeneralCargoIndicator_Consignment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_SpecialSecurityIndicator_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([SpecialSecurityIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_SpecialSecurityIndicator_Consignment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_ThirdPartyPayerIndicator_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ThirdPartyPayerIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_ThirdPartyPayerIndicator_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CarrierServiceInstructions_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([CarrierServiceInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CarrierServiceInstructions_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CustomsClearanceServiceInstructions_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([CustomsClearanceServiceInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CustomsClearanceServiceInstructions_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ForwarderServiceInstructions_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ForwarderServiceInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ForwarderServiceInstructions_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_SpecialServiceInstructions_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([SpecialServiceInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_SpecialServiceInstructions_Consignment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SequenceID_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([SequenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SequenceID_Consignment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ShippingPriorityLevelCode_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ShippingPriorityLevelCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ShippingPriorityLevelCode_Consignment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_HandlingCode_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([HandlingCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_HandlingCode_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_HandlingInstructions_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([HandlingInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_HandlingInstructions_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Information_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([Information])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Information_Consignment]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalGoodsItemQuantity_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([TotalGoodsItemQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalGoodsItemQuantity_Consignment]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalTransportHandlingUnitQuantity_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([TotalTransportHandlingUnitQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalTransportHandlingUnitQuantity_Consignment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_InsuranceValueAmount_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([InsuranceValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_InsuranceValueAmount_Consignment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredForCarriageValueAmount_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([DeclaredForCarriageValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredForCarriageValueAmount_Consignment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredStatisticsValueAmount_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([DeclaredStatisticsValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredStatisticsValueAmount_Consignment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_FreeOnBoardValueAmount_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([FreeOnBoardValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_FreeOnBoardValueAmount_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_SpecialInstructions_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([SpecialInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_SpecialInstructions_Consignment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_SplitConsignmentIndicator_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([SplitConsignmentIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_SplitConsignmentIndicator_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DeliveryInstructions_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([DeliveryInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DeliveryInstructions_Consignment]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ConsignmentQuantity_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ConsignmentQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ConsignmentQuantity_Consignment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_ConsolidatableIndicator_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ConsolidatableIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_ConsolidatableIndicator_Consignment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_HaulageInstructions_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([HaulageInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_HaulageInstructions_Consignment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_LoadingSequenceID_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([LoadingSequenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_LoadingSequenceID_Consignment]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ChildConsignmentQuantity_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([ChildConsignmentQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ChildConsignmentQuantity_Consignment]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalPackagesQuantity_Consignment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consignment] ([TotalPackagesQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalPackagesQuantity_Consignment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_UtilityStatementTypeCode_Consumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[Consumption] ([UtilityStatementTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_UtilityStatementTypeCode_Consumption]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_AverageAmount_ConsumptionAverage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionAverage] ([AverageAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_AverageAmount_ConsumptionAverage]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ConsumptionAverage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionAverage] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ConsumptionAverage]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CorrectionType_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([CorrectionType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CorrectionType_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CorrectionTypeCode_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([CorrectionTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CorrectionTypeCode_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MeterNumber_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([MeterNumber])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MeterNumber_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_GasPressureQuantity_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([GasPressureQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_GasPressureQuantity_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ActualTemperatureReductionQuantity_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([ActualTemperatureReductionQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ActualTemperatureReductionQuantity_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_NormalTemperatureReductionQuantity_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([NormalTemperatureReductionQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_NormalTemperatureReductionQuantity_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_DifferenceTemperatureReductionQuantity_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([DifferenceTemperatureReductionQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_DifferenceTemperatureReductionQuantity_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_CorrectionUnitAmount_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([CorrectionUnitAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_CorrectionUnitAmount_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ConsumptionEnergyQuantity_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([ConsumptionEnergyQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ConsumptionEnergyQuantity_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ConsumptionWaterQuantity_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([ConsumptionWaterQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ConsumptionWaterQuantity_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_CorrectionAmount_ConsumptionCorrection] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionCorrection] ([CorrectionAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_CorrectionAmount_ConsumptionCorrection]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MeterNumber_ConsumptionHistory] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionHistory] ([MeterNumber])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MeterNumber_ConsumptionHistory]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_ConsumptionHistory] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionHistory] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_ConsumptionHistory]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_ConsumptionHistory] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionHistory] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_ConsumptionHistory]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ConsumptionLevelCode_ConsumptionHistory] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionHistory] ([ConsumptionLevelCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ConsumptionLevelCode_ConsumptionHistory]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ConsumptionLevel_ConsumptionHistory] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionHistory] ([ConsumptionLevel])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ConsumptionLevel_ConsumptionHistory]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ConsumptionHistory] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionHistory] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ConsumptionHistory]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ConsumptionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ConsumptionLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ParentDocumentLineReferenceID_ConsumptionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionLine] ([ParentDocumentLineReferenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ParentDocumentLineReferenceID_ConsumptionLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_InvoicedQuantity_ConsumptionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionLine] ([InvoicedQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_InvoicedQuantity_ConsumptionLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LineExtensionAmount_ConsumptionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionLine] ([LineExtensionAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LineExtensionAmount_ConsumptionLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ConsumptionPoint] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionPoint] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ConsumptionPoint]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ConsumptionPoint] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionPoint] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ConsumptionPoint]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SubscriberID_ConsumptionPoint] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionPoint] ([SubscriberID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SubscriberID_ConsumptionPoint]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_SubscriberType_ConsumptionPoint] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionPoint] ([SubscriberType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_SubscriberType_ConsumptionPoint]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SubscriberTypeCode_ConsumptionPoint] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionPoint] ([SubscriberTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SubscriberTypeCode_ConsumptionPoint]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalDeliveredQuantity_ConsumptionPoint] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionPoint] ([TotalDeliveredQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalDeliveredQuantity_ConsumptionPoint]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ConsumptionReport]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ConsumptionType_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([ConsumptionType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ConsumptionType_ConsumptionReport]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ConsumptionTypeCode_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([ConsumptionTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ConsumptionTypeCode_ConsumptionReport]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ConsumptionReport]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalConsumedQuantity_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([TotalConsumedQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalConsumedQuantity_ConsumptionReport]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_BasicConsumedQuantity_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([BasicConsumedQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_BasicConsumedQuantity_ConsumptionReport]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_ResidentOccupantsNumeric_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([ResidentOccupantsNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_ResidentOccupantsNumeric_ConsumptionReport]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ConsumersEnergyLevelCode_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([ConsumersEnergyLevelCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ConsumersEnergyLevelCode_ConsumptionReport]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ConsumersEnergyLevel_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([ConsumersEnergyLevel])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ConsumersEnergyLevel_ConsumptionReport]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ResidenceType_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([ResidenceType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ResidenceType_ConsumptionReport]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ResidenceTypeCode_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([ResidenceTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ResidenceTypeCode_ConsumptionReport]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_HeatingType_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([HeatingType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_HeatingType_ConsumptionReport]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_HeatingTypeCode_ConsumptionReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReport] ([HeatingTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_HeatingTypeCode_ConsumptionReport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ConsumptionReportID_ConsumptionReportReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReportReference] ([ConsumptionReportID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ConsumptionReportID_ConsumptionReportReference]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ConsumptionType_ConsumptionReportReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReportReference] ([ConsumptionType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ConsumptionType_ConsumptionReportReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ConsumptionTypeCode_ConsumptionReportReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReportReference] ([ConsumptionTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ConsumptionTypeCode_ConsumptionReportReference]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalConsumedQuantity_ConsumptionReportReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ConsumptionReportReference] ([TotalConsumedQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalConsumedQuantity_ConsumptionReportReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Contact] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contact] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Contact]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_Contact] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contact] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_Contact]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Telephone_Contact] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contact] ([Telephone])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Telephone_Contact]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Telefax_Contact] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contact] ([Telefax])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Telefax_Contact]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ElectronicMail_Contact] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contact] ([ElectronicMail])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ElectronicMail_Contact]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Contact] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contact] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Contact]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Contract]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_Contract]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_Contract]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_NominationDate_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([NominationDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_NominationDate_Contract]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_NominationTime_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([NominationTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_NominationTime_Contract]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ContractTypeCode_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([ContractTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ContractTypeCode_Contract]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ContractType_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([ContractType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ContractType_Contract]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Contract]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_Contract]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Contract] FOREIGN KEY([Ref])
REFERENCES [dbo].[Contract] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Contract]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_ContractExecutionRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractExecutionRequirement] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_ContractExecutionRequirement]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ExecutionRequirementCode_ContractExecutionRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractExecutionRequirement] ([ExecutionRequirementCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ExecutionRequirementCode_ContractExecutionRequirement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ContractExecutionRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractExecutionRequirement] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ContractExecutionRequirement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OptionsDescription_ContractExtension] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractExtension] ([OptionsDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OptionsDescription_ContractExtension]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_MinimumNumberNumeric_ContractExtension] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractExtension] ([MinimumNumberNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_MinimumNumberNumeric_ContractExtension]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_MaximumNumberNumeric_ContractExtension] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractExtension] ([MaximumNumberNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_MaximumNumberNumeric_ContractExtension]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ActivityTypeCode_ContractingActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractingActivity] ([ActivityTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ActivityTypeCode_ContractingActivity]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ActivityType_ContractingActivity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractingActivity] ([ActivityType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ActivityType_ContractingActivity]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_BuyerProfileURI_ContractingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractingParty] ([BuyerProfileURI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_BuyerProfileURI_ContractingParty]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PartyTypeCode_ContractingPartyType] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractingPartyType] ([PartyTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PartyTypeCode_ContractingPartyType]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PartyType_ContractingPartyType] FOREIGN KEY([Ref])
REFERENCES [dbo].[ContractingPartyType] ([PartyType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PartyType_ContractingPartyType]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CorporateRegistrationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[CorporateRegistrationScheme] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CorporateRegistrationScheme]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_CorporateRegistrationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[CorporateRegistrationScheme] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_CorporateRegistrationScheme]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CorporateRegistrationTypeCode_CorporateRegistrationScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[CorporateRegistrationScheme] ([CorporateRegistrationTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CorporateRegistrationTypeCode_CorporateRegistrationScheme]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_IdentificationCode_Country] FOREIGN KEY([Ref])
REFERENCES [dbo].[Country] ([IdentificationCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_IdentificationCode_Country]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_Country] FOREIGN KEY([Ref])
REFERENCES [dbo].[Country] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_Country]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_AccountID_CreditAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditAccount] ([AccountID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_AccountID_CreditAccount]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CreditNoteLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_CreditNoteLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_CreditNoteLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_CreditedQuantity_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([CreditedQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_CreditedQuantity_CreditNoteLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LineExtensionAmount_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([LineExtensionAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LineExtensionAmount_CreditNoteLine]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_TaxPointDate_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([TaxPointDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_TaxPointDate_CreditNoteLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_CreditNoteLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_CreditNoteLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentPurposeCode_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([PaymentPurposeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentPurposeCode_CreditNoteLine]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_FreeOfChargeIndicator_CreditNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[CreditNoteLine] ([FreeOfChargeIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_FreeOfChargeIndicator_CreditNoteLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomerAssignedAccountID_CustomerParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[CustomerParty] ([CustomerAssignedAccountID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomerAssignedAccountID_CustomerParty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SupplierAssignedAccountID_CustomerParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[CustomerParty] ([SupplierAssignedAccountID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SupplierAssignedAccountID_CustomerParty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_AdditionalAccountID_CustomerParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[CustomerParty] ([AdditionalAccountID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_AdditionalAccountID_CustomerParty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_CustomsDeclaration] FOREIGN KEY([Ref])
REFERENCES [dbo].[CustomsDeclaration] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_CustomsDeclaration]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_DebitNoteLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_DebitNoteLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_DebitNoteLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_DebitedQuantity_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([DebitedQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_DebitedQuantity_DebitNoteLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LineExtensionAmount_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([LineExtensionAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LineExtensionAmount_DebitNoteLine]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_TaxPointDate_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([TaxPointDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_TaxPointDate_DebitNoteLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_DebitNoteLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_DebitNoteLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentPurposeCode_DebitNoteLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DebitNoteLine] ([PaymentPurposeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentPurposeCode_DebitNoteLine]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_Declaration] FOREIGN KEY([Ref])
REFERENCES [dbo].[Declaration] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_Declaration]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DeclarationTypeCode_Declaration] FOREIGN KEY([Ref])
REFERENCES [dbo].[Declaration] ([DeclarationTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DeclarationTypeCode_Declaration]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Declaration] FOREIGN KEY([Ref])
REFERENCES [dbo].[Declaration] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Declaration]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Delivery]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_Delivery]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MinimumQuantity_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([MinimumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MinimumQuantity_Delivery]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MaximumQuantity_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([MaximumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MaximumQuantity_Delivery]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ActualDeliveryDate_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([ActualDeliveryDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ActualDeliveryDate_Delivery]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ActualDeliveryTime_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([ActualDeliveryTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ActualDeliveryTime_Delivery]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_LatestDeliveryDate_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([LatestDeliveryDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_LatestDeliveryDate_Delivery]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_LatestDeliveryTime_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([LatestDeliveryTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_LatestDeliveryTime_Delivery]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ReleaseID_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([ReleaseID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ReleaseID_Delivery]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TrackingID_Delivery] FOREIGN KEY([Ref])
REFERENCES [dbo].[Delivery] ([TrackingID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TrackingID_Delivery]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_DeliveryTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[DeliveryTerms] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_DeliveryTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_SpecialTerms_DeliveryTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[DeliveryTerms] ([SpecialTerms])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_SpecialTerms_DeliveryTerms]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LossRiskResponsibilityCode_DeliveryTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[DeliveryTerms] ([LossRiskResponsibilityCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LossRiskResponsibilityCode_DeliveryTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_LossRisk_DeliveryTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[DeliveryTerms] ([LossRisk])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_LossRisk_DeliveryTerms]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_DeliveryTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[DeliveryTerms] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_DeliveryTerms]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_BatchQuantity_DeliveryUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[DeliveryUnit] ([BatchQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_BatchQuantity_DeliveryUnit]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ConsumerUnitQuantity_DeliveryUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[DeliveryUnit] ([ConsumerUnitQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ConsumerUnitQuantity_DeliveryUnit]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_HazardousRiskIndicator_DeliveryUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[DeliveryUnit] ([HazardousRiskIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_HazardousRiskIndicator_DeliveryUnit]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_Percent_DependentPriceReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DependentPriceReference] ([Percent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_Percent_DependentPriceReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Despatch]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_RequestedDespatchDate_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([RequestedDespatchDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_RequestedDespatchDate_Despatch]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_RequestedDespatchTime_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([RequestedDespatchTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_RequestedDespatchTime_Despatch]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_EstimatedDespatchDate_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([EstimatedDespatchDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_EstimatedDespatchDate_Despatch]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_EstimatedDespatchTime_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([EstimatedDespatchTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_EstimatedDespatchTime_Despatch]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ActualDespatchDate_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([ActualDespatchDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ActualDespatchDate_Despatch]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ActualDespatchTime_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([ActualDespatchTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ActualDespatchTime_Despatch]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_GuaranteedDespatchDate_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([GuaranteedDespatchDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_GuaranteedDespatchDate_Despatch]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_GuaranteedDespatchTime_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([GuaranteedDespatchTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_GuaranteedDespatchTime_Despatch]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ReleaseID_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([ReleaseID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ReleaseID_Despatch]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Instructions_Despatch] FOREIGN KEY([Ref])
REFERENCES [dbo].[Despatch] ([Instructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Instructions_Despatch]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_DespatchLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_DespatchLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_DespatchLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LineStatusCode_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([LineStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LineStatusCode_DespatchLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_DeliveredQuantity_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([DeliveredQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_DeliveredQuantity_DespatchLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_BackorderQuantity_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([BackorderQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_BackorderQuantity_DespatchLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_BackorderReason_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([BackorderReason])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_BackorderReason_DespatchLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_OutstandingQuantity_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([OutstandingQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_OutstandingQuantity_DespatchLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OutstandingReason_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([OutstandingReason])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OutstandingReason_DespatchLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_OversupplyQuantity_DespatchLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[DespatchLine] ([OversupplyQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_OversupplyQuantity_DespatchLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_AttributeID_Dimension] FOREIGN KEY([Ref])
REFERENCES [dbo].[Dimension] ([AttributeID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_AttributeID_Dimension]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_Measure_Dimension] FOREIGN KEY([Ref])
REFERENCES [dbo].[Dimension] ([Measure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_Measure_Dimension]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Dimension] FOREIGN KEY([Ref])
REFERENCES [dbo].[Dimension] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Dimension]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_MinimumMeasure_Dimension] FOREIGN KEY([Ref])
REFERENCES [dbo].[Dimension] ([MinimumMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_MinimumMeasure_Dimension]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_MaximumMeasure_Dimension] FOREIGN KEY([Ref])
REFERENCES [dbo].[Dimension] ([MaximumMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_MaximumMeasure_Dimension]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PrintQualifier_DocumentDistribution] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentDistribution] ([PrintQualifier])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PrintQualifier_DocumentDistribution]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_MaximumCopiesNumeric_DocumentDistribution] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentDistribution] ([MaximumCopiesNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_MaximumCopiesNumeric_DocumentDistribution]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_DocumentReference]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_DocumentReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_DocumentReference]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_DocumentReference]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_DocumentReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentTypeCode_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([DocumentTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentTypeCode_DocumentReference]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DocumentType_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([DocumentType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DocumentType_DocumentReference]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_XPath_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([XPath])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_XPath_DocumentReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_LanguageID_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([LanguageID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_LanguageID_DocumentReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LocaleCode_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([LocaleCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LocaleCode_DocumentReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VersionID_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([VersionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VersionID_DocumentReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DocumentStatusCode_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([DocumentStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DocumentStatusCode_DocumentReference]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DocumentDescription_DocumentReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[DocumentReference] ([DocumentDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DocumentDescription_DocumentReference]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_Duty] FOREIGN KEY([Ref])
REFERENCES [dbo].[Duty] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_Duty]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Duty_Duty] FOREIGN KEY([Ref])
REFERENCES [dbo].[Duty] ([Duty])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Duty_Duty]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DutyCode_Duty] FOREIGN KEY([Ref])
REFERENCES [dbo].[Duty] ([DutyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DutyCode_Duty]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_RoleCode_EconomicOperatorRole] FOREIGN KEY([Ref])
REFERENCES [dbo].[EconomicOperatorRole] ([RoleCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_RoleCode_EconomicOperatorRole]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_RoleDescription_EconomicOperatorRole] FOREIGN KEY([Ref])
REFERENCES [dbo].[EconomicOperatorRole] ([RoleDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_RoleDescription_EconomicOperatorRole]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_LimitationDescription_EconomicOperatorShortList] FOREIGN KEY([Ref])
REFERENCES [dbo].[EconomicOperatorShortList] ([LimitationDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_LimitationDescription_EconomicOperatorShortList]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ExpectedQuantity_EconomicOperatorShortList] FOREIGN KEY([Ref])
REFERENCES [dbo].[EconomicOperatorShortList] ([ExpectedQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ExpectedQuantity_EconomicOperatorShortList]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MaximumQuantity_EconomicOperatorShortList] FOREIGN KEY([Ref])
REFERENCES [dbo].[EconomicOperatorShortList] ([MaximumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MaximumQuantity_EconomicOperatorShortList]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MinimumQuantity_EconomicOperatorShortList] FOREIGN KEY([Ref])
REFERENCES [dbo].[EconomicOperatorShortList] ([MinimumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MinimumQuantity_EconomicOperatorShortList]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CalculationMethodCode_EmissionCalculationMethod] FOREIGN KEY([Ref])
REFERENCES [dbo].[EmissionCalculationMethod] ([CalculationMethodCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CalculationMethodCode_EmissionCalculationMethod]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_FullnessIndicationCode_EmissionCalculationMethod] FOREIGN KEY([Ref])
REFERENCES [dbo].[EmissionCalculationMethod] ([FullnessIndicationCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_FullnessIndicationCode_EmissionCalculationMethod]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_DocumentID_Endorsement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Endorsement] ([DocumentID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_DocumentID_Endorsement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ApprovalStatus_Endorsement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Endorsement] ([ApprovalStatus])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ApprovalStatus_Endorsement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Remarks_Endorsement] FOREIGN KEY([Ref])
REFERENCES [dbo].[Endorsement] ([Remarks])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Remarks_Endorsement]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_RoleCode_EndorserParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[EndorserParty] ([RoleCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_RoleCode_EndorserParty]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_SequenceNumeric_EndorserParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[EndorserParty] ([SequenceNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_SequenceNumeric_EndorserParty]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TaxEnergyAmount_EnergyTaxReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnergyTaxReport] ([TaxEnergyAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TaxEnergyAmount_EnergyTaxReport]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TaxEnergyOnAccountAmount_EnergyTaxReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnergyTaxReport] ([TaxEnergyOnAccountAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TaxEnergyOnAccountAmount_EnergyTaxReport]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TaxEnergyBalanceAmount_EnergyTaxReport] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnergyTaxReport] ([TaxEnergyBalanceAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TaxEnergyBalanceAmount_EnergyTaxReport]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_EnvironmentalEmissionTypeCode_EnvironmentalEmission] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnvironmentalEmission] ([EnvironmentalEmissionTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_EnvironmentalEmissionTypeCode_EnvironmentalEmission]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_ValueMeasure_EnvironmentalEmission] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnvironmentalEmission] ([ValueMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_ValueMeasure_EnvironmentalEmission]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_EnvironmentalEmission] FOREIGN KEY([Ref])
REFERENCES [dbo].[EnvironmentalEmission] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_EnvironmentalEmission]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_EvaluationCriterionTypeCode_EvaluationCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[EvaluationCriterion] ([EvaluationCriterionTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_EvaluationCriterionTypeCode_EvaluationCriterion]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_EvaluationCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[EvaluationCriterion] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_EvaluationCriterion]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_ThresholdAmount_EvaluationCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[EvaluationCriterion] ([ThresholdAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_ThresholdAmount_EvaluationCriterion]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ThresholdQuantity_EvaluationCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[EvaluationCriterion] ([ThresholdQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ThresholdQuantity_EvaluationCriterion]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ExpressionCode_EvaluationCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[EvaluationCriterion] ([ExpressionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ExpressionCode_EvaluationCriterion]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Expression_EvaluationCriterion] FOREIGN KEY([Ref])
REFERENCES [dbo].[EvaluationCriterion] ([Expression])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Expression_EvaluationCriterion]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_IdentificationID_Event] FOREIGN KEY([Ref])
REFERENCES [dbo].[Event] ([IdentificationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_IdentificationID_Event]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_OccurrenceDate_Event] FOREIGN KEY([Ref])
REFERENCES [dbo].[Event] ([OccurrenceDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_OccurrenceDate_Event]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_OccurrenceTime_Event] FOREIGN KEY([Ref])
REFERENCES [dbo].[Event] ([OccurrenceTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_OccurrenceTime_Event]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TypeCode_Event] FOREIGN KEY([Ref])
REFERENCES [dbo].[Event] ([TypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TypeCode_Event]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Event] FOREIGN KEY([Ref])
REFERENCES [dbo].[Event] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Event]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CompletionIndicator_Event] FOREIGN KEY([Ref])
REFERENCES [dbo].[Event] ([CompletionIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CompletionIndicator_Event]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Comment_EventComment] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventComment] ([Comment])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Comment_EventComment]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_EventComment] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventComment] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_EventComment]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_EventComment] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventComment] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_EventComment]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_LineNumberNumeric_EventLineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventLineItem] ([LineNumberNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_LineNumberNumeric_EventLineItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Comment_EventTactic] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventTactic] ([Comment])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Comment_EventTactic]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_EventTactic] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventTactic] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_EventTactic]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ConsumerIncentiveTacticTypeCode_EventTacticEnumeration] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventTacticEnumeration] ([ConsumerIncentiveTacticTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ConsumerIncentiveTacticTypeCode_EventTacticEnumeration]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DisplayTacticTypeCode_EventTacticEnumeration] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventTacticEnumeration] ([DisplayTacticTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DisplayTacticTypeCode_EventTacticEnumeration]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_FeatureTacticTypeCode_EventTacticEnumeration] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventTacticEnumeration] ([FeatureTacticTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_FeatureTacticTypeCode_EventTacticEnumeration]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TradeItemPackingLabelingTypeCode_EventTacticEnumeration] FOREIGN KEY([Ref])
REFERENCES [dbo].[EventTacticEnumeration] ([TradeItemPackingLabelingTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TradeItemPackingLabelingTypeCode_EventTacticEnumeration]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Evidence] FOREIGN KEY([Ref])
REFERENCES [dbo].[Evidence] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Evidence]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_EvidenceTypeCode_Evidence] FOREIGN KEY([Ref])
REFERENCES [dbo].[Evidence] ([EvidenceTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_EvidenceTypeCode_Evidence]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Evidence] FOREIGN KEY([Ref])
REFERENCES [dbo].[Evidence] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Evidence]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CandidateStatement_Evidence] FOREIGN KEY([Ref])
REFERENCES [dbo].[Evidence] ([CandidateStatement])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CandidateStatement_Evidence]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_EvidenceSupplied] FOREIGN KEY([Ref])
REFERENCES [dbo].[EvidenceSupplied] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_EvidenceSupplied]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ThresholdValueComparisonCode_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([ThresholdValueComparisonCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ThresholdValueComparisonCode_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ThresholdQuantity_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([ThresholdQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ThresholdQuantity_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ExceptionStatusCode_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([ExceptionStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ExceptionStatusCode_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CollaborationPriorityCode_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([CollaborationPriorityCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CollaborationPriorityCode_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ExceptionResolutionCode_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([ExceptionResolutionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ExceptionResolutionCode_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SupplyChainActivityTypeCode_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([SupplyChainActivityTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SupplyChainActivityTypeCode_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PerformanceMetricTypeCode_ExceptionCriteriaLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionCriteriaLine] ([PerformanceMetricTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PerformanceMetricTypeCode_ExceptionCriteriaLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ExceptionStatusCode_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([ExceptionStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ExceptionStatusCode_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CollaborationPriorityCode_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([CollaborationPriorityCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CollaborationPriorityCode_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ResolutionCode_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([ResolutionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ResolutionCode_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_ComparedValueMeasure_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([ComparedValueMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_ComparedValueMeasure_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_SourceValueMeasure_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([SourceValueMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_SourceValueMeasure_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_VarianceQuantity_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([VarianceQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_VarianceQuantity_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SupplyChainActivityTypeCode_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([SupplyChainActivityTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SupplyChainActivityTypeCode_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PerformanceMetricTypeCode_ExceptionNotificationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExceptionNotificationLine] ([PerformanceMetricTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PerformanceMetricTypeCode_ExceptionNotificationLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SourceCurrencyCode_ExchangeRate] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExchangeRate] ([SourceCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SourceCurrencyCode_ExchangeRate]
GO
ALTER TABLE [dbo].[Rate] WITH CHECK ADD CONSTRAINT [FK_SourceCurrencyBaseRate_ExchangeRate] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExchangeRate] ([SourceCurrencyBaseRate])
GO
ALTER TABLE [dbo].[Rate] CHECK CONSTRAINT [FK_SourceCurrencyBaseRate_ExchangeRate]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TargetCurrencyCode_ExchangeRate] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExchangeRate] ([TargetCurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TargetCurrencyCode_ExchangeRate]
GO
ALTER TABLE [dbo].[Rate] WITH CHECK ADD CONSTRAINT [FK_TargetCurrencyBaseRate_ExchangeRate] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExchangeRate] ([TargetCurrencyBaseRate])
GO
ALTER TABLE [dbo].[Rate] CHECK CONSTRAINT [FK_TargetCurrencyBaseRate_ExchangeRate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ExchangeMarketID_ExchangeRate] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExchangeRate] ([ExchangeMarketID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ExchangeMarketID_ExchangeRate]
GO
ALTER TABLE [dbo].[Rate] WITH CHECK ADD CONSTRAINT [FK_CalculationRate_ExchangeRate] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExchangeRate] ([CalculationRate])
GO
ALTER TABLE [dbo].[Rate] CHECK CONSTRAINT [FK_CalculationRate_ExchangeRate]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_MathematicOperatorCode_ExchangeRate] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExchangeRate] ([MathematicOperatorCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_MathematicOperatorCode_ExchangeRate]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_Date_ExchangeRate] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExchangeRate] ([Date])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_Date_ExchangeRate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_URI_ExternalReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExternalReference] ([URI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_URI_ExternalReference]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DocumentHash_ExternalReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExternalReference] ([DocumentHash])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DocumentHash_ExternalReference]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_HashAlgorithmMethod_ExternalReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExternalReference] ([HashAlgorithmMethod])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_HashAlgorithmMethod_ExternalReference]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ExpiryDate_ExternalReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExternalReference] ([ExpiryDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ExpiryDate_ExternalReference]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ExpiryTime_ExternalReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExternalReference] ([ExpiryTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ExpiryTime_ExternalReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_MimeCode_ExternalReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExternalReference] ([MimeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_MimeCode_ExternalReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_FormatCode_ExternalReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExternalReference] ([FormatCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_FormatCode_ExternalReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_EncodingCode_ExternalReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExternalReference] ([EncodingCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_EncodingCode_ExternalReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CharacterSetCode_ExternalReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExternalReference] ([CharacterSetCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CharacterSetCode_ExternalReference]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_FileName_ExternalReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExternalReference] ([FileName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_FileName_ExternalReference]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ExternalReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ExternalReference] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ExternalReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_FinancialAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialAccount] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_FinancialAccount]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_FinancialAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialAccount] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_FinancialAccount]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_AliasName_FinancialAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialAccount] ([AliasName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_AliasName_FinancialAccount]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountTypeCode_FinancialAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialAccount] ([AccountTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountTypeCode_FinancialAccount]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountFormatCode_FinancialAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialAccount] ([AccountFormatCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountFormatCode_FinancialAccount]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CurrencyCode_FinancialAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialAccount] ([CurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CurrencyCode_FinancialAccount]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PaymentNote_FinancialAccount] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialAccount] ([PaymentNote])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PaymentNote_FinancialAccount]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_GuaranteeTypeCode_FinancialGuarantee] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialGuarantee] ([GuaranteeTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_GuaranteeTypeCode_FinancialGuarantee]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_FinancialGuarantee] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialGuarantee] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_FinancialGuarantee]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LiabilityAmount_FinancialGuarantee] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialGuarantee] ([LiabilityAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LiabilityAmount_FinancialGuarantee]
GO
ALTER TABLE [dbo].[Rate] WITH CHECK ADD CONSTRAINT [FK_AmountRate_FinancialGuarantee] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialGuarantee] ([AmountRate])
GO
ALTER TABLE [dbo].[Rate] CHECK CONSTRAINT [FK_AmountRate_FinancialGuarantee]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_FinancialInstitution] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialInstitution] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_FinancialInstitution]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_FinancialInstitution] FOREIGN KEY([Ref])
REFERENCES [dbo].[FinancialInstitution] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_FinancialInstitution]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ForecastPurposeCode_ForecastException] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastException] ([ForecastPurposeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ForecastPurposeCode_ForecastException]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ForecastTypeCode_ForecastException] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastException] ([ForecastTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ForecastTypeCode_ForecastException]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ForecastException] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastException] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ForecastException]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_ForecastException] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastException] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_ForecastException]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DataSourceCode_ForecastException] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastException] ([DataSourceCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DataSourceCode_ForecastException]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ComparisonDataCode_ForecastException] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastException] ([ComparisonDataCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ComparisonDataCode_ForecastException]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ComparisonForecastIssueTime_ForecastException] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastException] ([ComparisonForecastIssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ComparisonForecastIssueTime_ForecastException]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ComparisonForecastIssueDate_ForecastException] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastException] ([ComparisonForecastIssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ComparisonForecastIssueDate_ForecastException]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ForecastPurposeCode_ForecastExceptionCriterionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastExceptionCriterionLine] ([ForecastPurposeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ForecastPurposeCode_ForecastExceptionCriterionLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ForecastTypeCode_ForecastExceptionCriterionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastExceptionCriterionLine] ([ForecastTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ForecastTypeCode_ForecastExceptionCriterionLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ComparisonDataSourceCode_ForecastExceptionCriterionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastExceptionCriterionLine] ([ComparisonDataSourceCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ComparisonDataSourceCode_ForecastExceptionCriterionLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DataSourceCode_ForecastExceptionCriterionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastExceptionCriterionLine] ([DataSourceCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DataSourceCode_ForecastExceptionCriterionLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TimeDeltaDaysQuantity_ForecastExceptionCriterionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastExceptionCriterionLine] ([TimeDeltaDaysQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TimeDeltaDaysQuantity_ForecastExceptionCriterionLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ForecastLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ForecastLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ForecastLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ForecastLine]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_FrozenDocumentIndicator_ForecastLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastLine] ([FrozenDocumentIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_FrozenDocumentIndicator_ForecastLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ForecastTypeCode_ForecastLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastLine] ([ForecastTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ForecastTypeCode_ForecastLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ForecastRevisionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevisionLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ForecastRevisionLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ForecastRevisionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevisionLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ForecastRevisionLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ForecastRevisionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevisionLine] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ForecastRevisionLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_RevisedForecastLineID_ForecastRevisionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevisionLine] ([RevisedForecastLineID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_RevisedForecastLineID_ForecastRevisionLine]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_SourceForecastIssueDate_ForecastRevisionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevisionLine] ([SourceForecastIssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_SourceForecastIssueDate_ForecastRevisionLine]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_SourceForecastIssueTime_ForecastRevisionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevisionLine] ([SourceForecastIssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_SourceForecastIssueTime_ForecastRevisionLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AdjustmentReasonCode_ForecastRevisionLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ForecastRevisionLine] ([AdjustmentReasonCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AdjustmentReasonCode_ForecastRevisionLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ExpectedOperatorQuantity_FrameworkAgreement] FOREIGN KEY([Ref])
REFERENCES [dbo].[FrameworkAgreement] ([ExpectedOperatorQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ExpectedOperatorQuantity_FrameworkAgreement]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MaximumOperatorQuantity_FrameworkAgreement] FOREIGN KEY([Ref])
REFERENCES [dbo].[FrameworkAgreement] ([MaximumOperatorQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MaximumOperatorQuantity_FrameworkAgreement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Justification_FrameworkAgreement] FOREIGN KEY([Ref])
REFERENCES [dbo].[FrameworkAgreement] ([Justification])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Justification_FrameworkAgreement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Frequency_FrameworkAgreement] FOREIGN KEY([Ref])
REFERENCES [dbo].[FrameworkAgreement] ([Frequency])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Frequency_FrameworkAgreement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_GoodsItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SequenceNumberID_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([SequenceNumberID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SequenceNumberID_GoodsItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_GoodsItem]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_HazardousRiskIndicator_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([HazardousRiskIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_HazardousRiskIndicator_GoodsItem]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredCustomsValueAmount_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([DeclaredCustomsValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredCustomsValueAmount_GoodsItem]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredForCarriageValueAmount_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([DeclaredForCarriageValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredForCarriageValueAmount_GoodsItem]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredStatisticsValueAmount_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([DeclaredStatisticsValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredStatisticsValueAmount_GoodsItem]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_FreeOnBoardValueAmount_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([FreeOnBoardValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_FreeOnBoardValueAmount_GoodsItem]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_InsuranceValueAmount_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([InsuranceValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_InsuranceValueAmount_GoodsItem]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_ValueAmount_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([ValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_ValueAmount_GoodsItem]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_GrossWeightMeasure_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([GrossWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_GrossWeightMeasure_GoodsItem]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetWeightMeasure_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([NetWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetWeightMeasure_GoodsItem]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetNetWeightMeasure_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([NetNetWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetNetWeightMeasure_GoodsItem]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_ChargeableWeightMeasure_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([ChargeableWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_ChargeableWeightMeasure_GoodsItem]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_GrossVolumeMeasure_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([GrossVolumeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_GrossVolumeMeasure_GoodsItem]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetVolumeMeasure_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([NetVolumeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetVolumeMeasure_GoodsItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_GoodsItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PreferenceCriterionCode_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([PreferenceCriterionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PreferenceCriterionCode_GoodsItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_RequiredCustomsID_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([RequiredCustomsID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_RequiredCustomsID_GoodsItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CustomsStatusCode_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([CustomsStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CustomsStatusCode_GoodsItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_CustomsTariffQuantity_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([CustomsTariffQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_CustomsTariffQuantity_GoodsItem]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CustomsImportClassifiedIndicator_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([CustomsImportClassifiedIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CustomsImportClassifiedIndicator_GoodsItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ChargeableQuantity_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([ChargeableQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ChargeableQuantity_GoodsItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ReturnableQuantity_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([ReturnableQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ReturnableQuantity_GoodsItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TraceID_GoodsItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItem] ([TraceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TraceID_GoodsItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_GoodsItemContainer] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemContainer] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_GoodsItemContainer]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_GoodsItemContainer] FOREIGN KEY([Ref])
REFERENCES [dbo].[GoodsItemContainer] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_GoodsItemContainer]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportEmergencyCardCode_HazardousGoodsTransit] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousGoodsTransit] ([TransportEmergencyCardCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportEmergencyCardCode_HazardousGoodsTransit]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PackingCriteriaCode_HazardousGoodsTransit] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousGoodsTransit] ([PackingCriteriaCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PackingCriteriaCode_HazardousGoodsTransit]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_HazardousRegulationCode_HazardousGoodsTransit] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousGoodsTransit] ([HazardousRegulationCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_HazardousRegulationCode_HazardousGoodsTransit]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_InhalationToxicityZoneCode_HazardousGoodsTransit] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousGoodsTransit] ([InhalationToxicityZoneCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_InhalationToxicityZoneCode_HazardousGoodsTransit]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportAuthorizationCode_HazardousGoodsTransit] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousGoodsTransit] ([TransportAuthorizationCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportAuthorizationCode_HazardousGoodsTransit]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_HazardousItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PlacardNotation_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([PlacardNotation])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PlacardNotation_HazardousItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PlacardEndorsement_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([PlacardEndorsement])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PlacardEndorsement_HazardousItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AdditionalInformation_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([AdditionalInformation])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AdditionalInformation_HazardousItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_UNDGCode_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([UNDGCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_UNDGCode_HazardousItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_EmergencyProceduresCode_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([EmergencyProceduresCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_EmergencyProceduresCode_HazardousItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_MedicalFirstAidGuideCode_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([MedicalFirstAidGuideCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_MedicalFirstAidGuideCode_HazardousItem]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_TechnicalName_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([TechnicalName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_TechnicalName_HazardousItem]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_CategoryName_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([CategoryName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_CategoryName_HazardousItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_HazardousCategoryCode_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([HazardousCategoryCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_HazardousCategoryCode_HazardousItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UpperOrangeHazardPlacardID_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([UpperOrangeHazardPlacardID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UpperOrangeHazardPlacardID_HazardousItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_LowerOrangeHazardPlacardID_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([LowerOrangeHazardPlacardID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_LowerOrangeHazardPlacardID_HazardousItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_MarkingID_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([MarkingID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_MarkingID_HazardousItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_HazardClassID_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([HazardClassID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_HazardClassID_HazardousItem]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetWeightMeasure_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([NetWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetWeightMeasure_HazardousItem]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetVolumeMeasure_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([NetVolumeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetVolumeMeasure_HazardousItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_HazardousItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[HazardousItem] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_HazardousItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ImmobilizationCertificateID_ImmobilizedSecurity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ImmobilizedSecurity] ([ImmobilizationCertificateID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ImmobilizationCertificateID_ImmobilizedSecurity]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SecurityID_ImmobilizedSecurity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ImmobilizedSecurity] ([SecurityID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SecurityID_ImmobilizedSecurity]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ImmobilizedSecurity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ImmobilizedSecurity] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ImmobilizedSecurity]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_FaceValueAmount_ImmobilizedSecurity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ImmobilizedSecurity] ([FaceValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_FaceValueAmount_ImmobilizedSecurity]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_MarketValueAmount_ImmobilizedSecurity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ImmobilizedSecurity] ([MarketValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_MarketValueAmount_ImmobilizedSecurity]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_SharesNumberQuantity_ImmobilizedSecurity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ImmobilizedSecurity] ([SharesNumberQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_SharesNumberQuantity_ImmobilizedSecurity]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_InstructionForReturnsLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturnsLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_InstructionForReturnsLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_InstructionForReturnsLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturnsLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_InstructionForReturnsLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_InstructionForReturnsLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InstructionForReturnsLine] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_InstructionForReturnsLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_InventoryReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReportLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_InventoryReportLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_InventoryReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReportLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_InventoryReportLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_InventoryReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReportLine] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_InventoryReportLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_InventoryValueAmount_InventoryReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReportLine] ([InventoryValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_InventoryValueAmount_InventoryReportLine]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_AvailabilityDate_InventoryReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReportLine] ([AvailabilityDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_AvailabilityDate_InventoryReportLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AvailabilityStatusCode_InventoryReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InventoryReportLine] ([AvailabilityStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AvailabilityStatusCode_InventoryReportLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_InvoiceLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_InvoiceLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_InvoiceLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_InvoicedQuantity_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([InvoicedQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_InvoicedQuantity_InvoiceLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LineExtensionAmount_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([LineExtensionAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LineExtensionAmount_InvoiceLine]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_TaxPointDate_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([TaxPointDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_TaxPointDate_InvoiceLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_InvoiceLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_InvoiceLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentPurposeCode_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([PaymentPurposeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentPurposeCode_InvoiceLine]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_FreeOfChargeIndicator_InvoiceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[InvoiceLine] ([FreeOfChargeIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_FreeOfChargeIndicator_InvoiceLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Item]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_PackQuantity_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([PackQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_PackQuantity_Item]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_PackSizeNumeric_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([PackSizeNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_PackSizeNumeric_Item]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CatalogueIndicator_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([CatalogueIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CatalogueIndicator_Item]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_Item]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_HazardousRiskIndicator_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([HazardousRiskIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_HazardousRiskIndicator_Item]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AdditionalInformation_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([AdditionalInformation])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AdditionalInformation_Item]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Keyword_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([Keyword])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Keyword_Item]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_BrandName_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([BrandName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_BrandName_Item]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_ModelName_Item] FOREIGN KEY([Ref])
REFERENCES [dbo].[Item] ([ModelName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_ModelName_Item]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PriceAmount_ItemComparison] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemComparison] ([PriceAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PriceAmount_ItemComparison]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_ItemComparison] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemComparison] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_ItemComparison]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ItemIdentification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemIdentification] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ItemIdentification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ExtendedID_ItemIdentification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemIdentification] ([ExtendedID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ExtendedID_ItemIdentification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_BarcodeSymbologyID_ItemIdentification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemIdentification] ([BarcodeSymbologyID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_BarcodeSymbologyID_ItemIdentification]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TimeFrequencyCode_ItemInformationRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequestLine] ([TimeFrequencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TimeFrequencyCode_ItemInformationRequestLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SupplyChainActivityTypeCode_ItemInformationRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequestLine] ([SupplyChainActivityTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SupplyChainActivityTypeCode_ItemInformationRequestLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ForecastTypeCode_ItemInformationRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequestLine] ([ForecastTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ForecastTypeCode_ItemInformationRequestLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PerformanceMetricTypeCode_ItemInformationRequestLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInformationRequestLine] ([PerformanceMetricTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PerformanceMetricTypeCode_ItemInformationRequestLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ProductTraceID_ItemInstance] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInstance] ([ProductTraceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ProductTraceID_ItemInstance]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ManufactureDate_ItemInstance] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInstance] ([ManufactureDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ManufactureDate_ItemInstance]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ManufactureTime_ItemInstance] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInstance] ([ManufactureTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ManufactureTime_ItemInstance]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_BestBeforeDate_ItemInstance] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInstance] ([BestBeforeDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_BestBeforeDate_ItemInstance]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_RegistrationID_ItemInstance] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInstance] ([RegistrationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_RegistrationID_ItemInstance]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SerialID_ItemInstance] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemInstance] ([SerialID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SerialID_ItemInstance]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_LeadTimeMeasure_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([LeadTimeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_LeadTimeMeasure_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MinimumQuantity_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([MinimumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MinimumQuantity_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MaximumQuantity_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([MaximumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MaximumQuantity_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_HazardousRiskIndicator_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([HazardousRiskIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_HazardousRiskIndicator_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TradingRestrictions_ItemLocationQuantity] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemLocationQuantity] ([TradingRestrictions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TradingRestrictions_ItemLocationQuantity]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_FrozenPeriodDaysNumeric_ItemManagementProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemManagementProfile] ([FrozenPeriodDaysNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_FrozenPeriodDaysNumeric_ItemManagementProfile]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MinimumInventoryQuantity_ItemManagementProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemManagementProfile] ([MinimumInventoryQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MinimumInventoryQuantity_ItemManagementProfile]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MultipleOrderQuantity_ItemManagementProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemManagementProfile] ([MultipleOrderQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MultipleOrderQuantity_ItemManagementProfile]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_OrderIntervalDaysNumeric_ItemManagementProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemManagementProfile] ([OrderIntervalDaysNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_OrderIntervalDaysNumeric_ItemManagementProfile]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ReplenishmentOwnerDescription_ItemManagementProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemManagementProfile] ([ReplenishmentOwnerDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ReplenishmentOwnerDescription_ItemManagementProfile]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_TargetServicePercent_ItemManagementProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemManagementProfile] ([TargetServicePercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_TargetServicePercent_ItemManagementProfile]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TargetInventoryQuantity_ItemManagementProfile] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemManagementProfile] ([TargetInventoryQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TargetInventoryQuantity_ItemManagementProfile]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ItemProperty]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_ItemProperty]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_NameCode_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([NameCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_NameCode_ItemProperty]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TestMethod_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([TestMethod])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TestMethod_ItemProperty]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Value_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([Value])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Value_ItemProperty]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ValueQuantity_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([ValueQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ValueQuantity_ItemProperty]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ValueQualifier_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([ValueQualifier])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ValueQualifier_ItemProperty]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ImportanceCode_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([ImportanceCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ImportanceCode_ItemProperty]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ListValue_ItemProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemProperty] ([ListValue])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ListValue_ItemProperty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ItemPropertyGroup] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemPropertyGroup] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ItemPropertyGroup]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_ItemPropertyGroup] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemPropertyGroup] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_ItemPropertyGroup]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ImportanceCode_ItemPropertyGroup] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemPropertyGroup] ([ImportanceCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ImportanceCode_ItemPropertyGroup]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MinimumValue_ItemPropertyRange] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemPropertyRange] ([MinimumValue])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MinimumValue_ItemPropertyRange]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MaximumValue_ItemPropertyRange] FOREIGN KEY([Ref])
REFERENCES [dbo].[ItemPropertyRange] ([MaximumValue])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MaximumValue_ItemPropertyRange]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Language] FOREIGN KEY([Ref])
REFERENCES [dbo].[Language] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Language]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_Language] FOREIGN KEY([Ref])
REFERENCES [dbo].[Language] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_Language]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LocaleCode_Language] FOREIGN KEY([Ref])
REFERENCES [dbo].[Language] ([LocaleCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LocaleCode_Language]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_LineItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SalesOrderID_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([SalesOrderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SalesOrderID_LineItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_LineItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_LineItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LineStatusCode_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([LineStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LineStatusCode_LineItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_LineItem]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LineExtensionAmount_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([LineExtensionAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LineExtensionAmount_LineItem]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalTaxAmount_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([TotalTaxAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalTaxAmount_LineItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MinimumQuantity_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([MinimumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MinimumQuantity_LineItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MaximumQuantity_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([MaximumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MaximumQuantity_LineItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MinimumBackorderQuantity_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([MinimumBackorderQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MinimumBackorderQuantity_LineItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MaximumBackorderQuantity_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([MaximumBackorderQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MaximumBackorderQuantity_LineItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_InspectionMethodCode_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([InspectionMethodCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_InspectionMethodCode_LineItem]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_PartialDeliveryIndicator_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([PartialDeliveryIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_PartialDeliveryIndicator_LineItem]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_BackOrderAllowedIndicator_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([BackOrderAllowedIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_BackOrderAllowedIndicator_LineItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_LineItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_LineItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_WarrantyInformation_LineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineItem] ([WarrantyInformation])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_WarrantyInformation_LineItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_LineID_LineReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineReference] ([LineID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_LineID_LineReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_LineReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineReference] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_LineReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LineStatusCode_LineReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[LineReference] ([LineStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LineStatusCode_LineReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Location]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Location]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Conditions_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([Conditions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Conditions_Location]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CountrySubentity_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([CountrySubentity])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CountrySubentity_Location]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CountrySubentityCode_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([CountrySubentityCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CountrySubentityCode_Location]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LocationTypeCode_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([LocationTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LocationTypeCode_Location]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_InformationURI_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([InformationURI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_InformationURI_Location]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_Location] FOREIGN KEY([Ref])
REFERENCES [dbo].[Location] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_Location]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CoordinateSystemCode_LocationCoordinate] FOREIGN KEY([Ref])
REFERENCES [dbo].[LocationCoordinate] ([CoordinateSystemCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CoordinateSystemCode_LocationCoordinate]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_LatitudeDegreesMeasure_LocationCoordinate] FOREIGN KEY([Ref])
REFERENCES [dbo].[LocationCoordinate] ([LatitudeDegreesMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_LatitudeDegreesMeasure_LocationCoordinate]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_LatitudeMinutesMeasure_LocationCoordinate] FOREIGN KEY([Ref])
REFERENCES [dbo].[LocationCoordinate] ([LatitudeMinutesMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_LatitudeMinutesMeasure_LocationCoordinate]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LatitudeDirectionCode_LocationCoordinate] FOREIGN KEY([Ref])
REFERENCES [dbo].[LocationCoordinate] ([LatitudeDirectionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LatitudeDirectionCode_LocationCoordinate]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_LongitudeDegreesMeasure_LocationCoordinate] FOREIGN KEY([Ref])
REFERENCES [dbo].[LocationCoordinate] ([LongitudeDegreesMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_LongitudeDegreesMeasure_LocationCoordinate]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_LongitudeMinutesMeasure_LocationCoordinate] FOREIGN KEY([Ref])
REFERENCES [dbo].[LocationCoordinate] ([LongitudeMinutesMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_LongitudeMinutesMeasure_LocationCoordinate]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LongitudeDirectionCode_LocationCoordinate] FOREIGN KEY([Ref])
REFERENCES [dbo].[LocationCoordinate] ([LongitudeDirectionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LongitudeDirectionCode_LocationCoordinate]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_AltitudeMeasure_LocationCoordinate] FOREIGN KEY([Ref])
REFERENCES [dbo].[LocationCoordinate] ([AltitudeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_AltitudeMeasure_LocationCoordinate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_LotNumberID_LotIdentification] FOREIGN KEY([Ref])
REFERENCES [dbo].[LotIdentification] ([LotNumberID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_LotNumberID_LotIdentification]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ExpiryDate_LotIdentification] FOREIGN KEY([Ref])
REFERENCES [dbo].[LotIdentification] ([ExpiryDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ExpiryDate_LotIdentification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VesselID_MaritimeTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[MaritimeTransport] ([VesselID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VesselID_MaritimeTransport]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_VesselName_MaritimeTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[MaritimeTransport] ([VesselName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_VesselName_MaritimeTransport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_RadioCallSignID_MaritimeTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[MaritimeTransport] ([RadioCallSignID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_RadioCallSignID_MaritimeTransport]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ShipsRequirements_MaritimeTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[MaritimeTransport] ([ShipsRequirements])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ShipsRequirements_MaritimeTransport]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_GrossTonnageMeasure_MaritimeTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[MaritimeTransport] ([GrossTonnageMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_GrossTonnageMeasure_MaritimeTransport]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetTonnageMeasure_MaritimeTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[MaritimeTransport] ([NetTonnageMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetTonnageMeasure_MaritimeTransport]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MeterNumber_Meter] FOREIGN KEY([Ref])
REFERENCES [dbo].[Meter] ([MeterNumber])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MeterNumber_Meter]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MeterName_Meter] FOREIGN KEY([Ref])
REFERENCES [dbo].[Meter] ([MeterName])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MeterName_Meter]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MeterConstant_Meter] FOREIGN KEY([Ref])
REFERENCES [dbo].[Meter] ([MeterConstant])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MeterConstant_Meter]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_MeterConstantCode_Meter] FOREIGN KEY([Ref])
REFERENCES [dbo].[Meter] ([MeterConstantCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_MeterConstantCode_Meter]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalDeliveredQuantity_Meter] FOREIGN KEY([Ref])
REFERENCES [dbo].[Meter] ([TotalDeliveredQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalDeliveredQuantity_Meter]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_MeterProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterProperty] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_MeterProperty]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_NameCode_MeterProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterProperty] ([NameCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_NameCode_MeterProperty]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Value_MeterProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterProperty] ([Value])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Value_MeterProperty]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ValueQuantity_MeterProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterProperty] ([ValueQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ValueQuantity_MeterProperty]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ValueQualifier_MeterProperty] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterProperty] ([ValueQualifier])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ValueQualifier_MeterProperty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_MeterReading]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MeterReadingType_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([MeterReadingType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MeterReadingType_MeterReading]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_MeterReadingTypeCode_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([MeterReadingTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_MeterReadingTypeCode_MeterReading]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_PreviousMeterReadingDate_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([PreviousMeterReadingDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_PreviousMeterReadingDate_MeterReading]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_PreviousMeterQuantity_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([PreviousMeterQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_PreviousMeterQuantity_MeterReading]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_LatestMeterReadingDate_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([LatestMeterReadingDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_LatestMeterReadingDate_MeterReading]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_LatestMeterQuantity_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([LatestMeterQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_LatestMeterQuantity_MeterReading]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PreviousMeterReadingMethod_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([PreviousMeterReadingMethod])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PreviousMeterReadingMethod_MeterReading]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PreviousMeterReadingMethodCode_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([PreviousMeterReadingMethodCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PreviousMeterReadingMethodCode_MeterReading]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_LatestMeterReadingMethod_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([LatestMeterReadingMethod])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_LatestMeterReadingMethod_MeterReading]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LatestMeterReadingMethodCode_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([LatestMeterReadingMethodCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LatestMeterReadingMethodCode_MeterReading]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MeterReadingComments_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([MeterReadingComments])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MeterReadingComments_MeterReading]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_DeliveredQuantity_MeterReading] FOREIGN KEY([Ref])
REFERENCES [dbo].[MeterReading] ([DeliveredQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_DeliveredQuantity_MeterReading]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_MiscellaneousEventTypeCode_MiscellaneousEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[MiscellaneousEvent] ([MiscellaneousEventTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_MiscellaneousEventTypeCode_MiscellaneousEvent]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LineExtensionAmount_MonetaryTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[MonetaryTotal] ([LineExtensionAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LineExtensionAmount_MonetaryTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TaxExclusiveAmount_MonetaryTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[MonetaryTotal] ([TaxExclusiveAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TaxExclusiveAmount_MonetaryTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TaxInclusiveAmount_MonetaryTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[MonetaryTotal] ([TaxInclusiveAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TaxInclusiveAmount_MonetaryTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_AllowanceTotalAmount_MonetaryTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[MonetaryTotal] ([AllowanceTotalAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_AllowanceTotalAmount_MonetaryTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_ChargeTotalAmount_MonetaryTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[MonetaryTotal] ([ChargeTotalAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_ChargeTotalAmount_MonetaryTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PrepaidAmount_MonetaryTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[MonetaryTotal] ([PrepaidAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PrepaidAmount_MonetaryTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PayableRoundingAmount_MonetaryTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[MonetaryTotal] ([PayableRoundingAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PayableRoundingAmount_MonetaryTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PayableAmount_MonetaryTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[MonetaryTotal] ([PayableAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PayableAmount_MonetaryTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PayableAlternativeAmount_MonetaryTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[MonetaryTotal] ([PayableAlternativeAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PayableAlternativeAmount_MonetaryTotal]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_NotificationTypeCode_NotificationRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[NotificationRequirement] ([NotificationTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_NotificationTypeCode_NotificationRequirement]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_PostEventNotificationDurationMeasure_NotificationRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[NotificationRequirement] ([PostEventNotificationDurationMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_PostEventNotificationDurationMeasure_NotificationRequirement]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_PreEventNotificationDurationMeasure_NotificationRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[NotificationRequirement] ([PreEventNotificationDurationMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_PreEventNotificationDurationMeasure_NotificationRequirement]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_EstimatedConsumedQuantity_OnAccountPayment] FOREIGN KEY([Ref])
REFERENCES [dbo].[OnAccountPayment] ([EstimatedConsumedQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_EstimatedConsumedQuantity_OnAccountPayment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_OnAccountPayment] FOREIGN KEY([Ref])
REFERENCES [dbo].[OnAccountPayment] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_OnAccountPayment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SubstitutionStatusCode_OrderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLine] ([SubstitutionStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SubstitutionStatusCode_OrderLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_OrderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_OrderLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_LineID_OrderLineReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLineReference] ([LineID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_LineID_OrderLineReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SalesOrderLineID_OrderLineReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLineReference] ([SalesOrderLineID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SalesOrderLineID_OrderLineReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_OrderLineReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLineReference] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_OrderLineReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_LineStatusCode_OrderLineReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderLineReference] ([LineStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_LineStatusCode_OrderLineReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_OrderReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderReference] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_OrderReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SalesOrderID_OrderReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderReference] ([SalesOrderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SalesOrderID_OrderReference]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CopyIndicator_OrderReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderReference] ([CopyIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CopyIndicator_OrderReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_OrderReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderReference] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_OrderReference]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_OrderReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderReference] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_OrderReference]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_OrderReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderReference] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_OrderReference]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CustomerReference_OrderReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderReference] ([CustomerReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CustomerReference_OrderReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_OrderTypeCode_OrderReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[OrderReference] ([OrderTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_OrderTypeCode_OrderReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Package]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_Package]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_ReturnableMaterialIndicator_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([ReturnableMaterialIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_ReturnableMaterialIndicator_Package]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PackageLevelCode_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([PackageLevelCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PackageLevelCode_Package]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PackagingTypeCode_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([PackagingTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PackagingTypeCode_Package]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PackingMaterial_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([PackingMaterial])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PackingMaterial_Package]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TraceID_Package] FOREIGN KEY([Ref])
REFERENCES [dbo].[Package] ([TraceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TraceID_Package]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_MarkCareIndicator_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([MarkCareIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_MarkCareIndicator_Party]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_MarkAttentionIndicator_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([MarkAttentionIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_MarkAttentionIndicator_Party]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_WebsiteURI_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([WebsiteURI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_WebsiteURI_Party]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_LogoReferenceID_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([LogoReferenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_LogoReferenceID_Party]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_EndpointID_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([EndpointID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_EndpointID_Party]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_IndustryClassificationCode_Party] FOREIGN KEY([Ref])
REFERENCES [dbo].[Party] ([IndustryClassificationCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_IndustryClassificationCode_Party]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_PartyIdentification] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyIdentification] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_PartyIdentification]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_RegistrationName_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([RegistrationName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_RegistrationName_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CompanyID_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([CompanyID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CompanyID_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_RegistrationDate_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([RegistrationDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_RegistrationDate_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_RegistrationExpirationDate_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([RegistrationExpirationDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_RegistrationExpirationDate_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CompanyLegalFormCode_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([CompanyLegalFormCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CompanyLegalFormCode_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CompanyLegalForm_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([CompanyLegalForm])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CompanyLegalForm_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_SoleProprietorshipIndicator_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([SoleProprietorshipIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_SoleProprietorshipIndicator_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CompanyLiquidationStatusCode_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([CompanyLiquidationStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CompanyLiquidationStatusCode_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_CorporateStockAmount_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([CorporateStockAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_CorporateStockAmount_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_FullyPaidSharesIndicator_PartyLegalEntity] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyLegalEntity] ([FullyPaidSharesIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_FullyPaidSharesIndicator_PartyLegalEntity]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_PartyName] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyName] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_PartyName]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_RegistrationName_PartyTaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyTaxScheme] ([RegistrationName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_RegistrationName_PartyTaxScheme]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CompanyID_PartyTaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyTaxScheme] ([CompanyID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CompanyID_PartyTaxScheme]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxLevelCode_PartyTaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyTaxScheme] ([TaxLevelCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxLevelCode_PartyTaxScheme]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ExemptionReasonCode_PartyTaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyTaxScheme] ([ExemptionReasonCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ExemptionReasonCode_PartyTaxScheme]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ExemptionReason_PartyTaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[PartyTaxScheme] ([ExemptionReason])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ExemptionReason_PartyTaxScheme]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Payment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Payment] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Payment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PaidAmount_Payment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Payment] ([PaidAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PaidAmount_Payment]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ReceivedDate_Payment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Payment] ([ReceivedDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ReceivedDate_Payment]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_PaidDate_Payment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Payment] ([PaidDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_PaidDate_Payment]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_PaidTime_Payment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Payment] ([PaidTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_PaidTime_Payment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_InstructionID_Payment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Payment] ([InstructionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_InstructionID_Payment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_PaymentMandate] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMandate] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_PaymentMandate]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_MandateTypeCode_PaymentMandate] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMandate] ([MandateTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_MandateTypeCode_PaymentMandate]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_MaximumPaymentInstructionsNumeric_PaymentMandate] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMandate] ([MaximumPaymentInstructionsNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_MaximumPaymentInstructionsNumeric_PaymentMandate]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_MaximumPaidAmount_PaymentMandate] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMandate] ([MaximumPaidAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_MaximumPaidAmount_PaymentMandate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SignatureID_PaymentMandate] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMandate] ([SignatureID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SignatureID_PaymentMandate]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_PaymentMeans]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentMeansCode_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([PaymentMeansCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentMeansCode_PaymentMeans]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_PaymentDueDate_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([PaymentDueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_PaymentDueDate_PaymentMeans]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentChannelCode_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([PaymentChannelCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentChannelCode_PaymentMeans]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_InstructionID_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([InstructionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_InstructionID_PaymentMeans]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_InstructionNote_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([InstructionNote])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_InstructionNote_PaymentMeans]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_PaymentID_PaymentMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentMeans] ([PaymentID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_PaymentID_PaymentMeans]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_PaymentTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_PaymentMeansID_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([PaymentMeansID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_PaymentMeansID_PaymentTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_PrepaidPaymentReferenceID_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([PrepaidPaymentReferenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_PrepaidPaymentReferenceID_PaymentTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_PaymentTerms]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ReferenceEventCode_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([ReferenceEventCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ReferenceEventCode_PaymentTerms]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_SettlementDiscountPercent_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([SettlementDiscountPercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_SettlementDiscountPercent_PaymentTerms]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_PenaltySurchargePercent_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([PenaltySurchargePercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_PenaltySurchargePercent_PaymentTerms]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_PaymentPercent_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([PaymentPercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_PaymentPercent_PaymentTerms]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_PaymentTerms]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_SettlementDiscountAmount_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([SettlementDiscountAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_SettlementDiscountAmount_PaymentTerms]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PenaltyAmount_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([PenaltyAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PenaltyAmount_PaymentTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_PaymentTermsDetailsURI_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([PaymentTermsDetailsURI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_PaymentTermsDetailsURI_PaymentTerms]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_PaymentDueDate_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([PaymentDueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_PaymentDueDate_PaymentTerms]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_InstallmentDueDate_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([InstallmentDueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_InstallmentDueDate_PaymentTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_InvoicingPartyReference_PaymentTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[PaymentTerms] ([InvoicingPartyReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_InvoicingPartyReference_PaymentTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_PerformanceDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[PerformanceDataLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_PerformanceDataLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_PerformanceDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[PerformanceDataLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_PerformanceDataLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_PerformanceValueQuantity_PerformanceDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[PerformanceDataLine] ([PerformanceValueQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_PerformanceValueQuantity_PerformanceDataLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PerformanceMetricTypeCode_PerformanceDataLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[PerformanceDataLine] ([PerformanceMetricTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PerformanceMetricTypeCode_PerformanceDataLine]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_StartDate_Period] FOREIGN KEY([Ref])
REFERENCES [dbo].[Period] ([StartDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_StartDate_Period]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_StartTime_Period] FOREIGN KEY([Ref])
REFERENCES [dbo].[Period] ([StartTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_StartTime_Period]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_EndDate_Period] FOREIGN KEY([Ref])
REFERENCES [dbo].[Period] ([EndDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_EndDate_Period]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_EndTime_Period] FOREIGN KEY([Ref])
REFERENCES [dbo].[Period] ([EndTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_EndTime_Period]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_DurationMeasure_Period] FOREIGN KEY([Ref])
REFERENCES [dbo].[Period] ([DurationMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_DurationMeasure_Period]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DescriptionCode_Period] FOREIGN KEY([Ref])
REFERENCES [dbo].[Period] ([DescriptionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DescriptionCode_Period]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Period] FOREIGN KEY([Ref])
REFERENCES [dbo].[Period] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Period]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Person]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_FirstName_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([FirstName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_FirstName_Person]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_FamilyName_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([FamilyName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_FamilyName_Person]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Title_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([Title])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Title_Person]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_MiddleName_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([MiddleName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_MiddleName_Person]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_OtherName_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([OtherName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_OtherName_Person]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_NameSuffix_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([NameSuffix])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_NameSuffix_Person]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_JobTitle_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([JobTitle])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_JobTitle_Person]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_NationalityID_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([NationalityID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_NationalityID_Person]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_GenderCode_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([GenderCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_GenderCode_Person]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_BirthDate_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([BirthDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_BirthDate_Person]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_BirthplaceName_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([BirthplaceName])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_BirthplaceName_Person]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OrganizationDepartment_Person] FOREIGN KEY([Ref])
REFERENCES [dbo].[Person] ([OrganizationDepartment])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OrganizationDepartment_Person]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_AttributeID_PhysicalAttribute] FOREIGN KEY([Ref])
REFERENCES [dbo].[PhysicalAttribute] ([AttributeID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_AttributeID_PhysicalAttribute]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PositionCode_PhysicalAttribute] FOREIGN KEY([Ref])
REFERENCES [dbo].[PhysicalAttribute] ([PositionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PositionCode_PhysicalAttribute]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DescriptionCode_PhysicalAttribute] FOREIGN KEY([Ref])
REFERENCES [dbo].[PhysicalAttribute] ([DescriptionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DescriptionCode_PhysicalAttribute]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_PhysicalAttribute] FOREIGN KEY([Ref])
REFERENCES [dbo].[PhysicalAttribute] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_PhysicalAttribute]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Pickup] FOREIGN KEY([Ref])
REFERENCES [dbo].[Pickup] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Pickup]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ActualPickupDate_Pickup] FOREIGN KEY([Ref])
REFERENCES [dbo].[Pickup] ([ActualPickupDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ActualPickupDate_Pickup]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ActualPickupTime_Pickup] FOREIGN KEY([Ref])
REFERENCES [dbo].[Pickup] ([ActualPickupTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ActualPickupTime_Pickup]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_EarliestPickupDate_Pickup] FOREIGN KEY([Ref])
REFERENCES [dbo].[Pickup] ([EarliestPickupDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_EarliestPickupDate_Pickup]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_EarliestPickupTime_Pickup] FOREIGN KEY([Ref])
REFERENCES [dbo].[Pickup] ([EarliestPickupTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_EarliestPickupTime_Pickup]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_LatestPickupDate_Pickup] FOREIGN KEY([Ref])
REFERENCES [dbo].[Pickup] ([LatestPickupDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_LatestPickupDate_Pickup]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_LatestPickupTime_Pickup] FOREIGN KEY([Ref])
REFERENCES [dbo].[Pickup] ([LatestPickupTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_LatestPickupTime_Pickup]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_PowerOfAttorney] FOREIGN KEY([Ref])
REFERENCES [dbo].[PowerOfAttorney] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_PowerOfAttorney]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_PowerOfAttorney] FOREIGN KEY([Ref])
REFERENCES [dbo].[PowerOfAttorney] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_PowerOfAttorney]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_IssueTime_PowerOfAttorney] FOREIGN KEY([Ref])
REFERENCES [dbo].[PowerOfAttorney] ([IssueTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_IssueTime_PowerOfAttorney]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_PowerOfAttorney] FOREIGN KEY([Ref])
REFERENCES [dbo].[PowerOfAttorney] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_PowerOfAttorney]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PriceAmount_Price] FOREIGN KEY([Ref])
REFERENCES [dbo].[Price] ([PriceAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PriceAmount_Price]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_BaseQuantity_Price] FOREIGN KEY([Ref])
REFERENCES [dbo].[Price] ([BaseQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_BaseQuantity_Price]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PriceChangeReason_Price] FOREIGN KEY([Ref])
REFERENCES [dbo].[Price] ([PriceChangeReason])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PriceChangeReason_Price]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PriceTypeCode_Price] FOREIGN KEY([Ref])
REFERENCES [dbo].[Price] ([PriceTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PriceTypeCode_Price]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PriceType_Price] FOREIGN KEY([Ref])
REFERENCES [dbo].[Price] ([PriceType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PriceType_Price]
GO
ALTER TABLE [dbo].[Rate] WITH CHECK ADD CONSTRAINT [FK_OrderableUnitFactorRate_Price] FOREIGN KEY([Ref])
REFERENCES [dbo].[Price] ([OrderableUnitFactorRate])
GO
ALTER TABLE [dbo].[Rate] CHECK CONSTRAINT [FK_OrderableUnitFactorRate_Price]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_PriceExtension] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriceExtension] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_PriceExtension]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_PriceList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriceList] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_PriceList]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_StatusCode_PriceList] FOREIGN KEY([Ref])
REFERENCES [dbo].[PriceList] ([StatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_StatusCode_PriceList]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PreviousCancellationReasonCode_ProcessJustification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcessJustification] ([PreviousCancellationReasonCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PreviousCancellationReasonCode_ProcessJustification]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ProcessReasonCode_ProcessJustification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcessJustification] ([ProcessReasonCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ProcessReasonCode_ProcessJustification]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ProcessReason_ProcessJustification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcessJustification] ([ProcessReason])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ProcessReason_ProcessJustification]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ProcessJustification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcessJustification] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ProcessJustification]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ProcurementProject]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_ProcurementProject]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_ProcurementProject]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ProcurementTypeCode_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([ProcurementTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ProcurementTypeCode_ProcurementProject]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ProcurementSubTypeCode_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([ProcurementSubTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ProcurementSubTypeCode_ProcurementProject]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_QualityControlCode_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([QualityControlCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_QualityControlCode_ProcurementProject]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_RequiredFeeAmount_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([RequiredFeeAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_RequiredFeeAmount_ProcurementProject]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_FeeDescription_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([FeeDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_FeeDescription_ProcurementProject]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_RequestedDeliveryDate_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([RequestedDeliveryDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_RequestedDeliveryDate_ProcurementProject]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_EstimatedOverallContractQuantity_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([EstimatedOverallContractQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_EstimatedOverallContractQuantity_ProcurementProject]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ProcurementProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProject] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ProcurementProject]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ProcurementProjectLot] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProcurementProjectLot] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ProcurementProjectLot]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ProjectReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProjectReference] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ProjectReference]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ProjectReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProjectReference] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ProjectReference]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_IssueDate_ProjectReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[ProjectReference] ([IssueDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_IssueDate_ProjectReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PromotionalEventTypeCode_PromotionalEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[PromotionalEvent] ([PromotionalEventTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PromotionalEventTypeCode_PromotionalEvent]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_SubmissionDate_PromotionalEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[PromotionalEvent] ([SubmissionDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_SubmissionDate_PromotionalEvent]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_FirstShipmentAvailibilityDate_PromotionalEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[PromotionalEvent] ([FirstShipmentAvailibilityDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_FirstShipmentAvailibilityDate_PromotionalEvent]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_LatestProposalAcceptanceDate_PromotionalEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[PromotionalEvent] ([LatestProposalAcceptanceDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_LatestProposalAcceptanceDate_PromotionalEvent]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_PromotionalEventLineItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[PromotionalEventLineItem] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_PromotionalEventLineItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SpecificationID_PromotionalSpecification] FOREIGN KEY([Ref])
REFERENCES [dbo].[PromotionalSpecification] ([SpecificationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SpecificationID_PromotionalSpecification]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AdmissionCode_QualificationResolution] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualificationResolution] ([AdmissionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AdmissionCode_QualificationResolution]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ExclusionReason_QualificationResolution] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualificationResolution] ([ExclusionReason])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ExclusionReason_QualificationResolution]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Resolution_QualificationResolution] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualificationResolution] ([Resolution])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Resolution_QualificationResolution]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ResolutionDate_QualificationResolution] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualificationResolution] ([ResolutionDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ResolutionDate_QualificationResolution]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ResolutionTime_QualificationResolution] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualificationResolution] ([ResolutionTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ResolutionTime_QualificationResolution]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_ParticipationPercent_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([ParticipationPercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_ParticipationPercent_QualifyingParty]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PersonalSituation_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([PersonalSituation])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PersonalSituation_QualifyingParty]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_OperatingYearsQuantity_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([OperatingYearsQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_OperatingYearsQuantity_QualifyingParty]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_EmployeeQuantity_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([EmployeeQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_EmployeeQuantity_QualifyingParty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_BusinessClassificationEvidenceID_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([BusinessClassificationEvidenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_BusinessClassificationEvidenceID_QualifyingParty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_BusinessIdentityEvidenceID_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([BusinessIdentityEvidenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_BusinessIdentityEvidenceID_QualifyingParty]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TendererRoleCode_QualifyingParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[QualifyingParty] ([TendererRoleCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TendererRoleCode_QualifyingParty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_QuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[QuotationLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_QuotationLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_QuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[QuotationLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_QuotationLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_QuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[QuotationLine] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_QuotationLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LineExtensionAmount_QuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[QuotationLine] ([LineExtensionAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LineExtensionAmount_QuotationLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalTaxAmount_QuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[QuotationLine] ([TotalTaxAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalTaxAmount_QuotationLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_RequestForQuotationLineID_QuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[QuotationLine] ([RequestForQuotationLineID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_RequestForQuotationLineID_QuotationLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TrainID_RailTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[RailTransport] ([TrainID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TrainID_RailTransport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_RailCarID_RailTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[RailTransport] ([RailCarID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_RailCarID_RailTransport]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ReceiptLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ReceiptLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ReceiptLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ReceivedQuantity_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([ReceivedQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ReceivedQuantity_ReceiptLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ShortQuantity_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([ShortQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ShortQuantity_ReceiptLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ShortageActionCode_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([ShortageActionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ShortageActionCode_ReceiptLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_RejectedQuantity_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([RejectedQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_RejectedQuantity_ReceiptLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_RejectReasonCode_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([RejectReasonCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_RejectReasonCode_ReceiptLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_RejectReason_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([RejectReason])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_RejectReason_ReceiptLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_RejectActionCode_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([RejectActionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_RejectActionCode_ReceiptLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_QuantityDiscrepancyCode_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([QuantityDiscrepancyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_QuantityDiscrepancyCode_ReceiptLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_OversupplyQuantity_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([OversupplyQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_OversupplyQuantity_ReceiptLine]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ReceivedDate_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([ReceivedDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ReceivedDate_ReceiptLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TimingComplaintCode_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([TimingComplaintCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TimingComplaintCode_ReceiptLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TimingComplaint_ReceiptLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReceiptLine] ([TimingComplaint])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TimingComplaint_ReceiptLine]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_Regulation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Regulation] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_Regulation]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_LegalReference_Regulation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Regulation] ([LegalReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_LegalReference_Regulation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_OntologyURI_Regulation] FOREIGN KEY([Ref])
REFERENCES [dbo].[Regulation] ([OntologyURI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_OntologyURI_Regulation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_RelatedItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[RelatedItem] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_RelatedItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_RelatedItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[RelatedItem] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_RelatedItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_RelatedItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[RelatedItem] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_RelatedItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ReminderLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_ReminderLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_ReminderLine]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_BalanceBroughtForwardIndicator_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([BalanceBroughtForwardIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_BalanceBroughtForwardIndicator_ReminderLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DebitLineAmount_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([DebitLineAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DebitLineAmount_ReminderLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_CreditLineAmount_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([CreditLineAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_CreditLineAmount_ReminderLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AccountingCostCode_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([AccountingCostCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AccountingCostCode_ReminderLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AccountingCost_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([AccountingCost])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AccountingCost_ReminderLine]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_PenaltySurchargePercent_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([PenaltySurchargePercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_PenaltySurchargePercent_ReminderLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_ReminderLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentPurposeCode_ReminderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[ReminderLine] ([PaymentPurposeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentPurposeCode_ReminderLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DebitLineAmount_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([DebitLineAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DebitLineAmount_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_CreditLineAmount_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([CreditLineAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_CreditLineAmount_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_BalanceAmount_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([BalanceAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_BalanceAmount_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentPurposeCode_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([PaymentPurposeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentPurposeCode_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_InvoicingPartyReference_RemittanceAdviceLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RemittanceAdviceLine] ([InvoicingPartyReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_InvoicingPartyReference_RemittanceAdviceLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_Renewal] FOREIGN KEY([Ref])
REFERENCES [dbo].[Renewal] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_Renewal]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_RequestForQuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotationLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_RequestForQuotationLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_RequestForQuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotationLine] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_RequestForQuotationLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_RequestForQuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotationLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_RequestForQuotationLine]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_OptionalLineItemIndicator_RequestForQuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotationLine] ([OptionalLineItemIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_OptionalLineItemIndicator_RequestForQuotationLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PrivacyCode_RequestForQuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotationLine] ([PrivacyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PrivacyCode_RequestForQuotationLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SecurityClassificationCode_RequestForQuotationLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForQuotationLine] ([SecurityClassificationCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SecurityClassificationCode_RequestForQuotationLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MinimumQuantity_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([MinimumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MinimumQuantity_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MaximumQuantity_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([MaximumQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MaximumQuantity_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_TaxIncludedIndicator_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([TaxIncludedIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_TaxIncludedIndicator_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_MinimumAmount_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([MinimumAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_MinimumAmount_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_MaximumAmount_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([MaximumAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_MaximumAmount_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_EstimatedAmount_RequestForTenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestForTenderLine] ([EstimatedAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_EstimatedAmount_RequestForTenderLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_EstimatedOverallContractAmount_RequestedTenderTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestedTenderTotal] ([EstimatedOverallContractAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_EstimatedOverallContractAmount_RequestedTenderTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalAmount_RequestedTenderTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestedTenderTotal] ([TotalAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalAmount_RequestedTenderTotal]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_TaxIncludedIndicator_RequestedTenderTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestedTenderTotal] ([TaxIncludedIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_TaxIncludedIndicator_RequestedTenderTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_MinimumAmount_RequestedTenderTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestedTenderTotal] ([MinimumAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_MinimumAmount_RequestedTenderTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_MaximumAmount_RequestedTenderTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestedTenderTotal] ([MaximumAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_MaximumAmount_RequestedTenderTotal]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MonetaryScope_RequestedTenderTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestedTenderTotal] ([MonetaryScope])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MonetaryScope_RequestedTenderTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_AverageSubsequentContractAmount_RequestedTenderTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[RequestedTenderTotal] ([AverageSubsequentContractAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_AverageSubsequentContractAmount_RequestedTenderTotal]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ReferenceID_Response] FOREIGN KEY([Ref])
REFERENCES [dbo].[Response] ([ReferenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ReferenceID_Response]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ResponseCode_Response] FOREIGN KEY([Ref])
REFERENCES [dbo].[Response] ([ResponseCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ResponseCode_Response]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Response] FOREIGN KEY([Ref])
REFERENCES [dbo].[Response] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Response]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_EffectiveDate_Response] FOREIGN KEY([Ref])
REFERENCES [dbo].[Response] ([EffectiveDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_EffectiveDate_Response]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_EffectiveTime_Response] FOREIGN KEY([Ref])
REFERENCES [dbo].[Response] ([EffectiveTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_EffectiveTime_Response]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ValidatorID_ResultOfVerification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ResultOfVerification] ([ValidatorID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ValidatorID_ResultOfVerification]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ValidationResultCode_ResultOfVerification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ResultOfVerification] ([ValidationResultCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ValidationResultCode_ResultOfVerification]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ValidationDate_ResultOfVerification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ResultOfVerification] ([ValidationDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ValidationDate_ResultOfVerification]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ValidationTime_ResultOfVerification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ResultOfVerification] ([ValidationTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ValidationTime_ResultOfVerification]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ValidateProcess_ResultOfVerification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ResultOfVerification] ([ValidateProcess])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ValidateProcess_ResultOfVerification]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ValidateTool_ResultOfVerification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ResultOfVerification] ([ValidateTool])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ValidateTool_ResultOfVerification]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ValidateToolVersion_ResultOfVerification] FOREIGN KEY([Ref])
REFERENCES [dbo].[ResultOfVerification] ([ValidateToolVersion])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ValidateToolVersion_ResultOfVerification]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_RetailPlannedImpact] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailPlannedImpact] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_RetailPlannedImpact]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ForecastPurposeCode_RetailPlannedImpact] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailPlannedImpact] ([ForecastPurposeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ForecastPurposeCode_RetailPlannedImpact]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ForecastTypeCode_RetailPlannedImpact] FOREIGN KEY([Ref])
REFERENCES [dbo].[RetailPlannedImpact] ([ForecastTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ForecastTypeCode_RetailPlannedImpact]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_LicensePlateID_RoadTransport] FOREIGN KEY([Ref])
REFERENCES [dbo].[RoadTransport] ([LicensePlateID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_LicensePlateID_RoadTransport]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_SalesItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[SalesItem] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_SalesItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_SecondaryHazard] FOREIGN KEY([Ref])
REFERENCES [dbo].[SecondaryHazard] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_SecondaryHazard]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PlacardNotation_SecondaryHazard] FOREIGN KEY([Ref])
REFERENCES [dbo].[SecondaryHazard] ([PlacardNotation])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PlacardNotation_SecondaryHazard]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PlacardEndorsement_SecondaryHazard] FOREIGN KEY([Ref])
REFERENCES [dbo].[SecondaryHazard] ([PlacardEndorsement])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PlacardEndorsement_SecondaryHazard]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_EmergencyProceduresCode_SecondaryHazard] FOREIGN KEY([Ref])
REFERENCES [dbo].[SecondaryHazard] ([EmergencyProceduresCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_EmergencyProceduresCode_SecondaryHazard]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Extension_SecondaryHazard] FOREIGN KEY([Ref])
REFERENCES [dbo].[SecondaryHazard] ([Extension])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Extension_SecondaryHazard]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_WeekDayCode_ServiceFrequency] FOREIGN KEY([Ref])
REFERENCES [dbo].[ServiceFrequency] ([WeekDayCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_WeekDayCode_ServiceFrequency]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ServiceProviderParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ServiceProviderParty] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ServiceProviderParty]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ServiceTypeCode_ServiceProviderParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ServiceProviderParty] ([ServiceTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ServiceTypeCode_ServiceProviderParty]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ServiceType_ServiceProviderParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ServiceProviderParty] ([ServiceType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ServiceType_ServiceProviderParty]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_PartecipationPercent_ShareholderParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShareholderParty] ([PartecipationPercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_PartecipationPercent_ShareholderParty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Shipment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ShippingPriorityLevelCode_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([ShippingPriorityLevelCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ShippingPriorityLevelCode_Shipment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_HandlingCode_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([HandlingCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_HandlingCode_Shipment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_HandlingInstructions_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([HandlingInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_HandlingInstructions_Shipment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Information_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([Information])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Information_Shipment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_GrossWeightMeasure_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([GrossWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_GrossWeightMeasure_Shipment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetWeightMeasure_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([NetWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetWeightMeasure_Shipment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetNetWeightMeasure_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([NetNetWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetNetWeightMeasure_Shipment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_GrossVolumeMeasure_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([GrossVolumeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_GrossVolumeMeasure_Shipment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_NetVolumeMeasure_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([NetVolumeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_NetVolumeMeasure_Shipment]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalGoodsItemQuantity_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([TotalGoodsItemQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalGoodsItemQuantity_Shipment]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalTransportHandlingUnitQuantity_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([TotalTransportHandlingUnitQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalTransportHandlingUnitQuantity_Shipment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_InsuranceValueAmount_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([InsuranceValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_InsuranceValueAmount_Shipment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredCustomsValueAmount_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([DeclaredCustomsValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredCustomsValueAmount_Shipment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredForCarriageValueAmount_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([DeclaredForCarriageValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredForCarriageValueAmount_Shipment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DeclaredStatisticsValueAmount_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([DeclaredStatisticsValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DeclaredStatisticsValueAmount_Shipment]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_FreeOnBoardValueAmount_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([FreeOnBoardValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_FreeOnBoardValueAmount_Shipment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_SpecialInstructions_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([SpecialInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_SpecialInstructions_Shipment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DeliveryInstructions_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([DeliveryInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DeliveryInstructions_Shipment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_SplitConsignmentIndicator_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([SplitConsignmentIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_SplitConsignmentIndicator_Shipment]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ConsignmentQuantity_Shipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[Shipment] ([ConsignmentQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ConsignmentQuantity_Shipment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_ShipmentStage]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportModeCode_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([TransportModeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportModeCode_ShipmentStage]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportMeansTypeCode_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([TransportMeansTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportMeansTypeCode_ShipmentStage]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransitDirectionCode_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([TransitDirectionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransitDirectionCode_ShipmentStage]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_PreCarriageIndicator_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([PreCarriageIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_PreCarriageIndicator_ShipmentStage]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_OnCarriageIndicator_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([OnCarriageIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_OnCarriageIndicator_ShipmentStage]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_EstimatedDeliveryDate_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([EstimatedDeliveryDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_EstimatedDeliveryDate_ShipmentStage]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_EstimatedDeliveryTime_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([EstimatedDeliveryTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_EstimatedDeliveryTime_ShipmentStage]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_RequiredDeliveryDate_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([RequiredDeliveryDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_RequiredDeliveryDate_ShipmentStage]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_RequiredDeliveryTime_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([RequiredDeliveryTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_RequiredDeliveryTime_ShipmentStage]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_LoadingSequenceID_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([LoadingSequenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_LoadingSequenceID_ShipmentStage]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SuccessiveSequenceID_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([SuccessiveSequenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SuccessiveSequenceID_ShipmentStage]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Instructions_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([Instructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Instructions_ShipmentStage]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DemurrageInstructions_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([DemurrageInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DemurrageInstructions_ShipmentStage]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_CrewQuantity_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([CrewQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_CrewQuantity_ShipmentStage]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_PassengerQuantity_ShipmentStage] FOREIGN KEY([Ref])
REFERENCES [dbo].[ShipmentStage] ([PassengerQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_PassengerQuantity_ShipmentStage]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_Signature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Signature] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_Signature]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_Signature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Signature] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_Signature]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ValidationDate_Signature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Signature] ([ValidationDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ValidationDate_Signature]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ValidationTime_Signature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Signature] ([ValidationTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ValidationTime_Signature]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ValidatorID_Signature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Signature] ([ValidatorID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ValidatorID_Signature]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CanonicalizationMethod_Signature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Signature] ([CanonicalizationMethod])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CanonicalizationMethod_Signature]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_SignatureMethod_Signature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Signature] ([SignatureMethod])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_SignatureMethod_Signature]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_StatementLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_StatementLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_UUID_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([UUID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_UUID_StatementLine]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_BalanceBroughtForwardIndicator_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([BalanceBroughtForwardIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_BalanceBroughtForwardIndicator_StatementLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DebitLineAmount_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([DebitLineAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DebitLineAmount_StatementLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_CreditLineAmount_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([CreditLineAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_CreditLineAmount_StatementLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_BalanceAmount_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([BalanceAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_BalanceAmount_StatementLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentPurposeCode_StatementLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StatementLine] ([PaymentPurposeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentPurposeCode_StatementLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ConditionCode_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([ConditionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ConditionCode_Status]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ReferenceDate_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([ReferenceDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ReferenceDate_Status]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ReferenceTime_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([ReferenceTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ReferenceTime_Status]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Status]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_StatusReasonCode_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([StatusReasonCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_StatusReasonCode_Status]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_StatusReason_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([StatusReason])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_StatusReason_Status]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SequenceID_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([SequenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SequenceID_Status]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Text_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([Text])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Text_Status]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_IndicationIndicator_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([IndicationIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_IndicationIndicator_Status]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_Percent_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([Percent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_Percent_Status]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_ReliabilityPercent_Status] FOREIGN KEY([Ref])
REFERENCES [dbo].[Status] ([ReliabilityPercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_ReliabilityPercent_Status]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_StockAvailabilityReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReportLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_StockAvailabilityReportLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_StockAvailabilityReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReportLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_StockAvailabilityReportLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_StockAvailabilityReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReportLine] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_StockAvailabilityReportLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_ValueAmount_StockAvailabilityReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReportLine] ([ValueAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_ValueAmount_StockAvailabilityReportLine]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_AvailabilityDate_StockAvailabilityReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReportLine] ([AvailabilityDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_AvailabilityDate_StockAvailabilityReportLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AvailabilityStatusCode_StockAvailabilityReportLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[StockAvailabilityReportLine] ([AvailabilityStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AvailabilityStatusCode_StockAvailabilityReportLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_LocationID_Stowage] FOREIGN KEY([Ref])
REFERENCES [dbo].[Stowage] ([LocationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_LocationID_Stowage]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Location_Stowage] FOREIGN KEY([Ref])
REFERENCES [dbo].[Stowage] ([Location])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Location_Stowage]
GO
ALTER TABLE [dbo].[Rate] WITH CHECK ADD CONSTRAINT [FK_Rate_SubcontractTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubcontractTerms] ([Rate])
GO
ALTER TABLE [dbo].[Rate] CHECK CONSTRAINT [FK_Rate_SubcontractTerms]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_UnknownPriceIndicator_SubcontractTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubcontractTerms] ([UnknownPriceIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_UnknownPriceIndicator_SubcontractTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_SubcontractTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubcontractTerms] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_SubcontractTerms]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_Amount_SubcontractTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubcontractTerms] ([Amount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_Amount_SubcontractTerms]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SubcontractingConditionsCode_SubcontractTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubcontractTerms] ([SubcontractingConditionsCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SubcontractingConditionsCode_SubcontractTerms]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_MaximumPercent_SubcontractTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubcontractTerms] ([MaximumPercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_MaximumPercent_SubcontractTerms]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_MinimumPercent_SubcontractTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubcontractTerms] ([MinimumPercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_MinimumPercent_SubcontractTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ConsumptionID_SubscriberConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubscriberConsumption] ([ConsumptionID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ConsumptionID_SubscriberConsumption]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SpecificationTypeCode_SubscriberConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubscriberConsumption] ([SpecificationTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SpecificationTypeCode_SubscriberConsumption]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_SubscriberConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubscriberConsumption] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_SubscriberConsumption]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalMeteredQuantity_SubscriberConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SubscriberConsumption] ([TotalMeteredQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalMeteredQuantity_SubscriberConsumption]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_SupplierConsumption] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierConsumption] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_SupplierConsumption]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_CustomerAssignedAccountID_SupplierParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierParty] ([CustomerAssignedAccountID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_CustomerAssignedAccountID_SupplierParty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_AdditionalAccountID_SupplierParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierParty] ([AdditionalAccountID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_AdditionalAccountID_SupplierParty]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DataSendingCapability_SupplierParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[SupplierParty] ([DataSendingCapability])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DataSendingCapability_SupplierParty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TaxCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxCategory] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TaxCategory]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_TaxCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxCategory] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_TaxCategory]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_Percent_TaxCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxCategory] ([Percent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_Percent_TaxCategory]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_BaseUnitMeasure_TaxCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxCategory] ([BaseUnitMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_BaseUnitMeasure_TaxCategory]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PerUnitAmount_TaxCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxCategory] ([PerUnitAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PerUnitAmount_TaxCategory]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxExemptionReasonCode_TaxCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxCategory] ([TaxExemptionReasonCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxExemptionReasonCode_TaxCategory]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TaxExemptionReason_TaxCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxCategory] ([TaxExemptionReason])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TaxExemptionReason_TaxCategory]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TierRange_TaxCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxCategory] ([TierRange])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TierRange_TaxCategory]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_TierRatePercent_TaxCategory] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxCategory] ([TierRatePercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_TierRatePercent_TaxCategory]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxScheme] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TaxScheme]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_TaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxScheme] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_TaxScheme]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TaxTypeCode_TaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxScheme] ([TaxTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TaxTypeCode_TaxScheme]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CurrencyCode_TaxScheme] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxScheme] ([CurrencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CurrencyCode_TaxScheme]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TaxableAmount_TaxSubtotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxSubtotal] ([TaxableAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TaxableAmount_TaxSubtotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TaxAmount_TaxSubtotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxSubtotal] ([TaxAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TaxAmount_TaxSubtotal]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_CalculationSequenceNumeric_TaxSubtotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxSubtotal] ([CalculationSequenceNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_CalculationSequenceNumeric_TaxSubtotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TransactionCurrencyTaxAmount_TaxSubtotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxSubtotal] ([TransactionCurrencyTaxAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TransactionCurrencyTaxAmount_TaxSubtotal]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_Percent_TaxSubtotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxSubtotal] ([Percent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_Percent_TaxSubtotal]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_BaseUnitMeasure_TaxSubtotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxSubtotal] ([BaseUnitMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_BaseUnitMeasure_TaxSubtotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PerUnitAmount_TaxSubtotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxSubtotal] ([PerUnitAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PerUnitAmount_TaxSubtotal]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TierRange_TaxSubtotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxSubtotal] ([TierRange])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TierRange_TaxSubtotal]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_TierRatePercent_TaxSubtotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxSubtotal] ([TierRatePercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_TierRatePercent_TaxSubtotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TaxAmount_TaxTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxTotal] ([TaxAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TaxAmount_TaxTotal]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_RoundingAmount_TaxTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxTotal] ([RoundingAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_RoundingAmount_TaxTotal]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_TaxEvidenceIndicator_TaxTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxTotal] ([TaxEvidenceIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_TaxEvidenceIndicator_TaxTotal]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_TaxIncludedIndicator_TaxTotal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TaxTotal] ([TaxIncludedIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_TaxIncludedIndicator_TaxTotal]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_CallDate_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([CallDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_CallDate_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_CallTime_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([CallTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_CallTime_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ServiceNumberCalled_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([ServiceNumberCalled])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ServiceNumberCalled_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TelecommunicationsServiceCategory_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([TelecommunicationsServiceCategory])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TelecommunicationsServiceCategory_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TelecommunicationsServiceCategoryCode_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([TelecommunicationsServiceCategoryCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TelecommunicationsServiceCategoryCode_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_MovieTitle_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([MovieTitle])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_MovieTitle_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_RoamingPartnerName_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([RoamingPartnerName])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_RoamingPartnerName_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PayPerView_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([PayPerView])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PayPerView_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TelecommunicationsServiceCall_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([TelecommunicationsServiceCall])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TelecommunicationsServiceCall_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TelecommunicationsServiceCallCode_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([TelecommunicationsServiceCallCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TelecommunicationsServiceCallCode_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_CallBaseAmount_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([CallBaseAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_CallBaseAmount_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_CallExtensionAmount_TelecommunicationsService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsService] ([CallExtensionAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_CallExtensionAmount_TelecommunicationsService]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TelecommunicationsSupplyType_TelecommunicationsSupply] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupply] ([TelecommunicationsSupplyType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TelecommunicationsSupplyType_TelecommunicationsSupply]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TelecommunicationsSupplyTypeCode_TelecommunicationsSupply] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupply] ([TelecommunicationsSupplyTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TelecommunicationsSupplyTypeCode_TelecommunicationsSupply]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PrivacyCode_TelecommunicationsSupply] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupply] ([PrivacyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PrivacyCode_TelecommunicationsSupply]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TelecommunicationsSupply] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupply] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TelecommunicationsSupply]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalAmount_TelecommunicationsSupply] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupply] ([TotalAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalAmount_TelecommunicationsSupply]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TelecommunicationsSupplyLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupplyLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TelecommunicationsSupplyLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PhoneNumber_TelecommunicationsSupplyLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupplyLine] ([PhoneNumber])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PhoneNumber_TelecommunicationsSupplyLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TelecommunicationsSupplyLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupplyLine] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TelecommunicationsSupplyLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LineExtensionAmount_TelecommunicationsSupplyLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TelecommunicationsSupplyLine] ([LineExtensionAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LineExtensionAmount_TelecommunicationsSupplyLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_AttributeID_Temperature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Temperature] ([AttributeID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_AttributeID_Temperature]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_Measure_Temperature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Temperature] ([Measure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_Measure_Temperature]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_Temperature] FOREIGN KEY([Ref])
REFERENCES [dbo].[Temperature] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_Temperature]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TenderLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TenderLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_Quantity_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([Quantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_Quantity_TenderLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LineExtensionAmount_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([LineExtensionAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LineExtensionAmount_TenderLine]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_TotalTaxAmount_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([TotalTaxAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_TotalTaxAmount_TenderLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OrderableUnit_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([OrderableUnit])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OrderableUnit_TenderLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ContentUnitQuantity_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([ContentUnitQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ContentUnitQuantity_TenderLine]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_OrderQuantityIncrementNumeric_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([OrderQuantityIncrementNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_OrderQuantityIncrementNumeric_TenderLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MinimumOrderQuantity_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([MinimumOrderQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MinimumOrderQuantity_TenderLine]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MaximumOrderQuantity_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([MaximumOrderQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MaximumOrderQuantity_TenderLine]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_WarrantyInformation_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([WarrantyInformation])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_WarrantyInformation_TenderLine]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PackLevelCode_TenderLine] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderLine] ([PackLevelCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PackLevelCode_TenderLine]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TenderEnvelopeID_TenderPreparation] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderPreparation] ([TenderEnvelopeID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TenderEnvelopeID_TenderPreparation]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TenderEnvelopeTypeCode_TenderPreparation] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderPreparation] ([TenderEnvelopeTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TenderEnvelopeTypeCode_TenderPreparation]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TenderPreparation] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderPreparation] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TenderPreparation]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_OpenTenderID_TenderPreparation] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderPreparation] ([OpenTenderID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_OpenTenderID_TenderPreparation]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_TenderRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderRequirement] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_TenderRequirement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TenderRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderRequirement] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TenderRequirement]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TenderResultCode_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([TenderResultCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TenderResultCode_TenderResult]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TenderResult]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_AdvertisementAmount_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([AdvertisementAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_AdvertisementAmount_TenderResult]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_AwardDate_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([AwardDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_AwardDate_TenderResult]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_AwardTime_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([AwardTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_AwardTime_TenderResult]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ReceivedTenderQuantity_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([ReceivedTenderQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ReceivedTenderQuantity_TenderResult]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_LowerTenderAmount_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([LowerTenderAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_LowerTenderAmount_TenderResult]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_HigherTenderAmount_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([HigherTenderAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_HigherTenderAmount_TenderResult]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_StartDate_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([StartDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_StartDate_TenderResult]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ReceivedElectronicTenderQuantity_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([ReceivedElectronicTenderQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ReceivedElectronicTenderQuantity_TenderResult]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_ReceivedForeignTenderQuantity_TenderResult] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderResult] ([ReceivedForeignTenderQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_ReceivedForeignTenderQuantity_TenderResult]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_VariantID_TenderedProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderedProject] ([VariantID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_VariantID_TenderedProject]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_FeeAmount_TenderedProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderedProject] ([FeeAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_FeeAmount_TenderedProject]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_FeeDescription_TenderedProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderedProject] ([FeeDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_FeeDescription_TenderedProject]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TenderEnvelopeID_TenderedProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderedProject] ([TenderEnvelopeID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TenderEnvelopeID_TenderedProject]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TenderEnvelopeTypeCode_TenderedProject] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderedProject] ([TenderEnvelopeTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TenderEnvelopeTypeCode_TenderedProject]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CompanyLegalFormCode_TendererQualificationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationRequest] ([CompanyLegalFormCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CompanyLegalFormCode_TendererQualificationRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CompanyLegalForm_TendererQualificationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationRequest] ([CompanyLegalForm])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CompanyLegalForm_TendererQualificationRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PersonalSituation_TendererQualificationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationRequest] ([PersonalSituation])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PersonalSituation_TendererQualificationRequest]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_OperatingYearsQuantity_TendererQualificationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationRequest] ([OperatingYearsQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_OperatingYearsQuantity_TendererQualificationRequest]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_EmployeeQuantity_TendererQualificationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationRequest] ([EmployeeQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_EmployeeQuantity_TendererQualificationRequest]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TendererQualificationRequest] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererQualificationRequest] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TendererQualificationRequest]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_TendererRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererRequirement] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_TendererRequirement]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TendererRequirementTypeCode_TendererRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererRequirement] ([TendererRequirementTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TendererRequirementTypeCode_TendererRequirement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TendererRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererRequirement] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TendererRequirement]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_LegalReference_TendererRequirement] FOREIGN KEY([Ref])
REFERENCES [dbo].[TendererRequirement] ([LegalReference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_LegalReference_TendererRequirement]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TenderingProcess]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_OriginalContractingSystemID_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([OriginalContractingSystemID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_OriginalContractingSystemID_TenderingProcess]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TenderingProcess]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_NegotiationDescription_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([NegotiationDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_NegotiationDescription_TenderingProcess]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ProcedureCode_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([ProcedureCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ProcedureCode_TenderingProcess]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_UrgencyCode_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([UrgencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_UrgencyCode_TenderingProcess]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ExpenseCode_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([ExpenseCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ExpenseCode_TenderingProcess]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PartPresentationCode_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([PartPresentationCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PartPresentationCode_TenderingProcess]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ContractingSystemCode_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([ContractingSystemCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ContractingSystemCode_TenderingProcess]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SubmissionMethodCode_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([SubmissionMethodCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SubmissionMethodCode_TenderingProcess]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CandidateReductionConstraintIndicator_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([CandidateReductionConstraintIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CandidateReductionConstraintIndicator_TenderingProcess]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_GovernmentAgreementConstraintIndicator_TenderingProcess] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingProcess] ([GovernmentAgreementConstraintIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_GovernmentAgreementConstraintIndicator_TenderingProcess]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_AwardingMethodTypeCode_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([AwardingMethodTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_AwardingMethodTypeCode_TenderingTerms]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PriceEvaluationCode_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([PriceEvaluationCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PriceEvaluationCode_TenderingTerms]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_MaximumVariantQuantity_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([MaximumVariantQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_MaximumVariantQuantity_TenderingTerms]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_VariantConstraintIndicator_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([VariantConstraintIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_VariantConstraintIndicator_TenderingTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AcceptedVariantsDescription_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([AcceptedVariantsDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AcceptedVariantsDescription_TenderingTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_PriceRevisionFormulaDescription_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([PriceRevisionFormulaDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_PriceRevisionFormulaDescription_TenderingTerms]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_FundingProgramCode_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([FundingProgramCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_FundingProgramCode_TenderingTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_FundingProgram_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([FundingProgram])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_FundingProgram_TenderingTerms]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_MaximumAdvertisementAmount_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([MaximumAdvertisementAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_MaximumAdvertisementAmount_TenderingTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Note_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([Note])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Note_TenderingTerms]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_PaymentFrequencyCode_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([PaymentFrequencyCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_PaymentFrequencyCode_TenderingTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_EconomicOperatorRegistryURI_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([EconomicOperatorRegistryURI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_EconomicOperatorRegistryURI_TenderingTerms]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_RequiredCurriculaIndicator_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([RequiredCurriculaIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_RequiredCurriculaIndicator_TenderingTerms]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_OtherConditionsIndicator_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([OtherConditionsIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_OtherConditionsIndicator_TenderingTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_AdditionalConditions_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([AdditionalConditions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_AdditionalConditions_TenderingTerms]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_LatestSecurityClearanceDate_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([LatestSecurityClearanceDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_LatestSecurityClearanceDate_TenderingTerms]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_DocumentationFeeAmount_TenderingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TenderingTerms] ([DocumentationFeeAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_DocumentationFeeAmount_TenderingTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TradeFinancing] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeFinancing] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TradeFinancing]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_FinancingInstrumentCode_TradeFinancing] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradeFinancing] ([FinancingInstrumentCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_FinancingInstrumentCode_TradeFinancing]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Information_TradingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradingTerms] ([Information])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Information_TradingTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Reference_TradingTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TradingTerms] ([Reference])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Reference_TradingTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransactionConditions] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransactionConditions] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransactionConditions]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ActionCode_TransactionConditions] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransactionConditions] ([ActionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ActionCode_TransactionConditions]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TransactionConditions] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransactionConditions] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TransactionConditions]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransportEquipment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ReferencedConsignmentID_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([ReferencedConsignmentID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ReferencedConsignmentID_TransportEquipment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportEquipmentTypeCode_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([TransportEquipmentTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportEquipmentTypeCode_TransportEquipment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ProviderTypeCode_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([ProviderTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ProviderTypeCode_TransportEquipment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_OwnerTypeCode_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([OwnerTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_OwnerTypeCode_TransportEquipment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SizeTypeCode_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([SizeTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SizeTypeCode_TransportEquipment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DispositionCode_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([DispositionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DispositionCode_TransportEquipment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_FullnessIndicationCode_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([FullnessIndicationCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_FullnessIndicationCode_TransportEquipment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_RefrigerationOnIndicator_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([RefrigerationOnIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_RefrigerationOnIndicator_TransportEquipment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Information_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([Information])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Information_TransportEquipment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_ReturnabilityIndicator_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([ReturnabilityIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_ReturnabilityIndicator_TransportEquipment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_LegalStatusIndicator_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([LegalStatusIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_LegalStatusIndicator_TransportEquipment]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_AirFlowPercent_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([AirFlowPercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_AirFlowPercent_TransportEquipment]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_HumidityPercent_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([HumidityPercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_HumidityPercent_TransportEquipment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_AnimalFoodApprovedIndicator_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([AnimalFoodApprovedIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_AnimalFoodApprovedIndicator_TransportEquipment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_HumanFoodApprovedIndicator_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([HumanFoodApprovedIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_HumanFoodApprovedIndicator_TransportEquipment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_DangerousGoodsApprovedIndicator_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([DangerousGoodsApprovedIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_DangerousGoodsApprovedIndicator_TransportEquipment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_RefrigeratedIndicator_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([RefrigeratedIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_RefrigeratedIndicator_TransportEquipment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Characteristics_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([Characteristics])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Characteristics_TransportEquipment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DamageRemarks_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([DamageRemarks])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DamageRemarks_TransportEquipment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TransportEquipment]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_SpecialTransportRequirements_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([SpecialTransportRequirements])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_SpecialTransportRequirements_TransportEquipment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_GrossWeightMeasure_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([GrossWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_GrossWeightMeasure_TransportEquipment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_GrossVolumeMeasure_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([GrossVolumeMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_GrossVolumeMeasure_TransportEquipment]
GO
ALTER TABLE [dbo].[Measure] WITH CHECK ADD CONSTRAINT [FK_TareWeightMeasure_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([TareWeightMeasure])
GO
ALTER TABLE [dbo].[Measure] CHECK CONSTRAINT [FK_TareWeightMeasure_TransportEquipment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TrackingDeviceCode_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([TrackingDeviceCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TrackingDeviceCode_TransportEquipment]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_PowerIndicator_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([PowerIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_PowerIndicator_TransportEquipment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TraceID_TransportEquipment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipment] ([TraceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TraceID_TransportEquipment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransportEquipmentSeal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipmentSeal] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransportEquipmentSeal]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SealIssuerTypeCode_TransportEquipmentSeal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipmentSeal] ([SealIssuerTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SealIssuerTypeCode_TransportEquipmentSeal]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Condition_TransportEquipmentSeal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipmentSeal] ([Condition])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Condition_TransportEquipmentSeal]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SealStatusCode_TransportEquipmentSeal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipmentSeal] ([SealStatusCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SealStatusCode_TransportEquipmentSeal]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_SealingPartyType_TransportEquipmentSeal] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEquipmentSeal] ([SealingPartyType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_SealingPartyType_TransportEquipmentSeal]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_IdentificationID_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([IdentificationID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_IdentificationID_TransportEvent]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_OccurrenceDate_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([OccurrenceDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_OccurrenceDate_TransportEvent]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_OccurrenceTime_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([OccurrenceTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_OccurrenceTime_TransportEvent]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportEventTypeCode_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([TransportEventTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportEventTypeCode_TransportEvent]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_TransportEvent]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_CompletionIndicator_TransportEvent] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportEvent] ([CompletionIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_CompletionIndicator_TransportEvent]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TransportUserSpecialTerms_TransportExecutionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionTerms] ([TransportUserSpecialTerms])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TransportUserSpecialTerms_TransportExecutionTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TransportServiceProviderSpecialTerms_TransportExecutionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionTerms] ([TransportServiceProviderSpecialTerms])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TransportServiceProviderSpecialTerms_TransportExecutionTerms]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ChangeConditions_TransportExecutionTerms] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportExecutionTerms] ([ChangeConditions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ChangeConditions_TransportExecutionTerms]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportHandlingUnitTypeCode_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([TransportHandlingUnitTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportHandlingUnitTypeCode_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_HandlingCode_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([HandlingCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_HandlingCode_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_HandlingInstructions_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([HandlingInstructions])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_HandlingInstructions_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Indicator] WITH CHECK ADD CONSTRAINT [FK_HazardousRiskIndicator_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([HazardousRiskIndicator])
GO
ALTER TABLE [dbo].[Indicator] CHECK CONSTRAINT [FK_HazardousRiskIndicator_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalGoodsItemQuantity_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([TotalGoodsItemQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalGoodsItemQuantity_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_TotalPackageQuantity_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([TotalPackageQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_TotalPackageQuantity_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_DamageRemarks_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([DamageRemarks])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_DamageRemarks_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ShippingMarks_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([ShippingMarks])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ShippingMarks_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TraceID_TransportHandlingUnit] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportHandlingUnit] ([TraceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TraceID_TransportHandlingUnit]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_JourneyID_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([JourneyID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_JourneyID_TransportMeans]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_RegistrationNationalityID_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([RegistrationNationalityID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_RegistrationNationalityID_TransportMeans]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_RegistrationNationality_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([RegistrationNationality])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_RegistrationNationality_TransportMeans]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_DirectionCode_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([DirectionCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_DirectionCode_TransportMeans]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportMeansTypeCode_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([TransportMeansTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportMeansTypeCode_TransportMeans]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TradeServiceCode_TransportMeans] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportMeans] ([TradeServiceCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TradeServiceCode_TransportMeans]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_SequenceNumeric_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([SequenceNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_SequenceNumeric_TransportSchedule]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_ReferenceDate_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([ReferenceDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_ReferenceDate_TransportSchedule]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_ReferenceTime_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([ReferenceTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_ReferenceTime_TransportSchedule]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_ReliabilityPercent_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([ReliabilityPercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_ReliabilityPercent_TransportSchedule]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Remarks_TransportSchedule] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportSchedule] ([Remarks])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Remarks_TransportSchedule]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_SequenceNumeric_TransportationSegment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationSegment] ([SequenceNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_SequenceNumeric_TransportationSegment]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TransportExecutionPlanReferenceID_TransportationSegment] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationSegment] ([TransportExecutionPlanReferenceID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TransportExecutionPlanReferenceID_TransportationSegment]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TransportServiceCode_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([TransportServiceCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TransportServiceCode_TransportationService]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_TariffClassCode_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([TariffClassCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_TariffClassCode_TransportationService]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Priority_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([Priority])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Priority_TransportationService]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_FreightRateClassCode_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([FreightRateClassCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_FreightRateClassCode_TransportationService]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TransportationServiceDescription_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([TransportationServiceDescription])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TransportationServiceDescription_TransportationService]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_TransportationServiceDetailsURI_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([TransportationServiceDetailsURI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_TransportationServiceDetailsURI_TransportationService]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_NominationDate_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([NominationDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_NominationDate_TransportationService]
GO
ALTER TABLE [dbo].[Time] WITH CHECK ADD CONSTRAINT [FK_NominationTime_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([NominationTime])
GO
ALTER TABLE [dbo].[Time] CHECK CONSTRAINT [FK_NominationTime_TransportationService]
GO
ALTER TABLE [dbo].[Name] WITH CHECK ADD CONSTRAINT [FK_Name_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([Name])
GO
ALTER TABLE [dbo].[Name] CHECK CONSTRAINT [FK_Name_TransportationService]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_SequenceNumeric_TransportationService] FOREIGN KEY([Ref])
REFERENCES [dbo].[TransportationService] ([SequenceNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_SequenceNumeric_TransportationService]
GO
ALTER TABLE [dbo].[Amount] WITH CHECK ADD CONSTRAINT [FK_PriceAmount_UnstructuredPrice] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnstructuredPrice] ([PriceAmount])
GO
ALTER TABLE [dbo].[Amount] CHECK CONSTRAINT [FK_PriceAmount_UnstructuredPrice]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_TimeAmount_UnstructuredPrice] FOREIGN KEY([Ref])
REFERENCES [dbo].[UnstructuredPrice] ([TimeAmount])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_TimeAmount_UnstructuredPrice]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_UtilityItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_SubscriberID_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([SubscriberID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_SubscriberID_UtilityItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_SubscriberType_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([SubscriberType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_SubscriberType_UtilityItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_SubscriberTypeCode_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([SubscriberTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_SubscriberTypeCode_UtilityItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Description_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([Description])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Description_UtilityItem]
GO
ALTER TABLE [dbo].[Quantity] WITH CHECK ADD CONSTRAINT [FK_PackQuantity_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([PackQuantity])
GO
ALTER TABLE [dbo].[Quantity] CHECK CONSTRAINT [FK_PackQuantity_UtilityItem]
GO
ALTER TABLE [dbo].[Numeric] WITH CHECK ADD CONSTRAINT [FK_PackSizeNumeric_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([PackSizeNumeric])
GO
ALTER TABLE [dbo].[Numeric] CHECK CONSTRAINT [FK_PackSizeNumeric_UtilityItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_ConsumptionType_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([ConsumptionType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_ConsumptionType_UtilityItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_ConsumptionTypeCode_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([ConsumptionTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_ConsumptionTypeCode_UtilityItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_CurrentChargeType_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([CurrentChargeType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_CurrentChargeType_UtilityItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_CurrentChargeTypeCode_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([CurrentChargeTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_CurrentChargeTypeCode_UtilityItem]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_OneTimeChargeType_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([OneTimeChargeType])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_OneTimeChargeType_UtilityItem]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_OneTimeChargeTypeCode_UtilityItem] FOREIGN KEY([Ref])
REFERENCES [dbo].[UtilityItem] ([OneTimeChargeTypeCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_OneTimeChargeTypeCode_UtilityItem]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_URI_WebSiteAccess] FOREIGN KEY([Ref])
REFERENCES [dbo].[WebSiteAccess] ([URI])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_URI_WebSiteAccess]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Password_WebSiteAccess] FOREIGN KEY([Ref])
REFERENCES [dbo].[WebSiteAccess] ([Password])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Password_WebSiteAccess]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Login_WebSiteAccess] FOREIGN KEY([Ref])
REFERENCES [dbo].[WebSiteAccess] ([Login])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Login_WebSiteAccess]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_Rank_WinningParty] FOREIGN KEY([Ref])
REFERENCES [dbo].[WinningParty] ([Rank])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_Rank_WinningParty]
GO
ALTER TABLE [dbo].[Identifier] WITH CHECK ADD CONSTRAINT [FK_ID_WorkPhaseReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[WorkPhaseReference] ([ID])
GO
ALTER TABLE [dbo].[Identifier] CHECK CONSTRAINT [FK_ID_WorkPhaseReference]
GO
ALTER TABLE [dbo].[Code] WITH CHECK ADD CONSTRAINT [FK_WorkPhaseCode_WorkPhaseReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[WorkPhaseReference] ([WorkPhaseCode])
GO
ALTER TABLE [dbo].[Code] CHECK CONSTRAINT [FK_WorkPhaseCode_WorkPhaseReference]
GO
ALTER TABLE [dbo].[Text] WITH CHECK ADD CONSTRAINT [FK_WorkPhase_WorkPhaseReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[WorkPhaseReference] ([WorkPhase])
GO
ALTER TABLE [dbo].[Text] CHECK CONSTRAINT [FK_WorkPhase_WorkPhaseReference]
GO
ALTER TABLE [dbo].[Percent] WITH CHECK ADD CONSTRAINT [FK_ProgressPercent_WorkPhaseReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[WorkPhaseReference] ([ProgressPercent])
GO
ALTER TABLE [dbo].[Percent] CHECK CONSTRAINT [FK_ProgressPercent_WorkPhaseReference]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_StartDate_WorkPhaseReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[WorkPhaseReference] ([StartDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_StartDate_WorkPhaseReference]
GO
ALTER TABLE [dbo].[Date] WITH CHECK ADD CONSTRAINT [FK_EndDate_WorkPhaseReference] FOREIGN KEY([Ref])
REFERENCES [dbo].[WorkPhaseReference] ([EndDate])
GO
ALTER TABLE [dbo].[Date] CHECK CONSTRAINT [FK_EndDate_WorkPhaseReference]
GO